@@ -60,6 +60,7 @@ struct CreateImageOptions
 struct IODevice
 {
 	/* the basics */
+	const char *tag;
 	iodevice_t type;
 	int count;
 	const char *file_extensions;
@@ -74,6 +75,7 @@ struct IODevice
 	unsigned int must_be_loaded : 1;
 	unsigned int load_at_init : 1;
 	unsigned int error : 1;
+	unsigned int not_working : 1;
 
 	/* image handling callbacks */
 	device_init_handler init;
@@ -112,6 +114,10 @@ int device_typeid(const char *name);
 /* device allocation */
 struct IODevice *devices_allocate(const struct GameDriver *gamedrv);
 
+/* device lookup */
+const struct IODevice *device_find_tag(const struct IODevice *devices, const char *tag);
+int device_count_tag(const struct IODevice *devices, const char *tag);
+
 /* device lookup; both of these function assume only one of each type of device */
 const struct IODevice *device_find(const struct IODevice *devices, iodevice_t type);
 int device_count(iodevice_t type);
