@@ -1,3 +1,11 @@
+/*********************************************************************
+
+	mflopimg.c
+
+	MESS interface to the floppy disk image abstraction code
+
+*********************************************************************/
+
 #include "mflopimg.h"
 #include "utils.h"
 #include "image.h"
@@ -21,7 +29,7 @@ struct floppy_error_map
 	const char *message;
 };
 
-static struct floppy_error_map errmap[] =
+static const struct floppy_error_map errmap[] =
 {
 	{ FLOPPY_ERROR_SUCCESS,			IMAGE_ERROR_SUCCESS },
 	{ FLOPPY_ERROR_INTERNAL,		IMAGE_ERROR_INTERNAL },
@@ -38,6 +46,13 @@ static struct mess_flopimg *get_flopimg(mess_image *image)
 
 
 
+floppy_image *flopimg_get_image(mess_image *image)
+{
+	return get_flopimg(image)->floppy;
+}
+
+
+
 static void flopimg_seek_callback(mess_image *image, int physical_track)
 {
 	struct mess_flopimg *flopimg;
@@ -241,7 +256,7 @@ static int internal_floppy_device_load(mess_image *image, mame_file *file, int c
 	flopimg = get_flopimg(image);
 
 	/* figure out the floppy options */
-	dev = device_find(Machine->devices, IO_FLOPPY);
+	dev = image_device(image);
 	assert(dev);
 	floppy_options = dev->user1;
 
