@@ -62,7 +62,12 @@ CASSETTE_FORMATLIST_END
 
 static double map_double(double d, UINT64 low, UINT64 high, UINT64 value)
 {
+#if defined(_MSC_VER) && (_MSC_VER <= 1200)
+	/* casting unsigned __int64 to double is not supported on VC6 or before */
+	return d * (INT64)(value - low) / (INT64)(high - low);
+#else
 	return d * (value - low) / (high - low);
+#endif
 }
 
 
