@@ -1,4 +1,5 @@
 #include "driver.h"
+#include "sound/custom.h"
 
 /* use this for debugging */
 #if 0
@@ -31,7 +32,4 @@ extern VIDEO_START( arcadia );
 extern VIDEO_UPDATE( arcadia );
 
 extern struct CustomSound_interface arcadia_sound_interface;
-extern int arcadia_custom_start (const struct MachineSound *driver);
-extern void arcadia_custom_stop (void);
-extern void arcadia_custom_update (void);
 extern void arcadia_soundport_w (int mode, int data);
