@@ -1,3 +1,17 @@
+/*********************************************************************
+
+	mac.h
+	
+	MESS Macintosh driver declarations
+
+*********************************************************************/
+
+#ifndef MESS_MAC_H
+#define MESS_MAC_H
+
+#include "mame.h"
+#include "sound/custom.h"
+
 /* from machine/mac.c */
 MACHINE_INIT( mac );
 
@@ -17,8 +31,6 @@ READ16_HANDLER ( mac_scc_r );
 WRITE16_HANDLER ( mac_scc_w );
 READ16_HANDLER ( macplus_scsi_r );
 WRITE16_HANDLER ( macplus_scsi_w );
-DEVICE_LOAD(mac_floppy);
-DEVICE_UNLOAD(mac_floppy);
 NVRAM_HANDLER( mac );
 void mac_scc_mouse_irq( int x, int y );
 
@@ -30,12 +42,13 @@ PALETTE_INIT( mac );
 void mac_set_screen_buffer( int buffer );
 
 /* from sndhrdw/mac.c */
-int mac_sh_start( const struct MachineSound *msound );
-void mac_sh_stop( void );
-void mac_sh_update( void );
+void *mac_sh_start(int clock, const struct CustomSound_interface *config);
 
 void mac_enable_sound( int on );
 void mac_set_sound_buffer( int buffer );
 void mac_set_volume( int volume );
 
 void mac_sh_updatebuffer(void);
+
+#endif /* MESS_MAC_H */
+
