@@ -11,6 +11,8 @@
 #include <ctype.h>
 #include "driver.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/sid6581.h"
+#include "mscommon.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
@@ -20,8 +22,6 @@
 #include "includes/vc20tape.h"
 #include "includes/vic6567.h"
 #include "includes/vdc8563.h"
-#include "includes/sid6581.h"
-#include "mscommon.h"
 
 #include "includes/c128.h"
 
@@ -750,8 +750,6 @@ static void c128_common_driver_init (void)
 	c128 = 1;
 	vc20_tape_open (c64_tape_read);
 
-	cbm_drive_open ();
-
 	cia6526_init();
 
 	c64_cia0.todin50hz = c64_pal;
@@ -785,7 +783,6 @@ void c128pal_driver_init (void)
 
 void c128_driver_shutdown (void)
 {
-	cbm_drive_close ();
 	vc20_tape_close ();
 }
 
@@ -795,7 +792,7 @@ MACHINE_INIT( c128 )
 	c64_common_init_machine ();
 	c128_vicaddr = c64_vicaddr = c64_memory;
 
-	sid6581_reset(0);
+	sndti_reset(SOUND_SID6581, 0);
 
 	c64_rom_recognition ();
 	c64_rom_load();
