@@ -12,6 +12,7 @@
 #include "driver.h"
 #include "image.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/sid6581.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
@@ -20,7 +21,6 @@
 #include "includes/vc1541.h"
 #include "includes/vc20tape.h"
 #include "includes/ted7360.h"
-#include "includes/sid6581.h"
 
 #include "includes/c16.h"
 
@@ -509,8 +509,6 @@ static void c16_common_driver_init (void)
 
 	c16_tape_open ();
 
-	cbm_drive_open ();
-
 	if (REAL_C1551)
 		c1551_config (0, 0, &config);
 
@@ -530,7 +528,6 @@ void c16_driver_init (void)
 void c16_driver_shutdown (void)
 {
 	vc20_tape_close ();
-	cbm_drive_close ();
 }
 
 static WRITE8_HANDLER(c16_sidcart_16k)
@@ -563,14 +560,17 @@ MACHINE_INIT( c16 )
 	tpi6525_3_reset();
 	c364_speech_init();
 
-	sid6581_reset(0);
-	if (SIDCARD) {
-		sid6581_set_type(0, MOS8580);
+	sndti_reset(SOUND_SID8580, 0);
+
+	if (SIDCARD)
+	{
 		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0xfd40, 0xfd5f, 0, 0, sid6581_0_port_r);
 		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM,  0xfd40, 0xfd5f, 0, 0, sid6581_0_port_w);
 		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0xfe80, 0xfe9f, 0, 0, sid6581_0_port_r);
 		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM,  0xfe80, 0xfe9f, 0, 0, sid6581_0_port_w);
-	} else {
+	}
+	else
+	{
 		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0xfd40, 0xfd5f, 0, 0, MRA8_NOP);
 		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM,  0xfd40, 0xfd5f, 0, 0, MWA8_NOP);
 		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0xfe80, 0xfe9f, 0, 0, MRA8_NOP);
@@ -782,8 +782,6 @@ INTERRUPT_GEN( c16_frame_interrupt )
 {
 	int value;
 
-	sid6581_update();
-
 	value = 0xff;
 	if (KEY_ATSIGN)
 		value &= ~0x80;
