@@ -11,7 +11,7 @@
  * - Halnote
  *   writes to page 0?
  * - Playball
- *   Has sample ROM.
+ *   Unemulated D7756C, same as src/drivers/homerun.c
  * - Some ascii8 w/ sram need 32kb sram?
  * - MegaRAM
  * - fmsx painter.rom
@@ -21,6 +21,9 @@
 #include "includes/msx_slot.h"
 #include "includes/msx.h"
 #include "includes/wd179x.h"
+#include "sound/k051649.h"
+#include "sound/2413intf.h"
+#include "sound/dac.h"
 
 extern MSX msx1;
 
