@@ -66,6 +66,8 @@ TODO:
 #include "99_usbsm.h"
 
 #include "sound/tms5220.h"	/* for tms5220_set_variant() */
+#include "sound/5220intf.h"
+#include "sound/sn76496.h"
 
 #include "devices/harddriv.h"	/* for device_init_mess_hd() */
 #include "smc92x4.h"	/* for smc92x4_hd_load()/smc92x4_hd_unload() */
@@ -404,8 +406,6 @@ void init_ti99_4(void)
 
 	/* set up memory pointers */
 	xRAM_ptr = (UINT16 *) (memory_region(REGION_CPU1) + offset_xram);
-	cartridge_pages[0] = (UINT16 *) (memory_region(REGION_CPU1)+offset_cart);
-	cartridge_pages[1] = (UINT16 *) (memory_region(REGION_CPU1)+offset_cart + 0x2000);
 	console_GROMs.data_ptr = memory_region(region_grom);
 
 	/* Generate missing chunk of each console GROMs */
@@ -424,8 +424,6 @@ void init_ti99_4a(void)
 
 	/* set up memory pointers */
 	xRAM_ptr = (UINT16 *) (memory_region(REGION_CPU1) + offset_xram);
-	cartridge_pages[0] = (UINT16 *) (memory_region(REGION_CPU1)+offset_cart);
-	cartridge_pages[1] = (UINT16 *) (memory_region(REGION_CPU1)+offset_cart + 0x2000);
 	console_GROMs.data_ptr = memory_region(region_grom);
 }
 
@@ -469,6 +467,13 @@ void init_ti99_4p(void)
 	/*console_GROMs.data_ptr = memory_region(region_grom);*/
 }
 
+DEVICE_INIT( ti99_cart )
+{
+	int id = image_index_in_device(image);
+	cartridge_pages[id] = (UINT16 *) (memory_region(REGION_CPU1) + offset_cart + (id * 0x2000));
+	return INIT_PASS;
+}
+
 /*
 	Load ROM.  All files are in raw binary format.
 	1st ROM: GROM (up to 40kb)
@@ -783,7 +788,7 @@ void machine_init_ti99(void)
 			memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x9000, 0x93ff, 0, 0, ti99_rspeech_r);
 			memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x9400, 0x97ff, 0, 0, ti99_wspeech_w);
 
-			tms5220_set_variant(variant_tms0285);
+			sndti_set_info_int(SOUND_TMS5220, 0, SNDINFO_INT_TMS5220_VARIANT, variant_tms0285);
 		}
 	}
 	else
@@ -877,9 +882,6 @@ void machine_init_ti99(void)
 
 void machine_stop_ti99(void)
 {
-	if (has_speech)
-		tms5220_set_variant(variant_tms5220);
-
 	if (has_ide)
 		ti99_ide_save_memcard();
 
