@@ -28,51 +28,6 @@ UINT32 mess_ram_size;
 data8_t *mess_ram;
 data8_t mess_ram_default_value = 0xCD;
 
-struct distributed_images
-{
-	const char *names[IO_COUNT][MAX_DEV_INSTANCES];
-	int count[IO_COUNT];
-};
-
-
-
-/*****************************************************************************
- *  --Distribute images to their respective Devices--
- *  Copy the Images specified at the CLI from options.image_files[] to the
- *  array of filenames we keep here, depending on the Device type identifier
- *  of each image.  Multiple instances of the same device are allowed
- *  RETURNS 0 on success, 1 if failed
- ****************************************************************************/
-
-static int distribute_images(struct distributed_images *images)
-{
-	int i;
-
-	logerror("Distributing Images to Devices...\n");
-	/* Set names to NULL */
-
-	for( i = 0; i < options.image_count; i++ )
-	{
-		int type = options.image_files[i].type;
-
-		assert(type < IO_COUNT);
-
-		/* Do we have too many devices? */
-		if (images->count[type] >= MAX_DEV_INSTANCES)
-		{
-			printf(" Too many devices of type %d\n", type);
-			return 1;
-		}
-
-		/* Add a filename to the arrays of names */
-		images->names[type][images->count[type]] = options.image_files[i].name;
-		images->count[type]++;
-	}
-
-	/* everything was fine */
-	return 0;
-}
-
 
 
 static int ram_init(const struct GameDriver *gamedrv)
@@ -138,8 +93,7 @@ static int ram_init(const struct GameDriver *gamedrv)
 
 int devices_init(const struct GameDriver *gamedrv)
 {
-	const struct IODevice *dev;
-	int i, id;
+	int i;
 
 	/* convienient place to call this */
 	{
@@ -165,7 +119,7 @@ int devices_init(const struct GameDriver *gamedrv)
 	/* Check that the driver supports all devices requested (options struct)*/
 	for( i = 0; i < options.image_count; i++ )
 	{
-		if (!device_find(Machine->devices	, options.image_files[i].type))
+		if (!device_find(Machine->devices, options.image_files[i].type))
 		{
 			printf(" ERROR: Device [%s] is not supported by this system\n",device_typename(options.image_files[i].type));
 			return 1;
@@ -177,19 +131,8 @@ int devices_init(const struct GameDriver *gamedrv)
 		return 1;
 
 	/* init all devices */
-	for (i = 0; Machine->devices[i].type < IO_COUNT; i++)
-	{
-		dev = &Machine->devices[i];
-
-		/* all instances */
-		for (id = 0; id < dev->count; id++)
-		{
-			mess_image *img = image_from_device_and_index(dev, id);
-			image_init(img);
-		}
-	}
+	image_init();
 	devices_inited = TRUE;
-
 	return 0;
 }
 
@@ -199,57 +142,97 @@ int devices_initialload(const struct GameDriver *gamedrv, int ispreload)
 {
 	int i;
 	int id;
-	int result;
-	int count;
-	struct distributed_images images;
+	int result = INIT_FAIL;
+	int devcount;
+	int *allocated_slots;
 	const struct IODevice *dev;
-	const char *imagename;
-	mess_image *img;
+	const char *image_name;
+	mess_image *image;
+	iodevice_t devtype;
 
 	/* normalize ispreload */
 	ispreload = ispreload ? 1 : 0;
 
+	/* wrong time to preload? */
+	if (ispreload != devices_inited)
+		return 0;
+
+	/* count number of devices, and record a list of allocated slots */
+	devcount = 0;
+	for (dev = Machine->devices; dev->type < IO_COUNT; dev++)
+		devcount++;
+	allocated_slots = malloc(devcount * sizeof(*allocated_slots));
+	if (!allocated_slots)
+		goto error;
+	memset(allocated_slots, 0, devcount * sizeof(*allocated_slots));
+
 	/* distribute images to appropriate devices */
-	memset(&images, 0, sizeof(images));
-	if (distribute_images(&images))
-		return 1;
-
-	/* load all devices with matching preload */
-	for (i = 0; Machine->devices[i].type < IO_COUNT; i++)
+	for (i = 0; i < options.image_count; i++)
 	{
-		dev = &Machine->devices[i];
-		count = images.count[dev->type];
+		/* get the image type and filename */
+		image_name = options.image_files[i].name;
+		image_name = (image_name && image_name[0]) ? image_name : NULL;
+		devtype = options.image_files[i].type;
+		assert(devtype >= 0);
+		assert(devtype < IO_COUNT);
 
-		if (dev->must_be_loaded && (count != dev->count))
-		{
-			printf("Driver requires that device %s must have an image to load\n", device_typename(dev->type));
-			return 1;
-		}
+		image = NULL;
 
-		/* all instances */
-		for (id = 0; id < count; id++)
+		for (dev = Machine->devices; dev->type < IO_COUNT; dev++)
 		{
-			if (dev->load_at_init == ispreload)
+			if (dev->type == devtype)
 			{
-				imagename = images.names[dev->type][id];
-				if (imagename)
+				id = allocated_slots[dev - Machine->devices];
+				if (id < dev->count)
 				{
-					img = image_from_devtype_and_index(dev->type, id);
-
-					/* load this image */
-					result = image_load(img, images.names[dev->type][id]);
-
-					if (result != INIT_PASS)
+					result = INIT_PASS;
+					if (image_name)
 					{
-						printf("Driver reports load for %s device failed\n", device_typename(dev->type));
-						printf("Ensure image is valid and exists and (if needed) can be created\n");
-						return 1;
+						/* try to load this image */
+						image = image_from_device_and_index(dev, id);
+						result = image_load(image, image_name);
+					}
+					if (result == INIT_PASS)
+					{
+						allocated_slots[dev - Machine->devices]++;
+						break;
 					}
 				}
 			}
 		}
+		if (dev->type >= IO_COUNT)
+		{
+			if (image)
+			{
+				printf("Device %s load (%s) failed: %s\n",
+					device_typename(devtype),
+					osd_basename((char *) image_name),
+					image_error(image));
+			}
+			else
+			{
+				printf("Too many devices of type %d\n", devtype);
+			}
+			goto error;
+		}
 	}
+
+	/* make sure that any required devices have been allocated */
+	for (dev = Machine->devices; dev->type < IO_COUNT; dev++)
+	{
+		if (dev->must_be_loaded && (allocated_slots[dev - Machine->devices] != dev->count))
+		{
+			printf("Driver requires that device %s must have an image to load\n", device_typename(dev->type));
+			goto error;
+		}
+	}
+	free(allocated_slots);
 	return 0;
+
+error:
+	if (allocated_slots)
+		free(allocated_slots);
+	return 1;
 }
 
 
@@ -260,27 +243,12 @@ int devices_initialload(const struct GameDriver *gamedrv, int ispreload)
  */
 void devices_exit(void)
 {
-	const struct IODevice *dev;
-	int i, id;
-	mess_image *img;
-
 	/* unload all devices */
 	image_unload_all(FALSE);
 	image_unload_all(TRUE);
 
 	/* exit all devices */
-	for (i = 0; Machine->devices[i].type < IO_COUNT; i++)
-	{
-		dev = &Machine->devices[i];
-
-		/* all instances */
-		for( id = 0; id < dev->count; id++ )
-		{
-			img = image_from_devtype_and_index(dev->type, id);
-			image_exit(img);
-		}
-	}
-
+	image_exit();
 	devices_inited = FALSE;
 }
 
@@ -476,9 +444,22 @@ void write32_with_write8_handler(write8_handler handler, offs_t offset, data32_t
 
 ***************************************************************************/
 
- READ8_HANDLER( return8_00 )	{ return 0x00; }
- READ8_HANDLER( return8_FE )	{ return 0xFE; }
- READ8_HANDLER( return8_FF )	{ return 0xFF; }
+READ8_HANDLER( return8_00 )	{ return 0x00; }
+READ8_HANDLER( return8_FE )	{ return 0xFE; }
+READ8_HANDLER( return8_FF )	{ return 0xFF; }
+
+
+
+/***************************************************************************
+
+	Dummy read handlers
+
+***************************************************************************/
+
+void mess_config_save_xml(int type, mame_file *file)
+{
+	osd_config_save_xml(type, file);
+}
 
 
 
@@ -495,7 +476,6 @@ int mess_validitychecks(void)
 	int error = 0;
 	struct IODevice *devices;
 	const struct IODevice *dev;
-	long used_devices;
 	const char *s1;
 	const char *s2;
 	extern int device_valididtychecks(void);
@@ -543,7 +523,6 @@ int mess_validitychecks(void)
 		}
 
 		/* check device array */
-		used_devices = 0;
 		for (j = 0; devices[j].type < IO_COUNT; j++)
 		{
 			dev = &devices[j];
@@ -554,14 +533,6 @@ int mess_validitychecks(void)
 				error = 1;
 			}
 
-			/* make sure that we can't duplicate devices */
-			if (used_devices & (1 << dev->type))
-			{
-				printf("%s: device type '%s' is specified multiple times\n", drivers[i]->name, device_typename(dev->type));
-				error = 1;
-			}
-			used_devices |= (1 << dev->type);
-
 			/* File Extensions Checks
 			 * 
 			 * Checks the following
@@ -660,72 +631,3 @@ int mess_validitychecks(void)
 #endif /* WIN32 */
 	return error;
 }
-
-enum
-{
-	TESTERROR_SUCCESS			= 0,
-
-	/* benign errors */
-	TESTERROR_NOROMS			= 1,
-
-	/* failures */
-	TESTERROR_INITDEVICESFAILED	= -1
-};
-
-#if 0
-static int try_driver(const struct GameDriver *gamedrv)
-{
-	int i;
-	int error;
-	void *mem[128];
-
-	Machine->gamedrv = gamedrv;
-	Machine->drv = gamedrv->drv;
-	memset(&Machine->memory_region, 0, sizeof(Machine->memory_region));
-	if (readroms() != 0)
-	{
-		error = TESTERROR_NOROMS;
-	}
-	else
-	{
-		if (device_init(gamedrv) != 0)
-			error = TESTERROR_INITDEVICESFAILED;
-		else
-			devices_exit();
-		for (i = 0;i < MAX_MEMORY_REGIONS;i++)
-			free_memory_region(i);
-	}
-
-	/* hammer away on malloc, to detect any memory errors */
-	for (i = 0; i < sizeof(mem) / sizeof(mem[0]); i++)
-		mem[i] = malloc((i * 131 % 51) + 64);
-	for (i = 0; i < sizeof(mem) / sizeof(mem[0]); i++)
-		free(mem[i]);
-
-	return 0;
-}
-#endif
-
-void messtestdriver(const struct GameDriver *gamedrv, const char *(*getfodderimage)(unsigned int index, int *foddertype))
-{
-	struct GameOptions saved_options;
-
-	/* preserve old options; the MESS GUI needs this */
-	memcpy(&saved_options, &options, sizeof(saved_options));
-
-	/* clear out images in options */
-	memset(&options.image_files, 0, sizeof(options.image_files));
-	options.image_count = 0;
-
-	/* try running with no attached devices */
-#if 0
-	error = try_driver(gamedrv);
-	if (gamedrv->flags & GAME_COMPUTER)
-		assert(error >= 0);	/* computers should succeed when ran with no attached devices */
-	else
-		assert(error <= 0);	/* consoles can fail; but should never fail due to a no roms error */
-#endif
-
-	/* restore old options */
-	memcpy(&options, &saved_options, sizeof(options));
-}
