@@ -258,10 +258,19 @@ TESTDRIVER( nc200 )		/* 19?? NC200										*/
 	DRIVER( apple2p )	/* 1979 Apple ][+ 									*/
 	DRIVER( apple2c )	/* 1984 Apple //c									*/
 	DRIVER( apple2c0 )	/* 1986 Apple //c (3.5 ROM) 						*/
+	DRIVER( apple2c3 )	/* 1986 Apple //c (Original Mem. Exp.)				*/
 	DRIVER( apple2cp )	/* 1988 Apple //c+									*/
 	DRIVER( apple2e )	/* 1983 Apple //e									*/
 	DRIVER( apple2ee )	/* 1985 Apple //e Enhanced							*/
 	DRIVER( apple2ep )	/* 1987 Apple //e Platinum							*/
+	DRIVER( apple2g1 )	/* 1987 Apple IIgs ROM01							*/
+	DRIVER( apple2gs )	/* 1989 Apple IIgs ROM03							*/
+	DRIVER( ace100 )    /* 1982 Apple ][ clone								*/
+	DRIVER( laser128 )  /* 1987 Apple //c clone								*/
+	DRIVER( las128ex )  /* 1987 Apple //c clone								*/
+	DRIVER( las3000 )   /* 1983 (semi) Apple ][+ clone						*/
+	DRIVER( apple3 )    /* 1980 Apple ///     								*/
+
 /*
  * Lisa 				 January			 1983
  * Lisa 2 				 January			 1984
@@ -447,6 +456,18 @@ TESTDRIVER( tree4th )		/* Sinclair ZX-81 Tree-Forth by Tree Systems			*/
 	DRIVER( specpl3e )	/* 2000 ZX Spectrum +3e 					*/
 	DRIVER( specp3es )	/* 2000 ZX Spectrum +3e (Spain)					*/
 
+	DRIVER( ql )		/* Sinclair QL							*/
+	DRIVER( ql_jm )
+	DRIVER( ql_tb )
+	DRIVER( ql_js )
+	DRIVER( ql_jsu )
+	DRIVER( ql_mge )
+	DRIVER( ql_mgf )
+	DRIVER( ql_mgg )
+	DRIVER( ql_mgi )
+	DRIVER( ql_mgs )
+	DRIVER( ql_efp )
+
 	/* SHARP */
 	DRIVER( pc1251 )	/* Pocket Computer 1251 							*/
 TESTDRIVER( trs80pc3 )	/* Tandy TRS80 PC-3									*/
@@ -730,6 +751,12 @@ TESTDRIVER( mekd2 )		/* 1977 Motorola Evaluation Kit						*/
 	DRIVER( mato )		/* Mato (Basic ROM) (PMD-85.2 clone)								*/
 	DRIVER( matoh )		/* Mato (Games ROM) (PMD-85.2 clone)								*/
 
+	/* Microkey */
+	DRIVER( primoa32 )	/* Primo A-32											*/
+TESTDRIVER( primoa48 )		/* Primo A-48											*/
+	DRIVER( primoa64 )	/* Primo A-64											*/
+	DRIVER( primob64 )	/* Primo B-64											*/
+
 	/* Team Concepts */
 	/* CPU not known, else should be easy, look into systems/comquest.c */
 TESTDRIVER( comquest )	/* Comquest Plus German								*/
@@ -781,6 +808,17 @@ TESTDRIVER( hp48g ) 	/* HP48 G/GX										*/
 	DRIVER( tx0_64kw )	/* April 1956 MIT TX-0 (64kw RAM)                   */
 	DRIVER( tx0_8kw )	/* 1962 MIT TX-0 (8kw RAM)                          */
 
+	/* Luxor Datorer AB */
+	DRIVER( abc80 )
+	DRIVER( abc802 )
+	DRIVER( abc800m )
+	DRIVER( abc800c )
+	DRIVER( abc806 )
+
+	/* SGI */
+	DRIVER( ip204415 )	/* IP20 IRIS Indigo workstation                     */
+	DRIVER( ip225015 )	/* IP22 Indy workstation                            */
+
 /****************Games*******************************************************/
 	/* Computer Electronic */
 TESTDRIVER( mk1 )		/* Chess Champion MK I								*/
