@@ -39,6 +39,7 @@ Some bugs left :
 #include "devices/printer.h"
 #include "devices/cassette.h"
 #include "inputx.h"
+#include "sound/ay8910.h"
 
 #ifdef AMSTRAD_VIDEO_EVENT_LIST
 /* for event list */
@@ -1341,12 +1342,8 @@ ADDRESS_MAP_END
 /* I've handled the I/O ports in this way, because the ports
 are not fully decoded by the CPC h/w. Doing it this way means
 I can decode it myself and a lot of  software should work */
-static ADDRESS_MAP_START(readport_amstrad, ADDRESS_SPACE_IO, 8)
-	AM_RANGE(0x0000, 0xffff) AM_READ(AmstradCPC_ReadPortHandler)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START(writeport_amstrad, ADDRESS_SPACE_IO, 8)
-	AM_RANGE(0x0000, 0xffff) AM_WRITE(AmstradCPC_WritePortHandler)
+static ADDRESS_MAP_START(amstrad_io, ADDRESS_SPACE_IO, 8)
+	AM_RANGE(0x0000, 0xffff) AM_READWRITE(AmstradCPC_ReadPortHandler, AmstradCPC_WritePortHandler)
 ADDRESS_MAP_END
 
 /* Additional notes for the AY-3-8912 in the CPC design
@@ -1555,25 +1552,13 @@ INPUT_PORTS_END
    --------------------*/
 static struct AY8910interface ay8912_interface =
 {
-	1,		                       /* total number of 8910 in the machine */
-	1000000,                     /* base clock : 1.0 MHz */
-	{ 25 },                      /* mixing_level */
-	{amstrad_psg_porta_read},    /* portA read */
-	{amstrad_psg_porta_read},    /* portB read */
-	{ NULL },                    /* portA write */
-	{ NULL }                     /* portB write */
-                               /* IRQ handler for the YM2203 ??? */
+	amstrad_psg_porta_read,	/* portA read */
+	amstrad_psg_porta_read,	/* portB read */
+	NULL,					/* portA write */
+	NULL					/* portB write */
 };
 
 
-/* ------------------
-   - Wave_interface -
-   ------------------*/
-
-static struct Wave_interface wave_interface = {
-	1,		/* 1 cassette recorder */
-	{ 50 }	/* mixing levels in percent */
-};
 
 /* actual clock to CPU is 4Mhz, but it is slowed by memory
 accessess. A HALT is used for every memory access by the CPU.
@@ -1596,9 +1581,8 @@ speed of 3.8Mhz */
 static MACHINE_DRIVER_START( amstrad )
 	/* Machine hardware */
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(readmem_amstrad,writemem_amstrad)
-	MDRV_CPU_IO_MAP(readport_amstrad,writeport_amstrad)
+	MDRV_CPU_IO_MAP(amstrad_io, 0)
 
 	MDRV_FRAMES_PER_SECOND(AMSTRAD_FPS)
 	MDRV_INTERLEAVE(1)
@@ -1620,8 +1604,12 @@ static MACHINE_DRIVER_START( amstrad )
 	MDRV_VIDEO_EOF( amstrad )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8912_interface)
-	MDRV_SOUND_ADD(WAVE, wave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MDRV_SOUND_ADD(AY8910, 1000000)
+	MDRV_SOUND_CONFIG(ay8912_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)	
 MACHINE_DRIVER_END
 
 
@@ -1664,7 +1652,7 @@ static void cpc6128_floppy_getinfo(struct IODevice *dev)
 static void cpc6128_cassette_getinfo(struct IODevice *dev)
 {
 	/* cassette */
-	cassette_device_getinfo(dev, NULL, NULL, (cassette_state) -1);
+	cassette_device_getinfo(dev, NULL, NULL, CASSETTE_STOPPED | CASSETTE_SPEAKER_ENABLED);
 	dev->count = 1;
 }
 
