@@ -56,6 +56,7 @@ ADDRESS_MAP_START( astrocade_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 ADDRESS_MAP_START( astrocade_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x08, 0x08) AM_MIRROR(0xff00) AM_READ(astrocade_intercept_r)
 	AM_RANGE(0x0e, 0x0e) AM_MIRROR(0xff00) AM_READ(astrocade_video_retrace_r)
 	/*AM_RANGE(0x0f, 0x0f) AM_MIRROR(0xff00) AM_READ(astrocade_horiz_r)*/
@@ -74,6 +75,7 @@ ADDRESS_MAP_START( astrocade_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 ADDRESS_MAP_START( astrocade_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x00, 0x07) AM_MIRROR(0xff00) AM_WRITE(astrocade_colour_register_w)
 	AM_RANGE(0x08, 0x08) AM_MIRROR(0xff00) AM_WRITE(astrocade_mode_w)
 	AM_RANGE(0x09, 0x09) AM_MIRROR(0xff00) AM_WRITE(astrocade_colour_split_w)
@@ -171,18 +173,11 @@ INPUT_PORTS_START( astrocde )
 
 INPUT_PORTS_END
 
-static struct astrocade_interface astrocade_1chip_interface =
-{
-	1,			/* Number of chips */
-	1789773,	/* Clock speed */
-	{255}		/* Volume */
-};
 
 
 static MACHINE_DRIVER_START( astrocde )
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 1789000)        /* 1.789 Mhz */
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(astrocade_readmem,astrocade_writemem)
 	MDRV_CPU_IO_MAP(astrocade_readport,astrocade_writeport)
 	MDRV_CPU_VBLANK_INT(astrocade_interrupt,256)
@@ -202,7 +197,9 @@ static MACHINE_DRIVER_START( astrocde )
 	MDRV_VIDEO_UPDATE( generic_bitmapped )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(ASTROCADE, astrocade_1chip_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(ASTROCADE, 1789773)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 
