@@ -522,9 +522,15 @@ ROM_START(bbcb)
 
 	ROM_LOAD("os12.rom", 0x40000,0x4000, CRC(3c14fc70) SHA1(0d9bcaf6a393c9ce2359ed700ddb53c232c2c45d))
 
+	/* usos12.rom is the USA version of the OS. acorn tried to release the BBC B in the USA calling it the */
+	/* "Acorn Proton", it failed to sell in the USA and was withdrawn from the market. */
+	/* the main difference is the screen resolution setting the display to work on American TV's */
+	/*ROM_LOAD("usos12.rom", 0x40000,0x4000, CRC(c8e946a9) ) */
+
+
 	ROM_LOAD("basic2.rom",  0x00000, 0x4000, CRC(79434781) SHA1(4a7393f3a45ea309f744441c16723e2ef447a281)) /* rom page 15 3c000 */
 	/*ROM_LOAD("speech-1.0.rom",  0x08000, 0x2000, CRC(e63f7fb7) ) */
-	ROM_RELOAD(                 0x0a000, 0x2000                )
+	/*ROM_RELOAD(                 0x0a000, 0x2000                ) */
 	/*ROM_LOAD("dfs144.rom",  0x04000, 0x4000, CRC(9fb8d13f) SHA1(387d2468c6e1360f5b531784ce95d5f71a50c2b5))    rom page 14 38000    */
 	                                                      /* rom page 0  00000 */
 	                                                      /* rom page 1  04000 */
@@ -653,14 +659,6 @@ static INTERRUPT_GEN( bbcb_vsync )
 }
 
 
-static struct SN76496interface sn76496_interface =
-{
-	1,		/* 1 chip */
-	{ 4000000 },	/* 4Mhz */
-	{ 100 }
-};
-
-
 /*static struct TMS5220interface tms5220_interface = */
 /*{ */
 /*	680000L, */
@@ -693,7 +691,9 @@ static MACHINE_DRIVER_START( bbca )
 	MDRV_VIDEO_UPDATE(bbc)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SN76496, 4000000)	/* 4 MHz */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 /*	MDRV_SOUND_ADD(TMS5220, tms5220_interface) */
 MACHINE_DRIVER_END
 
@@ -750,7 +750,9 @@ static MACHINE_DRIVER_START( bbcm )
 	MDRV_VIDEO_UPDATE(bbc)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SN76496, 4000000)	/* 4 MHz */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 
 	MDRV_NVRAM_HANDLER( mc146818 )
 MACHINE_DRIVER_END
