@@ -294,13 +294,13 @@ U102 23256 (read compatible 27256?) 32kB 1571 system rom
 */
 
 #include "driver.h"
+#include "sound/sid6581.h"
 
 #define VERBOSE_DBG 0
 #include "includes/cbm.h"
 #include "includes/cia6526.h"
 #include "includes/vic6567.h"
 #include "includes/vdc8563.h"
-#include "includes/sid6581.h"
 #include "includes/cbmserb.h"
 #include "includes/vc1541.h"
 #include "includes/vc20tape.h"
@@ -379,6 +379,7 @@ static ADDRESS_MAP_START( c128_z80_writemem , ADDRESS_SPACE_PROGRAM, 8)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( c128_z80_readio , ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x1000, 0x13ff) AM_READ( c64_colorram_read)
 	AM_RANGE(0xd000, 0xd3ff) AM_READ( vic2_port_r)
 	AM_RANGE(0xd400, 0xd4ff) AM_READ( sid6581_0_port_r)
@@ -390,6 +391,7 @@ static ADDRESS_MAP_START( c128_z80_readio , ADDRESS_SPACE_IO, 8)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( c128_z80_writeio , ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x1000, 0x13ff) AM_WRITE( c64_colorram_write)
 	AM_RANGE(0xd000, 0xd3ff) AM_WRITE( vic2_port_w)
 	AM_RANGE(0xd400, 0xd4ff) AM_WRITE( sid6581_0_port_w)
@@ -1250,47 +1252,16 @@ ROM_START (c128nor)
 	ROM_REGION (0x100, REGION_GFX1, 0)
 ROM_END
 
-static SID6581_interface pal_sound_interface =
+static SID6581_interface sound_interface =
 {
-	{
-		sid6581_custom_start,
-		sid6581_custom_stop,
-		sid6581_custom_update
-	},
-	1,
-	{
-		{
-			MIXER(50, MIXER_PAN_CENTER),
-			MOS6581,
-			VIC6569_CLOCK,
-			c64_paddle_read
-		}
-	}
+	c64_paddle_read
 };
 
-static SID6581_interface ntsc_sound_interface =
-{
-	{
-		sid6581_custom_start,
-		sid6581_custom_stop,
-		sid6581_custom_update
-	},
-	1,
-	{
-		{
-			MIXER(50, MIXER_PAN_CENTER),
-			MOS6581,
-			VIC6567_CLOCK,
-			c64_paddle_read
-		}
-	}
-};
 
 
 static MACHINE_DRIVER_START( c128 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, VIC6567_CLOCK)
-	MDRV_CPU_FLAGS( CPU_16BIT_PORT )
 	MDRV_CPU_PROGRAM_MAP( c128_z80_readmem, c128_z80_writemem )
 	MDRV_CPU_IO_MAP( c128_z80_readio, c128_z80_writeio )
 	MDRV_CPU_VBLANK_INT(c64_frame_interrupt, 1)
@@ -1321,8 +1292,12 @@ static MACHINE_DRIVER_START( c128 )
 	MDRV_VIDEO_UPDATE( c128 )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("custom",	CUSTOM, ntsc_sound_interface)
-	MDRV_SOUND_ADD_TAG("dac",		DAC, vc20tape_sound_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD_TAG("sid6581", SID6581, VIC6567_CLOCK)
+	MDRV_SOUND_CONFIG(sound_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MDRV_SOUND_ADD_TAG("dac", DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -1335,12 +1310,12 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( c128pal )
 	MDRV_IMPORT_FROM( c128 )
 	MDRV_CPU_REPLACE( "main", Z80, VIC6569_CLOCK )
-	MDRV_CPU_FLAGS( CPU_16BIT_PORT )
 	MDRV_CPU_REPLACE( "m8502", M8502, VIC6569_CLOCK )
 	MDRV_FRAMES_PER_SECOND(VIC6569_VRETRACERATE)
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("custom", CUSTOM, pal_sound_interface)
+	MDRV_SOUND_REPLACE("sid6581", SID6581, VIC6569_CLOCK)
+	MDRV_SOUND_CONFIG(sound_interface)
 MACHINE_DRIVER_END
 
 #define init_c128 c128_driver_init
