@@ -154,6 +154,7 @@ when problems start with -log and look into error.log file
 
 
 #include "driver.h"
+#include "sound/sid6581.h"
 
 #define VERBOSE_DBG 0
 #include "includes/cbm.h"
@@ -162,7 +163,6 @@ when problems start with -log and look into error.log file
 #include "includes/vc1541.h"
 #include "includes/vc20tape.h"
 #include "includes/ted7360.h"
-#include "includes/sid6581.h"
 #include "devices/cartslot.h"
 #include "inputx.h"
 
@@ -709,41 +709,6 @@ ROM_START (c364)
 	 ROM_LOAD ("spk3cc4.bin", 0x28000, 0x4000, CRC(5227c2ee) SHA1(59af401cbb2194f689898271c6e8aafa28a7af11))
 ROM_END
 
-static SID6581_interface sidc16_sound_interface =
-{
-	{
-		sid6581_custom_start,
-		sid6581_custom_stop,
-		sid6581_custom_update
-	},
-	1,
-	{
-		{
-			MIXER(50, MIXER_PAN_CENTER),
-			MOS8580,
-			TED7360PAL_CLOCK/4,
-			NULL
-		}
-	}
-};
-
-static SID6581_interface sidplus4_sound_interface =
-{
-	{
-		sid6581_custom_start,
-		sid6581_custom_stop,
-		sid6581_custom_update
-	},
-	1,
-	{
-		{
-			MIXER(50, MIXER_PAN_CENTER),
-			MOS8580,
-			TED7360NTSC_CLOCK/4,
-			NULL
-		}
-	}
-};
 
 
 static MACHINE_DRIVER_START( c16 )
@@ -770,9 +735,12 @@ static MACHINE_DRIVER_START( c16 )
 	MDRV_VIDEO_UPDATE( ted7360 )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("ted7360", CUSTOM, ted7360_sound_interface)
-	MDRV_SOUND_ADD_TAG("sid", CUSTOM, sidc16_sound_interface)
-	MDRV_SOUND_ADD_TAG("dac", DAC, vc20tape_sound_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD_TAG("ted7360", CUSTOM, 0)
+	MDRV_SOUND_CONFIG(ted7360_sound_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD_TAG("sid", SID8580, TED7360PAL_CLOCK/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -803,7 +771,8 @@ static MACHINE_DRIVER_START( plus4 )
 	MDRV_CPU_REPLACE( "main", M7501, 1200000)
 	MDRV_CPU_PROGRAM_MAP( plus4_readmem, plus4_writemem )
 	MDRV_FRAMES_PER_SECOND(TED7360NTSC_VRETRACERATE)
-	MDRV_SOUND_REPLACE("sid", CUSTOM, sidplus4_sound_interface)
+
+	MDRV_SOUND_REPLACE("sid", SID8580, TED7360NTSC_CLOCK/4)
 MACHINE_DRIVER_END
 
 
