@@ -190,12 +190,12 @@ when problems start with -log and look into error.log file
 
 #include "driver.h"
 #include "inputx.h"
+#include "sound/sid6581.h"
 
 #define VERBOSE_DBG 0
 #include "includes/cbm.h"
 #include "includes/cia6526.h"
 #include "includes/vic6567.h"
-#include "includes/sid6581.h"
 #include "includes/cbmserb.h"
 #include "includes/vc1541.h"
 #include "includes/vc20tape.h"
@@ -756,58 +756,9 @@ ROM_END
 	 ROM_LOAD( "rom80.e0",    0x12000, 0x2000, CRC(e801dadc ))
 #endif
 
-static SID6581_interface ultimax_sound_interface =
+static SID6581_interface sound_interface =
 {
-	{
-		sid6581_custom_start,
-		sid6581_custom_stop,
-		sid6581_custom_update
-	},
-	1,
-	{
-		{
-			MIXER(50, MIXER_PAN_CENTER),
-			MOS6581,
-			1000000,
-			c64_paddle_read
-		}
-	}
-};
-
-static SID6581_interface pal_sound_interface =
-{
-	{
-		sid6581_custom_start,
-		sid6581_custom_stop,
-		sid6581_custom_update
-	},
-	1,
-	{
-		{
-			MIXER(50, MIXER_PAN_CENTER),
-			MOS6581,
-			VIC6569_CLOCK,
-			c64_paddle_read
-		}
-	}
-};
-
-static SID6581_interface ntsc_sound_interface =
-{
-	{
-		sid6581_custom_start,
-		sid6581_custom_stop,
-		sid6581_custom_update
-	},
-	1,
-	{
-		{
-			MIXER(50, MIXER_PAN_CENTER),
-			MOS6581,
-			VIC6567_CLOCK,
-			c64_paddle_read
-		}
-	}
+	c64_paddle_read
 };
 
 static MACHINE_DRIVER_START( c64 )
@@ -826,8 +777,13 @@ static MACHINE_DRIVER_START( c64 )
 	MDRV_IMPORT_FROM( vh_vic2 )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("custom", CUSTOM, ntsc_sound_interface)
-	MDRV_SOUND_ADD_TAG("dac", DAC, vc20tape_sound_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD_TAG("sid", SID6581, VIC6567_CLOCK)
+	MDRV_SOUND_CONFIG(sound_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
+
+	MDRV_SOUND_ADD_TAG("dac", DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -835,7 +791,10 @@ static MACHINE_DRIVER_START( ultimax )
 	MDRV_IMPORT_FROM( c64 )
 	MDRV_CPU_REPLACE( "main", M6510, 1000000)
 	MDRV_CPU_PROGRAM_MAP( ultimax_readmem, ultimax_writemem )
-	MDRV_SOUND_REPLACE( "custom", CUSTOM, ultimax_sound_interface)
+
+	MDRV_SOUND_REPLACE("sid", SID6581, 1000000)
+	MDRV_SOUND_CONFIG(sound_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 
@@ -849,7 +808,10 @@ static MACHINE_DRIVER_START( c64pal )
 	MDRV_IMPORT_FROM( c64 )
 	MDRV_CPU_REPLACE( "main", M6510, VIC6569_CLOCK)
 	MDRV_FRAMES_PER_SECOND(VIC6569_VRETRACERATE)
-	MDRV_SOUND_REPLACE( "custom", CUSTOM, pal_sound_interface)
+
+	MDRV_SOUND_REPLACE("sid", SID6581, VIC6569_CLOCK)
+	MDRV_SOUND_CONFIG(sound_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 
