@@ -160,6 +160,7 @@ when problems start with -log and look into error.log file
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6502/m6509.h"
+#include "sound/sid6581.h"
 
 #define VERBOSE_DBG 0
 #include "includes/cbm.h"
@@ -167,7 +168,6 @@ when problems start with -log and look into error.log file
 #include "includes/tpi6525.h"
 #include "includes/vic6567.h"
 #include "includes/crtc6845.h"
-#include "includes/sid6581.h"
 #include "includes/cbmserb.h"
 #include "includes/vc1541.h"
 #include "includes/vc20tape.h"
@@ -863,24 +863,6 @@ ROM_END
 
 #endif
 
-static SID6581_interface sid_sound_interface =
-{
-	{
-		sid6581_custom_start,
-		sid6581_custom_stop,
-		sid6581_custom_update
-	},
-	1,
-	{
-		{
-			MIXER(50, MIXER_PAN_CENTER),
-			MOS6581,
-			1000000,
-			NULL
-		}
-	}
-};
-
 
 static MACHINE_DRIVER_START( cbm600 )
 	/* basic machine hardware */
@@ -909,7 +891,9 @@ static MACHINE_DRIVER_START( cbm600 )
 	MDRV_VIDEO_UPDATE( cbmb )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(CUSTOM, sid_sound_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SID6581, 1000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 
@@ -943,7 +927,9 @@ static MACHINE_DRIVER_START( cbm500 )
 	MDRV_IMPORT_FROM( vh_vic2 )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("custom", CUSTOM, sid_sound_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SID6581, 1000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 #define init_cbm500 cbm500_driver_init
