@@ -31,6 +31,8 @@ Changes:
 #include "includes/coupe.h"
 #include "includes/wd179x.h"
 #include "devices/basicdsk.h"
+#include "sound/saa1099.h"
+#include "sound/speaker.h"
 
 ADDRESS_MAP_START( coupe_readmem , ADDRESS_SPACE_PROGRAM, 8)
 	AM_RANGE( 0x0000, 0x3FFF) AM_READ( MRA8_BANK1 )
@@ -267,12 +269,9 @@ static WRITE8_HANDLER( coupe_port_w )
 	}
 }
 
-ADDRESS_MAP_START( coupe_readport , ADDRESS_SPACE_IO, 8)	
- AM_RANGE(	0x0000, 0x0ffff) AM_READ( coupe_port_r)
-ADDRESS_MAP_END
-
-ADDRESS_MAP_START( coupe_writeport , ADDRESS_SPACE_IO, 8)
-	 AM_RANGE(	0x0000, 0x0ffff) AM_WRITE( coupe_port_w)
+ADDRESS_MAP_START( coupe_io , ADDRESS_SPACE_IO, 8)	
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
+	AM_RANGE( 0x0000, 0x0ffff) AM_READWRITE( coupe_port_r, coupe_port_w )
 ADDRESS_MAP_END
 
 static struct GfxDecodeInfo coupe_gfxdecodeinfo[] = {
@@ -412,24 +411,13 @@ static PALETTE_INIT( coupe )
 	memcpy(colortable,coupe_colortable,sizeof(coupe_colortable));
 }
 
-static struct Speaker_interface coupe_speaker_interface=
-{
-	1,
-	{50},
-};
 
-static struct SAA1099_interface coupe_saa1099_interface=
-{
-	1,
-	{{50,50}},
-};
 
 static MACHINE_DRIVER_START( coupe )
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 6000000)        /* 6 Mhz */
-	MDRV_CPU_FLAGS( CPU_16BIT_PORT )
 	MDRV_CPU_PROGRAM_MAP(coupe_readmem,coupe_writemem)
-	MDRV_CPU_IO_MAP(coupe_readport,coupe_writeport)
+	MDRV_CPU_IO_MAP(coupe_io, 0)
 	MDRV_CPU_VBLANK_INT(coupe_line_interrupt, 192 + 10)	/* 192 scanlines + 10 lines of vblank (approx).. */
 	MDRV_FRAMES_PER_SECOND(50)
 	MDRV_VBLANK_DURATION(0)
@@ -450,8 +438,11 @@ static MACHINE_DRIVER_START( coupe )
 	MDRV_VIDEO_UPDATE( generic_bitmapped )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SPEAKER, coupe_speaker_interface)
-	MDRV_SOUND_ADD(SAA1099, coupe_saa1099_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SPEAKER, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MDRV_SOUND_ADD(SAA1099, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 /***************************************************************************
