@@ -27,6 +27,7 @@
 #include "devices/snapquik.h"
 #include "devices/cartslot.h"
 #include "devices/coco_vhd.h"
+#include "sound/ay8910.h"
 
 #define SHOW_FULL_AREA			0
 #define JOYSTICK_DELTA			10
@@ -262,6 +263,7 @@ INPUT_PORTS_START( dragon32 )
 	PORT_CONFNAME( 0x03, 0x01, "Cart Auto-Start" )
 	PORT_CONFSETTING(    0x00, DEF_STR( Off ) )
 	PORT_CONFSETTING(    0x01, DEF_STR( On ) )
+
 INPUT_PORTS_END
 
 /* CoCo keyboard
@@ -484,41 +486,31 @@ INPUT_PORTS_START( coco3 )
 	PORT_CONFSETTING(	0x00, DEF_STR( Normal ) )
 	PORT_CONFSETTING(	0x10, "Hi-Res Interface" )
 	PORT_CONFSETTING(	0x30, "Hi-Res Interface (CoCoMax 3 Style)" )
+	PORT_CONFSETTING(	0x20, "The Rat Graphics Mouse" )
 	
 	PORT_START /* 13 */
 	PORT_CONFNAME( 0x03, 0x00, "Real Time Clock" )
 	PORT_CONFSETTING(    0x00, "Disto" )
 	PORT_CONFSETTING(    0x01, "Cloud-9" )
 
+	PORT_START_TAG("rat_mouse_x")
+	PORT_BIT( 0x03, 0x00,  IPT_MOUSE_X) PORT_NAME("Rat Mouse X") PORT_SENSITIVITY(100) PORT_KEYDELTA(1) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_PLAYER(1)
+	PORT_START_TAG("rat_mouse_y")
+	PORT_BIT( 0x03, 0x00,  IPT_MOUSE_Y) PORT_NAME("Rat Mouse Y") PORT_SENSITIVITY(100) PORT_KEYDELTA(1) PORT_CODE_DEC(KEYCODE_UP) PORT_CODE_INC(KEYCODE_DOWN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_PLAYER(1)
+
 	PORT_START_TAG(DRAGON_COCO_CART_AUTOSTART) 
 	PORT_CONFNAME( 0x03, 0x01, "Cart Auto-Start" )
 	PORT_CONFSETTING(    0x00, DEF_STR( Off ) )
 	PORT_CONFSETTING(    0x01, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static struct DACinterface d_dac_interface =
-{
-	1,
-	{ 100 }
-};
-
-static struct Wave_interface d_wave_interface =
-{
-	1,
-	{ 25 }		/* mixing levels */
-};
-
 /* AY-8912 for Dragon Alpha, the AY-8912 simply an AY-8910 with only one io port. */
 static struct AY8910interface ay8912_interface =
 {
-	1,		                    /* total number of 8910 in the machine */
-	1000000,                    /* base clock : 1.0 MHz */
-	{ 75 },                     /* mixing_level */
-	{dgnalpha_psg_porta_read},  /* portA read */
-	{NULL},    					/* portB read */
-	{dgnalpha_psg_porta_write},  /* portA write */
-	{ NULL }					/* portB write */
-								/* IRQ handler for the YM2203 ??? */
+	dgnalpha_psg_porta_read,	/* portA read */
+	NULL,    					/* portB read */
+	dgnalpha_psg_porta_write,	/* portA write */
+	NULL						/* portB write */
 };
 
 
@@ -537,8 +529,11 @@ static MACHINE_DRIVER_START( dragon32 )
 	MDRV_M6847_PAL( dragon )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, d_dac_interface)
-	MDRV_SOUND_ADD(WAVE, d_wave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( dragon64 )
@@ -556,8 +551,11 @@ static MACHINE_DRIVER_START( dragon64 )
 	MDRV_M6847_PAL( dragon )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, d_dac_interface)
-	MDRV_SOUND_ADD(WAVE, d_wave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( dgnalpha )
@@ -575,9 +573,14 @@ static MACHINE_DRIVER_START( dgnalpha )
 	MDRV_M6847_PAL( dragon )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, d_dac_interface)
-	MDRV_SOUND_ADD(WAVE, d_wave_interface)
-	MDRV_SOUND_ADD(AY8910, ay8912_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(AY8910, 1000000)
+	MDRV_SOUND_CONFIG(ay8912_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( coco )
@@ -595,8 +598,11 @@ static MACHINE_DRIVER_START( coco )
 	MDRV_M6847_NTSC( dragon )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, d_dac_interface)
-	MDRV_SOUND_ADD(WAVE, d_wave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( coco2 )
@@ -614,8 +620,11 @@ static MACHINE_DRIVER_START( coco2 )
 	MDRV_M6847_PAL( dragon )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, d_dac_interface)
-	MDRV_SOUND_ADD(WAVE, d_wave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( coco2b )
@@ -633,8 +642,11 @@ static MACHINE_DRIVER_START( coco2b )
 	MDRV_M6847_NTSC( coco2b )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, d_dac_interface)
-	MDRV_SOUND_ADD(WAVE, d_wave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( coco3 )
@@ -661,8 +673,11 @@ static MACHINE_DRIVER_START( coco3 )
 	MDRV_VIDEO_UPDATE(coco3)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, d_dac_interface)
-	MDRV_SOUND_ADD(WAVE, d_wave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( coco3h )
