@@ -110,10 +110,12 @@ static WRITE8_HANDLER(kc85_4_port_w)
 
 
 ADDRESS_MAP_START( readport_kc85_4 , ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE( 0x0000, 0x0ffff) AM_READ( kc85_4_port_r )
 ADDRESS_MAP_END
 
 ADDRESS_MAP_START( writeport_kc85_4 , ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x0000, 0x0ffff) AM_WRITE( kc85_4_port_w)
 ADDRESS_MAP_END
 
@@ -313,10 +315,12 @@ static WRITE8_HANDLER(kc85_3_port_w)
 
 
 ADDRESS_MAP_START( readport_kc85_3 , ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE( 0x0000, 0x0ffff) AM_READ( kc85_3_port_r)
 ADDRESS_MAP_END
 
 ADDRESS_MAP_START( writeport_kc85_3 , ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE( 0x0000, 0x0ffff) AM_WRITE( kc85_3_port_w)
 ADDRESS_MAP_END
 
@@ -361,24 +365,10 @@ MACHINE_DRIVER_START( cpu_kc_disc )
 MACHINE_DRIVER_END
 
 
-static struct Speaker_interface kc_speaker_interface=
-{
-	1,
-	{50},
-};
-
-static struct Wave_interface kc_wave_interface=
-{
-	1,	  /* number of cassette drives = number of waves to mix */
-	{25},	/* default mixing level */
-
-};
-
 
 static MACHINE_DRIVER_START( kc85_3 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, KC85_3_CLOCK)
-	MDRV_CPU_FLAGS( CPU_16BIT_PORT )
 	MDRV_CPU_PROGRAM_MAP(readmem_kc85_3, writemem_kc85_3)
 	MDRV_CPU_IO_MAP(readport_kc85_3, writeport_kc85_3)
 	MDRV_CPU_CONFIG(kc85_daisy_chain)
@@ -400,8 +390,11 @@ static MACHINE_DRIVER_START( kc85_3 )
 	MDRV_VIDEO_UPDATE( kc85_3 )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SPEAKER, kc_speaker_interface)
-	MDRV_SOUND_ADD(WAVE, kc_wave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(SPEAKER, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -409,7 +402,6 @@ static MACHINE_DRIVER_START( kc85_4 )
 	MDRV_IMPORT_FROM( kc85_3 )
 
 	MDRV_CPU_REPLACE("main", Z80, KC85_4_CLOCK)
-	MDRV_CPU_FLAGS( CPU_16BIT_PORT )
 	MDRV_CPU_PROGRAM_MAP(readmem_kc85_4, writemem_kc85_4)
 	MDRV_CPU_IO_MAP(readport_kc85_4, writeport_kc85_4)
 
