@@ -293,24 +293,13 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 	{-1}
 };	 /* end of array */
 
-static struct beep_interface mz700_beep_interface =
-{
-	1,
-	{ 50 }
-};
 
 
-static struct Wave_interface wave_interface =
-{
-	1,
-	{ 50 }
-};
 static MACHINE_DRIVER_START(mz700)
 
 	/* basic machine hardware */
 	/* Z80 CPU @ 3.5 MHz */
 	MDRV_CPU_ADD(Z80, 3500000)
-	/*MDRV_CPU_FLAGS(0)*/
 	/*MDRV_CPU_CONFIG(0)*/
 	MDRV_CPU_PROGRAM_MAP(readmem_mz700, writemem_mz700)
 	MDRV_CPU_IO_MAP(readport_mz700, writeport_mz700)
@@ -338,10 +327,11 @@ static MACHINE_DRIVER_START(mz700)
 	/*MDRV_VIDEO_EOF(mz700)*/
 	MDRV_VIDEO_UPDATE(mz700)
 
-	MDRV_SOUND_ATTRIBUTES(0)
-	MDRV_SOUND_ADD(BEEP, mz700_beep_interface)
-	MDRV_SOUND_ADD(WAVE, wave_interface)
-
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MDRV_SOUND_ADD(BEEP, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START(mz800)
@@ -370,10 +360,11 @@ static MACHINE_DRIVER_START(mz800)
 	MDRV_VIDEO_START(mz700)
 	MDRV_VIDEO_UPDATE(mz700)
 
-	MDRV_SOUND_ATTRIBUTES(0)
-	MDRV_SOUND_ADD(BEEP, mz700_beep_interface)
-	MDRV_SOUND_ADD(WAVE, wave_interface)
-
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MDRV_SOUND_ADD(BEEP, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
