@@ -128,19 +128,7 @@ INPUT_PORTS_START( sms )
 
 INPUT_PORTS_END
 
-static struct SN76496interface sn76496_interface =
-{
-	1,				/* 1 chip */
-	{ 4194304 },			/* 4.194304 MHz */
-	{ 100 }
-};
 
-static struct YM2413interface ym2413_interface =
-{
-	1,
-	8000000,
-	{ 50 },
-};
 
 static MACHINE_DRIVER_START(sms)
 	/* basic machine hardware */
@@ -154,7 +142,6 @@ static MACHINE_DRIVER_START(sms)
 	MDRV_INTERLEAVE(1)
 
 	MDRV_MACHINE_INIT(sms)
-	MDRV_MACHINE_STOP(sms)
 	MDRV_NVRAM_HANDLER(sms)
 
 	/* video hardware */
@@ -169,7 +156,9 @@ static MACHINE_DRIVER_START(sms)
 	MDRV_VIDEO_UPDATE(sms)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SN76496, 4194304)	/* 4.194304 MHz */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START(smspal)
@@ -185,7 +174,8 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START(smsj21)
 	MDRV_IMPORT_FROM(smspal)
 
-	MDRV_SOUND_ADD(YM2413, ym2413_interface)
+	MDRV_SOUND_ADD(YM2413, 8000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START(smsm3)
@@ -204,7 +194,6 @@ static MACHINE_DRIVER_START(gamegear)
 	MDRV_INTERLEAVE(1)
 
 	MDRV_MACHINE_INIT(sms)
-	MDRV_MACHINE_STOP(sms)
 	MDRV_NVRAM_HANDLER(sms)
 
 	/* video hardware */
@@ -213,13 +202,14 @@ static MACHINE_DRIVER_START(gamegear)
 	MDRV_VISIBLE_AREA(6*8, 26*8-1, 3*8, 21*8-1)
 	MDRV_PALETTE_LENGTH(32)
 	MDRV_COLORTABLE_LENGTH(0)
-	/*MDRV_PALETTE_INIT(advision)*/
 
 	MDRV_VIDEO_START(sms)
 	MDRV_VIDEO_UPDATE(sms)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SN76496, 4194304)	/* 4.194304 MHz */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 ROM_START(sms)
