@@ -655,12 +655,6 @@ static Z80_DaisyChain sord_m5_daisy_chain[] =
 };
 
 
-static struct SN76496interface sn76496_interface =
-{
-    1,  		/* 1 chip 		*/
-    {3579545},  /* 3.579545 MHz */
-    { 100 }
-};
 
 static INTERRUPT_GEN( sord_interrupt )
 {
@@ -692,7 +686,9 @@ static MACHINE_DRIVER_START( sord_m5 )
 	MDRV_TMS9928A( &tms9928a_interface )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SN76496, 3579545)	/* 3.579545 MHz */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 
