@@ -147,6 +147,8 @@ http://www.z88forever.org.uk/zxplus3e/
 #include "devices/snapquik.h"
 #include "devices/cartslot.h"
 #include "devices/cassette.h"
+#include "sound/ay8910.h"
+#include "sound/speaker.h"
 
 /* +3 hardware */
 #include "includes/nec765.h"
@@ -160,12 +162,7 @@ extern void spectrum_plus3_update_memory(void);
 
 static struct AY8910interface spectrum_ay_interface =
 {
-	1,
-	1773400,
-	{25,25},
-	{0},
-	{0},
-	{0}
+	NULL
 };
 
 
@@ -344,13 +341,15 @@ static WRITE8_HANDLER ( spectrum_port_w )
 /* ports are not decoded full.
 The function decodes the ports appropriately */
 static ADDRESS_MAP_START (spectrum_readport, ADDRESS_SPACE_IO, 8)
-		AM_RANGE(0x0000, 0xffff) AM_READ( spectrum_port_r)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
+	AM_RANGE(0x0000, 0xffff) AM_READ( spectrum_port_r)
 ADDRESS_MAP_END
 
 /* ports are not decoded full.
 The function decodes the ports appropriately */
 static ADDRESS_MAP_START (spectrum_writeport, ADDRESS_SPACE_IO, 8)
-		AM_RANGE(0x0000, 0xffff) AM_WRITE( spectrum_port_w)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
+	AM_RANGE(0x0000, 0xffff) AM_WRITE( spectrum_port_w)
 ADDRESS_MAP_END
 
 
@@ -518,12 +517,14 @@ static WRITE8_HANDLER ( spectrum_128_port_w )
 /* ports are not decoded full.
 The function decodes the ports appropriately */
 static ADDRESS_MAP_START (spectrum_128_readport, ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x0000, 0xffff) AM_READ( spectrum_128_port_r)
 ADDRESS_MAP_END
 
 /* ports are not decoded full.
 The function decodes the ports appropriately */
 static ADDRESS_MAP_START (spectrum_128_writeport, ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x0000, 0xffff) AM_WRITE( spectrum_128_port_w)
 ADDRESS_MAP_END
 
@@ -1323,10 +1324,12 @@ void ts2068_update_memory(void)
 
 
 static ADDRESS_MAP_START (ts2068_readport, ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x0000, 0x0ffff) AM_READ( ts2068_port_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START (ts2068_writeport, ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x0000, 0x0ffff) AM_WRITE( ts2068_port_w)
 ADDRESS_MAP_END
 
@@ -2012,24 +2015,11 @@ static INTERRUPT_GEN( spec_interrupt )
 	cpunum_set_input_line(0, 0, PULSE_LINE);
 }
 
-static struct Speaker_interface spectrum_speaker_interface=
-{
-	1,
-	{50},
-};
-
-static struct Wave_interface spectrum_wave_interface=
-{
-	1,	  /* number of cassette drives = number of waves to mix */
-	{25},	/* default mixing level */
-
-};
 
 
 static MACHINE_DRIVER_START( spectrum )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, 3500000)        /* 3.5 Mhz */
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(spectrum_readmem,spectrum_writemem)
 	MDRV_CPU_IO_MAP(spectrum_readport,spectrum_writeport)
 	MDRV_CPU_VBLANK_INT(spec_interrupt,1)
@@ -2053,8 +2043,11 @@ static MACHINE_DRIVER_START( spectrum )
 	MDRV_VIDEO_EOF( spectrum )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SPEAKER, spectrum_speaker_interface)	/* standard spectrum sound */
-	MDRV_SOUND_ADD(WAVE, spectrum_wave_interface)		/* cassette wave sound */
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(SPEAKER, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -2062,7 +2055,6 @@ static MACHINE_DRIVER_START( spectrum_128 )
 	MDRV_IMPORT_FROM( spectrum )
 
 	MDRV_CPU_REPLACE("main", Z80, 3500000)        /* 3.5 Mhz */
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(spectrum_128_readmem,spectrum_128_writemem)
 	MDRV_CPU_IO_MAP(spectrum_128_readport,spectrum_128_writeport)
 	MDRV_FRAMES_PER_SECOND(50.021)
@@ -2074,7 +2066,9 @@ static MACHINE_DRIVER_START( spectrum_128 )
 	MDRV_VIDEO_UPDATE( spectrum_128 )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, spectrum_ay_interface)	/* Ay-3-8912 sound */
+	MDRV_SOUND_ADD(AY8910, 1773400)
+	MDRV_SOUND_CONFIG(spectrum_ay_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)	
 MACHINE_DRIVER_END
 
 
@@ -2091,7 +2085,6 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( ts2068 )
 	MDRV_IMPORT_FROM( spectrum_128 )
 	MDRV_CPU_REPLACE("main", Z80, 3580000)        /* 3.58 Mhz */
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(ts2068_mem, 0)
 	MDRV_CPU_IO_MAP(ts2068_readport,ts2068_writeport)
 	MDRV_FRAMES_PER_SECOND(60)
