@@ -319,9 +319,7 @@ static MACHINE_INIT( svision )
 
 struct CustomSound_interface svision_sound_interface =
 {
-	svision_custom_start,
-	NULL,
-	svision_custom_update
+	svision_custom_start
 };
 
 
@@ -338,6 +336,7 @@ static MACHINE_DRIVER_START( svision )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)	/* lcd */
+	MDRV_ASPECT_RATIO(160, 160)
 	MDRV_SCREEN_SIZE(160, 160)
 	MDRV_VISIBLE_AREA(0, 160-1, 0, 160-1)
 	MDRV_PALETTE_LENGTH(sizeof(svision_palette) / (sizeof(svision_palette[0]) * 3))
@@ -346,8 +345,11 @@ static MACHINE_DRIVER_START( svision )
 	MDRV_VIDEO_UPDATE( svision )
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(CUSTOM, svision_sound_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_CONFIG(svision_sound_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(0, "right", 0.50)
 MACHINE_DRIVER_END
 
 ROM_START(svision)
