@@ -77,6 +77,7 @@ TODO :
 #include "vidhrdw/tms9928a.h"
 #include "devices/cartslot.h"
 #include "devices/cassette.h"
+#include "sound/sn76496.h"
 
 
 /* mapper state */
@@ -86,7 +87,7 @@ static char cartridge_enable;
 static void tape_interrupt_handler(int dummy);
 
 static char tape_interrupt_enable;
-static void *tape_interrupt_timer;
+static mame_timer *tape_interrupt_timer;
 
 /* parallel interface state */
 static mame_file *printer_fp;
@@ -552,33 +553,13 @@ static const TMS9928a_interface tms9929a_interface =
 	/*tms9901_set_int2*/NULL
 };
 
-/*
-	SN76489 or SN76496 sound chip(?)
-*/
-static struct SN76496interface tms9919interface =
-{
-	1,				/* one sound chip */
-	{ 3579545 },	/* clock speed. connected to the TMS9918A CPUCLK pin? */
-	{ 75 }			/* Volume.  I don't know the best value. */
-};
 
-/*
-	1 tape units
-*/
-static struct Wave_interface tape_input_intf =
-{
-	1,
-	{
-		20			/* Volume */
-	}
-};
 
 static MACHINE_DRIVER_START(tutor)
 
 	/* basic machine hardware */
 	/* TMS9995 CPU @ 10.7 MHz */
 	MDRV_CPU_ADD(TMS9995, 10700000)
-	/*MDRV_CPU_FLAGS(0)*/
 	MDRV_CPU_CONFIG(tutor_processor_config)
 	MDRV_CPU_PROGRAM_MAP(tutor_memmap, 0)
 	MDRV_CPU_IO_MAP(tutor_readcru, /*tutor_writecru*/0)
@@ -590,17 +571,17 @@ static MACHINE_DRIVER_START(tutor)
 	/*MDRV_INTERLEAVE(interleave)*/
 
 	MDRV_MACHINE_INIT( tutor )
-	/*MDRV_MACHINE_STOP( tutor )*/
 	/*MDRV_NVRAM_HANDLER( NULL )*/
 
 	/* video hardware */
 	MDRV_TMS9928A( &tms9929a_interface )
 
 	/* sound */
-	MDRV_SOUND_ATTRIBUTES(0)
-	MDRV_SOUND_ADD(SN76496, tms9919interface)
-	MDRV_SOUND_ADD(WAVE, tape_input_intf)
-
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SN76496, 3579545)	/* 3.579545 MHz */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 MACHINE_DRIVER_END
 
 
