@@ -750,8 +750,12 @@ static MACHINE_DRIVER_START( vic20 )
 	MDRV_VIDEO_UPDATE( vic6560 )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(CUSTOM, vic6560_sound_interface)
-	MDRV_SOUND_ADD(DAC, vc20tape_sound_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_CONFIG(vic6560_sound_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
