@@ -14,6 +14,7 @@
  ******************************************************************************/
 #include "driver.h"
 #include "includes/z88.h"
+#include "sound/speaker.h"
 
 struct blink_hw blink;
 
@@ -601,15 +602,11 @@ static  READ8_HANDLER(z88_port_r)
 
 
 static ADDRESS_MAP_START( z88_io, ADDRESS_SPACE_IO, 8)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x0000, 0x0ffff) AM_READWRITE(z88_port_r, z88_port_w)
 ADDRESS_MAP_END
 
 
-static struct Speaker_interface z88_speaker_interface=
-{
-  1,
-  {50}
-};
 
 /*
 -------------------------------------------------------------------------
@@ -713,7 +710,6 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( z88 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, 3276800)
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(z88_mem, 0)
 	MDRV_CPU_IO_MAP(z88_io, 0)
 	MDRV_FRAMES_PER_SECOND(50)
@@ -734,7 +730,9 @@ static MACHINE_DRIVER_START( z88 )
 	MDRV_VIDEO_UPDATE( z88 )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SPEAKER, z88_speaker_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(SPEAKER, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
