@@ -50,6 +50,7 @@ ADDRESS_MAP_START( pc8300_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( zx80_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) ) 
 	AM_RANGE(0x0000, 0xffff) AM_READWRITE(zx_io_r, zx_io_w)
 ADDRESS_MAP_END
 
@@ -409,16 +410,7 @@ static PALETTE_INIT( ts1000 )
 	memcpy(colortable, zx_colortable, sizeof (zx_colortable));
 }
 
-static struct Wave_interface zx81_wave_interface = {
-	1,		/* 1 cassette recorder */
-	{50}		/* mixing levels in percent */
-};
 
-static struct DACinterface zx81_dac_interface =
-{
-	1,		/* number of DACs */
-	{50}		/* volume */
-};
 
 #define ZX81_CPU_CLOCK			3250000
 #define ZX81_CYCLES_PER_SCANLINE	207
@@ -437,7 +429,6 @@ static struct DACinterface zx81_dac_interface =
 static MACHINE_DRIVER_START( zx80 )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, ZX81_CPU_CLOCK)
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(zx80_map, 0)
 	MDRV_CPU_IO_MAP(zx80_io_map, 0)
 	MDRV_FRAMES_PER_SECOND(ZX81_PAL_FRAMES_PER_SECOND)
@@ -458,8 +449,11 @@ static MACHINE_DRIVER_START( zx80 )
 	MDRV_VIDEO_UPDATE(zx)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(WAVE, zx81_wave_interface)
-	MDRV_SOUND_ADD(DAC, zx81_dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MDRV_SOUND_ADD(WAVE, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( zx81 )
