@@ -51,12 +51,14 @@ static imgtoolerr_t internal_open(const struct ImageModule *module, const char *
 	if (outimg)
 		*outimg = NULL;
 
-	if (createopts ? !module->create : !module->open)
+	/* is the requested functionality implemented? */
+	if ((read_or_write == OSD_FOPEN_RW_CREATE) ? !module->create : !module->open)
 	{
 		err = IMGTOOLERR_UNIMPLEMENTED | IMGTOOLERR_SRC_FUNCTIONALITY;
 		goto done;
 	}
 
+	/* open the stream */
 	f = stream_open(fname, read_or_write);
 	if (!f)
 	{
@@ -64,6 +66,7 @@ static imgtoolerr_t internal_open(const struct ImageModule *module, const char *
 		goto done;
 	}
 
+	/* setup the image structure */
 	size = sizeof(struct _imgtool_image) + module->image_extra_bytes;
 	image = (imgtool_image *) malloc(size);
 	if (!image)
@@ -74,7 +77,8 @@ static imgtoolerr_t internal_open(const struct ImageModule *module, const char *
 	memset(image, '\0', size);
 	image->module = module;
 	
-	if (createopts)
+	/* actually call create or open */
+	if (read_or_write == OSD_FOPEN_RW_CREATE)
 		err = module->create(image, f, createopts);
 	else
 		err = module->open(image, f);
@@ -107,6 +111,7 @@ done:
 
 imgtoolerr_t img_open(const struct ImageModule *module, const char *fname, int read_or_write, imgtool_image **outimg)
 {
+	read_or_write = read_or_write ? OSD_FOPEN_RW : OSD_FOPEN_READ;
 	return internal_open(module, fname, read_or_write, NULL, outimg);
 }
 
@@ -414,6 +419,92 @@ done:
 
 
 
+imgtoolerr_t img_getchain(imgtool_image *img, const char *path, imgtool_chainent *chain, size_t chain_size)
+{
+	size_t i;
+
+	assert(chain_size > 0);
+
+	if (!img->module->get_chain)
+		return IMGTOOLERR_UNIMPLEMENTED | IMGTOOLERR_SRC_FUNCTIONALITY;
+
+	/* initialize the chain array, so the module's get_chain function can be lazy */
+	for (i = 0; i < chain_size; i++)
+	{
+		chain[i].level = 0;
+		chain[i].block = ~0;
+	}
+
+	return img->module->get_chain(img, path, chain, chain_size - 1);
+}
+
+
+
+imgtoolerr_t img_getchain_string(imgtool_image *img, const char *path, char *buffer, size_t buffer_len)
+{
+	imgtoolerr_t err;
+	imgtool_chainent chain[512];
+	UINT64 last_block;
+	UINT8 cur_level = 0;
+	int len, i;
+	int comma_needed = FALSE;
+
+	/* determine the last block identifier */
+	chain[0].block = ~0;
+	last_block = chain[0].block;
+
+	err = img_getchain(img, path, chain, sizeof(chain) / sizeof(chain[0]));
+	if (err)
+		return err;
+
+	len = snprintf(buffer, buffer_len, "[");
+	buffer += len;
+	buffer_len -= len;
+
+	for (i = 0; chain[i].block != last_block; i++)
+	{
+		while(cur_level < chain[i].level)
+		{
+			len = snprintf(buffer, buffer_len, " [");
+			buffer += len;
+			buffer_len -= len;
+			cur_level++;
+			comma_needed = FALSE;
+		}
+		while(cur_level > chain[i].level)
+		{
+			len = snprintf(buffer, buffer_len, "]");
+			buffer += len;
+			buffer_len -= len;
+			cur_level--;
+		}
+
+		if (comma_needed)
+		{
+			len = snprintf(buffer, buffer_len, ", ");
+			buffer += len;
+			buffer_len -= len;
+		}
+
+		len = snprintf(buffer, buffer_len, "%u", (unsigned) chain[i].block);
+		buffer += len;
+		buffer_len -= len;
+		comma_needed = TRUE;
+	}
+
+	do
+	{
+		len = snprintf(buffer, buffer_len, "]");
+		buffer += len;
+		buffer_len -= len;
+	}
+	while(cur_level-- > 0);
+
+	return IMGTOOLERR_SUCCESS;
+}
+
+
+
 imgtoolerr_t img_freespace(imgtool_image *img, UINT64 *sz)
 {
 	imgtoolerr_t err;
@@ -741,7 +832,7 @@ imgtoolerr_t img_create(const struct ImageModule *module, const char *fname,
 	option_resolution *alloc_resolution = NULL;
 
 	/* allocate dummy options if necessary */
-	if (!opts)
+	if (!opts && module->createimage_optguide)
 	{
 		alloc_resolution = option_resolution_create(module->createimage_optguide, module->createimage_optspec);
 		if (!alloc_resolution)
@@ -751,7 +842,8 @@ imgtoolerr_t img_create(const struct ImageModule *module, const char *fname,
 		}
 		opts = alloc_resolution;
 	}
-	option_resolution_finish(opts);
+	if (opts)
+		option_resolution_finish(opts);
 
 	err = internal_open(module, fname, OSD_FOPEN_RW_CREATE, opts, image);
 	if (err)
