@@ -1,3 +1,11 @@
+/***************************************************************************
+
+	imgterrs.c
+
+	Imgtool errors
+
+***************************************************************************/
+
 #include <assert.h>
 #include "imgterrs.h"
 
@@ -10,6 +18,8 @@ static const char *msgs[] =
 	"Write error",
 	"Image is read only",
 	"Corrupt image",
+	"Corrupt file",
+	"Corrupt directory",
 	"File not found",
 	"Unrecognized format",
 	"Not implemented",
@@ -20,9 +30,16 @@ static const char *msgs[] =
 	"Invalid parameter",
 	"Bad file name",
 	"Out of space on image",
-	"Input past end of file"
+	"Input past end of file",
+	"Cannot specify path",
+	"Invalid path",
+	"Path not found",
+	"Directory not empty",
+	"Seek error"
 };
 
+
+
 const char *imgtool_error(imgtoolerr_t err)
 {
 	err = ERRORCODE(err) - 1;
