@@ -1,8 +1,16 @@
+/***************************************************************************
+
+	imgterrs.h
+
+	Imgtool errors
+
+***************************************************************************/
+
 #ifndef IMGTERRS_H
 #define IMGTERRS_H
 
 /* Error codes */
-enum 
+typedef enum 
 {
 	IMGTOOLERR_SUCCESS,
 	IMGTOOLERR_OUTOFMEMORY,
@@ -12,6 +20,8 @@ enum
 	IMGTOOLERR_WRITEERROR,
 	IMGTOOLERR_READONLY,
 	IMGTOOLERR_CORRUPTIMAGE,
+	IMGTOOLERR_CORRUPTFILE,
+	IMGTOOLERR_CORRUPTDIR,
 	IMGTOOLERR_FILENOTFOUND,
 	IMGTOOLERR_MODULENOTFOUND,
 	IMGTOOLERR_UNIMPLEMENTED,
@@ -22,10 +32,13 @@ enum
 	IMGTOOLERR_PARAMCORRUPT,
 	IMGTOOLERR_BADFILENAME,
 	IMGTOOLERR_NOSPACE,
-	IMGTOOLERR_INPUTPASTEND
-};
-
-typedef int imgtoolerr_t;
+	IMGTOOLERR_INPUTPASTEND,
+	IMGTOOLERR_CANNOTUSEPATH,
+	IMGTOOLERR_INVALIDPATH,
+	IMGTOOLERR_PATHNOTFOUND,
+	IMGTOOLERR_DIRNOTEMPTY,
+	IMGTOOLERR_SEEKERROR
+} imgtoolerr_t;
 
 
 
