@@ -151,8 +151,8 @@ static imgtoolerr_t os9_locate_lsn(imgtool_image *image, UINT32 lsn, UINT32 *hea
 	if (lsn > disk_info->total_sectors)
 		return IMGTOOLERR_CORRUPTIMAGE;
 
-	*head = 0;
-	*track = lsn / disk_info->sectors_per_track;
+	*track = lsn / (disk_info->sectors_per_track * disk_info->sides);
+	*head = (lsn / disk_info->sectors_per_track) % disk_info->sides;
 	*sector = (lsn % disk_info->sectors_per_track) + 1;
 	return IMGTOOLERR_SUCCESS;
 }
@@ -390,8 +390,8 @@ static imgtoolerr_t os9_set_file_size(imgtool_image *image,
 	current_lsn_count = (file_info->file_size + disk_info->sector_size - 1) / disk_info->sector_size;
 	new_lsn_count = (new_size + disk_info->sector_size - 1) / disk_info->sector_size;
 
-	/* check to see if we are out of space */
-	if (new_lsn_count - current_lsn_count > free_lsns)
+	/* check to see if the file is growing and we do not have enough space */
+	if ((new_lsn_count > current_lsn_count) && (new_lsn_count - current_lsn_count > free_lsns))
 		return IMGTOOLERR_NOSPACE;
 
 	if (current_lsn_count != new_lsn_count)
@@ -630,11 +630,11 @@ static imgtoolerr_t os9_diskimage_open(imgtool_image *image)
 	info->bootstrap_size			= pick_integer(header,  24, 2);
 	info->sector_size				= pick_integer(header, 104, 2);
 
-	info->sides					= (attributes & 0x01) ? 2 : 1;
-	info->double_density		= (attributes & 0x02) ? 1 : 0;
-	info->double_track			= (attributes & 0x04) ? 1 : 0;
-	info->quad_track_density	= (attributes & 0x08) ? 1 : 0;
-	info->octal_track_density	= (attributes & 0x10) ? 1 : 0;
+	info->sides					= (info->format_flags & 0x01) ? 2 : 1;
+	info->double_density		= (info->format_flags & 0x02) ? 1 : 0;
+	info->double_track			= (info->format_flags & 0x04) ? 1 : 0;
+	info->quad_track_density	= (info->format_flags & 0x08) ? 1 : 0;
+	info->octal_track_density	= (info->format_flags & 0x10) ? 1 : 0;
 
 	pick_string(header, 31, 32, info->name);
 
