@@ -1,6 +1,6 @@
 /***************************************************************************
 
-	CHD compression frontend
+    CHD compression frontend
 
 ***************************************************************************/
 
@@ -30,13 +30,9 @@
 #endif
 #endif
 
-#if defined(__MWERKS__) && macintosh
-#include <console.h>
-#endif
-
 
 /***************************************************************************
-	CONSTANTS & DEFINES
+    CONSTANTS & DEFINES
 ***************************************************************************/
 
 #define IDE_SECTOR_SIZE			512
@@ -46,7 +42,7 @@
 
 
 /***************************************************************************
-	PROTOTYPES
+    PROTOTYPES
 ***************************************************************************/
 
 static struct chd_interface_file *chdman_open(const char *filename, const char *mode);
@@ -59,7 +55,7 @@ static UINT64 get_file_size(const char *file);
 
 
 /***************************************************************************
-	GLOBAL VARIABLES
+    GLOBAL VARIABLES
 ***************************************************************************/
 
 static struct chd_interface chdman_interface =
@@ -110,11 +106,11 @@ static const char *error_strings[] =
 
 
 /***************************************************************************
-	IMPLEMENTATION
+    IMPLEMENTATION
 ***************************************************************************/
 
 /*-------------------------------------------------
-	put_bigendian_uint32 - write a UINT32 in big-endian order to memory
+    put_bigendian_uint32 - write a UINT32 in big-endian order to memory
 -------------------------------------------------*/
 
 INLINE void put_bigendian_uint32(UINT8 *base, UINT32 value)
@@ -126,7 +122,7 @@ INLINE void put_bigendian_uint32(UINT8 *base, UINT32 value)
 }
 
 /*-------------------------------------------------
-	print_big_int - 64-bit int printing with commas
+    print_big_int - 64-bit int printing with commas
 -------------------------------------------------*/
 
 void print_big_int(UINT64 intvalue, char *output)
@@ -148,7 +144,7 @@ void print_big_int(UINT64 intvalue, char *output)
 
 
 /*-------------------------------------------------
-	big_int_string - return a string for a big int
+    big_int_string - return a string for a big int
 -------------------------------------------------*/
 
 char *big_int_string(UINT64 intvalue)
@@ -162,7 +158,7 @@ char *big_int_string(UINT64 intvalue)
 
 
 /*-------------------------------------------------
-	progress - generic progress callback
+    progress - generic progress callback
 -------------------------------------------------*/
 
 static void progress(const char *fmt, ...)
@@ -179,7 +175,7 @@ static void progress(const char *fmt, ...)
 
 
 /*-------------------------------------------------
-	error_string - return an error sting
+    error_string - return an error sting
 -------------------------------------------------*/
 
 static const char *error_string(int err)
@@ -196,7 +192,7 @@ static const char *error_string(int err)
 
 
 /*-------------------------------------------------
-	error - generic usage error display
+    error - generic usage error display
 -------------------------------------------------*/
 
 static void error(void)
@@ -207,6 +203,7 @@ static void error(void)
 	printf("   or: chdman -createcd input.toc output.chd\n");
 	printf("   or: chdman -copydata input.chd output.chd\n");
 	printf("   or: chdman -extract input.chd output.raw\n");
+	printf("   or: chdman -extractcd input.chd output.toc output.bin\n");
 	printf("   or: chdman -verify input.chd\n");
 	printf("   or: chdman -verifyfix input.chd\n");
 	printf("   or: chdman -update input.chd output.chd\n");
@@ -220,8 +217,8 @@ static void error(void)
 
 
 /*-------------------------------------------------
-	special_chd_init - set up a CHD file as a
-	"fake" raw file for input
+    special_chd_init - set up a CHD file as a
+    "fake" raw file for input
 -------------------------------------------------*/
 
 static void special_chd_init(struct chd_file *chd, UINT64 logicalbytes)
@@ -241,8 +238,8 @@ static void special_chd_init(struct chd_file *chd, UINT64 logicalbytes)
 
 
 /*-------------------------------------------------
-	special_chd_finished - finish using a CHD
-	file as a "fake" raw file for input
+    special_chd_finished - finish using a CHD
+    file as a "fake" raw file for input
 -------------------------------------------------*/
 
 static void special_chd_finished(void)
@@ -314,8 +311,8 @@ static void special_chd_finished(void)
 
 
 /*-------------------------------------------------
-	is_physical_drive - clue to Win32 code that
-	we're reading a physical drive directly
+    is_physical_drive - clue to Win32 code that
+    we're reading a physical drive directly
 -------------------------------------------------*/
 
 #ifdef _WIN32
@@ -328,8 +325,8 @@ static int is_physical_drive(const char *file)
 
 
 /*-------------------------------------------------
-	guess_chs - given a file and an offset,
-	compute a best guess CHS value set
+    guess_chs - given a file and an offset,
+    compute a best guess CHS value set
 -------------------------------------------------*/
 
 static void guess_chs(const char *filename, int offset, int sectorsize, UINT32 *cylinders, UINT32 *heads, UINT32 *sectors, UINT32 *bps)
@@ -407,8 +404,8 @@ static void guess_chs(const char *filename, int offset, int sectorsize, UINT32 *
 
 
 /*-------------------------------------------------
-	do_create - create a new compressed hard disk
-	image from a raw file
+    do_create - create a new compressed hard disk
+    image from a raw file
 -------------------------------------------------*/
 
 static void do_createhd(int argc, char *argv[])
@@ -508,8 +505,8 @@ static void do_createhd(int argc, char *argv[])
 }
 
 /*-------------------------------------------------
-	do_createcd - create a new compressed CD
-	image from a raw file
+    do_createcd - create a new compressed CD
+    image from a raw file
 -------------------------------------------------*/
 
 static void do_createcd(int argc, char *argv[])
@@ -569,16 +566,16 @@ static void do_createcd(int argc, char *argv[])
 		}
 
 		/*
-		printf("Track %02d: file %s offset %d type %d subtype %d datasize %d subsize %d frames %d extra %d\n", i,
-			track_info.fname[i], 
-			track_info.offset[i], 
-			toc.tracks[i].trktype,
-			toc.tracks[i].subtype,
-			toc.tracks[i].datasize,
-			toc.tracks[i].subsize,
-			toc.tracks[i].frames,
-			toc.tracks[i].extraframes);
-		*/		
+        printf("Track %02d: file %s offset %d type %d subtype %d datasize %d subsize %d frames %d extra %d\n", i,
+            track_info.fname[i],
+            track_info.offset[i],
+            toc.tracks[i].trktype,
+            toc.tracks[i].subtype,
+            toc.tracks[i].datasize,
+            toc.tracks[i].subsize,
+            toc.tracks[i].frames,
+            toc.tracks[i].extraframes);
+        */
 	}
 
 	/* create the new CHD file */
@@ -639,8 +636,8 @@ static void do_createcd(int argc, char *argv[])
 
 		printf("Compressing track %d / %d (file %s:%d, %d frames, %d hunks)\n", i+1, toc.numtrks, track_info.fname[i], track_info.offset[i], toc.tracks[i].frames, hunks);
 
- 		err = chd_compress_ex(chdex, track_info.fname[i], track_info.offset[i], 
-				trkbytespersec, CD_FRAMES_PER_HUNK, hunks, 
+ 		err = chd_compress_ex(chdex, track_info.fname[i], track_info.offset[i],
+				trkbytespersec, CD_FRAMES_PER_HUNK, hunks,
 				CD_FRAME_SIZE, progress);
 		if (err != CHDERR_NONE)
 		{
@@ -667,10 +664,10 @@ static void do_createcd(int argc, char *argv[])
 }
 
 /*
-	Create a new non-compressed hard disk image, with all hunks filled with 0s.
+    Create a new non-compressed hard disk image, with all hunks filled with 0s.
 
-	Example:
-		[program] -createblankhd out.hd 615 4 32 256 32768
+    Example:
+        [program] -createblankhd out.hd 615 4 32 256 32768
 */
 static void do_createblankhd(int argc, char *argv[])
 {
@@ -787,7 +784,7 @@ static void do_createblankhd(int argc, char *argv[])
 }
 
 /*
-	Compute the largest common divisor of two numbers.
+    Compute the largest common divisor of two numbers.
 */
 INLINE UINT32 lcd_u32(UINT32 a, UINT32 b)
 {
@@ -805,12 +802,12 @@ INLINE UINT32 lcd_u32(UINT32 a, UINT32 b)
 }
 
 /*-------------------------------------------------
-	Copy all hunks of data from one CHD file to another.  The hunk sizes do not
-	need to match.  If the source is shorter than the destination, the source
-	data will be padded with 0s.
+    Copy all hunks of data from one CHD file to another.  The hunk sizes do not
+    need to match.  If the source is shorter than the destination, the source
+    data will be padded with 0s.
 
-	Example
-		[program] -copydata in.hd out.hd
+    Example
+        [program] -copydata in.hd out.hd
 -------------------------------------------------*/
 static void do_copydata(int argc, char *argv[])
 {
@@ -930,8 +927,8 @@ static void do_copydata(int argc, char *argv[])
 }
 
 /*-------------------------------------------------
-	do_extract - extract a raw file from a
-	CHD image
+    do_extract - extract a raw file from a
+    CHD image
 -------------------------------------------------*/
 
 static void do_extract(int argc, char *argv[])
@@ -1028,11 +1025,175 @@ error:
 		chd_close(infile);
 }
 
+/*-------------------------------------------------
+    do_extractcd - extract a CDRDAO .toc/.bin
+    file from a CHD-CD image
+-------------------------------------------------*/
 
+static void do_extractcd(int argc, char *argv[])
+{
+	const char *inputfile, *outputfile, *outputfile2;
+	struct chd_file *infile = NULL;
+	void *hunk = NULL;
+	struct cdrom_file *cdrom = NULL;
+	struct cdrom_toc *toc = NULL;
+	FILE *outfile = NULL, *outfile2 = NULL;
+	int track, m, s, f, frame;
+	long trkoffs, trklen;
+	const char *typenames[8] = { "MODE1", "MODE1_RAW", "MODE2", "MODE2_FORM1", "MODE2_FORM2", "MODE2_FORM_MIX", "MODE2_RAW", "AUDIO" };
+	const char *subnames[2] = { "RW", "RW_RAW" };
+	unsigned char sector[CD_MAX_SECTOR_DATA + CD_MAX_SUBCODE_DATA];
+
+	/* require 5 args total */
+	if (argc != 5)
+		error();
+
+	/* extract the data */
+	inputfile = argv[2];
+	outputfile = argv[3];
+	outputfile2 = argv[4];
+
+	/* print some info */
+	printf("Input file:   %s\n", inputfile);
+	printf("Output files:  %s (toc) and %s (bin)\n", outputfile, outputfile2);
+
+	/* get the header */
+	infile = chd_open(inputfile, 0, NULL);
+	if (!infile)
+	{
+		printf("Error opening CHD file '%s': %s\n", inputfile, error_string(chd_get_last_error()));
+		goto error;
+	}
+
+	/* open the CD */
+	cdrom = cdrom_open(infile);
+	if (!cdrom)
+	{
+		printf("Error opening CHD-CD '%s'\n", inputfile);
+		goto error;
+	}
+
+	/* get the TOC data */
+	toc = cdrom_get_toc(cdrom);
+
+	/* create the output files */
+	outfile = fopen(outputfile, "w");
+	if (!outfile)
+	{
+		printf("Error opening output file '%s'\n", outputfile);
+		goto error;
+	}
+
+	outfile2 = fopen(outputfile2, "wb");
+	if (!outfile2)
+	{
+		printf("Error opening output file '%s'\n", outputfile2);
+		goto error;
+	}
+
+	/* process away */
+	fprintf(outfile, "CD_ROM\n\n\n");
+
+	trkoffs = 0;
+	for (track = 0; track < toc->numtrks; track++)
+	{
+		printf("Extracting track %d\n", track+1);
+
+		fprintf(outfile, "// Track %d\n", track+1);
+
+		/* write out the track type */
+		if (toc->tracks[track].subtype != CD_SUB_NONE)
+		{
+			fprintf(outfile, "TRACK %s %s\n", typenames[toc->tracks[track].trktype], subnames[toc->tracks[track].subtype]);
+		}
+		else
+		{
+			fprintf(outfile, "TRACK %s\n", typenames[toc->tracks[track].trktype]);
+		}
+
+		/* write out the attributes */
+		fprintf(outfile, "NO COPY\n");
+		if (toc->tracks[track].trktype == CD_TRACK_AUDIO)
+		{
+			fprintf(outfile, "NO PRE_EMPHASIS\n");
+			fprintf(outfile, "TWO_CHANNEL_AUDIO\n");
+
+			/* the first audio track on a mixed-track disc always has a 2 second pad */
+			if (track == 1)
+			{
+				if (toc->tracks[track].subtype != CD_SUB_NONE)
+				{
+					fprintf(outfile, "ZERO AUDIO %s 00:02:00\n", subnames[toc->tracks[track].subtype]);
+				}
+				else
+				{
+					fprintf(outfile, "ZERO AUDIO 00:02:00\n");
+				}
+			}
+		}
+
+		/* handle the datafile */
+		trklen = toc->tracks[track].frames;
+
+		/* convert to minutes/seconds/frames */
+		f = trklen;
+		s = f / 75;
+		f %= 75;
+		m = s / 60;
+		s %= 60;
+
+		if (track > 0)
+		{
+			fprintf(outfile, "DATAFILE \"%s\" #%ld %02d:%02d:%02d // length in bytes: %ld\n", outputfile2, trkoffs, m, s, f, trklen*(toc->tracks[track].datasize+toc->tracks[track].subsize));
+		}
+		else
+		{
+			fprintf(outfile, "DATAFILE \"%s\" %02d:%02d:%02d // length in bytes: %ld\n", outputfile2, m, s, f, trklen*(toc->tracks[track].datasize+toc->tracks[track].subsize));
+		}
+
+		if ((toc->tracks[track].trktype == CD_TRACK_AUDIO) && (track == 1))
+		{
+			fprintf(outfile, "START 00:02:00\n");
+		}
+
+		/* now handle the actual writeout */
+		for (frame = 0; frame < trklen; frame++)
+		{
+			cdrom_read_data(cdrom, cdrom_get_chd_start_of_track(cdrom, track)+frame, 1, sector, toc->tracks[track].trktype);
+			fwrite(sector, toc->tracks[track].datasize, 1, outfile2);
+			trkoffs += toc->tracks[track].datasize;
+			cdrom_read_subcode(cdrom, cdrom_get_chd_start_of_track(cdrom, track)+frame, sector);
+			fwrite(sector, toc->tracks[track].subsize, 1, outfile2);
+			trkoffs += toc->tracks[track].subsize;
+		}
+
+		fprintf(outfile, "\n\n");
+	}
+
+	printf("Completed!\n");
+
+	/* close everything down */
+	fclose(outfile);
+	fclose(outfile2);
+	free(hunk);
+	chd_close(infile);
+	return;
+
+error:
+	/* clean up our mess */
+	if (outfile)
+		fclose(outfile);
+	if (outfile2)
+		fclose(outfile2);
+	if (cdrom)
+		cdrom_close(cdrom);
+	if (infile)
+		chd_close(infile);
+}
 
 /*-------------------------------------------------
-	do_verify - validate the MD5/SHA1 on a drive
-	image
+    do_verify - validate the MD5/SHA1 on a drive
+    image
 -------------------------------------------------*/
 
 static void do_verify(int argc, char *argv[], int fix)
@@ -1069,7 +1230,7 @@ static void do_verify(int argc, char *argv[], int fix)
 		if (err == CHDERR_CANT_VERIFY)
 			printf("Can't verify this type of image (probably writeable)\n");
 		else
-			printf("Error during verify: %s\n", error_string(err));
+			printf("\nError during verify: %s\n", error_string(err));
 		chd_close(chd);
 		return;
 	}
@@ -1144,8 +1305,8 @@ static void do_verify(int argc, char *argv[], int fix)
 
 
 /*-------------------------------------------------
-	do_info - dump the header information from
-	a drive image
+    do_info - dump the header information from
+    a drive image
 -------------------------------------------------*/
 
 static void do_info(int argc, char *argv[])
@@ -1250,7 +1411,7 @@ static void do_info(int argc, char *argv[])
 
 
 /*-------------------------------------------------
-	handle_custom_chomp - custom chomp a file
+    handle_custom_chomp - custom chomp a file
 -------------------------------------------------*/
 
 #if ENABLE_CUSTOM_CHOMP
@@ -1332,8 +1493,8 @@ error:
 
 
 /*-------------------------------------------------
-	do_merge_update_chomp - merge a parent and its
-	child together (also works for update & chomp)
+    do_merge_update_chomp - merge a parent and its
+    child together (also works for update & chomp)
 -------------------------------------------------*/
 
 #define OPERATION_UPDATE		0
@@ -1467,8 +1628,8 @@ error:
 
 
 /*-------------------------------------------------
-	do_diff - generate a difference between two
-	CHD files
+    do_diff - generate a difference between two
+    CHD files
 -------------------------------------------------*/
 
 static void do_diff(int argc, char *argv[])
@@ -1550,8 +1711,8 @@ error:
 
 
 /*-------------------------------------------------
-	do_setchs - change the CHS values on a hard
-	disk image
+    do_setchs - change the CHS values on a hard
+    disk image
 -------------------------------------------------*/
 
 static void do_setchs(int argc, char *argv[])
@@ -1674,8 +1835,8 @@ cleanup:
 
 
 /*-------------------------------------------------
-	get_file_size - returns the 64-bit file size
-	for a file
+    get_file_size - returns the 64-bit file size
+    for a file
 -------------------------------------------------*/
 
 static UINT64 get_file_size(const char *file)
@@ -1720,7 +1881,7 @@ static UINT64 get_file_size(const char *file)
 
 
 /*-------------------------------------------------
-	chdman_open - open file
+    chdman_open - open file
 -------------------------------------------------*/
 
 static struct chd_interface_file *chdman_open(const char *filename, const char *mode)
@@ -1767,7 +1928,7 @@ static struct chd_interface_file *chdman_open(const char *filename, const char *
 
 
 /*-------------------------------------------------
-	chdman_close - close file
+    chdman_close - close file
 -------------------------------------------------*/
 
 static void chdman_close(struct chd_interface_file *file)
@@ -1786,7 +1947,7 @@ static void chdman_close(struct chd_interface_file *file)
 
 
 /*-------------------------------------------------
-	chdman_read - read from an offset
+    chdman_read - read from an offset
 -------------------------------------------------*/
 
 static UINT32 chdman_read(struct chd_interface_file *file, UINT64 offset, UINT32 count, void *buffer)
@@ -1871,7 +2032,7 @@ static UINT32 chdman_read(struct chd_interface_file *file, UINT64 offset, UINT32
 
 
 /*-------------------------------------------------
-	chdman_write - write to an offset
+    chdman_write - write to an offset
 -------------------------------------------------*/
 
 static UINT32 chdman_write(struct chd_interface_file *file, UINT64 offset, UINT32 count, const void *buffer)
@@ -1910,7 +2071,7 @@ static UINT32 chdman_write(struct chd_interface_file *file, UINT64 offset, UINT3
 
 
 /*-------------------------------------------------
-	chdman_length - return the current EOF
+    chdman_length - return the current EOF
 -------------------------------------------------*/
 
 static UINT64 chdman_length(struct chd_interface_file *file)
@@ -1949,7 +2110,7 @@ static UINT64 chdman_length(struct chd_interface_file *file)
 
 
 /*-------------------------------------------------
-	main - entry point
+    main - entry point
 -------------------------------------------------*/
 
 int main(int argc, char **argv)
@@ -1957,10 +2118,6 @@ int main(int argc, char **argv)
 	extern char build_version[];
 	printf("chdman - MAME Compressed Hunks of Data (CHD) manager %s\n", build_version);
 
-#if defined(__MWERKS__) && macintosh
-	argc = ccommand(& argv);
-#endif
-
 	/* require at least 1 argument */
 	if (argc < 2)
 		error();
@@ -1979,6 +2136,8 @@ int main(int argc, char **argv)
 		do_createcd(argc, argv);
 	else if (!stricmp(argv[1], "-extract"))
 		do_extract(argc, argv);
+	else if (!stricmp(argv[1], "-extractcd"))
+		do_extractcd(argc, argv);
 	else if (!stricmp(argv[1], "-verify"))
 		do_verify(argc, argv, 0);
 	else if (!stricmp(argv[1], "-verifyfix"))
