@@ -1,8 +1,8 @@
 /*********************************************************************
 
-	common.h
+    common.h
 
-	Generic functions, mostly ROM related.
+    Generic functions, mostly ROM related.
 
 *********************************************************************/
 
@@ -18,7 +18,7 @@ extern "C" {
 
 /***************************************************************************
 
-	Type definitions
+    Type definitions
 
 ***************************************************************************/
 
@@ -50,15 +50,6 @@ struct RomModule
 };
 
 
-struct GameSample
-{
-	int length;
-	int smpfreq;
-	int resolution;
-	signed char data[1];	/* extendable */
-};
-
-
 struct SystemBios
 {
 	int value;			/* value of mask to apply to ROM_BIOSFLAGS is chosen */
@@ -85,17 +76,10 @@ struct rom_load_data
 };
 
 
-struct GameSamples
-{
-	int total;	/* total number of samples */
-	struct GameSample *sample[1];	/* extendable */
-};
-
-
 
 /***************************************************************************
 
-	Constants and macros
+    Constants and macros
 
 ***************************************************************************/
 
@@ -143,7 +127,7 @@ enum
 
 /***************************************************************************
 
-	Core macros for the ROM loading system
+    Core macros for the ROM loading system
 
 ***************************************************************************/
 
@@ -301,7 +285,7 @@ enum
 
 /***************************************************************************
 
-	Derived macros for the ROM loading system
+    Derived macros for the ROM loading system
 
 ***************************************************************************/
 
@@ -315,6 +299,8 @@ enum
 #define ROM_REGION16_BE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_16BIT | ROMREGION_BE)
 #define ROM_REGION32_LE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_32BIT | ROMREGION_LE)
 #define ROM_REGION32_BE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_32BIT | ROMREGION_BE)
+#define ROM_REGION64_LE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_64BIT | ROMREGION_LE)
+#define ROM_REGION64_BE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_64BIT | ROMREGION_BE)
 
 /* ----- core ROM loading macros ----- */
 #define ROMMD5_LOAD(name,offset,length,hash,flags)   { name, offset, length, flags, hash },
@@ -359,7 +345,7 @@ enum
 
 /***************************************************************************
 
-	Derived macros for the alternate BIOS loading system
+    Derived macros for the alternate BIOS loading system
 
 ***************************************************************************/
 
@@ -376,7 +362,7 @@ enum
 
 /***************************************************************************
 
-	Global variables
+    Global variables
 
 ***************************************************************************/
 
@@ -389,16 +375,12 @@ extern unsigned int coinlockedout[COIN_COUNTERS];
 
 /***************************************************************************
 
-	Function prototypes
+    Function prototypes
 
 ***************************************************************************/
 
 void showdisclaimer(void);
 
-/* helper function that reads samples from disk - this can be used by other */
-/* drivers as well (e.g. a sound chip emulator needing drum samples) */
-struct GameSamples *readsamples(const char **samplenames,const char *name);
-
 /* return a pointer to the specified memory region - num can be either an absolute */
 /* number, or one of the REGION_XXX identifiers defined above */
 UINT8 *memory_region(int num);
@@ -472,7 +454,7 @@ void printromlist(const struct RomModule *romp,const char *name);
 
 /***************************************************************************
 
-	Useful macros to deal with bit shuffling encryptions
+    Useful macros to deal with bit shuffling encryptions
 
 ***************************************************************************/
 
@@ -532,6 +514,40 @@ void printromlist(const struct RomModule *romp,const char *name);
 		 (BIT(val, B1) <<  1) | \
 		 (BIT(val, B0) <<  0))
 
+#define BITSWAP32(val,B31,B30,B29,B28,B27,B26,B25,B24,B23,B22,B21,B20,B19,B18,B17,B16,B15,B14,B13,B12,B11,B10,B9,B8,B7,B6,B5,B4,B3,B2,B1,B0) \
+		((BIT(val,B31) << 31) | \
+		 (BIT(val,B30) << 30) | \
+		 (BIT(val,B29) << 29) | \
+		 (BIT(val,B28) << 28) | \
+		 (BIT(val,B27) << 27) | \
+		 (BIT(val,B26) << 26) | \
+		 (BIT(val,B25) << 25) | \
+		 (BIT(val,B24) << 24) | \
+		 (BIT(val,B23) << 23) | \
+		 (BIT(val,B22) << 22) | \
+		 (BIT(val,B21) << 21) | \
+		 (BIT(val,B20) << 20) | \
+		 (BIT(val,B19) << 19) | \
+		 (BIT(val,B18) << 18) | \
+		 (BIT(val,B17) << 17) | \
+		 (BIT(val,B16) << 16) | \
+		 (BIT(val,B15) << 15) | \
+		 (BIT(val,B14) << 14) | \
+		 (BIT(val,B13) << 13) | \
+		 (BIT(val,B12) << 12) | \
+		 (BIT(val,B11) << 11) | \
+		 (BIT(val,B10) << 10) | \
+		 (BIT(val, B9) <<  9) | \
+		 (BIT(val, B8) <<  8) | \
+		 (BIT(val, B7) <<  7) | \
+		 (BIT(val, B6) <<  6) | \
+		 (BIT(val, B5) <<  5) | \
+		 (BIT(val, B4) <<  4) | \
+		 (BIT(val, B3) <<  3) | \
+		 (BIT(val, B2) <<  2) | \
+		 (BIT(val, B1) <<  1) | \
+		 (BIT(val, B0) <<  0))
+
 
 #ifdef __cplusplus
 }
