@@ -20,60 +20,60 @@ author (Karl Stenerud) at karl@higashiyama-unet.ocn.ne.jp.
 /*
 
 Changes:
-	0.93 (2003-07-05):
-			Angelo Salese <lordkale@libero.it>
-			- Fixed the BCD conversion when using the Decimal Flag in ADC and SBC.
-			- Removed the two conversion tables for ADC and SBC as they aren't
-			  needed anymore.
+    0.93 (2003-07-05):
+            Angelo Salese <lordkale@libero.it>
+            - Fixed the BCD conversion when using the Decimal Flag in ADC and SBC.
+            - Removed the two conversion tables for ADC and SBC as they aren't
+              needed anymore.
 
-	0.92 (2000-05-28):
-			Lee Hammerton <lee-hammerton@hammerhead.ltd.uk>
-			- Fixed debugger bug that caused D to be misrepresented.
-			- Fixed MVN and MVP (they were reversed)
+    0.92 (2000-05-28):
+            Lee Hammerton <lee-hammerton@hammerhead.ltd.uk>
+            - Fixed debugger bug that caused D to be misrepresented.
+            - Fixed MVN and MVP (they were reversed)
 
-	0.91 (2000-05-22):
-			Lee Hammerton <lee-hammerton@hammerhead.ltd.uk>
-			- Fixed reset vector fetch to be little endian
-			- Fixed disassembler call bug
-			- Fixed C flag in SBC (should be inverted before operation)
-			- Fixed JSR to stack PC-1 and RTS to pull PC and add 1
+    0.91 (2000-05-22):
+            Lee Hammerton <lee-hammerton@hammerhead.ltd.uk>
+            - Fixed reset vector fetch to be little endian
+            - Fixed disassembler call bug
+            - Fixed C flag in SBC (should be inverted before operation)
+            - Fixed JSR to stack PC-1 and RTS to pull PC and add 1
 
-			Karl Stenerud <karl@higashiyama-unet.ocn.ne.jp>
-			- Added correct timing for absolute indexed operations
-			- SBC: fixed corruption of interim values
+            Karl Stenerud <karl@higashiyama-unet.ocn.ne.jp>
+            - Added correct timing for absolute indexed operations
+            - SBC: fixed corruption of interim values
 
-	0.90 (2000-05-17):
-			Karl Stenerud <karl@higashiyama-unet.ocn.ne.jp>
-			- first public release
+    0.90 (2000-05-17):
+            Karl Stenerud <karl@higashiyama-unet.ocn.ne.jp>
+            - first public release
 
 
 Note on timings:
-	- For instructions that write to memory (ASL, ASR, LSL, ROL, ROR, DEC,
-	  INC, STA, STZ), the absolute indexed addressing mode takes 1 extra
-	  cycle to complete.
-	- The spec says fc (JMP axi) is 6 cyles, but elsewhere says 8 cycles
-	  (which is what it should be)
+    - For instructions that write to memory (ASL, ASR, LSL, ROL, ROR, DEC,
+      INC, STA, STZ), the absolute indexed addressing mode takes 1 extra
+      cycle to complete.
+    - The spec says fc (JMP axi) is 6 cyles, but elsewhere says 8 cycles
+      (which is what it should be)
 
 
 TODO general:
-	- WAI will not stop if RDY is held high.
+    - WAI will not stop if RDY is held high.
 
-	- RDY internally held low when WAI executed and returned to hi when RES,
-	  ABORT, NMI, or IRQ asserted.
+    - RDY internally held low when WAI executed and returned to hi when RES,
+      ABORT, NMI, or IRQ asserted.
 
-	- ABORT will terminate WAI instruction but wil not restart the processor
+    - ABORT will terminate WAI instruction but wil not restart the processor
 
-	- If interrupt occurs after ABORT of WAI, processor returns to WAI
-	  instruction.
+    - If interrupt occurs after ABORT of WAI, processor returns to WAI
+      instruction.
 
-	- Add one cycle when indexing across page boundary and E=1 except for STA
-	  and STZ instructions.
+    - Add one cycle when indexing across page boundary and E=1 except for STA
+      and STZ instructions.
 
-	- Add 1 cycle if branch is taken. In Emulation (E= 1 ) mode only --add 1
-	  cycle if the branch is taken and crosses a page boundary.
+    - Add 1 cycle if branch is taken. In Emulation (E= 1 ) mode only --add 1
+      cycle if the branch is taken and crosses a page boundary.
 
-	- Add 1 cycle in Emulation mode (E=1) for (dir),y; abs,x; and abs,y
-	  addressing modes.
+    - Add 1 cycle in Emulation mode (E=1) for (dir),y; abs,x; and abs,y
+      addressing modes.
 
 */
 /* ======================================================================== */
@@ -187,7 +187,7 @@ int (*g65816i_execute[5])(int cycles) =
 /* ======================================================================== */
 
 
-void g65816_reset(void* param)
+static void g65816_reset(void* param)
 {
 		/* Start the CPU */
 		CPU_STOPPED = 0;
@@ -230,33 +230,27 @@ void g65816_reset(void* param)
 }
 
 /* Exit and clean up */
-void g65816_exit(void)
+static void g65816_exit(void)
 {
 	/* nothing to do yet */
 }
 
 /* Execute some instructions */
-int g65816_execute(int cycles)
+static int g65816_execute(int cycles)
 {
 	return FTABLE_EXECUTE(cycles);
 }
 
 
 /* Get the current CPU context */
-unsigned g65816_get_context(void *dst_context)
+static void g65816_get_context(void *dst_context)
 {
 	if(dst_context)
 		*(g65816i_cpu_struct*)dst_context = g65816i_cpu;
-	return sizeof(g65816i_cpu);
-}
-
-static void mame_g65816_get_context(void *dst_context)
-{
-	g65816_get_context(dst_context);
 }
 
 /* Set the current CPU context */
-void g65816_set_context(void *src_context)
+static void g65816_set_context(void *src_context)
 {
 	if(src_context)
 	{
@@ -266,32 +260,33 @@ void g65816_set_context(void *src_context)
 }
 
 /* Get the current Program Counter */
-unsigned g65816_get_pc(void)
+static unsigned g65816_get_pc(void)
 {
-	return REGISTER_PC;
+	return REGISTER_PB | REGISTER_PC;
 }
 
 /* Set the Program Counter */
-void g65816_set_pc(unsigned val)
+static void g65816_set_pc(unsigned val)
 {
 	REGISTER_PC = MAKE_UINT_16(val);
+	REGISTER_PB = (val >> 16) & 0xFF;
 	g65816_jumping(REGISTER_PB | REGISTER_PC);
 }
 
 /* Get the current Stack Pointer */
-unsigned g65816_get_sp(void)
+static unsigned g65816_get_sp(void)
 {
 	return REGISTER_S;
 }
 
 /* Set the Stack Pointer */
-void g65816_set_sp(unsigned val)
+static void g65816_set_sp(unsigned val)
 {
 	REGISTER_S = FLAG_E ? MAKE_UINT_8(val) | 0x100 : MAKE_UINT_16(val);
 }
 
 /* Get a register */
-unsigned g65816_get_reg(int regnum)
+static unsigned g65816_get_reg(int regnum)
 {
 	/* Set the function tables to emulation mode if the FTABLE is NULL */
 	if( FTABLE_GET_REG == NULL )
@@ -301,35 +296,19 @@ unsigned g65816_get_reg(int regnum)
 }
 
 /* Set a register */
-void g65816_set_reg(int regnum, unsigned value)
+static void g65816_set_reg(int regnum, unsigned value)
 {
 	FTABLE_SET_REG(regnum, value);
 }
 
-/* Load a CPU state */
-void g65816_state_load(void *file)
-{
-}
-
-/* Save the current CPU state */
-void g65816_state_save(void *file)
-{
-}
-
-/* Set the non-maskable interrupt line */
-void g65816_set_nmi_line(int state)
-{
-	FTABLE_SET_LINE(G65816_LINE_NMI, state);
-}
-
 /* Set an interrupt line */
-void g65816_set_irq_line(int line, int state)
+static void g65816_set_irq_line(int line, int state)
 {
 	FTABLE_SET_LINE(line, state);
 }
 
 /* Set the callback that is called when servicing an interrupt */
-void g65816_set_irq_callback(int (*callback)(int))
+static void g65816_set_irq_callback(int (*callback)(int))
 {
 	INT_ACK = callback;
 }
@@ -339,18 +318,18 @@ void g65816_set_irq_callback(int (*callback)(int))
 #ifdef MAME_DEBUG
 #include "g65816ds.h"
 #endif
-unsigned g65816_dasm(char *buffer, unsigned pc)
+static unsigned g65816_dasm(char *buffer, unsigned pc)
 {
 #ifdef MAME_DEBUG
-	return g65816_disassemble(buffer, (pc&0xffff), REGISTER_PB>>16, FLAG_M, FLAG_X);
+	return g65816_disassemble(buffer, (pc & 0x00ffff), (pc & 0xff0000) >> 16, FLAG_M, FLAG_X);
 #else
-	sprintf(buffer, "$%02X", g65816_read_8_immediate(REGISTER_PB | (pc&0xffff)));
+	sprintf(buffer, "$%02X", g65816_read_8_immediate((pc & 0xff0000) | (pc & 0x00ffff)));
 	return 1;
 #endif
 }
 
 
-void g65816_init(void){ return; }
+static void g65816_init(void){ return; }
 
 
 /**************************************************************************
@@ -387,6 +366,7 @@ static void g65816_set_info(UINT32 state, union cpuinfo *info)
 
 		/* --- the following bits of info are set as pointers to data or functions --- */
 		case CPUINFO_PTR_IRQ_CALLBACK:					g65816_set_irq_callback(info->irqcallback); break;
+		case CPUINFO_PTR_G65816_READVECTOR_CALLBACK:	READ_VECTOR = (read8_handler) info->f;		break;
 	}
 }
 
@@ -410,7 +390,7 @@ void g65816_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_MAX_INSTRUCTION_BYTES:			info->i = 3;							break;
 		case CPUINFO_INT_MIN_CYCLES:					info->i = 1;							break;
 		case CPUINFO_INT_MAX_CYCLES:					info->i = 20; /* rough guess */			break;
-		
+
 		case CPUINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:	info->i = 8;					break;
 		case CPUINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM: info->i = 24;					break;
 		case CPUINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_PROGRAM: info->i = 0;					break;
@@ -433,7 +413,7 @@ void g65816_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_PC:							info->i = g65816_get_pc();				break;
 		case CPUINFO_INT_SP:							info->i = g65816_get_sp();				break;
 
-		case CPUINFO_INT_REGISTER + G65816_PC:			info->i = g65816_get_reg(G65816_PC);	break;
+		case CPUINFO_INT_REGISTER + G65816_PC:			info->i = g65816_get_pc();	break;
 		case CPUINFO_INT_REGISTER + G65816_S:			info->i = g65816_get_reg(G65816_S);		break;
 		case CPUINFO_INT_REGISTER + G65816_P:			info->i = g65816_get_reg(G65816_P);		break;
 		case CPUINFO_INT_REGISTER + G65816_A:			info->i = g65816_get_reg(G65816_A);		break;
@@ -448,7 +428,7 @@ void g65816_get_info(UINT32 state, union cpuinfo *info)
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
 		case CPUINFO_PTR_SET_INFO:						info->setinfo = g65816_set_info;		break;
-		case CPUINFO_PTR_GET_CONTEXT:					info->getcontext = mame_g65816_get_context;	break;
+		case CPUINFO_PTR_GET_CONTEXT:					info->getcontext = g65816_get_context;	break;
 		case CPUINFO_PTR_SET_CONTEXT:					info->setcontext = g65816_set_context;	break;
 		case CPUINFO_PTR_INIT:							info->init = g65816_init;				break;
 		case CPUINFO_PTR_RESET:							info->reset = g65816_reset;				break;
@@ -460,6 +440,7 @@ void g65816_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &g65816_ICount;			break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = g65816i_register_layout;		break;
 		case CPUINFO_PTR_WINDOW_LAYOUT:					info->p = g65816i_window_layout;		break;
+		case CPUINFO_PTR_G65816_READVECTOR_CALLBACK:	info->f = (genf *) READ_VECTOR;			break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
 		case CPUINFO_STR_NAME:							strcpy(info->s = cpuintrf_temp_str(), "G65C816"); break;
@@ -480,7 +461,7 @@ void g65816_get_info(UINT32 state, union cpuinfo *info)
 				g65816i_cpu.flag_c & CFLAG_SET ? 'C':'.');
 			break;
 
-		case CPUINFO_STR_REGISTER + G65816_PC:			sprintf(info->s = cpuintrf_temp_str(), "PC:%04X", g65816i_cpu.pc); break;
+		case CPUINFO_STR_REGISTER + G65816_PC:			sprintf(info->s = cpuintrf_temp_str(), "PC:%06X", g65816_get_pc()); break;
 		case CPUINFO_STR_REGISTER + G65816_PB:			sprintf(info->s = cpuintrf_temp_str(), "PB:%02X", g65816i_cpu.pb>>16); break;
 		case CPUINFO_STR_REGISTER + G65816_DB:			sprintf(info->s = cpuintrf_temp_str(), "DB:%02X", g65816i_cpu.db>>16); break;
 		case CPUINFO_STR_REGISTER + G65816_D:			sprintf(info->s = cpuintrf_temp_str(), "D:%04X", g65816i_cpu.d); break;
