@@ -78,6 +78,14 @@ INLINE uint g65816i_read_8_direct(uint address)
 	return g65816_read_8(address);
 }
 
+INLINE uint g65816i_read_8_vector(uint address)
+{
+	if (READ_VECTOR)
+		return READ_VECTOR(address);
+	else
+		return g65816i_read_8_normal(address);
+}
+
 INLINE void g65816i_write_8_normal(uint address, uint value)
 {
 	address = ADDRESS_65816(address);
@@ -113,6 +121,12 @@ INLINE uint g65816i_read_16_direct(uint address)
 			(g65816i_read_8_direct(address+1)<<8);
 }
 
+INLINE uint g65816i_read_16_vector(uint address)
+{
+	return	 g65816i_read_8_vector(address) |
+			(g65816i_read_8_vector(address+1)<<8);
+}
+
 INLINE void g65816i_write_16_normal(uint address, uint value)
 {
 	g65816i_write_8_normal(address, value&0xff);
@@ -314,7 +328,7 @@ INLINE void g65816i_set_flag_i(uint value)
 		return;
 	}
 	FLAG_I = value;
-/*	g65816i_check_maskable_interrupt(); */
+/*  g65816i_check_maskable_interrupt(); */
 }
 
 
@@ -367,7 +381,7 @@ INLINE void g65816i_interrupt_hardware(uint vector)
 	FLAG_D = DFLAG_CLEAR;
 	g65816i_set_flag_i(IFLAG_SET);
 	REGISTER_PB = 0;
-	g65816i_jump_16(g65816i_read_16_normal(vector));
+	g65816i_jump_16(g65816i_read_16_vector(vector));
 	if(INT_ACK) INT_ACK(0);
 #else
 	CLK(8);
@@ -377,7 +391,7 @@ INLINE void g65816i_interrupt_hardware(uint vector)
 	FLAG_D = DFLAG_CLEAR;
 	g65816i_set_flag_i(IFLAG_SET);
 	REGISTER_PB = 0;
-	g65816i_jump_16(g65816i_read_16_normal(vector));
+	g65816i_jump_16(g65816i_read_16_vector(vector));
 	if(INT_ACK) INT_ACK(0);
 #endif
 }
@@ -624,7 +638,7 @@ INLINE uint EA_DIY(void)   {uint tmp = REGISTER_DB | OPER_16_D(); if((tmp^(tmp+R
 INLINE uint EA_DLIY(void)  {return OPER_24_D() + REGISTER_Y;}
 INLINE uint EA_AXI(void)   {return read_16_AXI(MAKE_UINT_16(OPER_16_IMM() + REGISTER_X));}
 INLINE uint EA_S(void)     {return MAKE_UINT_16(REGISTER_S + OPER_8_IMM());}
-INLINE uint EA_SIY(void)   {return EA_S() + REGISTER_DB + REGISTER_Y;}
+INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REGISTER_S + OPER_8_IMM()) + REGISTER_Y) | REGISTER_DB;}
 
 
 
@@ -2117,7 +2131,7 @@ TABLE_FUNCTION(void, set_line, (int line, int state))
 					CPU_STOPPED &= ~STOP_LEVEL_WAI;
 				return;
 			}
-/*			g65816i_interrupt_hardware(VECTOR_IRQ); */
+/*          g65816i_interrupt_hardware(VECTOR_IRQ); */
 			return;
 		case G65816_LINE_NMI:
 			if(state == CLEAR_LINE)
@@ -2195,11 +2209,34 @@ TABLE_FUNCTION(void, set_reg, (int regnum, uint val))
 		case G65816_X: REGISTER_X = MAKE_UINT_16(val); break;
 		case G65816_Y: REGISTER_Y = MAKE_UINT_16(val); break;
 #endif
+		case G65816_DB: REGISTER_DB = MAKE_UINT_8(val); break;
+		case G65816_PB: REGISTER_PB = MAKE_UINT_8(val); break;
 		case G65816_NMI_STATE: FTABLE_SET_LINE(G65816_LINE_NMI, val == 0 ? CLEAR_LINE : ASSERT_LINE); break;
 		case G65816_IRQ_STATE: FTABLE_SET_LINE(G65816_LINE_IRQ, val == 0 ? CLEAR_LINE : ASSERT_LINE); break;
 	 }
 }
 
+
+
+INLINE int g65816i_correct_mode(void)
+{
+#if EXECUTION_MODE == EXECUTION_MODE_E
+	return (FLAG_E == EFLAG_SET);
+#elif EXECUTION_MODE == EXECUTION_MODE_M0X0
+	return (FLAG_E == EFLAG_CLEAR) && (FLAG_M == MFLAG_CLEAR) && (FLAG_X == XFLAG_CLEAR);
+#elif EXECUTION_MODE == EXECUTION_MODE_M0X1
+	return (FLAG_E == EFLAG_CLEAR) && (FLAG_M == MFLAG_CLEAR) && (FLAG_X == XFLAG_SET);
+#elif EXECUTION_MODE == EXECUTION_MODE_M1X0
+	return (FLAG_E == EFLAG_CLEAR) && (FLAG_M == MFLAG_SET) && (FLAG_X == XFLAG_CLEAR);
+#elif EXECUTION_MODE == EXECUTION_MODE_M1X1
+	return (FLAG_E == EFLAG_CLEAR) && (FLAG_M == MFLAG_SET) && (FLAG_X == XFLAG_SET);
+#else
+#error Invalid EXECUTION_MODE
+#endif
+}
+
+
+
 TABLE_FUNCTION(int, execute, (int clocks))
 {
 	if(!CPU_STOPPED)
@@ -2207,17 +2244,18 @@ TABLE_FUNCTION(int, execute, (int clocks))
 		CLOCKS = clocks;
 		do
 		{
+			/* Note that I'm doing a per-instruction interrupt
+             * check until this core is working well enough
+             * to start trying fancy stuff.
+             */
+			g65816i_check_maskable_interrupt();
+
 			REGISTER_PPC = REGISTER_PC;
 			G65816_CALL_DEBUGGER;
 			REGISTER_PC++;
 			REGISTER_IR = read_8_IMM(REGISTER_PB | REGISTER_PPC);
 			FTABLE_OPCODES[REGISTER_IR]();
-			/* Note that I'm doing a per-instruction interrupt
-			 * check until this core is working well enough
-			 * to start trying fancy stuff.
-			 */
-			g65816i_check_maskable_interrupt();
-		} while(CLOCKS > 0);
+		} while((CLOCKS > 0) && g65816i_correct_mode());
 		return clocks - CLOCKS;
 	}
 	return clocks;
