@@ -1,6 +1,6 @@
 /****************************************************************************
-*			  real mode i286 emulator v1.4 by Fabrice Frances				*
-*				(initial work based on David Hedley's pcemu)                *
+*             real mode i286 emulator v1.4 by Fabrice Frances               *
+*               (initial work based on David Hedley's pcemu)                *
 ****************************************************************************/
 /* 26.March 2000 PeT changed set_irq_line */
 
@@ -64,6 +64,7 @@ typedef struct
 	UINT8 int_vector;
 	INT8 nmi_state;
 	INT8 irq_state;
+	INT8 test_state;	/* PJB 03/05 */
 	int extra_cycles;       /* extra cycles for interrupts */
 }
 i86_Regs;
@@ -85,7 +86,7 @@ static UINT8 parity_table[256];
 
 static struct i86_timing cycles;
 
-/* The interrupt number of a pending external interrupt pending NMI is 2.	*/
+/* The interrupt number of a pending external interrupt pending NMI is 2.   */
 /* For INTR interrupts, the level is caught on the bus during an INTA cycle */
 
 #define PREFIX(name) i86##name
@@ -125,6 +126,7 @@ static void i86_state_register(void)
 	state_save_register_INT8(  type, cpu, "NMI_STATE",		&I.nmi_state, 1);
 	state_save_register_INT8(  type, cpu, "IRQ_STATE",		&I.irq_state, 1);
 	state_save_register_int(   type, cpu, "EXTRA_CYCLES",	&I.extra_cycles);
+	state_save_register_INT8(  type, cpu, "TEST_STATE",		&I.test_state, 1);	/* PJB 03/05 */
 }
 
 static void i86_init(void)
@@ -215,6 +217,12 @@ static void set_irq_line(int irqline, int state)
 	}
 }
 
+/* PJB 03/05 */
+static void set_test_line(int state)
+{
+        I.test_state = !state;
+}
+
 static int i86_execute(int num_cycles)
 {
 	/* copy over the cycle counts if they're not correct */
@@ -372,7 +380,7 @@ static void v30_interrupt(unsigned int_num, BOOLEAN md_flag)
 	if (int_num == -1)
 	{
 		int_num = (*I.irq_callback) (0);
-/*		logerror(" (indirect ->%02d) ",int_num); */
+/*      logerror(" (indirect ->%02d) ",int_num); */
 	}
 
 	dest_off = ReadWord(int_num * 4);
@@ -384,7 +392,7 @@ static void v30_interrupt(unsigned int_num, BOOLEAN md_flag)
 	I.base[CS] = SegBase(CS);
 	I.pc = (I.base[CS] + dest_off) & AMASK;
 	change_pc(I.pc);
-/*	logerror("=%06x\n",activecpu_get_pc()); */
+/*  logerror("=%06x\n",activecpu_get_pc()); */
 }
 
 static void v30_trap(void)
@@ -462,6 +470,7 @@ static void i86_set_info(UINT32 state, union cpuinfo *info)
 		/* --- the following bits of info are set as 64-bit signed integers --- */
 		case CPUINFO_INT_INPUT_STATE + 0:				set_irq_line(0, info->i);				break;
 		case CPUINFO_INT_INPUT_STATE + INPUT_LINE_NMI:	set_irq_line(INPUT_LINE_NMI, info->i);	break;
+		case CPUINFO_INT_INPUT_STATE + INPUT_LINE_TEST:	set_test_line(info->i);	break; /* PJB 03/05 */
 
 		case CPUINFO_INT_PC:
 		case CPUINFO_INT_REGISTER + I86_PC:
@@ -499,7 +508,7 @@ static void i86_set_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_REGISTER + I86_SS:				I.sregs[SS] = info->i;	I.base[SS] = SegBase(SS); break;
 		case CPUINFO_INT_REGISTER + I86_DS:				I.sregs[DS] = info->i;	I.base[DS] = SegBase(DS); break;
 		case CPUINFO_INT_REGISTER + I86_VECTOR:			I.int_vector = info->i; 				break;
-		
+
 		/* --- the following bits of info are set as pointers to data or functions --- */
 		case CPUINFO_PTR_IRQ_CALLBACK:					I.irq_callback = info->irqcallback;		break;
 	}
@@ -525,7 +534,7 @@ void i86_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_MAX_INSTRUCTION_BYTES:			info->i = 8;							break;
 		case CPUINFO_INT_MIN_CYCLES:					info->i = 1;							break;
 		case CPUINFO_INT_MAX_CYCLES:					info->i = 50;							break;
-		
+
 		case CPUINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:	info->i = 8;					break;
 		case CPUINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM: info->i = 20;					break;
 		case CPUINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_PROGRAM: info->i = 0;					break;
@@ -539,14 +548,16 @@ void i86_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_INT_INPUT_STATE + 0:				info->i = I.irq_state;					break;
 		case CPUINFO_INT_INPUT_STATE + INPUT_LINE_NMI:	info->i = I.nmi_state;					break;
 
+		case CPUINFO_INT_INPUT_STATE + INPUT_LINE_TEST:	info->i = I.test_state;	                                break; /* PJB 03/05 */
+
 		case CPUINFO_INT_PREVIOUSPC:					info->i = I.prevpc;						break;
 
 		case CPUINFO_INT_PC:
 		case CPUINFO_INT_REGISTER + I86_PC:				info->i = I.pc;							break;
-		case CPUINFO_INT_REGISTER + I86_IP:				info->i = I.pc - I.base[CS];			break;		
+		case CPUINFO_INT_REGISTER + I86_IP:				info->i = I.pc - I.base[CS];			break;
 		case CPUINFO_INT_SP:							info->i = I.base[SS] + I.regs.w[SP];	break;
 		case CPUINFO_INT_REGISTER + I86_SP:				info->i = I.regs.w[SP];					break;
-		case CPUINFO_INT_REGISTER + I86_FLAGS: 			CompressFlags(); info->i = I.flags;		break;
+		case CPUINFO_INT_REGISTER + I86_FLAGS: 			I.flags = CompressFlags(); info->i = I.flags;		break;
 		case CPUINFO_INT_REGISTER + I86_AX:				info->i = I.regs.w[AX];					break;
 		case CPUINFO_INT_REGISTER + I86_CX:				info->i = I.regs.w[CX];					break;
 		case CPUINFO_INT_REGISTER + I86_DX:				info->i = I.regs.w[DX];					break;
