@@ -1,8 +1,8 @@
 /***************************************************************************
 
-	cpuintrf.h
+    cpuintrf.h
 
-	Core CPU interface functions and definitions.
+    Core CPU interface functions and definitions.
 
 ***************************************************************************/
 
@@ -20,7 +20,7 @@ extern "C" {
 
 /*************************************
  *
- *	Enum listing all the CPUs
+ *  Enum listing all the CPUs
  *
  *************************************/
 
@@ -127,6 +127,7 @@ enum
 	CPU_RM7000BE,
 	CPU_RM7000LE,
 	CPU_ARM,
+	CPU_ARM7,
 	CPU_SH2,
 	CPU_DSP32C,
 	CPU_PIC16C54,
@@ -156,8 +157,10 @@ enum
 	CPU_V810,
 	CPU_M37710,
 	CPU_PPC403,
+	CPU_PPC602,
 	CPU_PPC603,
 	CPU_SE3208,
+	CPU_MC68HC11,
 
 #ifdef MESS
 	CPU_APEXC,
@@ -181,7 +184,7 @@ enum
 
 /*************************************
  *
- *	Interrupt line constants
+ *  Interrupt line constants
  *
  *************************************/
 
@@ -223,7 +226,7 @@ enum
 
 /*************************************
  *
- *	CPU information constants
+ *  CPU information constants
  *
  *************************************/
 
@@ -332,16 +335,16 @@ union cpuinfo
 enum
 {
 	/* This value is passed to activecpu_get_reg to retrieve the previous
-	 * program counter value, ie. before a CPU emulation started
-	 * to fetch opcodes and arguments for the current instrution. */
+     * program counter value, ie. before a CPU emulation started
+     * to fetch opcodes and arguments for the current instrution. */
 	REG_PREVIOUSPC = CPUINFO_INT_PREVIOUSPC - CPUINFO_INT_REGISTER,
 
 	/* This value is passed to activecpu_get_reg to retrieve the current
-	 * program counter value. */
+     * program counter value. */
 	REG_PC = CPUINFO_INT_PC - CPUINFO_INT_REGISTER,
 
 	/* This value is passed to activecpu_get_reg to retrieve the current
-	 * stack pointer value. */
+     * stack pointer value. */
 	REG_SP = CPUINFO_INT_SP - CPUINFO_INT_REGISTER
 };
 
@@ -367,7 +370,7 @@ enum
 
 /*************************************
  *
- *	Core CPU interface structure
+ *  Core CPU interface structure
  *
  *************************************/
 
@@ -395,7 +398,7 @@ struct cpu_interface
 
 /*************************************
  *
- *	 Core CPU interface functions
+ *   Core CPU interface functions
  *
  *************************************/
 
@@ -424,7 +427,7 @@ void cpuintrf_set_dasm_override(offs_t (*dasm_override)(int cpunum, char *buffer
 
 /*************************************
  *
- *	 Active CPU acccessors
+ *   Active CPU acccessors
  *
  *************************************/
 
@@ -500,7 +503,7 @@ const char *activecpu_dump_state(void);
 
 /*************************************
  *
- *	 Specific CPU acccessors
+ *   Specific CPU acccessors
  *
  *************************************/
 
@@ -577,7 +580,7 @@ const char *cpunum_dump_state(int cpunum);
 
 /*************************************
  *
- *	 CPU type acccessors
+ *   CPU type acccessors
  *
  *************************************/
 
@@ -614,7 +617,7 @@ const char *cputype_get_info_string(int cputype, UINT32 state);
 
 /*************************************
  *
- *	 Miscellaneous functions
+ *   Miscellaneous functions
  *
  *************************************/
 
@@ -624,7 +627,7 @@ void cpu_dump_states(void);
 
 /*************************************
  *
- *	 Macros
+ *   Macros
  *
  *************************************/
 
@@ -636,7 +639,7 @@ void cpu_dump_states(void);
 
 /*************************************
  *
- *	 CPU interface accessors
+ *   CPU interface accessors
  *
  *************************************/
 
