@@ -1,9 +1,9 @@
 /*###################################################################################################
 **
 **
-**		debugcmd.c
-**		Debugger command interface engine.
-**		Written by Aaron Giles
+**      debugcmd.c
+**      Debugger command interface engine.
+**      Written by Aaron Giles
 **
 **
 **#################################################################################################*/
@@ -21,7 +21,7 @@
 
 
 /*###################################################################################################
-**	DEBUGGING
+**  DEBUGGING
 **#################################################################################################*/
 
 #define DEBUG			0
@@ -29,25 +29,25 @@
 
 
 /*###################################################################################################
-**	CONSTANTS
+**  CONSTANTS
 **#################################################################################################*/
 
 
 
 /*###################################################################################################
-**	TYPE DEFINITIONS
+**  TYPE DEFINITIONS
 **#################################################################################################*/
 
 
 
 /*###################################################################################################
-**	LOCAL VARIABLES
+**  LOCAL VARIABLES
 **#################################################################################################*/
 
 
 
 /*###################################################################################################
-**	PROTOTYPES
+**  PROTOTYPES
 **#################################################################################################*/
 
 static UINT64 execute_min(UINT32 ref, UINT32 params, UINT64 *param);
@@ -83,16 +83,17 @@ static void execute_dasm(int ref, int params, const char **param);
 static void execute_trace(int ref, int params, const char **param);
 static void execute_traceover(int ref, int params, const char **param);
 static void execute_snap(int ref, int params, const char **param);
+static void execute_source(int ref, int params, const char **param);
 
 
 
 /*###################################################################################################
-**	CODE
+**  CODE
 **#################################################################################################*/
 
 /*-------------------------------------------------
-	debug_command_init - initializes the command
-	system
+    debug_command_init - initializes the command
+    system
 -------------------------------------------------*/
 
 void debug_command_init(void)
@@ -157,12 +158,14 @@ void debug_command_init(void)
 	debug_console_register_command("traceover", 0, 1, 3, execute_traceover);
 
 	debug_console_register_command("snap",      0, 0, 1, execute_snap);
+
+	debug_console_register_command("source",	0, 1, 1, execute_source);
 }
 
 
 /*-------------------------------------------------
-	debug_command_exit - frees the command
-	system
+    debug_command_exit - frees the command
+    system
 -------------------------------------------------*/
 
 void debug_command_exit(void)
@@ -172,11 +175,11 @@ void debug_command_exit(void)
 
 
 /*###################################################################################################
-**	SIMPLE GLOBAL FUNCTIONS
+**  SIMPLE GLOBAL FUNCTIONS
 **#################################################################################################*/
 
 /*-------------------------------------------------
-	execute_min - return the minimum of two values
+    execute_min - return the minimum of two values
 -------------------------------------------------*/
 
 static UINT64 execute_min(UINT32 ref, UINT32 params, UINT64 *param)
@@ -186,7 +189,7 @@ static UINT64 execute_min(UINT32 ref, UINT32 params, UINT64 *param)
 
 
 /*-------------------------------------------------
-	execute_max - return the maximum of two values
+    execute_max - return the maximum of two values
 -------------------------------------------------*/
 
 static UINT64 execute_max(UINT32 ref, UINT32 params, UINT64 *param)
@@ -196,7 +199,7 @@ static UINT64 execute_max(UINT32 ref, UINT32 params, UINT64 *param)
 
 
 /*-------------------------------------------------
-	execute_if - if (a) return b; else return c;
+    execute_if - if (a) return b; else return c;
 -------------------------------------------------*/
 
 static UINT64 execute_if(UINT32 ref, UINT32 params, UINT64 *param)
@@ -207,12 +210,12 @@ static UINT64 execute_if(UINT32 ref, UINT32 params, UINT64 *param)
 
 
 /*###################################################################################################
-**	PARAMETER VALIDATION HELPERS
+**  PARAMETER VALIDATION HELPERS
 **#################################################################################################*/
 
 /*-------------------------------------------------
-	validate_parameter_number - validates a
-	number parameter
+    validate_parameter_number - validates a
+    number parameter
 -------------------------------------------------*/
 
 static int validate_parameter_number(const char *param, UINT64 *result)
@@ -228,8 +231,8 @@ static int validate_parameter_number(const char *param, UINT64 *result)
 
 
 /*-------------------------------------------------
-	validate_parameter_expression - validates an
-	expression parameter
+    validate_parameter_expression - validates an
+    expression parameter
 -------------------------------------------------*/
 
 static int validate_parameter_expression(const char *param, struct parsed_expression **result)
@@ -245,8 +248,8 @@ static int validate_parameter_expression(const char *param, struct parsed_expres
 
 
 /*-------------------------------------------------
-	validate_parameter_command - validates a
-	command parameter
+    validate_parameter_command - validates a
+    command parameter
 -------------------------------------------------*/
 
 static int validate_parameter_command(const char *param)
@@ -263,11 +266,11 @@ static int validate_parameter_command(const char *param)
 
 
 /*###################################################################################################
-**	COMMAND HANDLERS
+**  COMMAND HANDLERS
 **#################################################################################################*/
 
 /*-------------------------------------------------
-	execute_help - execute the help command
+    execute_help - execute the help command
 -------------------------------------------------*/
 
 static void execute_help(int ref, int params, const char *param[])
@@ -280,7 +283,7 @@ static void execute_help(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	mini_printf - safe printf to a buffer
+    mini_printf - safe printf to a buffer
 -------------------------------------------------*/
 
 static int mini_printf(char *buffer, const char *format, int params, UINT64 *param)
@@ -293,7 +296,7 @@ static int mini_printf(char *buffer, const char *format, int params, UINT64 *par
 	{
 		char c = *f++;
 		if (!c) break;
-		
+
 		/* escape sequences */
 		if (c == '\\')
 		{
@@ -307,13 +310,13 @@ static int mini_printf(char *buffer, const char *format, int params, UINT64 *par
 			}
 			continue;
 		}
-		
+
 		/* formatting */
 		else if (c == '%')
 		{
 			int width = 0;
 			int zerofill = 0;
-			
+
 			/* parse out the width */
 			for (;;)
 			{
@@ -324,14 +327,14 @@ static int mini_printf(char *buffer, const char *format, int params, UINT64 *par
 				width = width * 10 + (c - '0');
 			}
 			if (!c) break;
-			
+
 			/* get the format */
 			switch (c)
 			{
 				case '%':
 					*p++ = c;
 					break;
-				
+
 				case 'X':
 				case 'x':
 					if (params == 0)
@@ -347,7 +350,7 @@ static int mini_printf(char *buffer, const char *format, int params, UINT64 *par
 					param++;
 					params--;
 					break;
-				
+
 				case 'D':
 				case 'd':
 					if (params == 0)
@@ -361,12 +364,12 @@ static int mini_printf(char *buffer, const char *format, int params, UINT64 *par
 					break;
 			}
 		}
-		
+
 		/* normal stuff */
 		else
 			*p++ = c;
 	}
-	
+
 	/* NULL-terminate and exit */
 	*p = 0;
 	return 1;
@@ -374,7 +377,7 @@ static int mini_printf(char *buffer, const char *format, int params, UINT64 *par
 
 
 /*-------------------------------------------------
-	execute_printf - execute the printf command
+    execute_printf - execute the printf command
 -------------------------------------------------*/
 
 static void execute_printf(int ref, int params, const char *param[])
@@ -382,12 +385,12 @@ static void execute_printf(int ref, int params, const char *param[])
 	UINT64 values[MAX_COMMAND_PARAMS];
 	char buffer[1024];
 	int i;
-	
+
 	/* validate the other parameters */
 	for (i = 1; i < params; i++)
 		if (!validate_parameter_number(param[i], &values[i]))
 			return;
-	
+
 	/* then do a printf */
 	if (mini_printf(buffer, param[0], params - 1, &values[1]))
 		debug_console_write_line(buffer);
@@ -395,7 +398,7 @@ static void execute_printf(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_tracelog - execute the tracelog command
+    execute_tracelog - execute the tracelog command
 -------------------------------------------------*/
 
 static void execute_tracelog(int ref, int params, const char *param[])
@@ -404,16 +407,16 @@ static void execute_tracelog(int ref, int params, const char *param[])
 	UINT64 values[MAX_COMMAND_PARAMS];
 	char buffer[1024];
 	int i;
-	
+
 	/* if no tracefile, skip */
 	if (!file)
 		return;
-	
+
 	/* validate the other parameters */
 	for (i = 1; i < params; i++)
 		if (!validate_parameter_number(param[i], &values[i]))
 			return;
-	
+
 	/* then do a printf */
 	if (mini_printf(buffer, param[0], params - 1, &values[1]))
 		fprintf(file, "%s", buffer);
@@ -421,17 +424,23 @@ static void execute_tracelog(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_quit - execute the quit command
+    execute_quit - execute the quit command
 -------------------------------------------------*/
 
 static void execute_quit(int ref, int params, const char *param[])
 {
+	int cpunum;
+
+	/* turn off all traces */
+	for (cpunum = 0; cpunum < cpu_gettotalcpu(); cpunum++)
+		debug_cpu_trace(cpunum, NULL, 0, NULL);
+
 	osd_die("Exited via the debugger\n");
 }
 
 
 /*-------------------------------------------------
-	execute_do - execute the do command
+    execute_do - execute the do command
 -------------------------------------------------*/
 
 static void execute_do(int ref, int params, const char *param[])
@@ -442,13 +451,13 @@ static void execute_do(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_step - execute the step command
+    execute_step - execute the step command
 -------------------------------------------------*/
 
 static void execute_step(int ref, int params, const char *param[])
 {
 	UINT64 steps = 1;
-	
+
 	/* if we have a parameter, use it instead */
 	if (params > 0 && !validate_parameter_number(param[0], &steps))
 		return;
@@ -458,13 +467,13 @@ static void execute_step(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_over - execute the over command
+    execute_over - execute the over command
 -------------------------------------------------*/
 
 static void execute_over(int ref, int params, const char *param[])
 {
 	UINT64 steps = 1;
-	
+
 	/* if we have a parameter, use it instead */
 	if (params > 0 && !validate_parameter_number(param[0], &steps))
 		return;
@@ -474,7 +483,7 @@ static void execute_over(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_out - execute the out command
+    execute_out - execute the out command
 -------------------------------------------------*/
 
 static void execute_out(int ref, int params, const char *param[])
@@ -484,13 +493,13 @@ static void execute_out(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_go - execute the go command
+    execute_go - execute the go command
 -------------------------------------------------*/
 
 static void execute_go(int ref, int params, const char *param[])
 {
 	UINT64 addr = ~0;
-	
+
 	/* if we have a parameter, use it instead */
 	if (params > 0 && !validate_parameter_number(param[0], &addr))
 		return;
@@ -500,8 +509,8 @@ static void execute_go(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_go_vblank - execute the govblank
-	command
+    execute_go_vblank - execute the govblank
+    command
 -------------------------------------------------*/
 
 static void execute_go_vblank(int ref, int params, const char *param[])
@@ -511,13 +520,13 @@ static void execute_go_vblank(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_go_interrupt - execute the goint command
+    execute_go_interrupt - execute the goint command
 -------------------------------------------------*/
 
 static void execute_go_interrupt(int ref, int params, const char *param[])
 {
 	UINT64 irqline = -1;
-	
+
 	/* if we have a parameter, use it instead */
 	if (params > 0 && !validate_parameter_number(param[0], &irqline))
 		return;
@@ -527,7 +536,7 @@ static void execute_go_interrupt(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_next - execute the next command
+    execute_next - execute the next command
 -------------------------------------------------*/
 
 static void execute_next(int ref, int params, const char *param[])
@@ -537,7 +546,7 @@ static void execute_next(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_focus - execute the focus command
+    execute_focus - execute the focus command
 -------------------------------------------------*/
 
 static void execute_focus(int ref, int params, const char *param[])
@@ -554,7 +563,7 @@ static void execute_focus(int ref, int params, const char *param[])
 		return;
 	}
 
-	/* first clear the ignore flag on the focused CPU */		
+	/* first clear the ignore flag on the focused CPU */
 	debug_cpu_ignore_cpu(cpuwhich, 0);
 
 	/* then loop over CPUs and set the ignore flags on all other CPUs */
@@ -569,7 +578,7 @@ static void execute_focus(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_ignore - execute the ignore command
+    execute_ignore - execute the ignore command
 -------------------------------------------------*/
 
 static void execute_ignore(int ref, int params, const char *param[])
@@ -586,7 +595,7 @@ static void execute_ignore(int ref, int params, const char *param[])
 		for (cpunum = 0; cpunum < MAX_CPU; cpunum++)
 		{
 			const struct debug_cpu_info *info = debug_get_cpu_info(cpunum);
-			
+
 			/* build up a comma-separated list */
 			if (info && info->valid && info->ignoring)
 			{
@@ -594,13 +603,13 @@ static void execute_ignore(int ref, int params, const char *param[])
 				else buflen += sprintf(&buffer[buflen], ",%d", cpunum);
 			}
 		}
-		
+
 		/* special message for none */
 		if (buflen == 0)
 			sprintf(&buffer[buflen], "Not currently ignoring any CPUs");
 		debug_console_write_line(buffer);
 	}
-	
+
 	/* otherwise clear the ignore flag on all requested CPUs */
 	else
 	{
@@ -631,7 +640,7 @@ static void execute_ignore(int ref, int params, const char *param[])
 				debug_console_printf("Can't ignore all CPUs!\n");
 				return;
 			}
-			
+
 			debug_cpu_ignore_cpu(cpuwhich[paramnum], 1);
 			debug_console_printf("Now ignoring CPU %d", (int)cpuwhich[paramnum]);
 		}
@@ -640,7 +649,7 @@ static void execute_ignore(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_observe - execute the observe command
+    execute_observe - execute the observe command
 -------------------------------------------------*/
 
 static void execute_observe(int ref, int params, const char *param[])
@@ -657,7 +666,7 @@ static void execute_observe(int ref, int params, const char *param[])
 		for (cpunum = 0; cpunum < MAX_CPU; cpunum++)
 		{
 			const struct debug_cpu_info *info = debug_get_cpu_info(cpunum);
-			
+
 			/* build up a comma-separated list */
 			if (info && info->valid && !info->ignoring)
 			{
@@ -665,13 +674,13 @@ static void execute_observe(int ref, int params, const char *param[])
 				else buflen += sprintf(&buffer[buflen], ",%d", cpunum);
 			}
 		}
-		
+
 		/* special message for none */
 		if (buflen == 0)
 			buflen += sprintf(&buffer[buflen], "Not currently observing any CPUs");
 		debug_console_write_line(buffer);
 	}
-	
+
 	/* otherwise set the ignore flag on all requested CPUs */
 	else
 	{
@@ -698,8 +707,8 @@ static void execute_observe(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_bpset - execute the breakpoint set
-	command
+    execute_bpset - execute the breakpoint set
+    command
 -------------------------------------------------*/
 
 static void execute_bpset(int ref, int params, const char *param[])
@@ -712,7 +721,7 @@ static void execute_bpset(int ref, int params, const char *param[])
 	/* param 1 is the address */
 	if (!validate_parameter_number(param[0], &address))
 		return;
-	
+
 	/* param 2 is the condition */
 	if (params > 1 && !validate_parameter_expression(param[1], &condition))
 		return;
@@ -728,19 +737,19 @@ static void execute_bpset(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_bpclear - execute the breakpoint
-	clear command
+    execute_bpclear - execute the breakpoint
+    clear command
 -------------------------------------------------*/
 
 static void execute_bpclear(int ref, int params, const char *param[])
 {
 	UINT64 bpindex;
-	
+
 	/* if 0 parameters, clear all */
 	if (params == 0)
 	{
 		int cpunum;
-		
+
 		for (cpunum = 0; cpunum < MAX_CPU; cpunum++)
 		{
 			const struct debug_cpu_info *cpuinfo = debug_get_cpu_info(cpunum);
@@ -753,7 +762,7 @@ static void execute_bpclear(int ref, int params, const char *param[])
 		}
 		debug_console_write_line("Cleared all breakpoints");
 	}
-	
+
 	/* otherwise, clear the specific one */
 	else if (!validate_parameter_number(param[0], &bpindex))
 		return;
@@ -769,19 +778,19 @@ static void execute_bpclear(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_bpdisenable - execute the breakpoint
-	disable/enable commands
+    execute_bpdisenable - execute the breakpoint
+    disable/enable commands
 -------------------------------------------------*/
 
 static void execute_bpdisenable(int ref, int params, const char *param[])
 {
 	UINT64 bpindex;
-	
+
 	/* if 0 parameters, clear all */
 	if (params == 0)
 	{
 		int cpunum;
-		
+
 		for (cpunum = 0; cpunum < MAX_CPU; cpunum++)
 		{
 			const struct debug_cpu_info *cpuinfo = debug_get_cpu_info(cpunum);
@@ -797,7 +806,7 @@ static void execute_bpdisenable(int ref, int params, const char *param[])
 		else
 			debug_console_write_line("Enabled all breakpoints");
 	}
-	
+
 	/* otherwise, clear the specific one */
 	else if (!validate_parameter_number(param[0], &bpindex))
 		return;
@@ -813,26 +822,26 @@ static void execute_bpdisenable(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_bplist - execute the breakpoint list
-	command
+    execute_bplist - execute the breakpoint list
+    command
 -------------------------------------------------*/
 
 static void execute_bplist(int ref, int params, const char *param[])
 {
 	int cpunum, printed = 0;
 	char buffer[256];
-	
+
 	/* loop over all CPUs */
 	for (cpunum = 0; cpunum < MAX_CPU; cpunum++)
 	{
 		const struct debug_cpu_info *cpuinfo = debug_get_cpu_info(cpunum);
-		
+
 		if (cpuinfo->valid && cpuinfo->first_bp)
 		{
 			struct breakpoint *bp;
-			
+
 			debug_console_printf("CPU %d breakpoints:", cpunum);
-			
+
 			/* loop over the breakpoints */
 			for (bp = cpuinfo->first_bp; bp; bp = bp->next)
 			{
@@ -847,15 +856,15 @@ static void execute_bplist(int ref, int params, const char *param[])
 			}
 		}
 	}
-	
+
 	if (!printed)
 		debug_console_write_line("No breakpoints currently installed");
 }
 
 
 /*-------------------------------------------------
-	execute_wpset - execute the watchpoint set
-	command
+    execute_wpset - execute the watchpoint set
+    command
 -------------------------------------------------*/
 
 static void execute_wpset(int ref, int params, const char *param[])
@@ -869,11 +878,11 @@ static void execute_wpset(int ref, int params, const char *param[])
 	/* param 1 is the address */
 	if (!validate_parameter_number(param[0], &address))
 		return;
-	
+
 	/* param 2 is the length */
 	if (!validate_parameter_number(param[1], &length))
 		return;
-	
+
 	/* param 3 is the type */
 	if (!strcmp(param[2], "r"))
 		type = WATCHPOINT_READ;
@@ -886,7 +895,7 @@ static void execute_wpset(int ref, int params, const char *param[])
 		debug_console_printf("Invalid watchpoint type: expected r, w, or rw\n");
 		return;
 	}
-	
+
 	/* param 4 is the condition */
 	if (params > 3 && !validate_parameter_expression(param[3], &condition))
 		return;
@@ -902,14 +911,14 @@ static void execute_wpset(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_wpclear - execute the watchpoint
-	clear command
+    execute_wpclear - execute the watchpoint
+    clear command
 -------------------------------------------------*/
 
 static void execute_wpclear(int ref, int params, const char *param[])
 {
 	UINT64 wpindex;
-	
+
 	/* if 0 parameters, clear all */
 	if (params == 0)
 	{
@@ -921,7 +930,7 @@ static void execute_wpclear(int ref, int params, const char *param[])
 			if (cpuinfo->valid)
 			{
 				int spacenum;
-				
+
 				for (spacenum = 0; spacenum < ADDRESS_SPACES; spacenum++)
 				{
 					struct watchpoint *wp;
@@ -932,7 +941,7 @@ static void execute_wpclear(int ref, int params, const char *param[])
 		}
 		debug_console_write_line("Cleared all watchpoints");
 	}
-	
+
 	/* otherwise, clear the specific one */
 	else if (!validate_parameter_number(param[0], &wpindex))
 		return;
@@ -948,26 +957,26 @@ static void execute_wpclear(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_wpdisenable - execute the watchpoint
-	disable/enable commands
+    execute_wpdisenable - execute the watchpoint
+    disable/enable commands
 -------------------------------------------------*/
 
 static void execute_wpdisenable(int ref, int params, const char *param[])
 {
 	UINT64 wpindex;
-	
+
 	/* if 0 parameters, clear all */
 	if (params == 0)
 	{
 		int cpunum;
-		
+
 		for (cpunum = 0; cpunum < MAX_CPU; cpunum++)
 		{
 			const struct debug_cpu_info *cpuinfo = debug_get_cpu_info(cpunum);
 			if (cpuinfo->valid)
 			{
 				int spacenum;
-				
+
 				for (spacenum = 0; spacenum < ADDRESS_SPACES; spacenum++)
 				{
 					struct watchpoint *wp;
@@ -981,7 +990,7 @@ static void execute_wpdisenable(int ref, int params, const char *param[])
 		else
 			debug_console_write_line("Enabled all watchpoints");
 	}
-	
+
 	/* otherwise, clear the specific one */
 	else if (!validate_parameter_number(param[0], &wpindex))
 		return;
@@ -997,8 +1006,8 @@ static void execute_wpdisenable(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_wplist - execute the watchpoint list
-	command
+    execute_wplist - execute the watchpoint list
+    command
 -------------------------------------------------*/
 
 static void execute_wplist(int ref, int params, const char *param[])
@@ -1006,25 +1015,25 @@ static void execute_wplist(int ref, int params, const char *param[])
 	static const char *spacenames[ADDRESS_SPACES] = { "program", "data", "I/O" };
 	int cpunum, printed = 0;
 	char buffer[256];
-	
+
 	/* loop over all CPUs */
 	for (cpunum = 0; cpunum < MAX_CPU; cpunum++)
 	{
 		const struct debug_cpu_info *cpuinfo = debug_get_cpu_info(cpunum);
-		
+
 		if (cpuinfo->valid)
 		{
 			int spacenum;
-			
+
 			for (spacenum = 0; spacenum < ADDRESS_SPACES; spacenum++)
 			{
 				if (cpuinfo->space[spacenum].first_wp)
 				{
 					static const char *types[] = { "unkn ", "read ", "write", "r/w  " };
 					struct watchpoint *wp;
-					
+
 					debug_console_printf("CPU %d %s space watchpoints:", cpunum, spacenames[spacenum]);
-					
+
 					/* loop over the watchpoints */
 					for (wp = cpuinfo->space[spacenum].first_wp; wp; wp = wp->next)
 					{
@@ -1041,14 +1050,14 @@ static void execute_wplist(int ref, int params, const char *param[])
 			}
 		}
 	}
-	
+
 	if (!printed)
 		debug_console_write_line("No watchpoints currently installed");
 }
 
 
 /*-------------------------------------------------
-	execute_save - execute the save command
+    execute_save - execute the save command
 -------------------------------------------------*/
 
 static void execute_save(int ref, int params, const char *param[])
@@ -1057,7 +1066,7 @@ static void execute_save(int ref, int params, const char *param[])
 	const struct debug_cpu_info *info;
 	int spacenum = ref;
 	FILE *f;
-	int i;
+	UINT64 i;
 
 	/* validate parameters */
 	if (!validate_parameter_number(param[1], &offset))
@@ -1071,7 +1080,7 @@ static void execute_save(int ref, int params, const char *param[])
 	info = debug_get_cpu_info(cpunum);
 	offset = ADDR2BYTE(offset, info, spacenum);
 	endoffset = ADDR2BYTE(offset + length - 1, info, spacenum);
-	
+
 	/* open the file */
 	f = fopen(param[0], "wb");
 	if (!f)
@@ -1079,7 +1088,7 @@ static void execute_save(int ref, int params, const char *param[])
 		debug_console_printf("Error opening file '%s'", param[0]);
 		return;
 	}
-	
+
 	/* now write the data out */
 	cpuintrf_push_context(cpunum);
 	for (i = offset; i <= endoffset; i++)
@@ -1088,7 +1097,7 @@ static void execute_save(int ref, int params, const char *param[])
 		fwrite(&byte, 1, 1, f);
 	}
 	cpuintrf_pop_context();
-	
+
 	/* close the file */
 	fclose(f);
 	debug_console_write_line("Data saved successfully");
@@ -1096,7 +1105,7 @@ static void execute_save(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_dump - execute the dump command
+    execute_dump - execute the dump command
 -------------------------------------------------*/
 
 static void execute_dump(int ref, int params, const char *param[])
@@ -1105,7 +1114,7 @@ static void execute_dump(int ref, int params, const char *param[])
 	const struct debug_cpu_info *info;
 	int spacenum = ref;
 	FILE *f = NULL;
-	int i, j;
+	UINT64 i, j;
 
 	/* validate parameters */
 	if (!validate_parameter_number(param[1], &offset))
@@ -1118,7 +1127,7 @@ static void execute_dump(int ref, int params, const char *param[])
 		return;
 	if (params > 5 && !validate_parameter_number(param[5], &cpunum))
 		return;
-	
+
 	/* further validation */
 	if (cpunum >= cpu_gettotalcpu())
 	{
@@ -1145,17 +1154,17 @@ static void execute_dump(int ref, int params, const char *param[])
 		debug_console_printf("Error opening file '%s'", param[0]);
 		return;
 	}
-	
+
 	/* now write the data out */
 	cpuintrf_push_context(cpunum);
 	for (i = offset; i <= endoffset; i += 16)
 	{
 		char output[200];
 		int outdex = 0;
-		
+
 		/* print the address */
 		outdex += sprintf(&output[outdex], "%0*X: ", info->space[spacenum].addrchars, (UINT32)BYTE2ADDR(i, info, spacenum));
-		
+
 		/* print the bytes */
 		switch (width)
 		{
@@ -1203,7 +1212,7 @@ static void execute_dump(int ref, int params, const char *param[])
 				}
 				break;
 		}
-		
+
 		/* print the ASCII */
 		if (ascii)
 		{
@@ -1214,12 +1223,12 @@ static void execute_dump(int ref, int params, const char *param[])
 				outdex += sprintf(&output[outdex], "%c", (byte >= 32 && byte < 128) ? byte : '.');
 			}
 		}
-		
+
 		/* output the result */
 		fprintf(f, "%s\n", output);
 	}
 	cpuintrf_pop_context();
-	
+
 	/* close the file */
 	fclose(f);
 	debug_console_write_line("Data dumped successfully");
@@ -1227,7 +1236,7 @@ static void execute_dump(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_dasm - execute the dasm command
+    execute_dasm - execute the dasm command
 -------------------------------------------------*/
 
 static void execute_dasm(int ref, int params, const char *param[])
@@ -1247,7 +1256,7 @@ static void execute_dasm(int ref, int params, const char *param[])
 		return;
 	if (params > 4 && !validate_parameter_number(param[4], &cpunum))
 		return;
-	
+
 	/* further validation */
 	if (cpunum >= cpu_gettotalcpu())
 	{
@@ -1273,7 +1282,7 @@ static void execute_dasm(int ref, int params, const char *param[])
 		debug_console_printf("Error opening file '%s'", param[0]);
 		return;
 	}
-	
+
 	/* now write the data out */
 	cpuintrf_push_context(cpunum);
 	for (i = 0; i < length; )
@@ -1282,12 +1291,12 @@ static void execute_dasm(int ref, int params, const char *param[])
 		char output[200], disasm[200];
 		int outdex = 0;
 		int numbytes;
-		
+
 		/* print the address */
 		outdex += sprintf(&output[outdex], "%0*X: ", info->space[ADDRESS_SPACE_PROGRAM].addrchars, (UINT32)BYTE2ADDR(pcbyte, info, ADDRESS_SPACE_PROGRAM));
 
 		/* get the disassembly up front, but only if mapped */
-		if (memory_get_read_ptr(cpunum, ADDRESS_SPACE_PROGRAM, pcbyte) != NULL)
+		if (memory_get_op_ptr(cpunum, pcbyte) != NULL)
 		{
 			memory_set_opbase(pcbyte);
 			i += numbytes = activecpu_dasm(disasm, offset + i) & DASMFLAG_LENGTHMASK;
@@ -1309,17 +1318,17 @@ static void execute_dasm(int ref, int params, const char *param[])
 					for (j = 0; j < numbytes; j++)
 						outdex += sprintf(&output[outdex], "%02X ", (UINT32)debug_read_opcode(pcbyte + j, 1));
 					break;
-				
+
 				case 2:
 					for (j = 0; j < numbytes; j += 2)
 						outdex += sprintf(&output[outdex], "%04X ", (UINT32)debug_read_opcode(pcbyte + j, 2));
 					break;
-				
+
 				case 4:
 					for (j = 0; j < numbytes; j += 4)
 						outdex += sprintf(&output[outdex], "%08X ", (UINT32)debug_read_opcode(pcbyte + j, 4));
 					break;
-				
+
 				case 8:
 					for (j = 0; j < numbytes; j += 8)
 					{
@@ -1332,15 +1341,15 @@ static void execute_dasm(int ref, int params, const char *param[])
 				outdex += sprintf(&output[outdex], "%*s", byteswidth - (outdex - startdex), "");
 			outdex += sprintf(&output[outdex], "  ");
 		}
-		
+
 		/* add the disassembly */
 		sprintf(&output[outdex], "%s", disasm);
-		
+
 		/* output the result */
 		fprintf(f, "%s\n", output);
 	}
 	cpuintrf_pop_context();
-	
+
 	/* close the file */
 	fclose(f);
 	debug_console_write_line("Data dumped successfully");
@@ -1348,8 +1357,8 @@ static void execute_dasm(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_trace_internal - functionality for
-	trace over and trace info
+    execute_trace_internal - functionality for
+    trace over and trace info
 -------------------------------------------------*/
 
 static void execute_trace_internal(int ref, int params, const char *param[], int trace_over)
@@ -1365,7 +1374,7 @@ static void execute_trace_internal(int ref, int params, const char *param[], int
 		return;
 	if (params > 2 && !validate_parameter_command(action = param[2]))
 		return;
-	
+
 	/* further validation */
 	if (!stricmp(filename, "off"))
 		filename = NULL;
@@ -1396,7 +1405,7 @@ static void execute_trace_internal(int ref, int params, const char *param[], int
 
 
 /*-------------------------------------------------
-	execute_trace - execute the trace command
+    execute_trace - execute the trace command
 -------------------------------------------------*/
 
 static void execute_trace(int ref, int params, const char *param[])
@@ -1406,7 +1415,7 @@ static void execute_trace(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_traceover - execute the trace over command
+    execute_traceover - execute the trace over command
 -------------------------------------------------*/
 
 static void execute_traceover(int ref, int params, const char *param[])
@@ -1416,7 +1425,7 @@ static void execute_traceover(int ref, int params, const char *param[])
 
 
 /*-------------------------------------------------
-	execute_snap - execute the trace over command
+    execute_snap - execute the trace over command
 -------------------------------------------------*/
 
 static void execute_snap(int ref, int params, const char *param[])
@@ -1427,7 +1436,7 @@ static void execute_snap(int ref, int params, const char *param[])
 		save_screen_snapshot(artwork_get_ui_bitmap());
 		debug_console_printf("Saved snapshot\n");
 	}
-	
+
 	/* otherwise, we have to open the file ourselves */
 	else
 	{
@@ -1444,4 +1453,19 @@ static void execute_snap(int ref, int params, const char *param[])
 }
 
 
+/*-------------------------------------------------
+    execute_source - execute the source command
+-------------------------------------------------*/
+
+static void execute_source(int ref, int params, const char *param[])
+{
+	if (debug_source_file)
+		fclose(debug_source_file);
+
+	debug_source_file = fopen(param[0], "r");
+	if (!debug_source_file)
+		debug_console_printf("Cannot open command file '%s'\n", param[0]);
+}
+
+
 
