@@ -26,7 +26,7 @@ c800      command for the audio CPU
 c802-c803 background scroll
 c804      bit 7: flip screen
           bit 4: cpu B reset
-		  bit 0: coin counter
+          bit 0: coin counter
 c805      background palette bank selector
 c806      bit 0-1 ROM bank selector 00=1-N5.BIN
                                     01=1-N6.BIN
@@ -60,6 +60,7 @@ correctly.
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
 
 
 extern UINT8 *c1942_fgvideoram;
@@ -254,19 +255,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct AY8910interface ay8910_interface =
-{
-	2,	/* 2 chips */
-	1500000,	/* 1.5 MHz ? */
-	{ 25, 25 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
-
 static MACHINE_DRIVER_START( 1942 )
 
 	/* basic machine hardware */
@@ -275,7 +263,7 @@ static MACHINE_DRIVER_START( 1942 )
 	MDRV_CPU_VBLANK_INT(c1942_interrupt,2)
 
 	MDRV_CPU_ADD(Z80, 3000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 3 MHz ??? */
+	/* audio CPU */	/* 3 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_map, 0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
 
@@ -295,7 +283,12 @@ static MACHINE_DRIVER_START( 1942 )
 	MDRV_VIDEO_UPDATE(1942)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
