@@ -1,28 +1,29 @@
 /***************************************************************************
 
-	1943: The Battle of Midway
-	Capcom
+    1943: The Battle of Midway
+    Capcom
 
-	driver by Paul Leaman
+    driver by Paul Leaman
+
+    Games supported:
+        * 1943: The Battle of Midway (US)
+        * 1943: Midway Kaisen (Japan)
+        * 1943 Kai: Midway Kaisen (Japan)
 
-	Games supported:
-		* 1943: The Battle of Midway (US)
-		* 1943: Midway Kaisen (Japan)
-		* 1943 Kai: Midway Kaisen (Japan)
-		
 ***************************************************************************/
 
 /*
 
-	TODO:
-	
-	- use priority PROM for drawing sprites
+    TODO:
+
+    - use priority PROM for drawing sprites
 
 */
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/2203intf.h"
 
 extern UINT8 *c1943_scrollx;
 extern UINT8 *c1943_scrolly;
@@ -41,13 +42,13 @@ extern VIDEO_UPDATE( 1943 );
 
 static READ8_HANDLER( c1943_protection_r )
 {
-	/* 
-		This is a protection check. The game crashes (thru a jump to 0x8000)
-	    if a read from this address doesn't return the value it expects. 
-	*/
+	/*
+        This is a protection check. The game crashes (thru a jump to 0x8000)
+        if a read from this address doesn't return the value it expects.
+    */
 
 	int data = activecpu_get_reg(Z80_BC) >> 8;
-/*	logerror("protection read, PC: %04x Result:%02x\n",activecpu_get_pc(),data); */
+/*  logerror("protection read, PC: %04x Result:%02x\n",activecpu_get_pc(),data); */
 	return data;
 }
 
@@ -247,19 +248,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 	{ -1 }
 };
 
-/* Sound Interfaces */
-
-static struct YM2203interface ym2203_interface =
-{
-	2,			/* 2 chips */
-	1500000,	/* 1.5 MHz */
-	{ YM2203_VOL(10,15), YM2203_VOL(10,15) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 /* Machine Driver */
 
 static MACHINE_DRIVER_START( 1943 )
@@ -269,7 +257,7 @@ static MACHINE_DRIVER_START( 1943 )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
 
 	MDRV_CPU_ADD(Z80, 3000000)	/* 3 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_map, 0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 4)
 
@@ -289,7 +277,19 @@ static MACHINE_DRIVER_START( 1943 )
 	MDRV_VIDEO_UPDATE(1943)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("ym2203", YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.10)
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.10)
 MACHINE_DRIVER_END
 
 /* ROMs */
