@@ -54,6 +54,7 @@ JALCF1   BIN     1,048,576  02-07-99  1:11a JALCF1.BIN
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/okim6295.h"
 
 static struct tilemap *tx_tilemap,*bg_tilemap;
 data16_t *ac_txvram,*ac_bgvram;
@@ -99,7 +100,7 @@ static void draw_sprites(struct mame_bitmap *bitmap, const struct rectangle *cli
 			int w = (spriteram16[offs+0] & 0x0f);
 			int h = ((spriteram16[offs+0] & 0xf0) >> 4);
 			/*Unlike NMK16,the given Y offset is where the sprite must end instead
-			of where it starts.*/
+            of where it starts.*/
 			int sy = (spriteram16[offs+4] & 0x0ff) - ((h+1)*0x10);
 /**/		int pri = spriteram16[offs+5];
 /**/		int flipy = ((spriteram16[offs+1] & 0x0200) >> 9);
@@ -168,6 +169,7 @@ VIDEO_START( acommand )
 #define LED_ON		0x01c00
 #define SHOW_LEDS	0
 
+#if SHOW_LEDS
 static void draw_led(struct mame_bitmap *bitmap, int x, int y,data8_t value)
 {
 	plot_box(bitmap, x, y, 5, 9, 0x00000000);
@@ -215,7 +217,7 @@ static void draw_led(struct mame_bitmap *bitmap, int x, int y,data8_t value)
 		plot_pixel(bitmap, x+4, y+7, LED_ON);
 	}
 }
-
+#endif
 static UINT16 led0;
 
 VIDEO_UPDATE( acommand )
@@ -284,56 +286,56 @@ data16_t *ac_devram;
 
 static READ16_HANDLER(ac_devices_r)
 {
-/*	usrintf_showmessage("(PC=%06x) read at %04x",activecpu_get_pc(),offset*2); */
+/*  usrintf_showmessage("(PC=%06x) read at %04x",activecpu_get_pc(),offset*2); */
 	switch(offset)
 	{
 		case 0x0008/2:
 			/*
-				--x- ---- ---- ---- Ticket Dispenser - 2
-				---x ---- ---- ---- Ticket Dispenser - 1
-				---- -x-- ---- ---- Right Gun HIT
-				---- ---x ---- ---- Left Gun HIT
-				---- ---- --x- ---- Service Mode (Toggle)
-				---- ---- ---x ---- Service Coin
-				---- ---- ---- x--- COIN2
-				---- ---- ---- -x-- COIN1
-				---- ---- ---- --x- (Activate Test)
-				---- ---- ---- ---x (Advance Thru Tests)
-			*/
+                --x- ---- ---- ---- Ticket Dispenser - 2
+                ---x ---- ---- ---- Ticket Dispenser - 1
+                ---- -x-- ---- ---- Right Gun HIT
+                ---- ---x ---- ---- Left Gun HIT
+                ---- ---- --x- ---- Service Mode (Toggle)
+                ---- ---- ---x ---- Service Coin
+                ---- ---- ---- x--- COIN2
+                ---- ---- ---- -x-- COIN1
+                ---- ---- ---- --x- (Activate Test)
+                ---- ---- ---- ---x (Advance Thru Tests)
+            */
 			return input_port_0_word_r(0,0);
 		case 0x0014/2:
 			/*
-				write 0x40,read (~0x08)
-				write 0x08,read (~0x01)
+                write 0x40,read (~0x08)
+                write 0x08,read (~0x01)
 
-				---- ---- ---- ---x Boss Door - limit switch
-			*/
+                ---- ---- ---- ---x Boss Door - limit switch
+            */
 			return (ac_devram[offset]);
 		case 0x0016/2:
 			return OKIM6295_status_0_r(0);
 		case 0x0018/2:
 			/*
-				---- ---- ---- x--- Astronaut - switch
-			*/
+                ---- ---- ---- x--- Astronaut - switch
+            */
 			return ac_devram[offset];
 		case 0x001a/2:
 			return OKIM6295_status_1_r(0);
 		case 0x0040/2:
 			/*
-				x-x- x-x- x-x- xx-- (ACTIVE HIGH?) [eori #$aaac, D0]
-				---- ---- ---- --xx Boss Door - Motor
-			*/
+                x-x- x-x- x-x- xx-- (ACTIVE HIGH?) [eori #$aaac, D0]
+                ---- ---- ---- --xx Boss Door - Motor
+            */
 			return ac_devram[offset];
 		case 0x0044/2:
 			/*
-				xxxx xxxx x-x- x-x- (ACTIVE HIGH?) [eori #$ffaa, D0]
-			*/
+                xxxx xxxx x-x- x-x- (ACTIVE HIGH?) [eori #$ffaa, D0]
+            */
 			return ac_devram[offset];
 		case 0x005c/2:
 			/*
-				xxxx xxxx ---- ---- DIPSW4
-				---- ---- xxxx xxxx DIPSW3
-			*/
+                xxxx xxxx ---- ---- DIPSW4
+                ---- ---- xxxx xxxx DIPSW3
+            */
 			return input_port_1_word_r(0,0);
 	}
 	return ac_devram[offset];
@@ -527,14 +529,6 @@ static struct GfxDecodeInfo acommand_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static struct OKIM6295interface m6295_interface =
-{
-	2,              	/* 2 chips? */
-	{ 2400000/165 , 2400000/165 },	/* unknown */
-	{ REGION_SOUND1, REGION_SOUND2 },	/* memory region */
-	{ 100,100 }				/* volume */
-};
-
 static INTERRUPT_GEN( acommand_irq )
 {
 	if (cpu_getiloops() == 0)
@@ -564,7 +558,15 @@ static MACHINE_DRIVER_START( acommand )
 	MDRV_VIDEO_UPDATE(acommand)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, m6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, 2400000/165)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(OKIM6295, 2400000/165)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /***************************************************************************
