@@ -7,24 +7,24 @@ driver by Zsolt Vasvari
 
 Memory Mapped:
 
-0000-7fff   R	ROM
-8000-87ff	R/W	RAM
-a000		R	Watchdog Reset
-c080-c09f	W	Scroll RAM (1 byte for each column)
-c100-c1ff	W   Color RAM (1 line corresponds to 4 in the video ram)
+0000-7fff   R   ROM
+8000-87ff   R/W RAM
+a000        R   Watchdog Reset
+c080-c09f   W   Scroll RAM (1 byte for each column)
+c100-c1ff   W   Color RAM (1 line corresponds to 4 in the video ram)
 c200-c3ff   W   Sprite RAM
 c400-c7ff   W   Video RAM
-c800		R   DIP Switches
+c800        R   DIP Switches
 cc00-cc03   W   ??? (Maybe analog sound triggers?)
-cc04		W   Flip Screen
-cc05		W   Color Bank Select
-cc07		W   Coin Counter
+cc04        W   Flip Screen
+cc05        W   Color Bank Select
+cc07        W   Coin Counter
 
 
 I/O Ports:
 
-00-01		R/W AY8910 #0 (Port A = Input Port #0)
-80-81		R/W AY8910 #1 (Port A = Input Port #1)
+00-01       R/W AY8910 #0 (Port A = Input Port #0)
+80-81       R/W AY8910 #1 (Port A = Input Port #1)
 
 
 TODO:
@@ -35,6 +35,7 @@ TODO:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
 
 
 extern unsigned char *ambush_scrollram;
@@ -77,11 +78,13 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(AY8910_read_port_0_r)
 	AM_RANGE(0x80, 0x80) AM_READ(AY8910_read_port_1_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x80, 0x80) AM_WRITE(AY8910_control_port_1_w)
@@ -169,15 +172,14 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct AY8910interface ay8910_interface =
+static struct AY8910interface ay8910_interface_1 =
 {
-	2,	/* 2 chips */
-	1500000,	/* 1.5 MHz ? */
-	{ 25, 25 },
-	{ input_port_0_r, input_port_1_r },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 }
+	input_port_0_r
+};
+
+static struct AY8910interface ay8910_interface_2 =
+{
+	input_port_1_r
 };
 
 
@@ -204,7 +206,15 @@ static MACHINE_DRIVER_START( ambush )
 	MDRV_VIDEO_UPDATE(ambush)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_CONFIG(ay8910_interface_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_CONFIG(ay8910_interface_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -253,5 +263,25 @@ ROM_START( ambusht )
 	ROM_LOAD( "14.bpr",		  0x0300, 0x0100, CRC(622a8ce7) SHA1(6834f67874251f2ef3a33aec893311f5d10e496f) )  /* They don't look like color PROMs */
 ROM_END
 
+ROM_START( ambushv )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )       /* 64k for code */
+	ROM_LOAD( "n1_h7.bin",    0x0000, 0x2000, CRC(3c0833b4) SHA1(dd0cfb6da281742114abfe652d38038b078b959e) )
+	ROM_LOAD( "ambush.g7",    0x2000, 0x2000, CRC(90291409) SHA1(82f1e109bd066ad9fdea1ce0086be6c334e2658a) )
+	ROM_LOAD( "ambush.f7",    0x4000, 0x2000, CRC(d023ca29) SHA1(1ac44960cf6d79936517a9ad4bae6ccd825c9496) )
+	ROM_LOAD( "ambush.e7",    0x6000, 0x2000, CRC(6cc2d3ee) SHA1(dccb417d156460ca745d7b62f1df733cbf85d092) )
+
+	ROM_REGION( 0x4000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "ambush.n4",    0x0000, 0x2000, CRC(ecc0dc85) SHA1(577304bb575293b97b50eea4faafb5394e3da0f5) )
+	ROM_LOAD( "ambush.m4",    0x2000, 0x2000, CRC(e86ca98a) SHA1(fae0786bb78ead81653adddd2edb3058371ca5bc) )
+
+	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_LOAD( "a.bpr",        0x0000, 0x0100, CRC(5f27f511) SHA1(fe3ae701443ff50d3d03c0a5d0e0ab0e716b05cc) )  /* color PROMs */
+
+	ROM_LOAD( "b.bpr",        0x0100, 0x0100, CRC(1b03fd3b) SHA1(1a58b212476cacace6065056f23b59a69053a2f6) )	/* How is this selected, */
+	ROM_LOAD( "13.bpr",		  0x0200, 0x0100, CRC(547e970f) SHA1(e2ec0bece49fb283e43549703d6d5d6f561c69a6) )  /* I'm not sure what these do. */
+	ROM_LOAD( "14.bpr",		  0x0300, 0x0100, CRC(622a8ce7) SHA1(6834f67874251f2ef3a33aec893311f5d10e496f) )  /* They don't look like color PROMs */
+ROM_END
+
 GAME( 1983, ambush, 0,      ambush, ambush, 0, ROT0, "Nippon Amuse Co-Ltd", "Ambush" )
 GAME( 1983, ambusht,ambush, ambush, ambush, 0, ROT0, "Tecfri", "Ambush (Tecfri)" )
+GAME( 1983, ambushv,ambush, ambush, ambush, 0, ROT0, "Volt Elec co-ltd", "Ambush (Volt Elec co-ltd)" )
