@@ -103,9 +103,9 @@ PORT_START_TAG("IN0") \
 
 INPUT_PORTS_START( amidar )
 	AMIDAR_IN0
-	
+
 	AMIDAR_IN1
-	
+
 
 	PORT_START_TAG("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_4WAY PORT_COCKTAIL
@@ -198,7 +198,7 @@ AMIDAR_IN0
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	
+
 AMIDAR_DSW
 INPUT_PORTS_END
 
@@ -302,7 +302,7 @@ static MACHINE_DRIVER_START( amidar )
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
 
 	MDRV_CPU_ADD(Z80,14318000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 1.78975 MHz */
+	/* audio CPU */	/* 1.78975 MHz */
 	MDRV_CPU_PROGRAM_MAP(scobra_sound_readmem,scobra_sound_writemem)
 	MDRV_CPU_IO_MAP(scobra_sound_readport,scobra_sound_writeport)
 
@@ -315,7 +315,12 @@ static MACHINE_DRIVER_START( amidar )
 	MDRV_VIDEO_START(turtles)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, scobra_ay8910_interface)
+	MDRV_SOUND_ADD(AY8910, 14318000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.16)
+
+	MDRV_SOUND_ADD(AY8910, 14318000/8)
+	MDRV_SOUND_CONFIG(scobra_ay8910_interface_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.16)
 MACHINE_DRIVER_END
 
 
