@@ -84,21 +84,21 @@ X090-PC-A 171-5383
 X090-PC-B 171-5384
 
 
-CPU	:D317-0005 (NEC Z80 Custom)
-Sound	:NEC D780C-1
-	:YM2203C x 2
-OSC	:4.000MHz 6.000MHz
-	:18.432MHz
+CPU :D317-0005 (NEC Z80 Custom)
+Sound   :NEC D780C-1
+    :YM2203C x 2
+OSC :4.000MHz 6.000MHz
+    :18.432MHz
 
 
-EPR10120.C1	prg
-EPR10121.C2	 |
-EPR10122.C3	 |
-EPR10123.C4	 |
-EPR10124.C5	 |
-EPR10125.C10	/
+EPR10120.C1 prg
+EPR10121.C2  |
+EPR10122.C3  |
+EPR10123.C4  |
+EPR10124.C5  |
+EPR10125.C10    /
 
-EPR10126.D4	snd
+EPR10126.D4 snd
 
 EPR10127.06
 EPR10128.07
@@ -130,6 +130,7 @@ Dumped by Chackn
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "machine/segacrpt.h"
+#include "sound/2203intf.h"
 
 static READ8_HANDLER( angelkds_sound_r );
 static WRITE8_HANDLER( angelkds_sound_w );
@@ -234,6 +235,7 @@ static ADDRESS_MAP_START( writemem_main, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport_main, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x40, 0x40) AM_READ(input_port_0_r)	/* "Coinage" Dip Switches */
 	AM_RANGE(0x41, 0x41) AM_READ(input_port_1_r)	/* Other Dip Switches */
 	AM_RANGE(0x42, 0x42) AM_READ(input_port_2_r)	/* Players inputs (not needed ?) */
@@ -242,6 +244,7 @@ static ADDRESS_MAP_START( readport_main, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport_main, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(MWA8_NOP) /* 00 on start-up, not again */
 	AM_RANGE(0x42, 0x42) AM_WRITE(angelkds_cpu_bank_write)
 	AM_RANGE(0x43, 0x43) AM_WRITE(MWA8_NOP) /* 9a on start-up, not again */
@@ -265,12 +268,14 @@ static ADDRESS_MAP_START( writemem_sub, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport_sub, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(YM2203_status_port_0_r)
 	AM_RANGE(0x40, 0x40) AM_READ(YM2203_status_port_1_r)
 	AM_RANGE(0x80, 0x83) AM_READ(angelkds_sound_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport_sub, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM2203_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM2203_write_port_0_w)
 	AM_RANGE(0x40, 0x40) AM_WRITE(YM2203_control_port_1_w)
@@ -321,13 +326,13 @@ INPUT_PORTS_START( angelkds )
 	PORT_DIPSETTING(	0x70, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(	0x80, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(	0x90, DEF_STR( 2C_1C ) )
-/*	PORT_DIPSETTING(	0x60, DEF_STR( 2C_1C ) ) */
-/*	PORT_DIPSETTING(	0x50, DEF_STR( 2C_1C ) ) */
-/*	PORT_DIPSETTING(	0x40, DEF_STR( 2C_1C ) ) */
+/*  PORT_DIPSETTING(    0x60, DEF_STR( 2C_1C ) ) */
+/*  PORT_DIPSETTING(    0x50, DEF_STR( 2C_1C ) ) */
+/*  PORT_DIPSETTING(    0x40, DEF_STR( 2C_1C ) ) */
 	PORT_DIPSETTING(	0xf0, DEF_STR( 1C_1C ) )
-/*	PORT_DIPSETTING(	0x30, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x20, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x10, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x30, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x20, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x10, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(	0xe0, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(	0xd0, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(	0xc0, DEF_STR( 1C_4C ) )
@@ -339,13 +344,13 @@ INPUT_PORTS_START( angelkds )
 	PORT_DIPSETTING(	0x07, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(	0x08, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(	0x09, DEF_STR( 2C_1C ) )
-/*	PORT_DIPSETTING(	0x06, DEF_STR( 2C_1C ) ) */
-/*	PORT_DIPSETTING(	0x05, DEF_STR( 2C_1C ) ) */
-/*	PORT_DIPSETTING(	0x04, DEF_STR( 2C_1C ) ) */
+/*  PORT_DIPSETTING(    0x06, DEF_STR( 2C_1C ) ) */
+/*  PORT_DIPSETTING(    0x05, DEF_STR( 2C_1C ) ) */
+/*  PORT_DIPSETTING(    0x04, DEF_STR( 2C_1C ) ) */
 	PORT_DIPSETTING(	0x0f, DEF_STR( 1C_1C ) )
-/*	PORT_DIPSETTING(	0x03, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x02, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x01, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(	0x0e, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(	0x0d, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(	0x0c, DEF_STR( 1C_4C ) )
@@ -448,14 +453,11 @@ static void irqhandler(int irq)
 
 static struct YM2203interface ym2203_interface =
 {
-	2,                      /* 2 chips */
-	4000000,        /* 4 MHz ? */
-	{ YM2203_VOL(15,25), YM2203_VOL(15,25) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
+	0,
+	0,
+	0,
+	0,
+	irqhandler
 };
 
 /*** Graphics Decoding
@@ -511,7 +513,7 @@ static MACHINE_DRIVER_START( angelkds )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000) /* 8 MHz? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sub,writemem_sub)
 	MDRV_CPU_IO_MAP(readport_sub,writeport_sub)
 
@@ -529,7 +531,20 @@ static MACHINE_DRIVER_START( angelkds )
 	MDRV_VIDEO_START(angelkds)
 	MDRV_VIDEO_UPDATE(angelkds)
 
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.25)
+	MDRV_SOUND_ROUTE(1, "mono", 0.25)
+	MDRV_SOUND_ROUTE(2, "mono", 0.25)
+	MDRV_SOUND_ROUTE(3, "mono", 0.15)
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.25)
+	MDRV_SOUND_ROUTE(1, "mono", 0.25)
+	MDRV_SOUND_ROUTE(2, "mono", 0.25)
+	MDRV_SOUND_ROUTE(3, "mono", 0.15)
 MACHINE_DRIVER_END
 
 /*** Rom Loading
