@@ -85,7 +85,7 @@ Known issues :
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
-
+#include "sound/2203intf.h"
 
 
 /***************************************************************************
@@ -164,41 +164,13 @@ static void irqhandler(int irq)
 	cpunum_set_input_line(1, 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static struct YM2203interface argus_ym2203_interface =
+static struct YM2203interface ym2203_interface =
 {
-	1,				/* 1 chip  */
-	6000000 / 4, 	/* 1.5 MHz */
-	{ YM2203_VOL(50,15) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
-};
-
-static struct YM2203interface valtric_ym2203_interface =
-{
-	2,				/* 2 chips */
-	6000000 / 4, 	/* 1.5 MHz */
-	{ YM2203_VOL(50,15), YM2203_VOL(50,15) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
-};
-
-/* Volume setting is different from the others. */
-static struct YM2203interface butasan_ym2203_interface =
-{
-	2,				/* 2 chips */
-	6000000 / 4, 	/* 1.5 MHz */
-	{ YM2203_VOL(100,30), YM2203_VOL(100,30) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
+	0,
+	0,
+	0,
+	0,
+	irqhandler
 };
 
 
@@ -423,23 +395,27 @@ static ADDRESS_MAP_START( sound_writemem_b, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport_1, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x0000, 0x0000) AM_READ(YM2203_status_port_0_r)
-	AM_RANGE(0x0001, 0x0001) AM_READ(YM2203_read_port_0_r)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x00, 0x00) AM_READ(YM2203_status_port_0_r)
+	AM_RANGE(0x01, 0x01) AM_READ(YM2203_read_port_0_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport_1, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM2203_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM2203_write_port_0_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport_2, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x0000, 0x0000) AM_READ(YM2203_status_port_0_r)
-	AM_RANGE(0x0001, 0x0001) AM_READ(YM2203_read_port_0_r)
-	AM_RANGE(0x0080, 0x0080) AM_READ(YM2203_status_port_1_r)
-	AM_RANGE(0x0081, 0x0081) AM_READ(YM2203_read_port_1_r)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x00, 0x00) AM_READ(YM2203_status_port_0_r)
+	AM_RANGE(0x01, 0x01) AM_READ(YM2203_read_port_0_r)
+	AM_RANGE(0x80, 0x80) AM_READ(YM2203_status_port_1_r)
+	AM_RANGE(0x81, 0x81) AM_READ(YM2203_read_port_1_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport_2, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM2203_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM2203_write_port_0_w)
 	AM_RANGE(0x80, 0x80) AM_WRITE(YM2203_control_port_1_w)
@@ -767,7 +743,7 @@ static MACHINE_DRIVER_START( argus )
 	MDRV_CPU_VBLANK_INT(argus_interrupt,2)
 
 	MDRV_CPU_ADD(Z80, 5000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)			/* 4 MHz */
+	/* audio CPU */			/* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem_a,sound_writemem_a)
 	MDRV_CPU_IO_MAP(sound_readport_1,sound_writeport_1)
 
@@ -786,7 +762,14 @@ static MACHINE_DRIVER_START( argus )
 	MDRV_VIDEO_UPDATE(argus)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, argus_ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 6000000 / 4)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( valtric )
@@ -797,7 +780,7 @@ static MACHINE_DRIVER_START( valtric )
 	MDRV_CPU_VBLANK_INT(argus_interrupt,2)
 
 	MDRV_CPU_ADD(Z80, 5000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)			/* 5 MHz */
+	/* audio CPU */			/* 5 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem_a,sound_writemem_a)
 	MDRV_CPU_IO_MAP(sound_readport_2,sound_writeport_2)
 
@@ -816,7 +799,20 @@ static MACHINE_DRIVER_START( valtric )
 	MDRV_VIDEO_UPDATE(valtric)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, valtric_ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 6000000 / 4)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.50)
+
+	MDRV_SOUND_ADD(YM2203, 6000000 / 4)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( butasan )
@@ -827,7 +823,7 @@ static MACHINE_DRIVER_START( butasan )
 	MDRV_CPU_VBLANK_INT(argus_interrupt,2)
 
 	MDRV_CPU_ADD(Z80, 5000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)			/* 5 MHz */
+	/* audio CPU */			/* 5 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem_b,sound_writemem_b)
 	MDRV_CPU_IO_MAP(sound_readport_2,sound_writeport_2)
 
@@ -846,7 +842,20 @@ static MACHINE_DRIVER_START( butasan )
 	MDRV_VIDEO_UPDATE(butasan)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, butasan_ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 6000000 / 4)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.30)
+	MDRV_SOUND_ROUTE(1, "mono", 0.30)
+	MDRV_SOUND_ROUTE(2, "mono", 0.30)
+	MDRV_SOUND_ROUTE(3, "mono", 1.0)
+
+	MDRV_SOUND_ADD(YM2203, 6000000 / 4)
+	MDRV_SOUND_ROUTE(0, "mono", 0.30)
+	MDRV_SOUND_ROUTE(1, "mono", 0.30)
+	MDRV_SOUND_ROUTE(2, "mono", 0.30)
+	MDRV_SOUND_ROUTE(3, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
