@@ -1,34 +1,35 @@
 /***************************************************************************
 
-	Atari Avalanche hardware
+    Atari Avalanche hardware
 
-	driver by Mike Balfour
+    driver by Mike Balfour
 
-	Games supported:
-		* Avalanche
+    Games supported:
+        * Avalanche
 
-	Known issues:
-		* none at this time
+    Known issues:
+        * none at this time
 
 ****************************************************************************
 
-	Memory Map:
-					0000-1FFF				RAM
-					2000-2FFF		R		INPUTS
-					3000-3FFF		W		WATCHDOG
-					4000-4FFF		W		OUTPUTS
-					5000-5FFF		W		SOUND LEVEL
-					6000-7FFF		R		PROGRAM ROM
-					8000-DFFF				UNUSED
-					E000-FFFF				PROGRAM ROM (Remapped)
+    Memory Map:
+                    0000-1FFF               RAM
+                    2000-2FFF       R       INPUTS
+                    3000-3FFF       W       WATCHDOG
+                    4000-4FFF       W       OUTPUTS
+                    5000-5FFF       W       SOUND LEVEL
+                    6000-7FFF       R       PROGRAM ROM
+                    8000-DFFF               UNUSED
+                    E000-FFFF               PROGRAM ROM (Remapped)
 
-	If you have any questions about how this driver works, don't hesitate to
-	ask.  - Mike Balfour (mab22@po.cwru.edu)
+    If you have any questions about how this driver works, don't hesitate to
+    ask.  - Mike Balfour (mab22@po.cwru.edu)
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/discrete.h"
 #include "artwork.h"
 #include "avalnche.h"
 
@@ -36,7 +37,7 @@
 
 /*************************************
  *
- *	Overlay
+ *  Overlay
  *
  *************************************/
 
@@ -57,7 +58,7 @@ OVERLAY_END
 
 /*************************************
  *
- *	Palette generation
+ *  Palette generation
  *
  *************************************/
 
@@ -72,7 +73,7 @@ static PALETTE_INIT( avalnche )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -90,7 +91,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -129,11 +130,44 @@ INPUT_PORTS_START( avalnche )
 INPUT_PORTS_END
 
 
+INPUT_PORTS_START( cascade )
+	PORT_START_TAG("IN0")
+	PORT_BIT (0x03, IP_ACTIVE_HIGH, IPT_UNKNOWN ) /* Spare */
+	PORT_DIPNAME( 0x0c, 0x04, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
+	PORT_DIPNAME( 0x30, 0x00, DEF_STR( Language ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( English ) )
+	PORT_DIPSETTING(    0x30, DEF_STR( German ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( French ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( Italian ) )
+	PORT_BIT (0x40, IP_ACTIVE_HIGH, IPT_START2 )
+	PORT_BIT (0x80, IP_ACTIVE_HIGH, IPT_START1 )
+
+	PORT_START_TAG("IN1")
+	PORT_BIT ( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT ( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
+	PORT_DIPNAME( 0x04, 0x04, "Allow Extended Play" )
+	PORT_DIPSETTING(    0x00, DEF_STR( No ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( Yes ) )
+	PORT_DIPNAME( 0x08, 0x00, "Extended Play" )
+	PORT_DIPSETTING(    0x00, "1500 points" )
+	PORT_DIPSETTING(    0x08, "2500 points" )
+	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* SLAM */
+	PORT_SERVICE( 0x20, IP_ACTIVE_HIGH)
+	PORT_BIT ( 0x40, IP_ACTIVE_HIGH, IPT_BUTTON1 )	/* Serve */
+	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_VBLANK )	/* VBLANK */
+
+	PORT_START_TAG("IN2")
+	PORT_BIT( 0xff, 0x80, IPT_PADDLE ) PORT_MINMAX(0x40,0xb7) PORT_SENSITIVITY(50) PORT_KEYDELTA(10) PORT_CENTERDELTA(0)
+INPUT_PORTS_END
 
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -158,14 +192,18 @@ static MACHINE_DRIVER_START( avalnche )
 	MDRV_VIDEO_UPDATE(avalnche)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DISCRETE, avalnche_discrete_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DISCRETE, 0)
+	MDRV_SOUND_CONFIG(avalnche_discrete_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -179,11 +217,19 @@ ROM_START( avalnche )
 	ROM_LOAD_NIB_LOW ( "30614.c3",     	0x7800, 0x0800, CRC(a12d5d64) SHA1(1647d7416bf9266d07f066d3797bda943e004d24) )
 ROM_END
 
-
+ROM_START( cascade )
+	ROM_REGION( 0x8000, REGION_CPU1, 0 ) /* 32k for code */
+	ROM_LOAD( "10005.1a",     	0x6800, 0x0400, CRC(54774594) SHA1(03e013b563675fb8a30bd69836466a353db9bfc7) )
+	ROM_LOAD( "10005.1b",     	0x6c00, 0x0400, CRC(fd9575ad) SHA1(ed0a1343d3c0456d458561256d5ee966b6c213f4) )
+	ROM_LOAD( "10005.2a",     	0x7000, 0x0400, CRC(12857c75) SHA1(e42fdee70bd19d6f60e88f106a49dbbd68c591cd) )
+	ROM_LOAD( "10005.2b",     	0x7400, 0x0400, CRC(26361698) SHA1(587cc6f0dc068a74aac41c2cb3336d70d2dd91e5) )
+	ROM_LOAD( "10005.3a",     	0x7800, 0x0400, CRC(d1f422ff) SHA1(65ecbf0a22ba340d6a1768ed029030bac9c19e0f) )
+	ROM_LOAD( "10005.3b",     	0x7c00, 0x0400, CRC(bb243d96) SHA1(3a387a8c50cd9b0db37d12b94dc9e260892dbf21) )
+ROM_END
 
 /*************************************
  *
- *	Driver initialization
+ *  Driver initialization
  *
  *************************************/
 
@@ -196,8 +242,9 @@ static DRIVER_INIT( avalnche )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
-GAME( 1978, avalnche, 0, avalnche, avalnche, avalnche, ROT0, "Atari", "Avalanche" )
+GAME( 1978, avalnche, 0,        avalnche, avalnche, avalnche, ROT0, "Atari", "Avalanche" )
+GAME( 1978, cascade,  avalnche, avalnche, cascade,  avalnche, ROT0, "Sidam", "Cascade" )
