@@ -19,31 +19,31 @@ c000-ffff ROM (Super Bagman only)
 memory mapped ports:
 
 read:
-a000	  PAL16r6 output. (RD4 line)
-a800	  ? (read only in one place, not used) (RD5 line)
-b000	  DSW (RD6 line)
-b800	  watchdog reset (RD7 line)
+a000      PAL16r6 output. (RD4 line)
+a800      ? (read only in one place, not used) (RD5 line)
+b000      DSW (RD6 line)
+b800      watchdog reset (RD7 line)
 
 write:
-a000	  interrupt enable
-a001	  horizontal flip
-a002	  vertical flip
-a003	  video enable?? (seems to be unused in the schems)
-a004	  coin counter
-a007	  ? /SCS line in the schems connected to AY8910 pin A4 or AA (schems are unreadable)
+a000      interrupt enable
+a001      horizontal flip
+a002      vertical flip
+a003      video enable?? (seems to be unused in the schems)
+a004      coin counter
+a007      ? /SCS line in the schems connected to AY8910 pin A4 or AA (schems are unreadable)
 
 a800-a805 these lines control the state machine driving TMS5110 (only bit 0 matters)
-		  a800,a801,a802 - speech roms BIT select (000 bit 7, 001 bit 4, 010 bit 2)
-		  a803 - 0 keeps the state machine in reset state; 1 starts speech
-		  a804 - connected to speech rom 11 (QS) chip enable
-		  a805 - connected to speech rom 12 (QT) chip enable
-b000	  ?
-b800	  ?
+          a800,a801,a802 - speech roms BIT select (000 bit 7, 001 bit 4, 010 bit 2)
+          a803 - 0 keeps the state machine in reset state; 1 starts speech
+          a804 - connected to speech rom 11 (QS) chip enable
+          a805 - connected to speech rom 12 (QT) chip enable
+b000      ?
+b800      ?
 
 
 PAL16r6 This chip is custom logic used for guards controlling.
-		Inputs are connected to buffered address(!!!) lines AB0,AB1,AB2,AB3,AB4,AB5,AB6
-		We simulate this writing a800 to a805 there (which is wrong but works)
+        Inputs are connected to buffered address(!!!) lines AB0,AB1,AB2,AB3,AB4,AB5,AB6
+        We simulate this writing a800 to a805 there (which is wrong but works)
 
 
 I/O ports:
@@ -51,13 +51,15 @@ I/O ports:
 I/O 8  ;AY-3-8910 Control Reg.
 I/O 9  ;AY-3-8910 Data Write Reg.
 I/O C  ;AY-3-8910 Data Read Reg.
-		Port A of the 8910 is connected to IN0
-		Port B of the 8910 is connected to IN1
+        Port A of the 8910 is connected to IN0
+        Port B of the 8910 is connected to IN1
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/5110intf.h"
 #include "sound/tms5110.h"
 
 
@@ -253,10 +255,12 @@ static ADDRESS_MAP_START( pickin_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x0c, 0x0c) AM_READ(AY8910_read_port_0_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x08, 0x08) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x09, 0x09) AM_WRITE(AY8910_write_port_0_w)
 	/*AM_RANGE(0x56, 0x56) AM_WRITE(MWA8_NOP) */
@@ -503,19 +507,12 @@ static struct GfxDecodeInfo pickin_gfxdecodeinfo[] =
 
 static struct AY8910interface ay8910_interface =
 {
-	1,	/* 1 chip */
-	1500000,	/* 1.5 MHz??? */
-	{ 10 },
-	{ input_port_0_r },
-	{ input_port_1_r },
-	{ 0 },
-	{ 0 }
+	input_port_0_r,
+	input_port_1_r,
 };
 
 static struct TMS5110interface tms5110_interface =
 {
-	640000, /*640 kHz clock*/
-	100,	/*100 % mixing level */
 	0,		/*irq callback function*/
 	bagman_speech_rom_read_bit	/*M0 callback function. Called whenever chip requests a single bit of data*/
 };
@@ -545,8 +542,15 @@ static MACHINE_DRIVER_START( bagman )
 	MDRV_VIDEO_UPDATE(bagman)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(TMS5110, tms5110_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+
+	MDRV_SOUND_ADD(TMS5110, 640000)
+	MDRV_SOUND_CONFIG(tms5110_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( pickin )
@@ -574,7 +578,11 @@ static MACHINE_DRIVER_START( pickin )
 	MDRV_VIDEO_UPDATE(bagman)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 MACHINE_DRIVER_END
 
 /*
@@ -620,7 +628,11 @@ static MACHINE_DRIVER_START( botanic )
 	MDRV_VIDEO_UPDATE(bagman)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 MACHINE_DRIVER_END
 
 /***************************************************************************
