@@ -35,6 +35,7 @@ write:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/sn76496.h"
 
 
 extern UINT8 *bankp_videoram2;
@@ -64,6 +65,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( bankp_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READWRITE(input_port_0_r, SN76496_0_w)
 	AM_RANGE(0x01, 0x01) AM_READWRITE(input_port_1_r, SN76496_1_w)
 	AM_RANGE(0x02, 0x02) AM_READWRITE(input_port_2_r, SN76496_2_w)
@@ -159,15 +161,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct SN76496interface sn76496_interface =
-{
-	3,	/* 3 chips */
-	{ 15468480/4, 15468480/4, 15468480/4 },
-	{ 100, 100, 100 }
-};
-
-
-
 static MACHINE_DRIVER_START( bankp )
 
 	/* basic machine hardware */
@@ -192,7 +185,16 @@ static MACHINE_DRIVER_START( bankp )
 	MDRV_VIDEO_UPDATE(bankp)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 15468480/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(SN76496, 15468480/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(SN76496, 15468480/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
