@@ -3,7 +3,7 @@
 Battlantis(GX777) (c) 1987 Konami
 
 Preliminary driver by:
-	Manuel Abadia <manu@teleline.es>
+    Manuel Abadia <manu@teleline.es>
 
 ***************************************************************************/
 
@@ -12,6 +12,7 @@ Preliminary driver by:
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "vidhrdw/konamiic.h"
+#include "sound/3812intf.h"
 
 /* from vidhrdw */
 WRITE8_HANDLER( battlnts_spritebank_w );
@@ -93,7 +94,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************
 
-	Input Ports
+    Input Ports
 
 ***************************************************************************/
 
@@ -132,7 +133,7 @@ INPUT_PORTS_START( battlnts )
 	PORT_DIPSETTING(	0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(	0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(	0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(	0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )
@@ -229,7 +230,7 @@ INPUT_PORTS_START( thehustj )
 	PORT_DIPSETTING(	0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(	0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(	0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(	0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x03, 0x02, "Balls" )
@@ -325,18 +326,10 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /***************************************************************************
 
-	Machine Driver
+    Machine Driver
 
 ***************************************************************************/
 
-static struct YM3812interface ym3812_interface =
-{
-	2,				/* 2 chips */
-	3000000,		/* ? */
-	{ 100, 100 },
-	{ 0, 0 },
-};
-
 static MACHINE_DRIVER_START( battlnts )
 
 	/* basic machine hardware */
@@ -345,7 +338,7 @@ static MACHINE_DRIVER_START( battlnts )
 	MDRV_CPU_VBLANK_INT(battlnts_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* ? */
+	/* audio CPU */		/* ? */
 	MDRV_CPU_PROGRAM_MAP(battlnts_readmem_sound,battlnts_writemem_sound)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -362,7 +355,13 @@ static MACHINE_DRIVER_START( battlnts )
 	MDRV_VIDEO_UPDATE(battlnts)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 3000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(YM3812, 3000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -449,9 +448,9 @@ ROM_END
 
 
 /*
-	This recursive function doesn't use additional memory
-	(it could be easily converted into an iterative one).
-	It's called shuffle because it mimics the shuffling of a deck of cards.
+    This recursive function doesn't use additional memory
+    (it could be easily converted into an iterative one).
+    It's called shuffle because it mimics the shuffling of a deck of cards.
 */
 static void shuffle(UINT8 *buf,int len)
 {
