@@ -8,7 +8,7 @@
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "includes/berzerk.h"
-
+#include "sound/samples.h"
 
 
 static ADDRESS_MAP_START( berzerk_readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -48,6 +48,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x44, 0x44) AM_READ(berzerk_voiceboard_r)
 	AM_RANGE(0x48, 0x48) AM_READ(input_port_0_r)
 	AM_RANGE(0x49, 0x49) AM_READ(input_port_1_r)
@@ -66,6 +67,7 @@ static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x40, 0x46) AM_WRITE(berzerk_sound_control_a_w) /* First sound board */
 	AM_RANGE(0x47, 0x47) AM_WRITE(MWA8_NOP) /* not used sound stuff */
 	AM_RANGE(0x4b, 0x4b) AM_WRITE(berzerk_magicram_control_w)
@@ -332,8 +334,11 @@ static MACHINE_DRIVER_START( berzerk )
 	MDRV_VIDEO_UPDATE(generic_bitmapped)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SAMPLES, berzerk_samples_interface)
-	MDRV_SOUND_ADD(CUSTOM, berzerk_custom_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(berzerk_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( frenzy )
