@@ -57,6 +57,8 @@ J1100072A
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/msm5232.h"
 
 VIDEO_START( bigevglf );
 VIDEO_UPDATE( bigevglf );
@@ -311,6 +313,7 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( bigevglf_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(MWA8_NOP) 	/* video ram enable ???*/
 	AM_RANGE(0x01, 0x01) AM_WRITE(beg_gfxcontrol_w)  /* plane select */
 	AM_RANGE(0x02, 0x02) AM_WRITE(beg_banking_w)
@@ -320,6 +323,7 @@ static ADDRESS_MAP_START( bigevglf_writeport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( bigevglf_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x06, 0x06) AM_READ(beg_status_r)
 ADDRESS_MAP_END
 
@@ -341,6 +345,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( bigevglf_sub_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x08, 0x08) AM_WRITE(MWA8_NOP) /*coinlockout_w ???? watchdog ???? */
 	AM_RANGE(0x0c, 0x0c) AM_WRITE(bigevglf_mcu_w)
 	AM_RANGE(0x0e, 0x0e) AM_WRITE(MWA8_NOP) /* 0-enable MCU, 1-keep reset line ASSERTED; D0 goes to the input of ls74 and the /Q of this ls74 goes to reset line on 68705 */
@@ -355,16 +360,17 @@ static READ8_HANDLER( sub_cpu_mcu_coin_port_r )
 {
 	static int bit5=0;
 	/*
-			bit 0 and bit 1 = coin inputs
-			bit 3 and bit 4 = MCU status
-			bit 5           = must toggle, vblank ?
+            bit 0 and bit 1 = coin inputs
+            bit 3 and bit 4 = MCU status
+            bit 5           = must toggle, vblank ?
 
-	*/
+    */
 	bit5 ^= 0x20;
 	return bigevglf_mcu_status_r(0) | (readinputport(1) & 3) | bit5; /* bit 0 and bit 1 - coin inputs */
 }
 
 static ADDRESS_MAP_START( bigevglf_sub_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)
 	AM_RANGE(0x01, 0x01) AM_READ(MRA8_NOP)
 	AM_RANGE(0x02, 0x02) AM_READ(input_port_4_r)
@@ -454,23 +460,9 @@ MACHINE_INIT( bigevglf )
 }
 
 
-static struct AY8910interface ay8910_interface =
-{
-	1,	/* 1 chip */
-	8000000/4,	/* 2 MHz ? */
-	{ 15 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static struct MSM5232interface msm5232_interface =
 {
-	1,	/* 1 chip */
-	8000000/4,	/* 2 MHz ? */
-	{ { 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6 } },	/* 0.65 (???) uF capacitors */
-	{ 100 }	/* mixing level ??? */
+	{ 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6, 0.65e-6 }	/* 0.65 (???) uF capacitors */
 };
 
 static MACHINE_DRIVER_START( bigevglf )
@@ -486,11 +478,11 @@ static MACHINE_DRIVER_START( bigevglf )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)	/* vblank */
 
 	MDRV_CPU_ADD(Z80,8000000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* 4 MHz ? */
+	/* audio CPU */		/* 4 MHz ? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,2)	/* IRQ generated by ???;
-		2 irqs/frame give good music tempo but also SOUND ERROR in test mode,
-		4 irqs/frame give SOUND OK in test mode but music seems to be running too fast */
+        2 irqs/frame give good music tempo but also SOUND ERROR in test mode,
+        4 irqs/frame give SOUND OK in test mode but music seems to be running too fast */
 
 	MDRV_CPU_ADD(M68705,2000000)	/* ??? */
 	MDRV_CPU_PROGRAM_MAP(m68705_readmem,m68705_writemem)
@@ -510,8 +502,14 @@ static MACHINE_DRIVER_START( bigevglf )
 	MDRV_VIDEO_UPDATE(bigevglf)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface) /* YM2149 really */
-	MDRV_SOUND_ADD(MSM5232, msm5232_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 8000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15) /* YM2149 really */
+
+	MDRV_SOUND_ADD(MSM5232, 8000000/4)
+	MDRV_SOUND_CONFIG(msm5232_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /***************************************************************************
