@@ -1,44 +1,45 @@
 /********************************************************************
 
-			  Bionic Commando
+              Bionic Commando
 
 
 
 ToDo:
 - finish video driver
-	Some attributes are unknown. I don't remember the original game but
-	seems there are some problems:
-	- misplaced sprites ? ( see beginning of level 1 or 2 for example )
-	- sprite / sprite priority ? ( see level 2 the reflectors )
-	- sprite / background priority ? ( see level 1: birds walk through
-		branches of different trees )
-	- see the beginning of level 3: is the background screwed ?
+    Some attributes are unknown. I don't remember the original game but
+    seems there are some problems:
+    - misplaced sprites ? ( see beginning of level 1 or 2 for example )
+    - sprite / sprite priority ? ( see level 2 the reflectors )
+    - sprite / background priority ? ( see level 1: birds walk through
+        branches of different trees )
+    - see the beginning of level 3: is the background screwed ?
 
 - get rid of input port hack
 
-	Controls appear to be mapped at 0xFE4000, alongside dip switches, but there
-	is something strange going on that I can't (yet) figure out.
-	Player controls and coin inputs are supposed to magically appear at
-	0xFFFFFB (coin/start)
-	0xFFFFFD (player 2)
-	0xFFFFFF (player 1)
-	This is probably done by an MPU on the board (whose ROM is not
-	available).
+    Controls appear to be mapped at 0xFE4000, alongside dip switches, but there
+    is something strange going on that I can't (yet) figure out.
+    Player controls and coin inputs are supposed to magically appear at
+    0xFFFFFB (coin/start)
+    0xFFFFFD (player 2)
+    0xFFFFFF (player 1)
+    This is probably done by an MPU on the board (whose ROM is not
+    available).
 
-	The MPU also takes care of the commands for the sound CPU, which are stored
-	at FFFFF9.
+    The MPU also takes care of the commands for the sound CPU, which are stored
+    at FFFFF9.
 
-	IRQ4 seems to be control related.
-	On each interrupt, it reads 0xFE4000 (coin/start), shift the bits around
-	and move the resulting byte into a dword RAM location. The dword RAM location
-	is rotated by 8 bits each time this happens.
-	This is probably done to be pedantic about coin insertions (might be protection
-	related). In fact, currently coin insertions are not consistently recognized.
+    IRQ4 seems to be control related.
+    On each interrupt, it reads 0xFE4000 (coin/start), shift the bits around
+    and move the resulting byte into a dword RAM location. The dword RAM location
+    is rotated by 8 bits each time this happens.
+    This is probably done to be pedantic about coin insertions (might be protection
+    related). In fact, currently coin insertions are not consistently recognized.
 
 ********************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2151intf.h"
 
 
 WRITE16_HANDLER( bionicc_fgvideoram_w );
@@ -118,7 +119,7 @@ static READ16_HANDLER( hacked_soundcommand_r )
 
 INTERRUPT_GEN( bionicc_interrupt )
 {
-	if (cpu_getiloops() == 0) 
+	if (cpu_getiloops() == 0)
 		cpunum_set_input_line(0, 2, HOLD_LINE);
 	else
 		cpunum_set_input_line(0, 4, HOLD_LINE);
@@ -325,15 +326,6 @@ static struct GfxDecodeInfo gfxdecodeinfo_bionicc[] =
 };
 
 
-static struct YM2151interface ym2151_interface =
-{
-	1,                      /* 1 chip */
-	3579545,                /* 3.579545 MHz ? */
-	{ YM3012_VOL(60,MIXER_PAN_LEFT,60,MIXER_PAN_RIGHT) },
-	{ 0 }
-};
-
-
 static MACHINE_DRIVER_START( bionicc )
 
 	/* basic machine hardware */
@@ -342,7 +334,7 @@ static MACHINE_DRIVER_START( bionicc )
 	MDRV_CPU_VBLANK_INT(bionicc_interrupt,8)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)  /* 4 MHz ??? TODO: find real FRQ */
+	/* audio CPU */  /* 4 MHz ??? TODO: find real FRQ */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,4)	/* ??? */
 
@@ -360,7 +352,11 @@ static MACHINE_DRIVER_START( bionicc )
 	MDRV_VIDEO_EOF(bionicc)
 	MDRV_VIDEO_UPDATE(bionicc)
 
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_ROUTE(0, "mono", 0.60)
+	MDRV_SOUND_ROUTE(1, "mono", 0.60)
 MACHINE_DRIVER_END
 
 
