@@ -96,6 +96,7 @@ Stephh's notes (based on the games M68000 code and some tests) :
 #include "vidhrdw/generic.h"
 #include "sndhrdw/seibu.h"
 #include "cpu/z80/z80.h"
+#include "sound/3812intf.h"
 
 
 extern UINT16 *bloodbro_bgvideoram, *bloodbro_fgvideoram;
@@ -182,17 +183,17 @@ INPUT_PORTS_START( bloodbro )
 	PORT_DIPSETTING(      0x000a, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Free_Play ) )
 	/* Coin Mode 2
-	PORT_DIPNAME( 0x0006, 0x0006, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 5C_1C ) )
-	PORT_DIPSETTING(      0x0002, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(      0x0004, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x0006, DEF_STR( 1C_1C ) )
-	PORT_DIPNAME( 0x0018, 0x0018, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(      0x0018, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(      0x0008, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )
-	*/
+    PORT_DIPNAME( 0x0006, 0x0006, DEF_STR( Coin_A ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 5C_1C ) )
+    PORT_DIPSETTING(      0x0002, DEF_STR( 3C_1C ) )
+    PORT_DIPSETTING(      0x0004, DEF_STR( 2C_1C ) )
+    PORT_DIPSETTING(      0x0006, DEF_STR( 1C_1C ) )
+    PORT_DIPNAME( 0x0018, 0x0018, DEF_STR( Coin_B ) )
+    PORT_DIPSETTING(      0x0018, DEF_STR( 1C_2C ) )
+    PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )
+    PORT_DIPSETTING(      0x0008, DEF_STR( 1C_5C ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )
+    */
 	PORT_DIPNAME( 0x0020, 0x0020, "Starting Coin" )
 	PORT_DIPSETTING(      0x0020, DEF_STR( Normal ) )
 	PORT_DIPSETTING(      0x0000, "x2" )
@@ -272,17 +273,17 @@ INPUT_PORTS_START( weststry )
 	PORT_DIPSETTING(      0x000a, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Free_Play ) )
 	/* Coin Mode 2
-	PORT_DIPNAME( 0x0006, 0x0006, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 5C_1C ) )
-	PORT_DIPSETTING(      0x0002, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(      0x0004, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x0006, DEF_STR( 1C_1C ) )
-	PORT_DIPNAME( 0x0018, 0x0018, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(      0x0018, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(      0x0008, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )
-	*/
+    PORT_DIPNAME( 0x0006, 0x0006, DEF_STR( Coin_A ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 5C_1C ) )
+    PORT_DIPSETTING(      0x0002, DEF_STR( 3C_1C ) )
+    PORT_DIPSETTING(      0x0004, DEF_STR( 2C_1C ) )
+    PORT_DIPSETTING(      0x0006, DEF_STR( 1C_1C ) )
+    PORT_DIPNAME( 0x0018, 0x0018, DEF_STR( Coin_B ) )
+    PORT_DIPSETTING(      0x0018, DEF_STR( 1C_2C ) )
+    PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )
+    PORT_DIPSETTING(      0x0008, DEF_STR( 1C_5C ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )
+    */
 	PORT_DIPNAME( 0x0020, 0x0020, "Starting Coin" )
 	PORT_DIPSETTING(      0x0020, DEF_STR( Normal ) )
 	PORT_DIPSETTING(      0x0000, "x2" )
@@ -363,17 +364,17 @@ INPUT_PORTS_START( skysmash )
 	PORT_DIPSETTING(      0x000a, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Free_Play ) )
 	/* Coin Mode 2
-	PORT_DIPNAME( 0x0006, 0x0006, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 5C_1C ) )
-	PORT_DIPSETTING(      0x0002, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(      0x0004, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x0006, DEF_STR( 1C_1C ) )
-	PORT_DIPNAME( 0x0018, 0x0018, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(      0x0018, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(      0x0008, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )
-	*/
+    PORT_DIPNAME( 0x0006, 0x0006, DEF_STR( Coin_A ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 5C_1C ) )
+    PORT_DIPSETTING(      0x0002, DEF_STR( 3C_1C ) )
+    PORT_DIPSETTING(      0x0004, DEF_STR( 2C_1C ) )
+    PORT_DIPSETTING(      0x0006, DEF_STR( 1C_1C ) )
+    PORT_DIPNAME( 0x0018, 0x0018, DEF_STR( Coin_B ) )
+    PORT_DIPSETTING(      0x0018, DEF_STR( 1C_2C ) )
+    PORT_DIPSETTING(      0x0010, DEF_STR( 1C_3C ) )
+    PORT_DIPSETTING(      0x0008, DEF_STR( 1C_5C ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )
+    */
 	PORT_DIPNAME( 0x0020, 0x0020, "Starting Coin" )
 	PORT_DIPSETTING(      0x0020, DEF_STR( Normal ) )
 	PORT_DIPSETTING(      0x0000, "x2" )
@@ -528,7 +529,7 @@ static struct GfxDecodeInfo weststry_gfxdecodeinfo[] =
 /* Sound Interfaces */
 
 /* Parameters: YM3812 frequency, Oki frequency, Oki memory region */
-SEIBU_SOUND_SYSTEM_YM3812_HARDWARE(14318180/4, 8000, REGION_SOUND1);
+SEIBU_SOUND_SYSTEM_YM3812_HARDWARE
 
 /* Machine Drivers */
 
@@ -556,7 +557,7 @@ static MACHINE_DRIVER_START( bloodbro )
 	MDRV_VIDEO_UPDATE(bloodbro)
 
 	/* sound hardware */
-	SEIBU_SOUND_SYSTEM_YM3812_INTERFACE
+	SEIBU_SOUND_SYSTEM_YM3812_INTERFACE(14318180/4, 8000, 1)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( weststry )
