@@ -43,17 +43,18 @@ write:
 
 /*
 
-	TODO:
+    TODO:
 
-	- the cross hatch pattern test in service mode is too fast, each phase
-	  should take 15 seconds according to the service manual
-	- the two AY-3-8910's should be clocked independently at 2H and 4H
+    - the cross hatch pattern test in service mode is too fast, each phase
+      should take 15 seconds according to the service manual
+    - the two AY-3-8910's should be clocked independently at 2H and 4H
 
 */
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/ay8910.h"
 
 extern UINT8 *blueprnt_scrollram;
 
@@ -289,15 +290,18 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /* Sound Interfaces */
 
-static struct AY8910interface ay8910_interface =
+static struct AY8910interface ay8910_interface_1 =
 {
-	2,				/* 2 chips */
-	10000000/2/2/2,	/* the first chip should be clocked at 2H (1.25 MHz), the second one at 4H (625 kHz) */
-	{ 25, 25 },
-	{            0, input_port_2_r },
-	{ soundlatch_r, input_port_3_r },
-	{ dipsw_w },
-	{ 0 }
+	0,
+	soundlatch_r,
+	dipsw_w,
+	0
+};
+
+static struct AY8910interface ay8910_interface_2 =
+{
+	input_port_2_r,
+	input_port_3_r
 };
 
 /* Machine Driver */
@@ -308,7 +312,7 @@ static MACHINE_DRIVER_START( blueprnt )
 	MDRV_CPU_PROGRAM_MAP(blueprnt_map, 0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
 
-	MDRV_CPU_ADD(Z80, 10000000/2/2/2)	/* 1.25 MHz (2H)	// can't use CPU_AUDIO_CPU because this CPU reads the dip switches */
+	MDRV_CPU_ADD(Z80, 10000000/2/2/2)	/* 1.25 MHz (2H) */
 	MDRV_CPU_PROGRAM_MAP(sound_map, 0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 4)	/* IRQs connected to 32V */
 											/* NMIs are caused by the main CPU */
@@ -328,7 +332,15 @@ static MACHINE_DRIVER_START( blueprnt )
 	MDRV_VIDEO_UPDATE(blueprnt)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 10000000/2/2/2)
+	MDRV_SOUND_CONFIG(ay8910_interface_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 10000000/2/2/2/2)
+	MDRV_SOUND_CONFIG(ay8910_interface_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 /* ROMs */
