@@ -48,6 +48,8 @@ Sound: YM2203 and YM3526 driven by 6809.  Sound added by Bryan McPhail, 1/4/98.
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
+#include "sound/2203intf.h"
+#include "sound/3812intf.h"
 
 
 unsigned char *brkthru_nmi_enable; /* needs to be tracked down */
@@ -406,23 +408,9 @@ static void irqhandler(int linestate)
 	cpunum_set_input_line(1,M6809_IRQ_LINE,linestate);
 }
 
-static struct YM2203interface ym2203_interface =
-{
-	1,
-	1500000,	/* Unknown */
-	{ YM2203_VOL(50,10) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static struct YM3526interface ym3526_interface =
 {
-	1,			/* 1 chip */
-	3000000,	/* 3 MHz? */
-	{ 100 },		/* volume */
-	{ irqhandler },
+	irqhandler
 };
 
 
@@ -435,7 +423,7 @@ static MACHINE_DRIVER_START( brkthru )
 	MDRV_CPU_VBLANK_INT(brkthru_interrupt,2)
 
 	MDRV_CPU_ADD(M6809, 1250000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)        /* 1.25 MHz ? */
+	/* audio CPU */        /* 1.25 MHz ? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(58)
@@ -453,8 +441,17 @@ static MACHINE_DRIVER_START( brkthru )
 	MDRV_VIDEO_UPDATE(brkthru)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM3526, ym3526_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.10)
+	MDRV_SOUND_ROUTE(1, "mono", 0.10)
+	MDRV_SOUND_ROUTE(2, "mono", 0.10)
+	MDRV_SOUND_ROUTE(3, "mono", 0.50)
+
+	MDRV_SOUND_ADD(YM3526, 3000000)
+	MDRV_SOUND_CONFIG(ym3526_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( darwin )
@@ -465,23 +462,23 @@ static MACHINE_DRIVER_START( darwin )
 	MDRV_CPU_VBLANK_INT(brkthru_interrupt,2)
 
 	MDRV_CPU_ADD(M6809, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)        /* 1.25 MHz ? */
+	/* audio CPU */        /* 1.25 MHz ? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(15625.0/272)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	/* frames per second, vblank duration
-		Horizontal video frequency:
-			HSync = Dot Clock / Horizontal Frame Length
-			      = Xtal /2   / (HDisplay + HBlank)
-			      = 12MHz/2   / (240 + 144)
-			      = 15.625kHz
-		Vertical Video frequency:
-			VSync = HSync / Vertical Frame Length
-			      = HSync / (VDisplay + VBlank)
-			      = 15.625kHz / (240 + 32)
-			      = 57.444855Hz
-	tuned by Shingo SUZUKI(VSyncMAME Project) 2000/10/19 */
+        Horizontal video frequency:
+            HSync = Dot Clock / Horizontal Frame Length
+                  = Xtal /2   / (HDisplay + HBlank)
+                  = 12MHz/2   / (240 + 144)
+                  = 15.625kHz
+        Vertical Video frequency:
+            VSync = HSync / Vertical Frame Length
+                  = HSync / (VDisplay + VBlank)
+                  = 15.625kHz / (240 + 32)
+                  = 57.444855Hz
+    tuned by Shingo SUZUKI(VSyncMAME Project) 2000/10/19 */
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -495,8 +492,17 @@ static MACHINE_DRIVER_START( darwin )
 	MDRV_VIDEO_UPDATE(brkthru)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM3526, ym3526_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.10)
+	MDRV_SOUND_ROUTE(1, "mono", 0.10)
+	MDRV_SOUND_ROUTE(2, "mono", 0.10)
+	MDRV_SOUND_ROUTE(3, "mono", 0.50)
+
+	MDRV_SOUND_ADD(YM3526, 3000000)
+	MDRV_SOUND_CONFIG(ym3526_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -586,6 +592,7 @@ ROM_START( brkthruj )
 	ROM_LOAD( "brkthru.5",    0x8000, 0x8000, CRC(c309435f) SHA1(82914004c2b169a7c31aa49af83a699ebbc7b33f) )
 ROM_END
 
+/* bootleg, changed prg rom fails test, probably just the japanese version modified to have english title */
 ROM_START( forcebrk )
 	ROM_REGION( 0x20000, REGION_CPU1, 0 )     /* 64k for main CPU + 64k for banked ROMs */
 	ROM_LOAD( "1",            0x04000, 0x4000, CRC(09bd60ee) SHA1(9591a4c89bb69d5615a5d6b29c47e6b17350c007) )
@@ -670,5 +677,5 @@ ROM_END
 
 GAME( 1986, brkthru,  0,       brkthru, brkthru,  0, ROT0,   "Data East USA", "Break Thru (US)" )
 GAME( 1986, brkthruj, brkthru, brkthru, brkthruj, 0, ROT0,   "Data East Corporation", "Kyohkoh-Toppa (Japan)" )
-GAME( 1986, forcebrk, brkthru, brkthru, brkthruj, 0, ROT0,   "Data East Corporation", "Force Break (Japan)" )
+GAME( 1986, forcebrk, brkthru, brkthru, brkthruj, 0, ROT0,   "bootleg", "Force Break (bootleg)" )
 GAME( 1986, darwin,   0,       darwin,  darwin,   0, ROT270, "Data East Corporation", "Darwin 4078 (Japan)" )
