@@ -49,6 +49,7 @@ can take. Should the game reset????
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/ay8910.h"
 
 extern unsigned char *lnc_charbank;
 extern unsigned char *bnj_backgroundram;
@@ -534,7 +535,7 @@ static WRITE8_HANDLER( sound_command_w )
 
 INPUT_PORTS_START( btime )
 	COMMON_INPUTS
-	
+
 	PORT_START_TAG("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
@@ -593,7 +594,7 @@ INPUT_PORTS_END
 
 INPUT_PORTS_START( cookrace )
 	COMMON_INPUTS
-	
+
 	PORT_START_TAG("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH,IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH,IPT_UNKNOWN )
@@ -1289,18 +1290,6 @@ static struct GfxDecodeInfo disco_gfxdecodeinfo[] =
 
 
 
-static struct AY8910interface ay8910_interface =
-{
-	2,      /* 2 chips */
-	1500000,        /* 1.5 MHz ? (hand tuned) */
-	{ 23, 23 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
 static MACHINE_DRIVER_START( btime )
 
 	/* basic machine hardware */
@@ -1309,7 +1298,7 @@ static MACHINE_DRIVER_START( btime )
 	MDRV_CPU_VBLANK_INT(btime_irq_interrupt,1)
 
 	MDRV_CPU_ADD_TAG("sound", M6502, 500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,16)
 
@@ -1328,7 +1317,13 @@ static MACHINE_DRIVER_START( btime )
 	MDRV_VIDEO_UPDATE(btime)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
 MACHINE_DRIVER_END
 
 
@@ -1446,7 +1441,7 @@ MACHINE_DRIVER_END
 
 /***************************************************************************
 
-	Game driver(s)
+    Game driver(s)
 
 ***************************************************************************/
 
@@ -1799,8 +1794,8 @@ static READ8_HANDLER( wtennis_reset_hack_r )
 	unsigned char *RAM = memory_region(REGION_CPU1);
 
 	/* Otherwise the game goes into test mode and there is no way out that I
-	   can see.  I'm not sure how it can work, it probably somehow has to do
-	   with the tape system */
+       can see.  I'm not sure how it can work, it probably somehow has to do
+       with the tape system */
 
 	RAM[0xfc30] = 0;
 
@@ -1826,9 +1821,9 @@ static DRIVER_INIT( zoar )
 
 
 	/* At location 0xD50A is what looks like an undocumented opcode. I tried
-	   implementing it given what opcode 0x23 should do, but it still didn't
-	   work in demo mode. So this could be another protection or a bad ROM read.
-	   I'm NOPing it out for now. */
+       implementing it given what opcode 0x23 should do, but it still didn't
+       work in demo mode. So this could be another protection or a bad ROM read.
+       I'm NOPing it out for now. */
 	memset(&rom[0xd50a],0xea,8);
 
     init_btime();
