@@ -1,8 +1,8 @@
 /*************************************************************************
 
-	BattleToads
+    BattleToads
 
-	driver by Aaron Giles
+    driver by Aaron Giles
 
 **************************************************************************/
 
@@ -10,12 +10,13 @@
 #include "cpu/tms34010/tms34010.h"
 #include "vidhrdw/tlc34076.h"
 #include "btoads.h"
+#include "sound/bsmt2000.h"
 
 
 
 /*************************************
  *
- *	Global variables
+ *  Global variables
  *
  *************************************/
 
@@ -30,7 +31,7 @@ static UINT8 sound_int_state;
 
 /*************************************
  *
- *	Machine init
+ *  Machine init
  *
  *************************************/
 
@@ -43,7 +44,7 @@ static MACHINE_INIT( btoads )
 
 /*************************************
  *
- *	Main -> sound CPU communication
+ *  Main -> sound CPU communication
  *
  *************************************/
 
@@ -87,7 +88,7 @@ static READ16_HANDLER( main_sound_r )
 
 /*************************************
  *
- *	Sound -> main CPU communication
+ *  Sound -> main CPU communication
  *
  *************************************/
 
@@ -122,7 +123,7 @@ static READ8_HANDLER( sound_data_ready_r )
 
 /*************************************
  *
- *	Sound CPU interrupt generation
+ *  Sound CPU interrupt generation
  *
  *************************************/
 
@@ -148,7 +149,7 @@ static WRITE8_HANDLER( sound_int_state_w )
 
 /*************************************
  *
- *	Sound CPU BSMT2000 communication
+ *  Sound CPU BSMT2000 communication
  *
  *************************************/
 
@@ -169,7 +170,7 @@ static WRITE8_HANDLER( bsmt2000_port_w )
 
 /*************************************
  *
- *	Main CPU memory map
+ *  Main CPU memory map
  *
  *************************************/
 
@@ -205,7 +206,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory map
+ *  Sound CPU memory map
  *
  *************************************/
 
@@ -227,7 +228,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Input ports
+ *  Input ports
  *
  *************************************/
 
@@ -304,7 +305,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	34010 configuration
+ *  34010 configuration
  *
  *************************************/
 
@@ -322,24 +323,21 @@ static struct tms34010_config cpu_config =
 
 /*************************************
  *
- *	Sound definitions
+ *  Sound definitions
  *
  *************************************/
 
 static struct BSMT2000interface bsmt2000_interface =
 {
-	1,
-	{ 24000000 },
-	{ 12 },
-	{ REGION_SOUND1 },
-	{ 100 }
+	12,
+	REGION_SOUND1
 };
 
 
 
 /*************************************
  *
- *	Machine drivers
+ *  Machine drivers
  *
  *************************************/
 
@@ -350,7 +348,6 @@ static MACHINE_DRIVER_START( btoads )
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(sound_map,0)
 	MDRV_CPU_IO_MAP(sound_io_map,0)
 	MDRV_CPU_PERIODIC_INT(sound_interrupt,183)
@@ -370,15 +367,19 @@ static MACHINE_DRIVER_START( btoads )
 	MDRV_VIDEO_UPDATE(btoads)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(BSMT2000, bsmt2000_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(BSMT2000, 24000000)
+	MDRV_SOUND_CONFIG(bsmt2000_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -398,7 +399,7 @@ ROM_END
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
