@@ -240,12 +240,22 @@ Notes:
 
 
 Notes:
-- Bubble Bobble: service mode works only if the language switch is set to Japanese.
 - the original bubble bobble board has a 68701 protection MCU, which hasn't been
   read. Its behaviour is simulated and should be a good approximation but not
   100% accurate.
 - The coin inputs are handled by a custom called PC030. It would be responsible of
   handling the coin counters.
+- There is a weird dip switch in Bubble Bobble (SWB #7). When it is on, the game
+  takes the player score and the level number (increased by 1) and writes them,
+  byte by byte, to $F7FE and $F7FF ($F7FF receives the same data but with the
+  bit order reversed). After doing that, it sometimes hangs because it expects
+  the value at $F7FF to change.
+  This is done by routines $0F26 (player 1) and $0F74 (player 2).
+  Frankly I don't know what this could be. The schematics don't show anything
+  special there. A debug feature seems unlikely - why care about the score?
+  Could it be provision for some kind of externally controlled redemption scheme?
+- "Attract Sound" in Tokio is a very relative term - it just plays a veryshort
+  sound every four rounds of demo play.
 
 TODO:
 - bublbobl: the randomization of EXTEND letters is handled by the MCU. The simulation
@@ -261,6 +271,8 @@ TODO:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2203intf.h"
+#include "sound/3812intf.h"
 
 /* vidhrdw/bublbobl.c */
 extern UINT8 *bublbobl_objectram;
@@ -294,12 +306,12 @@ WRITE8_HANDLER( bublbobl_68705_portB_w );
 WRITE8_HANDLER( bublbobl_68705_ddrB_w );
 #endif
 
-
+#if 0 /* doesn't work for some reason */
 static WRITE8_HANDLER(soundcpu_reset_w)
 {
 	cpunum_set_input_line(2, INPUT_LINE_RESET, (data & 0x01) ? ASSERT_LINE : CLEAR_LINE);
 }
-
+#endif
 
 
 static ADDRESS_MAP_START( master_map, ADDRESS_SPACE_PROGRAM, 8 )
@@ -310,7 +322,7 @@ static ADDRESS_MAP_START( master_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe000, 0xf7ff) AM_RAM AM_SHARE(1)
 	AM_RANGE(0xf800, 0xf9ff) AM_RAM AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_swap_w) AM_BASE(&paletteram)
 	AM_RANGE(0xfa00, 0xfa00) AM_WRITE(bublbobl_sound_command_w)
-/*	AM_RANGE(0xfa03, 0xfa03) AM_WRITE(soundcpu_reset_w)	// doesn't work for some reason */
+/*  AM_RANGE(0xfa03, 0xfa03) AM_WRITE(soundcpu_reset_w) // doesn't work for some reason */
 	AM_RANGE(0xfa80, 0xfa80) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0xfb40, 0xfb40) AM_WRITE(bublbobl_bankswitch_w)
 	AM_RANGE(0xfc00, 0xffff) AM_RAM AM_BASE(&bublbobl_mcu_sharedram)
@@ -380,7 +392,7 @@ static ADDRESS_MAP_START( tokio_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xdd00, 0xdfff) AM_RAM AM_BASE(&bublbobl_objectram) AM_SIZE(&bublbobl_objectram_size)
 	AM_RANGE(0xe000, 0xf7ff) AM_RAM AM_SHARE(1)
 	AM_RANGE(0xf800, 0xf9ff) AM_RAM AM_WRITE(paletteram_RRRRGGGGBBBBxxxx_swap_w) AM_BASE(&paletteram)
-	AM_RANGE(0xfa00, 0xfa00) AM_WRITENOP /* ??? */
+	AM_RANGE(0xfa00, 0xfa00) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0xfa03, 0xfa03) AM_READ(input_port_0_r)
 	AM_RANGE(0xfa04, 0xfa04) AM_READ(input_port_1_r)
 	AM_RANGE(0xfa05, 0xfa05) AM_READ(input_port_2_r)
@@ -416,18 +428,22 @@ INPUT_PORTS_START( bublbobl )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0xf0, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_SPECIAL )	/* output: coin lockout */
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_SPECIAL )	/* output: select 1-way or 2-way coin counter */
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_SPECIAL )	/* output: trigger IRQ on main CPU (jumper switchable to vblank) */
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SPECIAL )	/* output: select read or write shared RAM */
 
 	PORT_START_TAG("DSW0")
-	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Language ) )
-	PORT_DIPSETTING(    0x01, DEF_STR( Japanese ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( English ) )
+	PORT_DIPNAME( 0x05, 0x04, "Mode" )
+	PORT_DIPSETTING(    0x04, "Game, English" )
+	PORT_DIPSETTING(    0x05, "Game, Japanese" )
+	PORT_DIPSETTING(    0x01, "Test (Grid and Inputs)" )
+	PORT_DIPSETTING(    0x00, "Test (RAM and Sound)" )
 	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Flip_Screen ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_SERVICE( 0x04, IP_ACTIVE_LOW ) /* works only in Japanese mode */
 	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
@@ -449,21 +465,22 @@ INPUT_PORTS_START( bublbobl )
 	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Very_Hard ) )
 	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Bonus_Life ) )
-	PORT_DIPSETTING(    0x08, "20K 80K" )
-	PORT_DIPSETTING(    0x0c, "30K 100K" )
-	PORT_DIPSETTING(    0x04, "40K 200K" )
-	PORT_DIPSETTING(    0x00, "50K 250K" )
+	PORT_DIPSETTING(    0x08, "20K 80K 300K" )
+	PORT_DIPSETTING(    0x0c, "30K 100K 400K" )
+	PORT_DIPSETTING(    0x04, "40K 200K 500K" )
+	PORT_DIPSETTING(    0x00, "50K 250K 500K" )
+	/* then more bonus lives at 1M 2M 3M 4M 5M - for all dip switch settings */
 	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x10, "1" )
 	PORT_DIPSETTING(    0x00, "2" )
 	PORT_DIPSETTING(    0x30, "3" )
 	PORT_DIPSETTING(    0x20, "5" )
-	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) ) /* Turning either of these switches on blanks the screen on reset */
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )	/* must be off (see notes) */
 	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x80, "ROM Type" )	/* will hang on startup if set to wrong type */
+	PORT_DIPSETTING(    0x80, "IC52=512kb, IC53=none" )
+	PORT_DIPSETTING(    0x00, "IC52=256kb, IC53=256kb" )
 
 	PORT_START_TAG("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  ) PORT_2WAY
@@ -488,13 +505,14 @@ INPUT_PORTS_END
 
 INPUT_PORTS_START( boblbobl )
 	PORT_START_TAG("DSW0")
-	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Language ) )
-	PORT_DIPSETTING(    0x01, DEF_STR( Japanese ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( English ) )
+	PORT_DIPNAME( 0x05, 0x04, "Mode" )
+	PORT_DIPSETTING(    0x04, "Game, English" )
+	PORT_DIPSETTING(    0x05, "Game, Japanese" )
+	PORT_DIPSETTING(    0x01, "Test (Grid and Inputs)" )
+	PORT_DIPSETTING(    0x00, "Test (RAM and Sound)" )
 	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Flip_Screen ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_SERVICE( 0x04, IP_ACTIVE_LOW ) /* works only in Japanese mode */
 	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
@@ -516,10 +534,11 @@ INPUT_PORTS_START( boblbobl )
 	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Very_Hard ) )
 	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Bonus_Life ) )
-	PORT_DIPSETTING(    0x08, "20K 80K" )
-	PORT_DIPSETTING(    0x0c, "30K 100K" )
-	PORT_DIPSETTING(    0x04, "40K 200K" )
-	PORT_DIPSETTING(    0x00, "50K 250K" )
+	PORT_DIPSETTING(    0x08, "20K 80K 300K" )
+	PORT_DIPSETTING(    0x0c, "30K 100K 400K" )
+	PORT_DIPSETTING(    0x04, "40K 200K 500K" )
+	PORT_DIPSETTING(    0x00, "50K 250K 500K" )
+	/* then more bonus lives at 1M 2M 3M 4M 5M - for all dip switch settings */
 	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x10, "1" )
 	PORT_DIPSETTING(    0x00, "2" )
@@ -534,8 +553,8 @@ INPUT_PORTS_START( boblbobl )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  ) PORT_2WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_2WAY
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
@@ -559,6 +578,7 @@ INPUT_PORTS_START( sboblbob )
 	PORT_DIPNAME( 0x01, 0x00, "Game" )
 	PORT_DIPSETTING(    0x01, "Bobble Bobble" )
 	PORT_DIPSETTING(    0x00, "Super Bobble Bobble" )
+	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
 
 	PORT_MODIFY( "DSW1" )
 	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Lives ) )
@@ -592,13 +612,14 @@ INPUT_PORTS_START( tokio )
 	PORT_DIPSETTING(    0x80, DEF_STR( 1C_2C ) )
 
 	PORT_START_TAG("DSW1")
-	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x03, DEF_STR( Easy ) )
-	PORT_DIPSETTING(    0x02, DEF_STR( Normal ) )
-	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Very_Hard ) )
-	PORT_DIPNAME( 0x0c, 0x08, DEF_STR( Bonus_Life ) )
-	PORT_DIPSETTING(    0x0C, "100K 400K" )
+	PORT_DIPNAME( 0x01, 0x01, "Enemies" )
+	PORT_DIPSETTING(    0x01, "Few (Easy)" )
+	PORT_DIPSETTING(    0x00, "Many (Hard)" )
+	PORT_DIPNAME( 0x02, 0x02, "Enemy Shots" )
+	PORT_DIPSETTING(    0x02, "Few (Easy)" )
+	PORT_DIPSETTING(    0x00, "Many (Hard)" )
+	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Bonus_Life ) )
+	PORT_DIPSETTING(    0x0c, "100K 400K" )
 	PORT_DIPSETTING(    0x08, "200K 400K" )
 	PORT_DIPSETTING(    0x04, "300K 400K" )
 	PORT_DIPSETTING(    0x00, "400K 400K" )
@@ -606,8 +627,8 @@ INPUT_PORTS_START( tokio )
 	PORT_DIPSETTING(    0x30, "3" )
 	PORT_DIPSETTING(    0x20, "4" )
 	PORT_DIPSETTING(    0x10, "5" )
-	PORT_DIPSETTING(    0x00, "99 (Cheat)")
-	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x00, "99 (Cheat)")	/* 6 in original version */
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unused ) )
 	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Language ) )
@@ -617,28 +638,28 @@ INPUT_PORTS_START( tokio )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* data ready from MCU */
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START_TAG("IN1")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  ) PORT_2WAY
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_2WAY
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  ) PORT_2WAY
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    ) PORT_2WAY
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  ) PORT_8WAY
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  ) PORT_8WAY
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    ) PORT_8WAY
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START_TAG("IN2")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  ) PORT_2WAY PORT_COCKTAIL
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_COCKTAIL
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  ) PORT_2WAY PORT_COCKTAIL
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    ) PORT_2WAY PORT_COCKTAIL
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
@@ -679,33 +700,11 @@ static void irqhandler(int irq)
 
 static struct YM2203interface ym2203_interface =
 {
-	1,				/* 1 chip */
-	MAIN_XTAL/8,	/* 3 MHz */
-	{ YM2203_VOL(25,25) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
-};
-
-static struct YM3526interface ym3526_interface =
-{
-	1,				/* 1 chip (no more supported) */
-	MAIN_XTAL/8,	/* 3 MHz */
-	{ 50 }			/* volume */
-};
-
-static struct YM2203interface tokio_ym2203_interface =
-{
-	1,				/* 1 chip */
-	MAIN_XTAL/8,	/* 3 MHz */
-	{ YM2203_VOL(100,8) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
+	0,
+	0,
+	0,
+	0,
+	irqhandler
 };
 
 
@@ -721,7 +720,7 @@ static MACHINE_DRIVER_START( tokio )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
 
 	MDRV_CPU_ADD(Z80, MAIN_XTAL/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 3 MHz */
+	/* audio CPU */	/* 3 MHz */
 	MDRV_CPU_PROGRAM_MAP(tokio_sound_map, 0) /* NMIs are triggered by the main CPU, IRQs are triggered by the YM2203 */
 
 	MDRV_FRAMES_PER_SECOND(VSYNC)	/* 59.185606 Hz */
@@ -738,7 +737,14 @@ static MACHINE_DRIVER_START( tokio )
 	MDRV_VIDEO_UPDATE(bublbobl)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, tokio_ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, MAIN_XTAL/8)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.08)
+	MDRV_SOUND_ROUTE(1, "mono", 0.08)
+	MDRV_SOUND_ROUTE(2, "mono", 0.08)
+	MDRV_SOUND_ROUTE(3, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( bublbobl )
@@ -752,7 +758,7 @@ static MACHINE_DRIVER_START( bublbobl )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
 
 	MDRV_CPU_ADD(Z80, MAIN_XTAL/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 3 MHz */
+	/* audio CPU */	/* 3 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_map, 0) /* IRQs are triggered by the YM2203 */
 
 #if 0
@@ -776,8 +782,14 @@ static MACHINE_DRIVER_START( bublbobl )
 	MDRV_VIDEO_UPDATE(bublbobl)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM3526, ym3526_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, MAIN_XTAL/8)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(YM3526, MAIN_XTAL/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( boblbobl )
@@ -788,7 +800,7 @@ static MACHINE_DRIVER_START( boblbobl )
 	MDRV_CPU_PROGRAM_MAP(bootleg_map, 0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)	/* interrupt mode 1, unlike Bubble Bobble */
 
-/*	MDRV_CPU_REMOVE("mcu") */
+/*  MDRV_CPU_REMOVE("mcu") */
 MACHINE_DRIVER_END
 
 
@@ -871,9 +883,67 @@ ROM_START( tokiob )
 ROM_END
 
 /* left for reference. The 68705 was from a bootleg, the original MCU is a 68701 */
-/*	ROM_LOAD( "68705.bin",    0x0000, 0x0800, CRC(78caa635) SHA1(a756e45b25b007843ba4f2204cad6081cf7260e9) )	   from a pirate board    */
+/*  ROM_LOAD( "68705.bin",    0x0000, 0x0800, CRC(78caa635) SHA1(a756e45b25b007843ba4f2204cad6081cf7260e9) )       from a pirate board    */
+
+
+/*
+
+bublbobl.zip - a78-05-1.52
+TAITO CORPORATION 1986
+ALL RIGHTS RESERVED
+VER 0.1 4.SEP,1986 SUMMER
+
+Name          Size    CRC32       Chip Type
+------------------------------------------
+a78-05-1.52   65536   0x9f8ee242  27C512
+a78-06-1.51   65536   0x36256bdc  27C512
+
+*/
 
 ROM_START( bublbobl )
+	ROM_REGION( 0x30000, REGION_CPU1, 0 )
+	ROM_LOAD( "a78-06-1.51",    0x00000, 0x10000, CRC(36256bdc) SHA1(e3a414291d77fc674f6c9476d1307d1c8206dfd7) )
+    /* ROMs banked at 8000-bfff */
+	ROM_LOAD( "a78-05-1.52",    0x10000, 0x10000, CRC(9f8ee242) SHA1(924150d4e7e087a9b2b0a294c2d0e9903a266c6c) )
+	/* 20000-2ffff empty */
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the second CPU */
+	ROM_LOAD( "a78-08.37",    0x0000, 0x08000, CRC(ae11a07b) SHA1(af7a335c8da637103103cc274e077f123908ebb7) )
+
+	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* 64k for the third CPU */
+	ROM_LOAD( "a78-07.46",    0x0000, 0x08000, CRC(4f9a26e8) SHA1(3105b34b88a7134493c2b3f584729f8b0407a011) )
+
+	ROM_REGION( 0x0800, REGION_CPU4, 0 )	/* 2k for the microcontroller */
+	ROM_LOAD( "68701.bin",    0x0000, 0x0800, NO_DUMP )
+
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
+	ROM_LOAD( "a78-09.12",    0x00000, 0x8000, CRC(20358c22) SHA1(2297af6c53d5807bf90a8e081075b8c72a994fc5) )    /* 1st plane */
+	ROM_LOAD( "a78-10.13",    0x08000, 0x8000, CRC(930168a9) SHA1(fd358c3c3b424bca285f67a1589eb98a345ff670) )
+	ROM_LOAD( "a78-11.14",    0x10000, 0x8000, CRC(9773e512) SHA1(33c1687ee575d66bf0e98add45d06da827813765) )
+	ROM_LOAD( "a78-12.15",    0x18000, 0x8000, CRC(d045549b) SHA1(0c12077d3ddc2ce6aa45a0224ad5540f3f218446) )
+	ROM_LOAD( "a78-13.16",    0x20000, 0x8000, CRC(d0af35c5) SHA1(c5a89f4d73acc0db86654540b3abfd77b3757db5) )
+	ROM_LOAD( "a78-14.17",    0x28000, 0x8000, CRC(7b5369a8) SHA1(1307b26d80e6f36ebe6c442bebec41d20066eaf9) )
+	/* 0x30000-0x3ffff empty */
+	ROM_LOAD( "a78-15.30",    0x40000, 0x8000, CRC(6b61a413) SHA1(44eddf12fb46fceca2addbe6da929aaea7636b13) )    /* 2nd plane */
+	ROM_LOAD( "a78-16.31",    0x48000, 0x8000, CRC(b5492d97) SHA1(d5b045e3ebaa44809757a4220cefb3c6815470da) )
+	ROM_LOAD( "a78-17.32",    0x50000, 0x8000, CRC(d69762d5) SHA1(3326fef4e0bd86681a3047dc11886bb171ecb609) )
+	ROM_LOAD( "a78-18.33",    0x58000, 0x8000, CRC(9f243b68) SHA1(32dce8d311a4be003693182a999e4053baa6bb0a) )
+	ROM_LOAD( "a78-19.34",    0x60000, 0x8000, CRC(66e9438c) SHA1(b94e62b6fbe7f4e08086d0365afc5cff6e0ccafd) )
+	ROM_LOAD( "a78-20.35",    0x68000, 0x8000, CRC(9ef863ad) SHA1(29f91b5a3765e4d6e6c3382db1d8d8297b6e56c8) )
+	/* 0x70000-0x7ffff empty */
+
+	ROM_REGION( 0x0100, REGION_PROMS, 0 )
+	ROM_LOAD( "a71-25.41",    0x0000, 0x0100, CRC(2d0f8545) SHA1(089c31e2f614145ef2743164f7b52ae35bc06808) )	/* video timing */
+ROM_END
+
+/*
+bublbob1.zip - a78-05.52
+TAITO CORPORATION 1986
+ALL RIGHTS RESERVED
+VER 0.018.AUG,1986 SUMMER
+*/
+
+ROM_START( bublbob1 )
 	ROM_REGION( 0x30000, REGION_CPU1, 0 )
 	ROM_LOAD( "a78-06.51",    0x00000, 0x08000, CRC(32c8305b) SHA1(6bf69b3edfbefd33cd670a762b4bf0b39629a220) )
     /* ROMs banked at 8000-bfff */
@@ -909,6 +979,13 @@ ROM_START( bublbobl )
 	ROM_LOAD( "a71-25.41",    0x0000, 0x0100, CRC(2d0f8545) SHA1(089c31e2f614145ef2743164f7b52ae35bc06808) )	/* video timing */
 ROM_END
 
+/*
+bublbobr.zip - a78-24.52
+1986 TAITO AMERICA CORP.
+LICENSED TO ROMSTAR FOR U.S.A.
+VER 5.1 8.NOV,1986 SUMMER
+*/
+
 ROM_START( bublbobr )
 	ROM_REGION( 0x30000, REGION_CPU1, 0 )
 	ROM_LOAD( "a78-25.51",    0x00000, 0x08000, CRC(2d901c9d) SHA1(72504225d3a26212e8f35508a79200eeb91138b6) )
@@ -945,6 +1022,13 @@ ROM_START( bublbobr )
 	ROM_LOAD( "a71-25.41",    0x0000, 0x0100, CRC(2d0f8545) SHA1(089c31e2f614145ef2743164f7b52ae35bc06808) )	/* video timing */
 ROM_END
 
+/*
+bubbobr1.zip - a78-21.52
+1986 TAITO AMERICA CORP.
+LICENSED TO ROMSTAR FOR U.S.A.
+VER 1.0 26.AUG,1986 SUMMER
+*/
+
 ROM_START( bubbobr1 )
 	ROM_REGION( 0x30000, REGION_CPU1, 0 )
 	ROM_LOAD( "a78-06.51",    0x00000, 0x08000, CRC(32c8305b) SHA1(6bf69b3edfbefd33cd670a762b4bf0b39629a220) )
@@ -1080,8 +1164,11 @@ static DRIVER_INIT( tokiob )
 
 GAMEX(1986, tokio,    0,        tokio,    tokio,    tokio,    ROT90, "Taito America Corporation (Romstar license)", "Tokio / Scramble Formation (US)", GAME_NOT_WORKING )
 GAME( 1986, tokiob,   tokio,    tokio,    tokio,    tokiob,   ROT90, "bootleg", "Tokio / Scramble Formation (bootleg)" )
+
 GAME( 1986, bublbobl, 0,        bublbobl, bublbobl, bublbobl, ROT0,  "Taito Corporation", "Bubble Bobble" )
+GAME( 1986, bublbob1, bublbobl, bublbobl, bublbobl, bublbobl, ROT0,  "Taito Corporation", "Bubble Bobble (older)" )
 GAME( 1986, bublbobr, bublbobl, bublbobl, bublbobl, bublbobl, ROT0,  "Taito America Corporation (Romstar license)", "Bubble Bobble (US with mode select)" )
 GAME( 1986, bubbobr1, bublbobl, bublbobl, bublbobl, bublbobl, ROT0,  "Taito America Corporation (Romstar license)", "Bubble Bobble (US)" )
+
 GAME( 1986, boblbobl, bublbobl, boblbobl, boblbobl, bublbobl, ROT0,  "bootleg", "Bobble Bobble" )
 GAME( 1986, sboblbob, bublbobl, boblbobl, sboblbob, bublbobl, ROT0,  "bootleg", "Super Bobble Bobble" )
