@@ -26,6 +26,8 @@ Known issues:
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
 
 #define BW_DEBUG 0
 #define BW_CHEAT 0
@@ -390,23 +392,6 @@ MACHINE_INIT( bwing )
 }
 
 
-static struct AY8910interface ay8910_interface =
-{
-	2,
-	1500000,
-	{ 50, 50 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 10 }
-};
-
 
 static MACHINE_DRIVER_START( bwing )
 
@@ -417,10 +402,10 @@ static MACHINE_DRIVER_START( bwing )
 
 	MDRV_CPU_ADD(M6809, 2000000)
 	MDRV_CPU_PROGRAM_MAP(bwp2_readmem, bwp2_writemem)
-/*	MDRV_CPU_VBLANK_INT(irq1_line_assert, 1) // vblank triggers FIRQ on CPU2 by design (unused) */
+/*  MDRV_CPU_VBLANK_INT(irq1_line_assert, 1) // vblank triggers FIRQ on CPU2 by design (unused) */
 
 	MDRV_CPU_ADD(DECO16, 2000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(bwp3_readmem, bwp3_writemem)
 	MDRV_CPU_IO_MAP(bwp3_readport, bwp3_writeport)
 	MDRV_CPU_PERIODIC_INT(bwp3_interrupt, 1000)
@@ -440,9 +425,16 @@ static MACHINE_DRIVER_START( bwing )
 	MDRV_VIDEO_UPDATE(bwing)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
 
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 MACHINE_DRIVER_END
 
 /***************************************************************************** */
