@@ -15,6 +15,8 @@ TODO:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
+#include "sound/okim6295.h"
+#include "sound/2413intf.h"
 
 
 /* in machine/kabuki.c */
@@ -160,12 +162,14 @@ static ADDRESS_MAP_START( cbasebal_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( cbasebal_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x10, 0x10) AM_READ(input_port_0_r)
 	AM_RANGE(0x11, 0x11) AM_READ(input_port_1_r)
 	AM_RANGE(0x12, 0x12) AM_READ(eeprom_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( cbasebal_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(cbasebal_bankswitch_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(eeprom_cs_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(eeprom_clock_w)
@@ -262,23 +266,6 @@ static struct GfxDecodeInfo cbasebal_gfxdecodeinfo[] =
 
 
 
-static struct YM2413interface ym2413_interface=
-{
-	1,	/* 1 chip */
-	3579545,	/* ???? */
-	{ YM2413_VOL(100,MIXER_PAN_CENTER,100,MIXER_PAN_CENTER) }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,			/* 1 chip */
-	{ 8000 },	/* 8000Hz ??? */
-	{ REGION_SOUND1 },	/* memory region */
-	{ 50 }
-};
-
-
-
 static MACHINE_DRIVER_START( cbasebal )
 
 	/* basic machine hardware */
@@ -303,8 +290,14 @@ static MACHINE_DRIVER_START( cbasebal )
 	MDRV_VIDEO_UPDATE(cbasebal)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
-	MDRV_SOUND_ADD(YM2413, ym2413_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(YM2413, 3579545)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
