@@ -1,9 +1,9 @@
 /***************************************************************************
 
-  Crude Buster (World version FX)		(c) 1990 Data East Corporation
-  Crude Buster (World version FU)		(c) 1990 Data East Corporation
-  Crude Buster (Japanese version)		(c) 1990 Data East Corporation
-  Two Crude (USA version)	    		(c) 1990 Data East USA
+  Crude Buster (World version FX)       (c) 1990 Data East Corporation
+  Crude Buster (World version FU)       (c) 1990 Data East Corporation
+  Crude Buster (Japanese version)       (c) 1990 Data East Corporation
+  Two Crude (USA version)               (c) 1990 Data East USA
 
   The 'FX' board is filled with 'FU' roms except for the 4 program roms,
   both boards have 'export' stickers which usually indicates a World version.
@@ -16,6 +16,9 @@
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/h6280/h6280.h"
+#include "sound/2203intf.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 VIDEO_START( twocrude );
 VIDEO_UPDATE( twocrude );
@@ -56,21 +59,21 @@ static WRITE16_HANDLER( twocrude_control_w )
 
 	case 4: /* Protection, maybe this is a PAL on the board?
 
-			80046 is level number
-			stop at stage and enter.
-			see also 8216..
+            80046 is level number
+            stop at stage and enter.
+            see also 8216..
 
-				9a 00 = pf4 over pf3 (normal) (level 0)
-				9a f1 =  (level 1 - water), pf3 over ALL sprites + pf4
-				9a 80 = pf3 over pf4 (Level 2 - copter)
-				9a 40 = pf3 over ALL sprites + pf4 (snow) level 3
-				9a c0 = doesn't matter?
-				9a ff = pf 3 over pf4
+                9a 00 = pf4 over pf3 (normal) (level 0)
+                9a f1 =  (level 1 - water), pf3 over ALL sprites + pf4
+                9a 80 = pf3 over pf4 (Level 2 - copter)
+                9a 40 = pf3 over ALL sprites + pf4 (snow) level 3
+                9a c0 = doesn't matter?
+                9a ff = pf 3 over pf4
 
-			I can't find a priority register, I assume it's tied to the
-			protection?!
+            I can't find a priority register, I assume it's tied to the
+            protection?!
 
-		*/
+        */
 		if ((data&0xffff)==0x9a00) prot=0;
 		if ((data&0xffff)==0xaa) prot=0x74;
 		if ((data&0xffff)==0x0200) prot=0x63<<8;
@@ -343,25 +346,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /******************************************************************************/
 
-static struct OKIM6295interface okim6295_interface =
-{
-	2,              /* 2 chips */
-	{ 32220000/32/132, 32220000/16/132 },/* Frequency */
-	{ REGION_SOUND1, REGION_SOUND2 },
-	{ 75, 60 } /* Note!  Keep chip 1 (voices) louder than chip 2 */
-};
-
-static struct YM2203interface ym2203_interface =
-{
-	1,
-	32220000/8, /* Accurate, audio section crystal is 32.220 MHz */
-	{ YM2203_VOL(60,60) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static void sound_irq(int state)
 {
 	cpunum_set_input_line(1,1,state); /* IRQ 2 */
@@ -369,10 +353,7 @@ static void sound_irq(int state)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	32220000/9, /* Accurate, audio section crystal is 32.220 MHz */
-	{ YM3012_VOL(45,MIXER_PAN_LEFT,45,MIXER_PAN_RIGHT) },
-	{ sound_irq }
+	sound_irq
 };
 
 static MACHINE_DRIVER_START( twocrude )
@@ -383,7 +364,7 @@ static MACHINE_DRIVER_START( twocrude )
 	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)/* VBL */
 
 	MDRV_CPU_ADD(H6280,32220000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Accurate */
+	/* audio CPU */	/* Accurate */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(58)
@@ -400,9 +381,23 @@ static MACHINE_DRIVER_START( twocrude )
 	MDRV_VIDEO_UPDATE(twocrude)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 32220000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
+
+	MDRV_SOUND_ADD(YM2151, 32220000/9)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.45)
+	MDRV_SOUND_ROUTE(1, "mono", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/32/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/32/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
 MACHINE_DRIVER_END
 
 /******************************************************************************/
