@@ -8,7 +8,7 @@
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
-
+#include "sound/dac.h"
 
 
 
@@ -33,11 +33,13 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)
 	AM_RANGE(0x01, 0x01) AM_READ(input_port_1_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x20, 0x3f) AM_WRITE(cheekyms_sprite_w)
 	AM_RANGE(0x40, 0x40) AM_WRITE(cheekyms_port_40_w)
 	AM_RANGE(0x80, 0x80) AM_WRITE(cheekyms_port_80_w)
@@ -131,13 +133,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 100 }
-};
-
-
 static MACHINE_DRIVER_START( cheekyms )
 
 	/* basic machine hardware */
@@ -162,7 +157,10 @@ static MACHINE_DRIVER_START( cheekyms )
 	MDRV_VIDEO_UPDATE(cheekyms)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
