@@ -15,6 +15,8 @@ Notes:
 #include "cpu/z80/z80.h"
 #include "cpu/konami/konami.h"
 #include "vidhrdw/konamiic.h"
+#include "sound/2151intf.h"
+#include "sound/k007232.h"
 
 static int K051316_readroms;
 
@@ -110,7 +112,7 @@ static WRITE8_HANDLER( chqflag_vreg_w )
 	}
 
 /*if ((data & 0xf8) && (data & 0xf8) != 0x88) */
-/*	usrintf_showmessage("chqflag_vreg_w %02x",data); */
+/*  usrintf_showmessage("chqflag_vreg_w %02x",data); */
 
 
 	/* other bits unknown. bit 5 is used. */
@@ -191,7 +193,7 @@ static ADDRESS_MAP_START( chqflag_readmem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xb000, 0xb00d) AM_READ(K007232_read_port_1_r)	/* 007232 (chip 2) */
 	AM_RANGE(0xc001, 0xc001) AM_READ(YM2151_status_port_0_r)	/* YM2151 */
 	AM_RANGE(0xd000, 0xd000) AM_READ(soundlatch_r)			/* soundlatch_r */
-	/*AM_RANGE(0xe000, 0xe000) AM_READ(MRA8_NOP)				   ???    */
+	/*AM_RANGE(0xe000, 0xe000) AM_READ(MRA8_NOP)                   ???    */
 ADDRESS_MAP_END
 
 static WRITE8_HANDLER( k007232_bankswitch_w )
@@ -258,7 +260,7 @@ INPUT_PORTS_START( chqflag )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "Coin Slot 2 Invalidity" ) */
+/*  PORT_DIPSETTING(    0x00, "Coin Slot 2 Invalidity" ) */
 
 	PORT_START	/* DSW #2 (according to the manual SW1 thru SW5 are not used) */
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unused ) )
@@ -330,11 +332,7 @@ static void chqflag_ym2151_irq_w(int data)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	3579545/2,	/* 3.579545/2 MHz? */
-	{ YM3012_VOL(80,MIXER_PAN_LEFT,80,MIXER_PAN_RIGHT) },
-	{ chqflag_ym2151_irq_w },
-	{ 0 }
+	chqflag_ym2151_irq_w
 };
 
 static void volume_callback0(int v)
@@ -353,14 +351,16 @@ static void volume_callback1(int v)
 	K007232_set_volume(1,0,(v & 0x0f)*0x11/2,(v >> 4)*0x11/2);
 }
 
-static struct K007232_interface k007232_interface =
+static struct K007232_interface k007232_interface_1 =
 {
-	2,															/* number of chips */
-	3579545,	/* clock */
-	{ REGION_SOUND1, REGION_SOUND2 },							/* memory regions */
-	{ K007232_VOL(20,MIXER_PAN_CENTER,20,MIXER_PAN_CENTER),		/* volume */
-		K007232_VOL(20,MIXER_PAN_LEFT,20,MIXER_PAN_RIGHT) },
-	{ volume_callback0,  volume_callback1 }						/* external port callback */
+	REGION_SOUND1,
+	volume_callback0
+};
+
+static struct K007232_interface k007232_interface_2 =
+{
+	REGION_SOUND2,
+	volume_callback1
 };
 
 static MACHINE_DRIVER_START( chqflag )
@@ -371,7 +371,7 @@ static MACHINE_DRIVER_START( chqflag )
 	MDRV_CPU_VBLANK_INT(chqflag_interrupt,16)	/* ? */
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ? */
+	/* audio CPU */	/* ? */
 	MDRV_CPU_PROGRAM_MAP(chqflag_readmem_sound,chqflag_writemem_sound)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -388,9 +388,24 @@ static MACHINE_DRIVER_START( chqflag )
 	MDRV_VIDEO_UPDATE(chqflag)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(K007232, k007232_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545/2)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.80)
+	MDRV_SOUND_ROUTE(1, "right", 0.80)
+
+	MDRV_SOUND_ADD(K007232, 3579545)
+	MDRV_SOUND_CONFIG(k007232_interface_1)
+	MDRV_SOUND_ROUTE(0, "left", 0.20)
+	MDRV_SOUND_ROUTE(0, "right", 0.20)
+	MDRV_SOUND_ROUTE(1, "left", 0.20)
+	MDRV_SOUND_ROUTE(1, "right", 0.20)
+
+	MDRV_SOUND_ADD(K007232, 3579545)
+	MDRV_SOUND_CONFIG(k007232_interface_2)
+	MDRV_SOUND_ROUTE(0, "left", 0.20)
+	MDRV_SOUND_ROUTE(1, "right", 0.20)
 MACHINE_DRIVER_END
 
 
