@@ -1,71 +1,72 @@
 /***************************************************************************
 
-	Atari Cloud 9 (prototype) hardware
+    Atari Cloud 9 (prototype) hardware
 
-	driver by Mike Balfour
+    driver by Mike Balfour
 
-	Games supported:
-		* Cloud 9
+    Games supported:
+        * Cloud 9
 
-	Known issues:
-		* none at this time
+    Known issues:
+        * none at this time
 
 ****************************************************************************
 
-	Cloud9 (prototype) driver.
+    Cloud9 (prototype) driver.
 
-	This hardware is yet another variant of the Centipede/Millipede hardware,
-	but as you can see there are some significant deviations...
+    This hardware is yet another variant of the Centipede/Millipede hardware,
+    but as you can see there are some significant deviations...
 
-	0000			R/W 	X index into the bitmap
-	0001			R/W 	Y index into the bitmap
-	0002			R/W 	Current bitmap pixel value
-	0003-05FF 	R/W 	RAM
-	0600-3FFF 	R/W 	Bitmap RAM bank 0 (and bank 1 ?)
-	5000-5073 	R/W 	Motion Object RAM
-	5400			W		Watchdog
-	5480			W		IRQ Acknowledge
-	5500-557F 	W		Color RAM (9 bits, 4 banks, LSB of Blue is addr&$40)
+    0000            R/W     X index into the bitmap
+    0001            R/W     Y index into the bitmap
+    0002            R/W     Current bitmap pixel value
+    0003-05FF   R/W     RAM
+    0600-3FFF   R/W     Bitmap RAM bank 0 (and bank 1 ?)
+    5000-5073   R/W     Motion Object RAM
+    5400            W       Watchdog
+    5480            W       IRQ Acknowledge
+    5500-557F   W       Color RAM (9 bits, 4 banks, LSB of Blue is addr&$40)
 
-	5580			W		Auto-increment X bitmap index (~D7)
-	5581			W		Auto-increment Y bitmap index (~D7)
-	5584			W		VRAM Both Banks - (D7) seems to allow writing to both banks
-	5585			W		Invert screen?
-	5586			W		VRAM Bank select?
-	5587			W		Color bank select
+    5580            W       Auto-increment X bitmap index (~D7)
+    5581            W       Auto-increment Y bitmap index (~D7)
+    5584            W       VRAM Both Banks - (D7) seems to allow writing to both banks
+    5585            W       Invert screen?
+    5586            W       VRAM Bank select?
+    5587            W       Color bank select
 
-	5600			W		Coin Counter 1 (D7)
-	5601			W		Coin Counter 2 (D7)
-	5602			W		Start1 LED (~D7)
-	5603			W		Start2 LED (~D7)
+    5600            W       Coin Counter 1 (D7)
+    5601            W       Coin Counter 2 (D7)
+    5602            W       Start1 LED (~D7)
+    5603            W       Start2 LED (~D7)
 
-	5680			W		Force Write to EAROM?
-	5700			W		EAROM Off?
-	5780			W		EAROM On?
+    5680            W       Force Write to EAROM?
+    5700            W       EAROM Off?
+    5780            W       EAROM On?
 
-	5800			R		IN0 (D7=Vblank, D6=Right Coin, D5=Left Coin, D4=Aux, D3=Self Test)
-	5801			R		IN1 (D7=Start1, D6=Start2, D5=Fire, D4=Zap)
-	5900			R		Trackball Vert
-	5901			R		Trackball Horiz
+    5800            R       IN0 (D7=Vblank, D6=Right Coin, D5=Left Coin, D4=Aux, D3=Self Test)
+    5801            R       IN1 (D7=Start1, D6=Start2, D5=Fire, D4=Zap)
+    5900            R       Trackball Vert
+    5901            R       Trackball Horiz
 
-	5A00-5A0F 	R/W 	Pokey 1
-	5B00-5B0F 	R/W 	Pokey 2
-	5C00-5CFF 	W		EAROM
-	6000-FFFF 	R		Program ROM
+    5A00-5A0F   R/W     Pokey 1
+    5B00-5B0F   R/W     Pokey 2
+    5C00-5CFF   W       EAROM
+    6000-FFFF   R       Program ROM
 
-	If you have any questions about how this driver works, don't hesitate to
-	ask.  - Mike Balfour (mab22@po.cwru.edu)
+    If you have any questions about how this driver works, don't hesitate to
+    ask.  - Mike Balfour (mab22@po.cwru.edu)
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/pokey.h"
 #include "cloud9.h"
 
 
 /*************************************
  *
- *	Output ports
+ *  Output ports
  *
  *************************************/
 
@@ -84,7 +85,7 @@ static WRITE8_HANDLER( cloud9_coin_counter_w )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -117,7 +118,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -172,7 +173,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -213,33 +214,27 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound interfaces
+ *  Sound interfaces
  *
  *************************************/
 
-static struct POKEYinterface pokey_interface =
+static struct POKEYinterface pokey_interface_1 =
 {
-	2,	/* 2 chips */
-	1500000,	/* 1.5 MHz??? */
-	{ 50, 50 },
-	/* The 8 pot handlers */
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 },
-	/* The allpot handler */
-	{ input_port_4_r, input_port_5_r },
+	{ 0 },
+	input_port_4_r
+};
+
+static struct POKEYinterface pokey_interface_2 =
+{
+	{ 0 },
+	input_port_5_r
 };
 
 
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -266,12 +261,20 @@ static MACHINE_DRIVER_START( cloud9 )
 	MDRV_VIDEO_UPDATE(cloud9)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(POKEY, pokey_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(POKEY, 1500000)
+	MDRV_SOUND_CONFIG(pokey_interface_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(POKEY, 1500000)
+	MDRV_SOUND_CONFIG(pokey_interface_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -294,7 +297,7 @@ ROM_END
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
