@@ -9,8 +9,8 @@
   Robocop 2         (c) 1991 Data East Corporation (Japanese version)
   Robocop 2         (c) 1991 Data East Corporation (World version)
   Stone Age         (Italian bootleg)
-  Mutant Fighter	(c) 1992 Data East Corporation (World version)
-  Death Brade		(c) 1992 Data East Corporation (Japanese version)
+  Mutant Fighter    (c) 1992 Data East Corporation (World version)
+  Death Brade       (c) 1992 Data East Corporation (Japanese version)
 
   Edward Randy runs on the same board as Caveman Ninja but the protection
   chip is different.  Robocop 2 also has a different protection chip but
@@ -40,6 +40,9 @@ Caveman Ninja Issues:
 #include "deco16ic.h"
 #include "decocrpt.h"
 #include "decoprot.h"
+#include "sound/2203intf.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 static int cninja_scanline, cninja_irq_mask;
 static void *raster_irq_timer;
@@ -98,10 +101,10 @@ static WRITE16_HANDLER( cninja_irq_w )
 	switch (offset) {
 	case 0:
 		/* IRQ enable:
-			0xca:	Raster IRQ turned off
-			0xc8:	Raster IRQ turned on (68k IRQ level 4)
-			0xd8:	Raster IRQ turned on (68k IRQ level 3)
-		*/
+            0xca:   Raster IRQ turned off
+            0xc8:   Raster IRQ turned on (68k IRQ level 4)
+            0xd8:   Raster IRQ turned on (68k IRQ level 3)
+        */
 		logerror("%08x:  IRQ write %d %08x\n",activecpu_get_pc(),offset,data);
 		cninja_irq_mask=data&0xff;
 		return;
@@ -258,7 +261,7 @@ static ADDRESS_MAP_START( robocop2_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 
 	AM_RANGE(0x180000, 0x1807ff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x18c064, 0x18c065) AM_WRITE(cninja_sound_w)
-/*	AM_RANGE(0x18c000, 0x18c0ff) AM_WRITE(cninja_loopback_w)    Protection writes    */
+/*  AM_RANGE(0x18c000, 0x18c0ff) AM_WRITE(cninja_loopback_w)    Protection writes    */
 	AM_RANGE(0x198000, 0x198001) AM_WRITE(buffer_spriteram16_w) /* DMA flag */
 	AM_RANGE(0x1a8000, 0x1a9fff) AM_WRITE(deco16_nonbuffered_palette_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x1b0000, 0x1b0007) AM_WRITE(cninja_irq_w)
@@ -495,8 +498,8 @@ INPUT_PORTS_START( cninja )
 	PORT_DIPSETTING(      0x0040, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x0080, 0x0080, DEF_STR( Unknown ) )	/* If DS #1-#6 are all ON */
-	PORT_DIPSETTING(      0x0080, DEF_STR( Off ) )		/*	Standard Coin Credit */
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )		/*	2 Coins to Start / 1 Coin to Continue */
+	PORT_DIPSETTING(      0x0080, DEF_STR( Off ) )		/*  Standard Coin Credit */
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )		/*  2 Coins to Start / 1 Coin to Continue */
 	PORT_DIPNAME( 0x0300, 0x0300, DEF_STR( Lives ) )
 	PORT_DIPSETTING(      0x0100, "1" )
 	PORT_DIPSETTING(      0x0000, "2" )
@@ -832,17 +835,6 @@ static MACHINE_INIT( cninja )
 	cninja_irq_mask=0;
 }
 
-static struct YM2203interface ym2203_interface =
-{
-	1,
-	32220000/8, /* Accurate, audio section crystal is 32.220 MHz */
-	{ YM2203_VOL(60,60) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static void sound_irq(int state)
 {
 	cpunum_set_input_line(1,1,state); /* IRQ 2 */
@@ -861,27 +853,13 @@ static WRITE8_HANDLER( sound_bankswitch_w )
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	32220000/9, /* Accurate, audio section crystal is 32.220 MHz */
-	{ YM3012_VOL(45,MIXER_PAN_LEFT,45,MIXER_PAN_RIGHT) },
-	{ sound_irq },
-	{ sound_bankswitch_w }
+	sound_irq,
+	sound_bankswitch_w
 };
 
 static struct YM2151interface ym2151_interface2 =
 {
-	1,
-	3579545,	/* 3.579545 MHz (?) */
-	{ YM3012_VOL(50,MIXER_PAN_CENTER,50,MIXER_PAN_CENTER) },
-	{ sound_irq2 }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	2,              /* 2 chips */
-	{ 32220000/32/132, 32220000/16/132 },/* Frequency */
-	{ REGION_SOUND1, REGION_SOUND2 },
-	{ 75, 60 } /* Note!  Keep chip 1 (voices) louder than chip 2 */
+	sound_irq2
 };
 
 /**********************************************************************************/
@@ -894,7 +872,7 @@ static MACHINE_DRIVER_START( cninja )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
 
 	MDRV_CPU_ADD(H6280,32220000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Accurate */
+	/* audio CPU */	/* Accurate */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_MACHINE_INIT(cninja)
@@ -913,9 +891,23 @@ static MACHINE_DRIVER_START( cninja )
 	MDRV_VIDEO_EOF(cninja)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 32220000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
+
+	MDRV_SOUND_ADD(YM2151, 32220000/9)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.45)
+	MDRV_SOUND_ROUTE(1, "mono", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/32/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/16/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( stoneage )
@@ -926,7 +918,7 @@ static MACHINE_DRIVER_START( stoneage )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(stoneage_s_readmem,stoneage_s_writemem)
 
 	MDRV_MACHINE_INIT(cninja)
@@ -945,8 +937,20 @@ static MACHINE_DRIVER_START( stoneage )
 	MDRV_VIDEO_EOF(cninja)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface2)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 32220000/9)
+	MDRV_SOUND_CONFIG(ym2151_interface2)
+	MDRV_SOUND_ROUTE(0, "mono", 0.45)
+	MDRV_SOUND_ROUTE(1, "mono", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/32/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/16/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( edrandy )
@@ -957,7 +961,7 @@ static MACHINE_DRIVER_START( edrandy )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
 
 	MDRV_CPU_ADD(H6280,32220000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Accurate */
+	/* audio CPU */	/* Accurate */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_MACHINE_INIT(cninja)
@@ -976,9 +980,23 @@ static MACHINE_DRIVER_START( edrandy )
 	MDRV_VIDEO_EOF(cninja)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 32220000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
+
+	MDRV_SOUND_ADD(YM2151, 32220000/9)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.45)
+	MDRV_SOUND_ROUTE(1, "mono", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/32/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/16/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( robocop2 )
@@ -989,7 +1007,7 @@ static MACHINE_DRIVER_START( robocop2 )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
 
 	MDRV_CPU_ADD(H6280,32220000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Accurate */
+	/* audio CPU */	/* Accurate */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_MACHINE_INIT(cninja)
@@ -1008,10 +1026,26 @@ static MACHINE_DRIVER_START( robocop2 )
 	MDRV_VIDEO_EOF(cninja)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2203, 32220000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.60)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.60)
+
+	MDRV_SOUND_ADD(YM2151, 32220000/9)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/32/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.75)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.75)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/16/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.60)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.60)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( mutantf )
@@ -1022,7 +1056,7 @@ static MACHINE_DRIVER_START( mutantf )
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
 	MDRV_CPU_ADD(H6280,32220000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem_mutantf,sound_writemem_mutantf)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -1039,9 +1073,22 @@ static MACHINE_DRIVER_START( mutantf )
 	MDRV_VIDEO_UPDATE(mutantf)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 32220000/9)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/32/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.75)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.75)
+
+	MDRV_SOUND_ADD(OKIM6295, 32220000/16/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.60)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.60)
 MACHINE_DRIVER_END
 
 /**********************************************************************************/
@@ -1227,7 +1274,7 @@ ROM_START( stoneage )
 	ROM_LOAD16_BYTE( "gl-09.rom",  0x00000,  0x10000,  CRC(5a2d4752) SHA1(617dd10a99b5b55ca64dcdd22a0f133b0d6b770d) )
 
 	/* The bootleg graphics are stored in a different arrangement but
-		seem to be the same as the original set */
+        seem to be the same as the original set */
 
 	ROM_REGION( 0x080000, REGION_GFX2, ROMREGION_DISPOSE )
 	ROM_LOAD( "mag-02.rom", 0x000000, 0x80000,  CRC(de89c69a) SHA1(b41bdf859854b5541c7eae7cd541b910cea1f839) )	/* tiles 3 */
