@@ -37,14 +37,14 @@ TODO:
 
 Credits:
 
-	Hardware Info:
-		Jose Tejada Gomez
-		Manuel Abadia
-		Cesareo Gutierrez
+    Hardware Info:
+        Jose Tejada Gomez
+        Manuel Abadia
+        Cesareo Gutierrez
 
-	MAME Driver:
-		Phil Stroffolino
-		Manuel Abadia
+    MAME Driver:
+        Phil Stroffolino
+        Manuel Abadia
 
 Memory Maps (preliminary):
 
@@ -54,29 +54,29 @@ Memory Maps (preliminary):
 
 MAIN CPU:
 ---------
-00c0-00c3	Objects control
-0500		bankswitch control
-0600-06ff	palette
-0800-1fff	RAM
-2000-2fff	Video RAM (banked)
-3000-3fff	Object RAM (banked)
-4000-7fff	Banked Area + IO + Video Registers
-8000-ffff	ROM
+00c0-00c3   Objects control
+0500        bankswitch control
+0600-06ff   palette
+0800-1fff   RAM
+2000-2fff   Video RAM (banked)
+3000-3fff   Object RAM (banked)
+4000-7fff   Banked Area + IO + Video Registers
+8000-ffff   ROM
 
 SOUND CPU:
 ----------
-0000-8000	ROM
-8000-87ef	RAM
-87f0-87ff	???
-9000-9001	YM2203
-9008		???
-9800		OKIM5205?
-a000		soundlatch?
-a800		OKIM5205?
-fffc-ffff	???
+0000-8000   ROM
+8000-87ef   RAM
+87f0-87ff   ???
+9000-9001   YM2203
+9008        ???
+9800        OKIM5205?
+a000        soundlatch?
+a800        OKIM5205?
+fffc-ffff   ???
 
 
-		Notes about the sound systsem of the bootleg:
+        Notes about the sound systsem of the bootleg:
         ---------------------------------------------
         The positions 0x87f0-0x87ff are very important, it
         does work similar to a semaphore (same as a lot of
@@ -86,39 +86,41 @@ fffc-ffff	???
         I have tried put here a K007232 chip, but it didn't
         work.
 
-		Sound chips: OKI M5205 & YM2203
+        Sound chips: OKI M5205 & YM2203
 
-		We are using the other sound hardware for now.
+        We are using the other sound hardware for now.
 
 ****************************
 * Combat School (Original) *
 ****************************
 
-0000-005f	Video Registers (banked)
-0400-0407	input ports
-0408		coin counters
-0410		bankswitch control
-0600-06ff	palette
-0800-1fff	RAM
-2000-2fff	Video RAM (banked)
-3000-3fff	Object RAM (banked)
-4000-7fff	Banked Area + IO + Video Registers
-8000-ffff	ROM
+0000-005f   Video Registers (banked)
+0400-0407   input ports
+0408        coin counters
+0410        bankswitch control
+0600-06ff   palette
+0800-1fff   RAM
+2000-2fff   Video RAM (banked)
+3000-3fff   Object RAM (banked)
+4000-7fff   Banked Area + IO + Video Registers
+8000-ffff   ROM
 
 SOUND CPU:
 ----------
-0000-8000	ROM
-8000-87ff	RAM
-9000		uPD7759
-b000		uPD7759
-c000		uPD7759
-d000		soundlatch_r
-e000-e001	YM2203
+0000-8000   ROM
+8000-87ff   RAM
+9000        uPD7759
+b000        uPD7759
+c000        uPD7759
+d000        soundlatch_r
+e000-e001   YM2203
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
+#include "sound/2203intf.h"
+#include "sound/upd7759.h"
 
 extern unsigned char* banked_area;
 
@@ -218,12 +220,12 @@ static WRITE8_HANDLER( combasc_sh_irqtrigger_w )
 
 static WRITE8_HANDLER( combasc_play_w )
 {
-	UPD7759_start_w(0, data & 2);
+	upd7759_start_w(0, data & 2);
 }
 
 static WRITE8_HANDLER( combasc_voice_reset_w )
 {
-    UPD7759_reset_w(0,data & 1);
+    upd7759_reset_w(0,data & 1);
 }
 
 static WRITE8_HANDLER( combasc_portA_w )
@@ -236,7 +238,7 @@ static mame_timer *combasc_interleave_timer;
 static READ8_HANDLER ( combasc_YM2203_status_port_0_r )
 {
 	static int boost = 1;
-	int status = YM2203Read(0,0);
+	int status = YM2203_status_port_0_r(0);
 
 	if (activecpu_get_pc() == 0x334)
 	{
@@ -275,7 +277,7 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( combasc_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0007) AM_WRITE(combasc_pf_control_w)
 	AM_RANGE(0x0020, 0x005f) AM_WRITE(combasc_scrollram_w)
-/*	AM_RANGE(0x0060, 0x00ff) AM_WRITE(MWA8_RAM)					   RAM    */
+/*  AM_RANGE(0x0060, 0x00ff) AM_WRITE(MWA8_RAM)                    RAM    */
 	AM_RANGE(0x0200, 0x0201) AM_WRITE(protection_w)
 	AM_RANGE(0x0206, 0x0206) AM_WRITE(protection_clock_w)
 	AM_RANGE(0x0408, 0x0408) AM_WRITE(combasc_coin_counter_w)	/* coin counters */
@@ -328,8 +330,8 @@ static ADDRESS_MAP_START( writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x87f0, 0x87ff) AM_WRITE(MWA8_RAM)				/* ??? */
  	AM_RANGE(0x9000, 0x9000) AM_WRITE(YM2203_control_port_0_w)/* YM 2203 */
 	AM_RANGE(0x9001, 0x9001) AM_WRITE(YM2203_write_port_0_w)	/* YM 2203 */
-	/*AM_RANGE(0x9800, 0x9800) AM_WRITE(combasc_unknown_w_1)	   OKIM5205?    */
-	/*AM_RANGE(0xa800, 0xa800) AM_WRITE(combasc_unknown_w_2)	   OKIM5205?    */
+	/*AM_RANGE(0x9800, 0x9800) AM_WRITE(combasc_unknown_w_1)       OKIM5205?    */
+	/*AM_RANGE(0xa800, 0xa800) AM_WRITE(combasc_unknown_w_2)       OKIM5205?    */
 	AM_RANGE(0x8800, 0xfffb) AM_WRITE(MWA8_ROM)				/* ROM */
 	AM_RANGE(0xfffc, 0xffff) AM_WRITE(MWA8_RAM)				/* ??? */
 ADDRESS_MAP_END
@@ -338,7 +340,7 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( combasc_readmem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)					/* ROM */
 	AM_RANGE(0x8000, 0x87ff) AM_READ(MRA8_RAM)					/* RAM */
-	AM_RANGE(0xb000, 0xb000) AM_READ(UPD7759_0_busy_r)			/* UPD7759 busy? */
+	AM_RANGE(0xb000, 0xb000) AM_READ(upd7759_0_busy_r)			/* upd7759 busy? */
 	AM_RANGE(0xd000, 0xd000) AM_READ(soundlatch_r)				/* soundlatch_r? */
 	AM_RANGE(0xe000, 0xe000) AM_READ(combasc_YM2203_status_port_0_r)	/* YM 2203 intercepted */
 ADDRESS_MAP_END
@@ -346,9 +348,9 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( combasc_writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)				/* ROM */
 	AM_RANGE(0x8000, 0x87ff) AM_WRITE(MWA8_RAM)				/* RAM */
-	AM_RANGE(0x9000, 0x9000) AM_WRITE(combasc_play_w)			/* uPD7759 play voice */
-	AM_RANGE(0xa000, 0xa000) AM_WRITE(UPD7759_0_port_w)		/* uPD7759 voice select */
-	AM_RANGE(0xc000, 0xc000) AM_WRITE(combasc_voice_reset_w)	/* uPD7759 reset? */
+	AM_RANGE(0x9000, 0x9000) AM_WRITE(combasc_play_w)			/* upd7759 play voice */
+	AM_RANGE(0xa000, 0xa000) AM_WRITE(upd7759_0_port_w)		/* upd7759 voice select */
+	AM_RANGE(0xc000, 0xc000) AM_WRITE(combasc_voice_reset_w)	/* upd7759 reset? */
  	AM_RANGE(0xe000, 0xe000) AM_WRITE(YM2203_control_port_0_w)/* YM 2203 */
 	AM_RANGE(0xe001, 0xe001) AM_WRITE(YM2203_write_port_0_w)	/* YM 2203 */
 ADDRESS_MAP_END
@@ -645,22 +647,16 @@ static struct GfxDecodeInfo combascb_gfxdecodeinfo[] =
 
 static struct YM2203interface ym2203_interface =
 {
-	1,							/* 1 chip */
-	3000000,					/* 24MHz(XTAL)/8 = 3MHz */
-	{ YM2203_VOL(20,20) },
-	{ 0 },
-	{ 0 },
-	{ combasc_portA_w },
-	{ 0 }
+	0,
+	0,
+	combasc_portA_w,
+	0
 };
 
-static struct UPD7759_interface upd7759_interface =
+static struct upd7759_interface upd7759_interface =
 {
-	1,							/* number of chips */
-	{ 70 },						/* volume */
-	{ REGION_SOUND1 },			/* memory region */
-	UPD7759_STANDALONE_MODE,	/* chip mode */
-	{0}
+	REGION_SOUND1,			/* memory region */
+	0
 };
 
 
@@ -674,7 +670,7 @@ static MACHINE_DRIVER_START( combasc )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,3579545)	/* 3.579545 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(combasc_readmem_sound,combasc_writemem_sound)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -696,8 +692,15 @@ static MACHINE_DRIVER_START( combasc )
 	MDRV_VIDEO_UPDATE(combasc)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(UPD7759, upd7759_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+
+	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
+	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.70)
 MACHINE_DRIVER_END
 
 /* combat school (bootleg on different hardware) */
@@ -709,7 +712,7 @@ static MACHINE_DRIVER_START( combascb )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,3579545)	/* 3.579545 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(combasc_readmem_sound,combasc_writemem_sound) /* FAKE */
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -731,8 +734,15 @@ static MACHINE_DRIVER_START( combascb )
 	MDRV_VIDEO_UPDATE(combascb)
 
 	/* We are using the original sound subsystem */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(UPD7759, upd7759_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+
+	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
+	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.70)
 MACHINE_DRIVER_END
 
 
