@@ -4,7 +4,7 @@ Universal board numbers (found on the schematics)
 
 Cosmic Guerilla - 7907A
 Cosmic Alien    - 7910
-Magical Spot	- 8013
+Magical Spot    - 8013
 Magical Spot II - 8013
 Devil Zone      - 8022
 
@@ -14,6 +14,8 @@ Devil Zone      - 8022
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/samples.h"
+#include "sound/dac.h"
 
 
 PALETTE_INIT( panic );
@@ -166,7 +168,7 @@ WRITE8_HANDLER( cosmicg_output_w )
 				 break;
 
 		case 9:  if (data) sample_start(3, 11, 0); break;	/* Got Ship */
-/*		case 11: watchdog_reset_w(0, 0); break;				   Watchdog    */
+/*      case 11: watchdog_reset_w(0, 0); break;                Watchdog    */
 		case 13: if (data) sample_start(8, 13-gun_die_select, 0); break;  /* Got Monster / Gunshot */
 		case 14: gun_die_select = data; break;
 		case 15: if (data) sample_start(5, 14, 0); break;	/* Coin Extend (extra base) */
@@ -214,9 +216,9 @@ static INTERRUPT_GEN( cosmicg_interrupt )
     /* Insert Coin */
 
 	/* R Nabet : fixed to make this piece of code sensible.
-	I assumed that the interrupt request lasted for as long as the coin was "sensed".
-	It makes sense and works fine, but I cannot be 100% sure this is correct,
-	as I have no Cosmic Guerilla console :-) . */
+    I assumed that the interrupt request lasted for as long as the coin was "sensed".
+    It makes sense and works fine, but I cannot be 100% sure this is correct,
+    as I have no Cosmic Guerilla console :-) . */
 
 	if ((readinputport(2) & 1)) /* Coin */
 	{
@@ -526,7 +528,7 @@ INPUT_PORTS_START( cosmicg )
 	PORT_START      /* Hard wired settings */
 
 	/* The coin slots are not memory mapped. Coin causes INT 4  */
-	/* This fake input port is used by the interrupt handler 	*/
+	/* This fake input port is used by the interrupt handler    */
 	/* to be notified of coin insertions. */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
 
@@ -828,7 +830,7 @@ INPUT_PORTS_START( nomnlnd )
 	PORT_DIPSETTING(    0x00, DEF_STR( None ) )
 	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 2C_1C ) )
-/*	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( 1C_2C ) )
 	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Lives ) )
@@ -876,7 +878,7 @@ INPUT_PORTS_START( nomnlndg )
 	PORT_DIPSETTING(    0x00, DEF_STR( None ) )
 	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 2C_1C ) )
-/*	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( 1C_2C ) )
 	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Lives ) )
@@ -947,12 +949,6 @@ static struct GfxDecodeInfo cosmica_gfxdecodeinfo[] =
 };
 
 
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 100 }
-};
-
 static const char *panic_sample_names[] =
 {
 	"*panic",
@@ -973,7 +969,6 @@ static const char *panic_sample_names[] =
 static struct Samplesinterface panic_samples_interface =
 {
 	9,	/* 9 channels */
-	25,	/* volume */
 	panic_sample_names
 };
 
@@ -1001,7 +996,6 @@ static const char *cosmicg_sample_names[] =
 static struct Samplesinterface cosmicg_samples_interface =
 {
 	9,	/* 9 channels */
-	25,	/* volume */
 	cosmicg_sample_names
 };
 
@@ -1039,8 +1033,14 @@ static MACHINE_DRIVER_START( panic )
 	MDRV_VIDEO_UPDATE(panic)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SAMPLES, panic_samples_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(panic_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1069,8 +1069,8 @@ static MACHINE_DRIVER_START( cosmicg )
 	MDRV_CPU_ADD(TMS9980, 1228500)
 			/* 9.828 MHz Crystal */
 			/* R Nabet : huh ? This would imply the crystal frequency is somehow divided by 2 before being
-			fed to the tms9904 or tms9980.  Also, I have never heard of a tms9900/9980 operating under
-			1.5MHz.  So, if someone can check this... */
+            fed to the tms9904 or tms9980.  Also, I have never heard of a tms9900/9980 operating under
+            1.5MHz.  So, if someone can check this... */
 	MDRV_CPU_PROGRAM_MAP(cosmicg_readmem,cosmicg_writemem)
 	MDRV_CPU_IO_MAP(cosmicg_readport,cosmicg_writeport)
 	MDRV_CPU_VBLANK_INT(cosmicg_interrupt,1)
@@ -1088,8 +1088,14 @@ static MACHINE_DRIVER_START( cosmicg )
 	MDRV_VIDEO_UPDATE(cosmicg)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SAMPLES, cosmicg_samples_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(cosmicg_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1111,7 +1117,10 @@ static MACHINE_DRIVER_START( magspot2 )
 	MDRV_VIDEO_UPDATE(magspot2)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1143,7 +1152,10 @@ static MACHINE_DRIVER_START( nomnlnd )
 	MDRV_VIDEO_UPDATE(nomnlnd)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
