@@ -1,14 +1,14 @@
 /***************************************************************************
 
-	Kitco Crowns Golf hardware
+    Kitco Crowns Golf hardware
 
-	driver by Aaron Giles
+    driver by Aaron Giles
 
-	Games supported:
-		* Crowns Golf (4 sets)
+    Games supported:
+        * Crowns Golf (4 sets)
 
-	Known bugs:
-		* not sure if the analog inputs are handled correctly
+    Known bugs:
+        * not sure if the analog inputs are handled correctly
 
 Text Strings in sound CPU ROM read:
 ARIES ELECA
@@ -21,12 +21,13 @@ WHO AM I?      (In place of "ARIES ELECA")
 
 ****************************************************************************
 
-	Memory map (TBA)
+    Memory map (TBA)
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "crgolf.h"
+#include "sound/ay8910.h"
 
 
 /* constants */
@@ -41,7 +42,7 @@ static data8_t main_to_sound_data, sound_to_main_data;
 
 /*************************************
  *
- *	ROM banking
+ *  ROM banking
  *
  *************************************/
 
@@ -61,7 +62,7 @@ static MACHINE_INIT( crgolf )
 
 /*************************************
  *
- *	Input ports
+ *  Input ports
  *
  *************************************/
 
@@ -98,7 +99,7 @@ static WRITE8_HANDLER( unknown_w )
 
 /*************************************
  *
- *	Main->Sound CPU communications
+ *  Main->Sound CPU communications
  *
  *************************************/
 
@@ -125,7 +126,7 @@ static READ8_HANDLER( main_to_sound_r )
 
 /*************************************
  *
- *	Sound->Main CPU communications
+ *  Sound->Main CPU communications
  *
  *************************************/
 
@@ -152,7 +153,7 @@ static READ8_HANDLER( sound_to_main_r )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -187,7 +188,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
@@ -215,7 +216,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -291,26 +292,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Sound definitions
- *
- *************************************/
-
-static struct AY8910interface ay8910_interface =
-{
-	1,
-	MASTER_CLOCK/3/2/2,
-	{ 100 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
-
-/*************************************
- *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -342,14 +324,16 @@ static MACHINE_DRIVER_START( crgolf )
 	MDRV_VIDEO_UPDATE(crgolf)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(AY8910, MASTER_CLOCK/3/2/2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definition(s)
+ *  ROM definition(s)
  *
  *************************************/
 
@@ -458,7 +442,7 @@ ROM_END
 
 /*************************************
  *
- *	Game driver(s)
+ *  Game driver(s)
  *
  *************************************/
 
