@@ -3,7 +3,7 @@
 Crime Fighters (Konami GX821) (c) 1989 Konami
 
 Preliminary driver by:
-	Manuel Abadia <manu@teleline.es>
+    Manuel Abadia <manu@teleline.es>
 
 ***************************************************************************/
 
@@ -11,6 +11,8 @@ Preliminary driver by:
 #include "vidhrdw/generic.h"
 #include "cpu/konami/konami.h" /* for the callback and the firq irq definition */
 #include "vidhrdw/konamiic.h"
+#include "sound/2151intf.h"
+#include "sound/k007232.h"
 
 
 /* prototypes */
@@ -109,7 +111,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************
 
-	Input Ports
+    Input Ports
 
 ***************************************************************************/
 
@@ -132,23 +134,23 @@ INPUT_PORTS_START( crimfght )
 	PORT_DIPSETTING(    0x0a, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x09, DEF_STR( 1C_7C ) )
 	PORT_DIPSETTING(    0x00, "1 Coin/99 Credits" )
-/*	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(    0x20, DEF_STR( 4C_1C ) )
-	PORT_DIPSETTING(    0x50, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(    0x80, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( 3C_2C ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( 4C_3C ) )
-	PORT_DIPSETTING(    0xf0, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(    0x30, DEF_STR( 3C_4C ) )
-	PORT_DIPSETTING(    0x70, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(    0xe0, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(    0x60, DEF_STR( 2C_5C ) )
-	PORT_DIPSETTING(    0xd0, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ) )
-	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
-	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
-	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-	PORT_DIPSETTING(    0x00, "Invalid" ) */
+/*  PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_B ) )
+    PORT_DIPSETTING(    0x20, DEF_STR( 4C_1C ) )
+    PORT_DIPSETTING(    0x50, DEF_STR( 3C_1C ) )
+    PORT_DIPSETTING(    0x80, DEF_STR( 2C_1C ) )
+    PORT_DIPSETTING(    0x40, DEF_STR( 3C_2C ) )
+    PORT_DIPSETTING(    0x10, DEF_STR( 4C_3C ) )
+    PORT_DIPSETTING(    0xf0, DEF_STR( 1C_1C ) )
+    PORT_DIPSETTING(    0x30, DEF_STR( 3C_4C ) )
+    PORT_DIPSETTING(    0x70, DEF_STR( 2C_3C ) )
+    PORT_DIPSETTING(    0xe0, DEF_STR( 1C_2C ) )
+    PORT_DIPSETTING(    0x60, DEF_STR( 2C_5C ) )
+    PORT_DIPSETTING(    0xd0, DEF_STR( 1C_3C ) )
+    PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ) )
+    PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
+    PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
+    PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
+    PORT_DIPSETTING(    0x00, "Invalid" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
@@ -274,7 +276,7 @@ INPUT_PORTS_START( crimfgtj )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )
@@ -354,17 +356,14 @@ INPUT_PORTS_END
 
 /***************************************************************************
 
-	Machine Driver
+    Machine Driver
 
 ***************************************************************************/
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	4000000,	/* adjusted to be in sync with Z80 CPU */
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },	/* music volume */
-	{ 0 },
-	{ crimfght_snd_bankswitch_w }
+	0,
+	crimfght_snd_bankswitch_w
 };
 
 static void volume_callback(int v)
@@ -375,11 +374,8 @@ static void volume_callback(int v)
 
 static struct K007232_interface k007232_interface =
 {
-	1,		/* number of chips */
-	3579545,	/* clock */
-	{ REGION_SOUND1 },	/* memory regions */
-	{ K007232_VOL(20,MIXER_PAN_CENTER,20,MIXER_PAN_CENTER) },	/* volume */
-	{ volume_callback }	/* external port callback */
+	REGION_SOUND1,	/* memory regions */
+	volume_callback	/* external port callback */
 };
 
 
@@ -391,11 +387,11 @@ static MACHINE_DRIVER_START( crimfght )
 	MDRV_CPU_PROGRAM_MAP(crimfght_readmem,crimfght_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
-	MDRV_CPU_ADD(Z80, 4000000)	/* compared with a real PCB, guessed but accurate */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	MDRV_CPU_ADD(Z80, 3579545)	/* verified with PCB */
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(crimfght_readmem_sound,crimfght_writemem_sound)
 
-	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_FRAMES_PER_SECOND(54)	/* adjusted - compared with PCB speed */
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
 	MDRV_MACHINE_INIT(crimfght)
@@ -410,9 +406,19 @@ static MACHINE_DRIVER_START( crimfght )
 	MDRV_VIDEO_UPDATE(crimfght)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(K007232, k007232_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)	/* verified with PCB */
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+
+	MDRV_SOUND_ADD(K007232, 3579545)
+	MDRV_SOUND_CONFIG(k007232_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.20)
+	MDRV_SOUND_ROUTE(0, "right", 0.20)
+	MDRV_SOUND_ROUTE(1, "left", 0.20)
+	MDRV_SOUND_ROUTE(1, "right", 0.20)
 MACHINE_DRIVER_END
 
 /***************************************************************************
