@@ -22,6 +22,8 @@ some bits by David Haywood
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/okim6295.h"
+#include "sound/3812intf.h"
 
 extern data16_t *crospang_bg_videoram,*crospang_fg_videoram;
 
@@ -86,12 +88,14 @@ static ADDRESS_MAP_START( crospang_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( crospang_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(YM3812_status_port_0_r)
 	AM_RANGE(0x02, 0x02) AM_READ(OKIM6295_status_0_r)
 	AM_RANGE(0x06, 0x06) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( crospang_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM3812_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM3812_write_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(OKIM6295_data_0_w)
@@ -204,18 +208,7 @@ static void irqhandler(int linestate)
 
 static struct YM3812interface ym3812_interface =
 {
-	1,
-	14318180/4,
-	{ 100 },		/* volume */
-	{ irqhandler },	/* IRQ Line */
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,
-	{ 8000 },	/* ? guess */
-	{ REGION_SOUND1 },
-	{ 100 }
+	irqhandler	/* IRQ Line */
 };
 
 static MACHINE_DRIVER_START( crospang )
@@ -226,7 +219,7 @@ static MACHINE_DRIVER_START( crospang )
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 14318180/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(crospang_sound_readmem,crospang_sound_writemem)
 	MDRV_CPU_IO_MAP(crospang_sound_readport,crospang_sound_writeport)
 
@@ -245,8 +238,15 @@ static MACHINE_DRIVER_START( crospang )
 	MDRV_VIDEO_UPDATE(crospang)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 14318180/4)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 ROM_START( crospang )
