@@ -1,20 +1,20 @@
 /***************************************************************************
 
-	Atari Cyberball hardware
+    Atari Cyberball hardware
 
-	driver by Aaron Giles
+    driver by Aaron Giles
 
-	Games supported:
-		* Cyberball (1988) [3 sets]
-		* Cyberball 2072, 2-players (1989) [4 sets]
-		* Tournament Cyberball 2072 (1989) [2 sets]
+    Games supported:
+        * Cyberball (1988) [3 sets]
+        * Cyberball 2072, 2-players (1989) [4 sets]
+        * Tournament Cyberball 2072 (1989) [2 sets]
 
-	Known bugs:
-		* none at this time
+    Known bugs:
+        * none at this time
 
 ****************************************************************************
 
-	Memory map (TBA)
+    Memory map (TBA)
 
 ***************************************************************************/
 
@@ -23,12 +23,13 @@
 #include "machine/atarigen.h"
 #include "sndhrdw/atarijsa.h"
 #include "cyberbal.h"
+#include "sound/2151intf.h"
 
 
 
 /*************************************
  *
- *	Initialization
+ *  Initialization
  *
  *************************************/
 
@@ -109,7 +110,7 @@ static MACHINE_INIT( cyberb2p )
 
 /*************************************
  *
- *	I/O read dispatch.
+ *  I/O read dispatch.
  *
  *************************************/
 
@@ -140,7 +141,7 @@ static READ16_HANDLER( sound_state_r )
 
 /*************************************
  *
- *	Extra I/O handlers.
+ *  Extra I/O handlers.
  *
  *************************************/
 
@@ -153,7 +154,7 @@ static WRITE16_HANDLER( p2_reset_w )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -186,7 +187,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Extra CPU memory handlers
+ *  Extra CPU memory handlers
  *
  *************************************/
 
@@ -213,7 +214,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
@@ -237,7 +238,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	68000 Sound CPU memory handlers
+ *  68000 Sound CPU memory handlers
  *
  *************************************/
 
@@ -254,7 +255,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	2-player main CPU memory handlers
+ *  2-player main CPU memory handlers
  *
  *************************************/
 
@@ -282,7 +283,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -374,7 +375,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -432,38 +433,20 @@ static struct GfxDecodeInfo gfxdecodeinfo_interleaved[] =
 
 /*************************************
  *
- *	Sound definitions
+ *  Sound definitions
  *
  *************************************/
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	ATARI_CLOCK_14MHz/4,
-#if (CYBERBALL_DUAL_MODE)
-	{ YM3012_VOL(60,MIXER_PAN_LEFT,60,MIXER_PAN_RIGHT) },
-#else
-	{ YM3012_VOL(30,MIXER_PAN_CENTER,30,MIXER_PAN_CENTER) },
-#endif
-	{ atarigen_ym2151_irq_gen }
-};
-
-
-static struct DACinterface dac_interface =
-{
-	2,
-#if (CYBERBALL_DUAL_MODE)
-	{ MIXER(100,MIXER_PAN_RIGHT), MIXER(100,MIXER_PAN_LEFT) }
-#else
-	{ MIXER(50,MIXER_PAN_CENTER), MIXER(50,MIXER_PAN_CENTER) }
-#endif
+	atarigen_ym2151_irq_gen
 };
 
 
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -472,26 +455,26 @@ static MACHINE_DRIVER_START( cyberbal )
 	/* basic machine hardware */
 	MDRV_CPU_ADD(M68000, ATARI_CLOCK_14MHz/2)
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
-	
+
 	MDRV_CPU_ADD(M6502, ATARI_CLOCK_14MHz/8)
 	MDRV_CPU_PROGRAM_MAP(sound_map,0)
 	MDRV_CPU_PERIODIC_INT(atarigen_6502_irq_gen,(UINT32)(1000000000.0/((double)ATARI_CLOCK_14MHz/4/4/16/16/14)))
-	
+
 	MDRV_CPU_ADD(M68000, ATARI_CLOCK_14MHz/2)
 	MDRV_CPU_PROGRAM_MAP(extra_map,0)
 	MDRV_CPU_VBLANK_INT(atarigen_video_int_gen,1)
-	
+
 	MDRV_CPU_ADD(M68000, ATARI_CLOCK_14MHz/2)
 	MDRV_CPU_PROGRAM_MAP(sound_68k_map,0)
 	MDRV_CPU_PERIODIC_INT(cyberbal_sound_68k_irq_gen,10000)
-	
+
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10)
-	
+
 	MDRV_MACHINE_INIT(cyberbal)
 	MDRV_NVRAM_HANDLER(atarigen)
-	
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_PIXEL_ASPECT_RATIO_1_2 | VIDEO_UPDATE_BEFORE_VBLANK)
 #if (CYBERBALL_DUAL_MODE)
@@ -504,14 +487,23 @@ static MACHINE_DRIVER_START( cyberbal )
 #endif
 	MDRV_GFXDECODE(gfxdecodeinfo_interleaved)
 	MDRV_PALETTE_LENGTH(4096)
-	
+
 	MDRV_VIDEO_START(cyberbal)
 	MDRV_VIDEO_UPDATE(cyberbal)
-	
+
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, ATARI_CLOCK_14MHz/4)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.60)
+	MDRV_SOUND_ROUTE(1, "right", 0.60)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -521,23 +513,23 @@ static MACHINE_DRIVER_START( cyberb2p )
 	MDRV_CPU_ADD(M68000, ATARI_CLOCK_14MHz/2)
 	MDRV_CPU_PROGRAM_MAP(cyberb2p_map,0)
 	MDRV_CPU_VBLANK_INT(atarigen_video_int_gen,1)
-	
+
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	
+
 	MDRV_MACHINE_INIT(cyberb2p)
 	MDRV_NVRAM_HANDLER(atarigen)
-	
+
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_PIXEL_ASPECT_RATIO_1_2 | VIDEO_UPDATE_BEFORE_VBLANK)
 	MDRV_SCREEN_SIZE(42*16, 30*8)
 	MDRV_VISIBLE_AREA(0*8, 42*16-1, 0*8, 30*8-1)
 	MDRV_GFXDECODE(gfxdecodeinfo)
 	MDRV_PALETTE_LENGTH(2048)
-	
+
 	MDRV_VIDEO_START(cyberb2p)
 	MDRV_VIDEO_UPDATE(cyberbal)
-	
+
 	/* sound hardware */
 	MDRV_IMPORT_FROM(jsa_ii_mono)
 MACHINE_DRIVER_END
@@ -546,7 +538,7 @@ MACHINE_DRIVER_END
 
 /*************************************
  *
- *	ROM definition(s)
+ *  ROM definition(s)
  *
  *************************************/
 
@@ -992,7 +984,7 @@ ROM_END
 
 /*************************************
  *
- *	Machine initialization
+ *  Machine initialization
  *
  *************************************/
 
@@ -1034,7 +1026,7 @@ static DRIVER_INIT( cyberb2p )
 
 /*************************************
  *
- *	Game driver(s)
+ *  Game driver(s)
  *
  *************************************/
 
