@@ -7,11 +7,11 @@ David Graves, Jarek Burczynski
 
 Sound panning and other enhancements: Hiromitsu Shioya
 
-Sources:		MAME Rastan driver
-			Raine source - invaluable for this driver -
-			many thanks to Richard Bush and the Raine Team.
+Sources:        MAME Rastan driver
+            Raine source - invaluable for this driver -
+            many thanks to Richard Bush and the Raine Team.
 
-				*****
+                *****
 
 Rom Versions
 ------------
@@ -50,9 +50,9 @@ Darius (Old JPN Ver.)
 -----------------------
 Sound Board
 K1100228A
-CPU 	:Z80 x2
-Sound	:YM2203C x2
-OSC 	:8.000MHz
+CPU     :Z80 x2
+Sound   :YM2203C x2
+OSC     :8.000MHz
 -----------------------
 A96_56.18
 A96_57.33
@@ -60,8 +60,8 @@ A96_57.33
 -----------------------
 M4300067A
 K1100226A
-CPU 	:MC68000P8 x2
-OSC 	:16000.00KHz
+CPU     :MC68000P8 x2
+OSC     :16000.00KHz
 -----------------------
 A96_28.152
 A96_29.185
@@ -88,8 +88,8 @@ A96_47.201
 
 -----------------------
 K1100227A
-OSC 	:26686.00KHz
-Other	:PC080SN x3
+OSC     :26686.00KHz
+Other   :PC080SN x3
 -----------------------
 A96_48.103
 A96_48.24
@@ -138,6 +138,9 @@ sounds.
 #include "vidhrdw/taitoic.h"
 #include "cpu/z80/z80.h"
 #include "sndhrdw/taitosnd.h"
+#include "sound/2203intf.h"
+#include "sound/msm5205.h"
+#include "sound/flt_vol.h"
 
 
 MACHINE_INIT( darius );
@@ -170,7 +173,7 @@ void parse_control( void )	/* assumes Z80 sandwiched between 68Ks */
 {
 	/* bit 0 enables cpu B */
 	/* however this fails when recovering from a save state
-	   if cpu B is disabled !! */
+       if cpu B is disabled !! */
 	cpunum_set_input_line(2, INPUT_LINE_RESET, (cpua_ctrl &0x1) ? CLEAR_LINE : ASSERT_LINE);
 
 }
@@ -324,7 +327,7 @@ static int nmi_enable = 0;
 static void reset_sound_region(void)
 {
 	cpu_setbank( STATIC_BANK1, memory_region(REGION_CPU2) + (banknum * 0x8000) + 0x10000 );
-/*	cpu_setbank( 1, memory_region(REGION_CPU2) + (banknum * 0x8000) + 0x10000 ); */
+/*  cpu_setbank( 1, memory_region(REGION_CPU2) + (banknum * 0x8000) + 0x10000 ); */
 
 }
 
@@ -332,8 +335,8 @@ static WRITE8_HANDLER( sound_bankswitch_w )
 {
 		banknum = data &0x03;
 		reset_sound_region();
-/*		banknum = data; */
-/*		reset_sound_region(); */
+/*      banknum = data; */
+/*      reset_sound_region(); */
 }
 
 static WRITE8_HANDLER( adpcm_command_w )
@@ -366,7 +369,10 @@ static void update_fm0( void )
 	int left, right;
 	left  = (        darius_pan[0]  * darius_vol[6])>>8;
 	right = ((0xff - darius_pan[0]) * darius_vol[6])>>8;
-	mixer_set_stereo_volume( 6, left, right ); /* FM #0 */
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, 6) >= 0)
+		flt_volume_set_volume(6, left / 100.0);
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, 7) >= 0)
+		flt_volume_set_volume(7, right / 100.0); /* FM #0 */
 }
 
 static void update_fm1( void )
@@ -374,7 +380,10 @@ static void update_fm1( void )
 	int left, right;
 	left  = (        darius_pan[1]  * darius_vol[7])>>8;
 	right = ((0xff - darius_pan[1]) * darius_vol[7])>>8;
-	mixer_set_stereo_volume( 7, left, right ); /* FM #1 */
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, 14) >= 0)
+		flt_volume_set_volume(14, left / 100.0);
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, 15) >= 0)
+		flt_volume_set_volume(15, right / 100.0); /* FM #1 */
 }
 
 static void update_psg0( int port )
@@ -382,7 +391,10 @@ static void update_psg0( int port )
 	int left, right;
 	left  = (        darius_pan[2]  * darius_vol[port])>>8;
 	right = ((0xff - darius_pan[2]) * darius_vol[port])>>8;
-	mixer_set_stereo_volume( port, left, right );
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, port*2+0) >= 0)
+		flt_volume_set_volume(port*2+0, left / 100.0);
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, port*2+1) >= 0)
+		flt_volume_set_volume(port*2+1, right / 100.0);
 }
 
 static void update_psg1( int port )
@@ -390,7 +402,10 @@ static void update_psg1( int port )
 	int left, right;
 	left  = (        darius_pan[3]  * darius_vol[port + 3])>>8;
 	right = ((0xff - darius_pan[3]) * darius_vol[port + 3])>>8;
-	mixer_set_stereo_volume( port + 3, left, right );
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, port*2+0+8) >= 0)
+		flt_volume_set_volume(port*2+0+8, left / 100.0);
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, port*2+1+8) >= 0)
+		flt_volume_set_volume(port*2+1+8, right / 100.0);
 }
 
 static void update_da( void )
@@ -398,7 +413,10 @@ static void update_da( void )
 	int left, right;
 	left  = darius_def_vol[(darius_pan[4]>>4)&0x0f];
 	right = darius_def_vol[(darius_pan[4]>>0)&0x0f];
-	mixer_set_stereo_volume( 8, left, right );
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, 16) >= 0)
+		flt_volume_set_volume(16, left / 100.0);
+	if (sndti_to_sndnum(SOUND_FILTER_VOLUME, 17) >= 0)
+		flt_volume_set_volume(17, right / 100.0); /* FM #1 */
 }
 
 static WRITE8_HANDLER( darius_fm0_pan )
@@ -509,7 +527,7 @@ static ADDRESS_MAP_START( darius_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xcc00, 0xcc00) AM_WRITE(darius_psg1_pan)
 	AM_RANGE(0xd000, 0xd000) AM_WRITE(darius_da_pan)
 	AM_RANGE(0xd400, 0xd400) AM_WRITE(adpcm_command_w)	/* ADPCM command for second Z80 to read from port 0x00 */
-/*	AM_RANGE(0xd800, 0xd800) AM_WRITE(display_value)	   ???    */
+/*  AM_RANGE(0xd800, 0xd800) AM_WRITE(display_value)       ???    */
 	AM_RANGE(0xdc00, 0xdc00) AM_WRITE(sound_bankswitch_w)
 ADDRESS_MAP_END
 
@@ -534,11 +552,8 @@ static void darius_adpcm_int (int data)
 
 static struct MSM5205interface msm5205_interface =
 {
-	1,				/* 1 chip */
-	384000, 			/* 384KHz */
-	{ darius_adpcm_int},	/* interrupt function */
-	{ MSM5205_S48_4B},	/* 8KHz   */
-	{ 100 }			/* volume */
+	darius_adpcm_int,	/* interrupt function */
+	MSM5205_S48_4B		/* 8KHz   */
 };
 
 static READ8_HANDLER( adpcm_command_read )
@@ -576,12 +591,14 @@ static WRITE8_HANDLER( adpcm_data_w )
 }
 
 static ADDRESS_MAP_START( darius_sound2_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(adpcm_command_read)
 	AM_RANGE(0x02, 0x02) AM_READ(readport2)	/* ??? */
 	AM_RANGE(0x03, 0x03) AM_READ(readport3)	/* ??? */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( darius_sound2_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(adpcm_nmi_disable)
 	AM_RANGE(0x01, 0x01) AM_WRITE(adpcm_nmi_enable)
 	AM_RANGE(0x02, 0x02) AM_WRITE(adpcm_data_w)
@@ -820,16 +837,21 @@ static void irqhandler(int irq)	/* assumes Z80 sandwiched between 68Ks */
 	cpunum_set_input_line(1,0,irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static struct YM2203interface ym2203_interface =
+static struct YM2203interface ym2203_interface_1 =
 {
-	2,			/* 2 chips */
-	4000000,	/* 4 MHz ??? */
-	{ YM2203_VOL(60,8), YM2203_VOL(60,8) },
-	{ 0, 0 },		/* portA read */
-	{ 0, 0 },
-	{ darius_write_portA0, darius_write_portA1 },	/* portA write */
-	{ darius_write_portB0, darius_write_portB1 },	/* portB write */
-	{ irqhandler, 0 }
+	0,		/* portA read */
+	0,
+	darius_write_portA0,	/* portA write */
+	darius_write_portB0,	/* portB write */
+	irqhandler
+};
+
+static struct YM2203interface ym2203_interface_2 =
+{
+	0,		/* portA read */
+	0,
+	darius_write_portA1,	/* portA write */
+	darius_write_portB1		/* portB write */
 };
 
 
@@ -845,7 +867,7 @@ static MACHINE_DRIVER_START( darius )
 	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,8000000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 4 MHz ? */
+	/* audio CPU */	/* 4 MHz ? */
 	MDRV_CPU_PROGRAM_MAP(darius_sound_readmem,darius_sound_writemem)
 
 	MDRV_CPU_ADD(M68000,16000000/2)	/* 8 MHz ? */
@@ -853,7 +875,7 @@ static MACHINE_DRIVER_START( darius )
 	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,8000000/2) /* 4 MHz ? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ADPCM player using MSM5205 */
+	/* audio CPU */	/* ADPCM player using MSM5205 */
 	MDRV_CPU_PROGRAM_MAP(darius_sound2_readmem,darius_sound2_writemem)
 	MDRV_CPU_IO_MAP(darius_sound2_readport,darius_sound2_writeport)
 
@@ -875,9 +897,73 @@ static MACHINE_DRIVER_START( darius )
 	MDRV_VIDEO_UPDATE(darius)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_CONFIG(ym2203_interface_1)
+	MDRV_SOUND_ROUTE(0, "filter.2203.0.0l", 0.08)
+	MDRV_SOUND_ROUTE(0, "filter.2203.0.0r", 0.08)
+	MDRV_SOUND_ROUTE(1, "filter.2203.0.1l", 0.08)
+	MDRV_SOUND_ROUTE(1, "filter.2203.0.1r", 0.08)
+	MDRV_SOUND_ROUTE(2, "filter.2203.0.2l", 0.08)
+	MDRV_SOUND_ROUTE(2, "filter.2203.0.2r", 0.08)
+	MDRV_SOUND_ROUTE(3, "filter.2203.0.3l", 0.60)
+	MDRV_SOUND_ROUTE(3, "filter.2203.0.3r", 0.60)
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_CONFIG(ym2203_interface_2)
+	MDRV_SOUND_ROUTE(0, "filter.2203.1.0l", 0.08)
+	MDRV_SOUND_ROUTE(0, "filter.2203.1.0r", 0.08)
+	MDRV_SOUND_ROUTE(1, "filter.2203.1.1l", 0.08)
+	MDRV_SOUND_ROUTE(1, "filter.2203.1.1r", 0.08)
+	MDRV_SOUND_ROUTE(2, "filter.2203.1.2l", 0.08)
+	MDRV_SOUND_ROUTE(2, "filter.2203.1.2r", 0.08)
+	MDRV_SOUND_ROUTE(3, "filter.2203.1.3l", 0.60)
+	MDRV_SOUND_ROUTE(3, "filter.2203.1.3r", 0.60)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "msm5205.l", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "msm5205.r", 1.0)
+
+	MDRV_SOUND_ADD_TAG("filter.2203.0.0l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.0.0r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.0.1l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.0.1r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.0.2l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.0.2r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.0.3l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.0.3r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD_TAG("filter.2203.1.0l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.1.0r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.1.1l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.1.1r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.1.2l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.1.2r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.1.3l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.2203.1.3r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD_TAG("msm5205.l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("msm5205.r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -909,7 +995,7 @@ ROM_START( darius )
 
 	ROM_REGION( 0x60000, REGION_GFX1, ROMREGION_DISPOSE )
 	/* There are THREE of each SCR gfx rom on the actual board,
-	   making a complete set for every PC080SN tilemap chip */
+       making a complete set for every PC080SN tilemap chip */
 	ROM_LOAD16_BYTE( "a96_48.24",    0x00000, 0x10000, CRC(39c9b3aa) SHA1(43a91d916c5a09207dfa37413feb5025636f37ae) )	/* 8x8 SCR tiles */
 	ROM_LOAD16_BYTE( "a96_49.25",    0x20000, 0x10000, CRC(37a7d88a) SHA1(cede0d810d74ec460dcc4b391bb1acd5a669a7b4) )
 	ROM_LOAD16_BYTE( "a96_50.26",    0x40000, 0x10000, CRC(75d738e4) SHA1(634606da46136ab605f5477af5639a20e39b44c4) )
@@ -1112,7 +1198,7 @@ ROM_END
 
 static DRIVER_INIT( darius )
 {
-/*	taitosnd_setz80_soundcpu( 2 ); */
+/*  taitosnd_setz80_soundcpu( 2 ); */
 
 	cpua_ctrl = 0xff;
 	state_save_register_UINT16("main1", 0, "control", &cpua_ctrl, 1);
@@ -1139,7 +1225,7 @@ MACHINE_INIT( darius )
 		memcpy( RAM + 0x8000*i + 0x14000, RAM + 0x4000*i, 0x4000 );
 	}
 
-	mixer_sound_enable_global_w( 1 );	/* mixer enabled */
+	sound_global_enable( 1 );	/* mixer enabled */
 
 	for( i = 0; i < DARIUS_VOL_MAX; i++ ){
 		darius_vol[i] = 0x00;	/* min volume */
