@@ -122,6 +122,9 @@ Stephh's notes (based on the games M68000 code and some tests) :
 #include "vidhrdw/generic.h"
 #include "cpu/h6280/h6280.h"
 #include "deco16ic.h"
+#include "sound/2203intf.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 VIDEO_START( dassault );
 VIDEO_UPDATE( dassault );
@@ -430,7 +433,7 @@ INPUT_PORTS_START( dassault )
 	PORT_DIPSETTING(    0x30, "2" )
 	PORT_DIPSETTING(    0x20, "3" )
 	PORT_DIPSETTING(    0x10, "4" )
-/*	PORT_DIPSETTING(    0x00, "4 (buggy)" ) */
+/*  PORT_DIPSETTING(    0x00, "4 (buggy)" ) */
 	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unused ) )
 	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -561,18 +564,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /**********************************************************************************/
 
-static struct YM2203interface ym2203_interface =
-{
-	1,
-	32220000/8,	/* Accurate, audio section crystal is 32.220 MHz */
-	{ YM2203_VOL(40,40) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static void sound_irq(int state)
 {
 	cpunum_set_input_line(2,1,state);
@@ -586,19 +577,8 @@ WRITE8_HANDLER( sound_bankswitch_w )
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	32220000/9, /* Accurate, audio section crystal is 32.220 MHz */
-	{ YM3012_VOL(45,MIXER_PAN_LEFT,45,MIXER_PAN_RIGHT) },
-	{ sound_irq },
-	{ sound_bankswitch_w }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	2,              /* 2 chips */
-	{ 7757, 15514 },/* Frequency */
-	{ REGION_SOUND1, REGION_SOUND2 },
-	{ 50, 25 }		/* Note!  Keep chip 1 louder than chip 2 */
+	sound_irq,
+	sound_bankswitch_w
 };
 
 /**********************************************************************************/
@@ -615,7 +595,7 @@ static MACHINE_DRIVER_START( dassault )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
 
 	MDRV_CPU_ADD(H6280,32220000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Accurate */
+	/* audio CPU */	/* Accurate */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -633,10 +613,26 @@ static MACHINE_DRIVER_START( dassault )
 	MDRV_VIDEO_UPDATE(dassault)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2203, 32220000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.40)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.40)
+
+	MDRV_SOUND_ADD(YM2151, 32220000/9)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 7757)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
+
+	MDRV_SOUND_ADD(OKIM6295, 15514)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.25)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.25)
 MACHINE_DRIVER_END
 
 /**********************************************************************************/
@@ -838,8 +834,8 @@ static void init_dassault(void)
 	data8_t *tmp = (data8_t *)malloc(0x80000);
 
 	/* Playfield 4 also has access to the char graphics, make things easier
-	by just copying the chars to both banks (if I just used a different gfx
-	bank then the colours would be wrong). */
+    by just copying the chars to both banks (if I just used a different gfx
+    bank then the colours would be wrong). */
 	memcpy(tmp+0x000000,dst+0x80000,0x80000);
 	memcpy(dst+0x090000,tmp+0x00000,0x80000);
 	memcpy(dst+0x080000,src+0x00000,0x10000);
@@ -858,8 +854,8 @@ static void init_thndzone(void)
 	data8_t *tmp = (data8_t *)malloc(0x80000);
 
 	/* Playfield 4 also has access to the char graphics, make things easier
-	by just copying the chars to both banks (if I just used a different gfx
-	bank then the colours would be wrong). */
+    by just copying the chars to both banks (if I just used a different gfx
+    bank then the colours would be wrong). */
 	memcpy(tmp+0x000000,dst+0x80000,0x80000);
 	memcpy(dst+0x090000,tmp+0x00000,0x80000);
 	memcpy(dst+0x080000,src+0x00000,0x10000);
