@@ -16,9 +16,9 @@
         flip the DIP and check it out!
 
   TODO:
-	- Gfx priorities (note that it has two 053251)
-	- Self Test Fails
-	- Some offsets/colours in DBZ1
+    - Gfx priorities (note that it has two 053251)
+    - Self Test Fails
+    - Some offsets/colours in DBZ1
 
 PCB Layout:
 
@@ -61,6 +61,8 @@ Notes:
 #include "vidhrdw/konamiic.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 /* BG LAYER */
 
@@ -214,9 +216,11 @@ static ADDRESS_MAP_START( dbz2sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( dbz2sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( dbz2sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(MWA8_NOP)
 ADDRESS_MAP_END
 
@@ -253,7 +257,7 @@ INPUT_PORTS_START( dbz )
 	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Unknown ) ) /* seems unused */
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Flip_Screen ) ) /* Definitely correct  */
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Flip_Screen ) ) /* Definitely correct */
 	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
@@ -313,7 +317,7 @@ INPUT_PORTS_START( dbz )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "Disabled" ) */
+/*  PORT_DIPSETTING(    0x00, "Disabled" ) */
 INPUT_PORTS_END
 
 INPUT_PORTS_START( dbz2 )
@@ -338,7 +342,7 @@ INPUT_PORTS_START( dbz2 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START_TAG("DSW1")
-	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) ) 
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( Normal ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( Hard ) )
@@ -349,7 +353,7 @@ INPUT_PORTS_START( dbz2 )
 	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Level_Select ) ) 
+	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Level_Select ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x20, 0x20, DEF_STR(Service_Mode ) )
@@ -406,25 +410,14 @@ INPUT_PORTS_START( dbz2 )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "Disabled" ) */
+/*  PORT_DIPSETTING(    0x00, "Disabled" ) */
 INPUT_PORTS_END
 
 /**********************************************************************************/
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	4000000,	/* total guess */
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },
-	{ dbz2_sound_irq }
-};
-
-static struct OKIM6295interface m6295_interface =
-{
-	1,  /* 1 chip */
-	{ 1056000/132 },	/* confirmed */
-	{ REGION_SOUND1 },
-	{ 100 }
+	dbz2_sound_irq
 };
 
 /**********************************************************************************/
@@ -459,7 +452,7 @@ static MACHINE_DRIVER_START( dbz2 )
 	MDRV_CPU_VBLANK_INT(dbz2_interrupt,2)
 
 	MDRV_CPU_ADD_TAG("sound", Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(dbz2sound_readmem, dbz2sound_writemem)
 	MDRV_CPU_IO_MAP(dbz2sound_readport,dbz2sound_writeport)
 
@@ -477,9 +470,17 @@ static MACHINE_DRIVER_START( dbz2 )
 	MDRV_PALETTE_LENGTH(0x4000/2)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, m6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 4000000)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+
+	MDRV_SOUND_ADD(OKIM6295, 1056000/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( dbz )
