@@ -1,14 +1,14 @@
 /***************************************************************************
 
-	D-Con									(c) 1992 Success
-	SD Gundam Psycho Salamander no Kyoui	(c) 1991 Banpresto/Bandai
+    D-Con                                   (c) 1992 Success
+    SD Gundam Psycho Salamander no Kyoui    (c) 1991 Banpresto/Bandai
 
-	These games run on Seibu hardware.
+    These games run on Seibu hardware.
 
-	Emulation by Bryan McPhail, mish@tendril.co.uk
+    Emulation by Bryan McPhail, mish@tendril.co.uk
 
-	Coin inputs are handled by the sound CPU, so they don't work with sound
-	disabled. Use the service switch instead.
+    Coin inputs are handled by the sound CPU, so they don't work with sound
+    disabled. Use the service switch instead.
 
 ***************************************************************************/
 
@@ -240,7 +240,7 @@ static struct GfxLayout dcon_charlayout =
 	RGN_FRAC(1,2),
 	4,			/* 4 bits per pixel */
 	{ 0,4,(0x10000*8)+0,0x10000*8+4,  },
-	{ 3,2,1,0, 11,10,9,8 ,8,9,10,11,0,1,2,3, },
+	{ 3,2,1,0, 11,10,9,8 },
 	{ 0*16, 1*16, 2*16, 3*16, 4*16, 5*16, 6*16, 7*16 },
 	128
 };
@@ -276,8 +276,8 @@ static struct GfxDecodeInfo dcon_gfxdecodeinfo[] =
 /******************************************************************************/
 
 /* Parameters: YM3812 frequency, Oki frequency, Oki memory region */
-SEIBU_SOUND_SYSTEM_YM3812_HARDWARE(4000000,8000,REGION_SOUND1);
-SEIBU_SOUND_SYSTEM_YM2151_HARDWARE(14318180/4,8000,REGION_SOUND1);
+SEIBU_SOUND_SYSTEM_YM3812_HARDWARE
+SEIBU_SOUND_SYSTEM_YM2151_HARDWARE
 
 static MACHINE_DRIVER_START( dcon )
 
@@ -303,7 +303,7 @@ static MACHINE_DRIVER_START( dcon )
 	MDRV_VIDEO_UPDATE(dcon)
 
 	/* sound hardware */
-	SEIBU_SOUND_SYSTEM_YM3812_INTERFACE
+	SEIBU_SOUND_SYSTEM_YM3812_INTERFACE(4000000,8000,1)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( sdgndmps )
@@ -330,7 +330,7 @@ static MACHINE_DRIVER_START( sdgndmps )
 	MDRV_VIDEO_UPDATE(sdgndmps)
 
 	/* sound hardware */
-	SEIBU_SOUND_SYSTEM_YM2151_INTERFACE
+	SEIBU_SOUND_SYSTEM_YM2151_INTERFACE(14318180/4,8000,1)
 MACHINE_DRIVER_END
 
 /***************************************************************************/
@@ -411,7 +411,7 @@ static DRIVER_INIT( sdgndmps )
 	data16_t *RAM = (data16_t *)memory_region(REGION_CPU1);
 	RAM[0x1356/2] = 0x4e71; /* beq -> nop */
 	RAM[0x1358/2] = 0x4e71;
-	
+
 	RAM[0x4de/2]  = 0x4245; /* ROM checksum */
 	RAM[0x4e0/2]  = 0x4e71;
 	RAM[0x4e2/2]  = 0x4e71;
