@@ -39,17 +39,18 @@ write:
 6801 AY8910 #2 Write Port
 7800 Bit 0 - Coin Counter 1
      Bit 1 - Coin Counter 2
-	 Bit 2 - ??? Pulsated when the player is hit
-	 Bit 3 - ??? Seems to be unused
-	 Bit 4 - Tied to AY8910 RST. Used to turn off sound
-	 Bit 5 - ??? Seem to be always on
-	 Bit 6 - Search light enable
+     Bit 2 - ??? Pulsated when the player is hit
+     Bit 3 - ??? Seems to be unused
+     Bit 4 - Tied to AY8910 RST. Used to turn off sound
+     Bit 5 - ??? Seem to be always on
+     Bit 6 - Search light enable
      Bit 7 - ???
 
 
 ***************************************************************************/
 
 #include "driver.h"
+#include "sound/ay8910.h"
 
 extern unsigned char *dday_bgvideoram;
 extern unsigned char *dday_fgvideoram;
@@ -303,18 +304,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct AY8910interface ay8910_interface =
-{
-	2,      /* 2 chips */
-	1000000,	/* 1.0 MHz ? */
-	{ 25, 25 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
 static MACHINE_DRIVER_START( dday )
 
 	/* basic machine hardware */
@@ -337,7 +326,13 @@ static MACHINE_DRIVER_START( dday )
 	MDRV_VIDEO_UPDATE(dday)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 1000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
