@@ -1,9 +1,9 @@
 /*
 
-	D-DAY	(c)Jaleco 1984
-	preliminary driver by Pierpaolo Prazzoli
+    D-DAY   (c)Jaleco 1984
+    preliminary driver by Pierpaolo Prazzoli
 ----------------------------------------------
-	Tomasz Slanina 2004.11.12. :
+    Tomasz Slanina 2004.11.12. :
 
   - correct sprite decoding
   - DMA  - see below
@@ -19,34 +19,34 @@ Is it 1984 or 1987 game ?
 There's text inside rom "1987.07    BY  ELS"
 -------------------------------------------------------------
 
-	DMA copy ?
+    DMA copy ?
 
-	Writes to adr. in range $e000-$e008 are usually like this:
+    Writes to adr. in range $e000-$e008 are usually like this:
 
-	ld hl,$e000
-	ld bc,XXxx
-	ld de,YYyy
-	ld (hl),c		;($e000),xx
-	ld (hl),b		;($e000),XX
-	inc hl
-	ld (hl),e		;($e001),yy
-	ld (hl),d		;($e001),YY
-	inc hl
-	ld bc,ZZzz
-	ld de,QQqq
-	ld (hl),c		;($e002),zz
-	ld (hl),b		;($e002),ZZ
-	inc hl
-	ld (hl),e		;($e003),qq
-	ld (hl),d		;($e003),QQ
-	ld a,WW
-	ld ($e008),a
-	ld a,1
-	ld ($f803),a
-	xor a
-	ld ($f083),a	; write latch
-	ld a,1
-	ld ($f083),a
+    ld hl,$e000
+    ld bc,XXxx
+    ld de,YYyy
+    ld (hl),c       ;($e000),xx
+    ld (hl),b       ;($e000),XX
+    inc hl
+    ld (hl),e       ;($e001),yy
+    ld (hl),d       ;($e001),YY
+    inc hl
+    ld bc,ZZzz
+    ld de,QQqq
+    ld (hl),c       ;($e002),zz
+    ld (hl),b       ;($e002),ZZ
+    inc hl
+    ld (hl),e       ;($e003),qq
+    ld (hl),d       ;($e003),QQ
+    ld a,WW
+    ld ($e008),a
+    ld a,1
+    ld ($f803),a
+    xor a
+    ld ($f083),a    ; write latch
+    ld a,1
+    ld ($f083),a
 
 where (my guess):
 
@@ -58,66 +58,67 @@ WW = $73 (always)
 
 It's used in (at least) three places :
 
-- $16e6	RAM -> spriteram
-	src = $8d6f
-	dst = $9000
-	size = $200
+- $16e6 RAM -> spriteram
+    src = $8d6f
+    dst = $9000
+    size = $200
 
-- $1cb1	RAM -> RAM
+- $1cb1 RAM -> RAM
 
-	src = $8432
-	dst = $807a
-	size = $364
+    src = $8432
+    dst = $807a
+    size = $364
 
-- $1cf4 	RAM -> RAM
+- $1cf4     RAM -> RAM
 
-	src = $805e
-	dst = $8432
-	size = $380
+    src = $805e
+    dst = $8432
+    size = $380
 
 ----------------------------------------------
 
 
-	CPU  : Z80
-	Sound: Z80 AY-3-8910(x2)
-	OSC  : 12.000MHz
+    CPU  : Z80
+    Sound: Z80 AY-3-8910(x2)
+    OSC  : 12.000MHz
 
-	-------
-	DD-8416
-	-------
-	ROMs:
-	1  - (2764)
-	2  |
-	3  |
-	4  |
-	5  |
-	6  |
-	7  |
-	8  |
-	9  |
-	10 |
-	11 /
+    -------
+    DD-8416
+    -------
+    ROMs:
+    1  - (2764)
+    2  |
+    3  |
+    4  |
+    5  |
+    6  |
+    7  |
+    8  |
+    9  |
+    10 |
+    11 /
 
-	-------
-	DD-8417
-	-------
-	ROMs:
-	12 - (2732)
-	13 /
+    -------
+    DD-8417
+    -------
+    ROMs:
+    12 - (2732)
+    13 /
 
-	14 - (2732)
-	15 /
+    14 - (2732)
+    15 /
 
-	16 - (2764)
-	17 |
-	18 |
-	19 /
+    16 - (2764)
+    17 |
+    18 |
+    19 /
 
 
 */
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
 
 static int char_bank = 0;
 static struct tilemap *bg_tilemap, *fg_tilemap;
@@ -185,19 +186,19 @@ static READ8_HANDLER(custom_r)
 	return ROM[offset|(bgadr<<11)];
 }
 
+#if 0
 static WRITE8_HANDLER(test_w)
 {
 		/*printf("W %x %x %x\n",offset,data,activecpu_get_previouspc()); */
 }
 
-
 static READ8_HANDLER(test_r)
 {
 		/*printf("R %x %x\n",offset,activecpu_get_previouspc()); */
 		UINT8 *ROM = memory_region(REGION_USER1);
 		return ROM[offset];
 }
-
+#endif
 
 static WRITE8_HANDLER( sound_w )
 {
@@ -435,13 +436,7 @@ VIDEO_UPDATE( ddayjlc )
 
 static struct AY8910interface ay8910_interface =
 {
-	2,  /* 2 chips */
-	12000000/4,
-	{ 100, 100 },
-	{ soundlatch_r, 0 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 }
+	soundlatch_r
 };
 
 static INTERRUPT_GEN( ddayjlc_interrupt )
@@ -462,7 +457,7 @@ static MACHINE_DRIVER_START( ddayjlc )
 	MDRV_CPU_VBLANK_INT(ddayjlc_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 12000000/3)     /* ? MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_cpu,0)
 	MDRV_CPU_VBLANK_INT(ddayjlc_snd_interrupt,1)
 
@@ -480,7 +475,14 @@ static MACHINE_DRIVER_START( ddayjlc )
 	MDRV_VIDEO_START(ddayjlc)
 	MDRV_VIDEO_UPDATE(ddayjlc)
 
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 12000000/4)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(AY8910, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
