@@ -26,10 +26,10 @@ banking in Toffy / Super toffy
 
 Super Toffy - Unico 1994
 
-Main cpu: 	MC6809EP
-Sound cpu: 	MC6809P
-Sound: 		YM2151
-Clocks:		12 MHz, 3.579MHz
+Main cpu:   MC6809EP
+Sound cpu:  MC6809P
+Sound:      YM2151
+Clocks:     12 MHz, 3.579MHz
 
 Graphics custom: MDE-2001
 
@@ -45,6 +45,9 @@ conversion kit which could be applied to a bootleg double dragon :-p?
 #include "cpu/m6809/m6809.h"
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
+#include "sound/msm5205.h"
 
 /* from vidhrdw */
 extern unsigned char *ddragon_bgvideoram,*ddragon_fgvideoram;
@@ -137,7 +140,7 @@ static WRITE8_HANDLER( toffy_bankswitch_w )
 	ddragon_scrolly_hi = ( ( data & 0x02 ) << 7 );
 	ddragon_scrollx_hi = ( ( data & 0x01 ) << 8 );
 
-/*	flip_screen_set(~data & 0x04); */
+/*  flip_screen_set(~data & 0x04); */
 
 	/* bit 3 unknown */
 
@@ -154,7 +157,7 @@ static WRITE8_HANDLER( darktowr_bankswitch_w )
 	ddragon_scrolly_hi = ( ( data & 0x02 ) << 7 );
 	ddragon_scrollx_hi = ( ( data & 0x01 ) << 8 );
 
-/*	flip_screen_set(~data & 0x04); */
+/*  flip_screen_set(~data & 0x04); */
 
 	/* bit 3 unknown */
 
@@ -164,8 +167,8 @@ static WRITE8_HANDLER( darktowr_bankswitch_w )
 		cpunum_set_input_line( 1, sprite_irq, (sprite_irq == INPUT_LINE_NMI) ? PULSE_LINE : HOLD_LINE );
 
 	darktowr_bank=(data & 0xe0) >> 5;
-/*	cpu_setbank( 1,&RAM[ 0x10000 + ( 0x4000 * ( ( data & 0xe0) >> 5 ) ) ] ); */
-/*	logerror("Bank %05x %02x %02x\n",activecpu_get_pc(),darktowr_bank,data); */
+/*  cpu_setbank( 1,&RAM[ 0x10000 + ( 0x4000 * ( ( data & 0xe0) >> 5 ) ) ] ); */
+/*  logerror("Bank %05x %02x %02x\n",activecpu_get_pc(),darktowr_bank,data); */
 }
 
 static READ8_HANDLER( darktowr_bank_r )
@@ -251,8 +254,8 @@ static WRITE8_HANDLER( ddragon_hd63701_internal_registers_w )
 	/* I don't know why port 0x17 is used..  Doesn't seem to be a standard MCU port */
 	if (offset==0x17) {
 		/* This is a guess, but makes sense.. The mcu definitely interrupts the main cpu.
-		I don't know what bit is the assert and what is the clear though (in comparison
-		it's quite obvious from the Double Dragon 2 code, below). */
+        I don't know what bit is the assert and what is the clear though (in comparison
+        it's quite obvious from the Double Dragon 2 code, below). */
 		if (data&3) {
 			cpunum_set_input_line(0,M6809_IRQ_LINE,ASSERT_LINE);
 			cpunum_set_input_line(1,sprite_irq, CLEAR_LINE );
@@ -292,11 +295,13 @@ static WRITE8_HANDLER( ddragon_spriteram_w )
 
 /*****************************************************************************/
 
+#if 0
 static WRITE8_HANDLER( cpu_sound_command_w )
 {
 	soundlatch_w( offset, data );
 	cpunum_set_input_line( snd_cpu, sound_irq, (sound_irq == INPUT_LINE_NMI) ? PULSE_LINE : HOLD_LINE );
 }
+#endif
 
 static WRITE8_HANDLER( dd_adpcm_w )
 {
@@ -855,27 +860,13 @@ static void irq_handler(int irq)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	3579545,	/* ??? */
-	{ YM3012_VOL(60,MIXER_PAN_LEFT,60,MIXER_PAN_RIGHT) },
-	{ irq_handler }
+	irq_handler
 };
 
 static struct MSM5205interface msm5205_interface =
 {
-	2,					/* 2 chips             */
-	384000,				/* 384KHz             */
-	{ dd_adpcm_int, dd_adpcm_int },/* interrupt function */
-	{ MSM5205_S48_4B, MSM5205_S48_4B },	/* 8kHz */
-	{ 50, 50 }				/* adjusted sound fx volume */
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,              /* 1 chip */
-	{ 8000 },           /* frequency (Hz) */
-	{ REGION_SOUND1 },  /* memory region */
-	{ 20 }	/* adjusted sound fx volume */
+	dd_adpcm_int,	/* interrupt function */
+	MSM5205_S48_4B	/* 8kHz */
 };
 
 static INTERRUPT_GEN( ddragon_interrupt )
@@ -909,7 +900,7 @@ static MACHINE_DRIVER_START( ddragon )
 	MDRV_CPU_PROGRAM_MAP(sub_readmem,sub_writemem)
 
  	MDRV_CPU_ADD(HD6309, 3579545)
- 	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+ 	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(((12000000.0 / 256.0) / 3.0) / 272.0)
@@ -929,8 +920,20 @@ static MACHINE_DRIVER_START( ddragon )
 	MDRV_VIDEO_UPDATE(ddragon)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.60)
+	MDRV_SOUND_ROUTE(1, "mono", 0.60)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( darktowr )
@@ -944,7 +947,7 @@ static MACHINE_DRIVER_START( darktowr )
 	MDRV_CPU_PROGRAM_MAP(sub_readmem,sub_writemem)
 
  	MDRV_CPU_ADD(HD6309, 3579545)
- 	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ? */
+ 	/* audio CPU */	/* ? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_CPU_ADD(M68705,8000000/2)  /* ? MHz */
@@ -967,8 +970,20 @@ static MACHINE_DRIVER_START( darktowr )
 	MDRV_VIDEO_UPDATE(ddragon)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.60)
+	MDRV_SOUND_ROUTE(1, "mono", 0.60)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( ddragonb )
@@ -982,7 +997,7 @@ static MACHINE_DRIVER_START( ddragonb )
 	MDRV_CPU_PROGRAM_MAP(sub_readmem,sub_writemem)
 
  	MDRV_CPU_ADD(HD6309, 3579545)
- 	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ? */
+ 	/* audio CPU */	/* ? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(((12000000.0 / 256.0) / 3.0) / 272.0)
@@ -1002,8 +1017,20 @@ static MACHINE_DRIVER_START( ddragonb )
 	MDRV_VIDEO_UPDATE(ddragon)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.60)
+	MDRV_SOUND_ROUTE(1, "mono", 0.60)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( ddragon2 )
@@ -1017,7 +1044,7 @@ static MACHINE_DRIVER_START( ddragon2 )
 	MDRV_CPU_PROGRAM_MAP(dd2_sub_readmem,dd2_sub_writemem)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 3.579545 MHz */
+	/* audio CPU */	/* 3.579545 MHz */
 	MDRV_CPU_PROGRAM_MAP(dd2_sound_readmem,dd2_sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(((12000000.0 / 256.0) / 3.0) / 272.0)
@@ -1037,8 +1064,16 @@ static MACHINE_DRIVER_START( ddragon2 )
 	MDRV_VIDEO_UPDATE(ddragon)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.60)
+	MDRV_SOUND_ROUTE(1, "mono", 0.60)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( toffy )
@@ -1049,7 +1084,7 @@ static MACHINE_DRIVER_START( toffy )
 	MDRV_CPU_VBLANK_INT(ddragon_interrupt,272)
 
 	MDRV_CPU_ADD(M6809, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(((12000000.0 / 256.0) / 3.0) / 272.0)
@@ -1068,8 +1103,12 @@ static MACHINE_DRIVER_START( toffy )
 	MDRV_MACHINE_INIT(toffy)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.60)
+	MDRV_SOUND_ROUTE(1, "right", 0.60)
 MACHINE_DRIVER_END
 
 /***************************************************************************
