@@ -1,25 +1,25 @@
 /******************************************************************
 
-	Double Dragon 3 					Technos Japan Corp 1990
-	The Combatribes 					Technos Japan Corp 1990
+    Double Dragon 3                     Technos Japan Corp 1990
+    The Combatribes                     Technos Japan Corp 1990
 
 
-	Notes:
+    Notes:
 
-	Both games have original and bootleg versions supported.
-	Double Dragon 3 bootleg has some misplaced graphics, but I
-	think this is how the real thing would look.
-	Combatribes has sprite lag but it seems to be caused by poor
-	programming and I think the original does the same.
+    Both games have original and bootleg versions supported.
+    Double Dragon 3 bootleg has some misplaced graphics, but I
+    think this is how the real thing would look.
+    Combatribes has sprite lag but it seems to be caused by poor
+    programming and I think the original does the same.
 
 ******************************************************************/
 
 /*
 
-	TODO:
+    TODO:
 
-	- coin counters/lockouts
-	- convert MACHINE_DRIVER_START( ctribe ) to use MDRV_IMPORT_FROM(ddragon3)
+    - coin counters/lockouts
+    - convert MACHINE_DRIVER_START( ctribe ) to use MDRV_IMPORT_FROM(ddragon3)
 
 */
 
@@ -28,6 +28,8 @@
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m68000/m68000.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 
 extern UINT16 *ddragon3_bg_videoram16;
@@ -68,14 +70,14 @@ static WRITE16_HANDLER( ddragon3_io16_w )
 		break;
 
 		case 2:
-		/*	this gets written to on startup and at the end of IRQ6
-		**	possibly trigger IRQ on sound CPU
-		*/
+		/*  this gets written to on startup and at the end of IRQ6
+        **  possibly trigger IRQ on sound CPU
+        */
 		break;
 
 		case 3:
-		/*	this gets written to on startup,
-		**	and at the end of IRQ5 (input port read) */
+		/*  this gets written to on startup,
+        **  and at the end of IRQ5 (input port read) */
 		break;
 
 		case 4:
@@ -289,7 +291,7 @@ INPUT_PORTS_START( ddrago3b )
 	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_BUTTON2 )	/* jump */
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_BUTTON3 )	/* kick */
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_START1 )
-	
+
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_SERVICE1 )
@@ -370,7 +372,7 @@ INPUT_PORTS_START( ctribe )
 	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_BUTTON2 )	/* jump */
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_START1 )
-	
+
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_SERVICE1 )
@@ -486,18 +488,7 @@ static void dd3_ymirq_handler(int irq)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	3579545,	/* Guess */
-	{ YM3012_VOL(45,MIXER_PAN_LEFT,45,MIXER_PAN_RIGHT) },
-	{ dd3_ymirq_handler }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,				/* 1 chip */
-	{ 8500 },		/* frequency (Hz) */
-	{ REGION_SOUND1 },	/* memory region */
-	{ 47 }
+	dd3_ymirq_handler
 };
 
 /* Interrupt Generators */
@@ -520,7 +511,7 @@ static MACHINE_DRIVER_START( ddragon3 )
 	MDRV_CPU_VBLANK_INT(ddragon3_cpu_interrupt, 2)
 
 	MDRV_CPU_ADD_TAG("audio", Z80, 3579545) /* Guess */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound, writemem_sound)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -537,9 +528,17 @@ static MACHINE_DRIVER_START( ddragon3 )
 	MDRV_VIDEO_UPDATE(ddragon3)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 8500)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.47)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.47)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( ddrago3b )
@@ -556,7 +555,7 @@ static MACHINE_DRIVER_START( ctribe )
 	MDRV_CPU_VBLANK_INT(ddragon3_cpu_interrupt,2)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Guess */
+	/* audio CPU */	/* Guess */
 	MDRV_CPU_PROGRAM_MAP(ctribe_readmem_sound,ctribe_writemem_sound)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -573,9 +572,17 @@ static MACHINE_DRIVER_START( ctribe )
 	MDRV_VIDEO_UPDATE(ctribe)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 8500)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.47)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.47)
 MACHINE_DRIVER_END
 
 /* ROMs */
@@ -595,7 +602,7 @@ ROM_START( ddragon3 )
 	ROM_LOAD( "dd3.a",   0x0c0000, 0x40000, CRC(0f74ea1c) SHA1(6bd8dd89bd22b29038cf502a898336e95e50a9cc) )
 
 	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE )
-	/* sprites	*/
+	/* sprites  */
 	ROM_LOAD( "dd3.3e",   0x000000, 0x20000, CRC(726c49b7) SHA1(dbafad47bb6b717c409fdc5d81c413f1282f2bbb) ) /*4a */
 	ROM_LOAD( "dd3.3d",   0x020000, 0x20000, CRC(37a1c335) SHA1(de70ba51788b601591c3aff71cb94aae349b272d) ) /*3a */
 	ROM_LOAD( "dd3.3c",   0x040000, 0x20000, CRC(2bcfe63c) SHA1(678ef0e7cc38e4df1e1d1e3f5cba6601aa520ec6) ) /*2a */
@@ -646,7 +653,7 @@ ROM_START( ddrago3b )
 	ROM_LOAD( "dd3.a",   0x0c0000, 0x40000, CRC(0f74ea1c) SHA1(6bd8dd89bd22b29038cf502a898336e95e50a9cc) )
 
 	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE )
-	/* sprites	*/
+	/* sprites  */
 	ROM_LOAD( "dd3.3e",   0x000000, 0x20000, CRC(726c49b7) SHA1(dbafad47bb6b717c409fdc5d81c413f1282f2bbb) ) /*4a */
 	ROM_LOAD( "dd3.3d",   0x020000, 0x20000, CRC(37a1c335) SHA1(de70ba51788b601591c3aff71cb94aae349b272d) ) /*3a */
 	ROM_LOAD( "dd3.3c",   0x040000, 0x20000, CRC(2bcfe63c) SHA1(678ef0e7cc38e4df1e1d1e3f5cba6601aa520ec6) ) /*2a */
