@@ -29,22 +29,22 @@ c001      DSWB
 c081      coins per play
 c002      DSWA
           bit 6-7 = lives
-		  bit 5 = upright/cocktail (0 = upright)
+          bit 5 = upright/cocktail (0 = upright)
           bit 4 = difficulty of EXTRA (1 = easy)
           bit 3 = unused?
           bit 2 = RACK TEST
-		  bit 0-1 = difficulty
+          bit 0-1 = difficulty
 c003      IN0
           bit 4-7 = joystick player 2
           bit 0-3 = joystick player 1
 c004      flipscreen (proper cocktail mode implemented by Chad Hendrickson Aug 1, 1999)
-c005	  IN1
+c005      IN1
           bit 7 = START 2
-		  bit 6 = unused
-		  bit 5 = jump player 2
-		  bit 4 = fire player 2
-		  bit 3 = START 1
-		  bit 2 = unused
+          bit 6 = unused
+          bit 5 = jump player 2
+          bit 4 = fire player 2
+          bit 3 = START 1
+          bit 2 = unused
           bit 1 = jump player 1(same effect as fire)
           bit 0 = fire player 1
 c085      during the boot sequence, clearing any of bits 0, 1, 3, 4, 5, 7 enters the
@@ -92,10 +92,10 @@ c003      bit 0-3 = joystick
 c004      flipscreen (proper cocktail mode implemented by Chad Hendrickson Aug 1, 1999)
 c005      bit 0 = fire
           bit 1 = fire (again?!)
-		  bit 2 = ?
-		  bit 3 = START 1
-		  bit 4-6 = ?
-		  bit 4 = START 2
+          bit 2 = ?
+          bit 3 = START 1
+          bit 4-6 = ?
+          bit 4 = START 2
 c081      coins per play
 
 write:
@@ -113,20 +113,22 @@ more sprite tiles, it also has a MSM5205 chip for sample playback.
 
 /*
 
-	TODO:
+    TODO:
 
-	- third CPU
-	- dip switch reading bug
-	- unknown ports 0 and 2
-	- bad communication in idsoccer
-	- adpcm status in idsoccer
-	- real values for the adpcm interface in idsoccer
-	- handle flipscreen on/off based on address line A7 (cX0X/cX8X)
+    - third CPU
+    - dip switch reading bug
+    - unknown ports 0 and 2
+    - bad communication in idsoccer
+    - adpcm status in idsoccer
+    - real values for the adpcm interface in idsoccer
+    - handle flipscreen on/off based on address line A7 (cX0X/cX8X)
 
 */
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/msm5205.h"
+#include "sound/sn76496.h"
 
 
 extern READ8_HANDLER( docastle_shared0_r );
@@ -228,13 +230,14 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( docastle_map3, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x00ff) AM_ROM
-	AM_RANGE(0x4000, 0x4fff) AM_RAM
+	AM_RANGE(0x4000, 0x47ff) AM_RAM
 	AM_RANGE(0x8000, 0x8008) AM_READ(docastle_shared1_r)	/* ??? */
 	AM_RANGE(0xc003, 0xc003) AM_NOP /* EP according to schematics */
 	AM_RANGE(0xc432, 0xc435) AM_NOP	/* ??? */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( docastle_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_NOP /* goes to CRT 46505S */
 	AM_RANGE(0x02, 0x02) AM_NOP /* goes to CRT 46505S */
 ADDRESS_MAP_END
@@ -636,27 +639,18 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /* Sound Interfaces */
 
-static struct SN76496interface sn76496_interface =
-{
-	4,	/* 4 chips */
-	{ 4000000, 4000000, 4000000, 4000000 },	/* 4 MHz */
-	{ 25, 25, 25, 25 }
-};
-
 static struct MSM5205interface msm5205_interface =
 {
-	1,						/* 1 chip */
-	384000,					/* 384 kHz	??? */
-	{ idsoccer_adpcm_int },	/* interrupt function */
-	{ MSM5205_S64_4B },		/* 6 kHz	??? */
-	{ 40 }					/* volume	??? */
+	idsoccer_adpcm_int,	/* interrupt function */
+	MSM5205_S64_4B		/* 6 kHz    ??? */
 };
 
 /* Machine Drivers */
 
 static MACHINE_DRIVER_START( docastle )
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", Z80, 4000000)	/* 4 MHz */
+/*  MDRV_CPU_ADD_TAG("main", Z80, 4000000)  // 4 MHz */
+	MDRV_CPU_ADD_TAG("main", Z80, 3900000)	/* make dip switches work in docastle and dorunrun */
 	MDRV_CPU_PROGRAM_MAP(docastle_map, 0)
 	MDRV_CPU_IO_MAP(docastle_io_map, 0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
@@ -685,7 +679,19 @@ static MACHINE_DRIVER_START( docastle )
 	MDRV_VIDEO_UPDATE(docastle)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 4000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(SN76496, 4000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(SN76496, 4000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(SN76496, 4000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( dorunrun )
@@ -716,7 +722,9 @@ static MACHINE_DRIVER_START( idsoccer )
 	MDRV_PALETTE_INIT(dorunrun)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 MACHINE_DRIVER_END
 
 /* ROMs */
@@ -797,7 +805,7 @@ ROM_START( docastlo )
 
 	ROM_REGION( 0x0200, REGION_PROMS, 0 )
 	/* which prom? this set has the same gfx as douni so i'm using that prom */
-/*	ROM_LOAD( "09c.bin",      0x0000, 0x0200, CRC(066f52bc) SHA1(99f4f2d0181bcaf389c16f127cc3e632d62ee417) ) // color prom */
+/*  ROM_LOAD( "09c.bin",      0x0000, 0x0200, CRC(066f52bc) SHA1(99f4f2d0181bcaf389c16f127cc3e632d62ee417) ) // color prom */
 	ROM_LOAD( "dorevc9.bin",  0x0000, 0x0200, CRC(96624ebe) SHA1(74ff21dc85dcb013c941ec6c06cafdb5bcc16960) ) /* color prom */
 ROM_END
 
@@ -942,7 +950,7 @@ ROM_START( dowild )
 	ROM_LOAD( "w10",          0x0000, 0x4000, CRC(d1f37fba) SHA1(827e2e3b140c4df2fd8780d7d05dc45694cf8f02) )
 
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )
-	ROM_LOAD( "01d.bin",      0x0000, 0x0200, NO_DUMP )
+	ROM_LOAD( "8300b-2",      0x0000, 0x0200, CRC(2747ca77) SHA1(abc0ca05925974c4b852827605ee2f1caefb8524) )
 
 	ROM_REGION( 0x4000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "w5",           0x0000, 0x4000, CRC(b294b151) SHA1(c8c15bf9ab2401052ec80fdfc8fe124c6aa52521) )
@@ -994,7 +1002,7 @@ ROM_START( kickridr )
 	ROM_LOAD( "k10",          0x0000, 0x4000, CRC(6843dbc0) SHA1(8a83f785e1fc2fa34a9955c19e27a1968a6d3f08) )
 
 	ROM_REGION( 0x10000, REGION_CPU3, 0 )
-	ROM_LOAD( "01d.bin",      0x0000, 0x0200, NO_DUMP )
+	ROM_LOAD( "8300b-2",      0x0000, 0x0200, CRC(2747ca77) SHA1(abc0ca05925974c4b852827605ee2f1caefb8524) )
 
 	ROM_REGION( 0x4000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "k5",           0x0000, 0x4000, CRC(3f7d7e49) SHA1(ed9697656a46c3e036665659a008396b323c9c2b) )
