@@ -2,8 +2,8 @@
 Dynamic Dice (??)
 
 Driver by
-	Tomasz Slanina
-	Pierpaolo Prazzoli
+    Tomasz Slanina
+    Pierpaolo Prazzoli
 --
 Old, rusty, not working pcb :
 
@@ -33,6 +33,7 @@ dy_6.bin (near Z80)
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
 
 static struct tilemap *bg_tilemap,*top_tilemap;
 static int ay_data;
@@ -55,12 +56,12 @@ static WRITE8_HANDLER( sound_data_w )
 static WRITE8_HANDLER( sound_control_w )
 {
 /*
-	AY 3-8910 :
+    AY 3-8910 :
 
-	D0 - BC1
-	D1 - BC2
-	D2 - BDIR
-	D3 - /Reset
+    D0 - BC1
+    D1 - BC2
+    D2 - BDIR
+    D3 - /Reset
 
 */
 	if ((data &7)==7) AY8910_control_port_0_w(0,ay_data);
@@ -89,6 +90,7 @@ static ADDRESS_MAP_START( dynadice_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( dynadice_sound_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(soundlatch_r)
 	AM_RANGE(0x01, 0x01) AM_WRITE(soundlatch_clear_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(sound_data_w)
@@ -192,17 +194,6 @@ VIDEO_UPDATE( dynadice )
 	tilemap_draw(bitmap,&myclip,top_tilemap,0,0);
 }
 
-static struct AY8910interface ay8910_interface =
-{
-	1,
-	2000000, /* guess */
-	{ 100 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 PALETTE_INIT( dynadice )
 {
 	int i;
@@ -216,7 +207,7 @@ static MACHINE_DRIVER_START( dynadice )
 	MDRV_CPU_IO_MAP(dynadice_io_map,0)
 
 	MDRV_CPU_ADD(Z80,18432000/6)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(dynadice_sound_map,0)
 	MDRV_CPU_IO_MAP(dynadice_sound_io_map,0)
 
@@ -237,7 +228,10 @@ static MACHINE_DRIVER_START( dynadice )
 	MDRV_VIDEO_START(dynadice)
 	MDRV_VIDEO_UPDATE(dynadice)
 
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 ROM_START( dynadice )
