@@ -1,23 +1,23 @@
 /***************************************************************************
 
-	Dynamite Duke						(c) 1989 Seibu Kaihatsu/Fabtek
-	The Double Dynamites				(c) 1989 Seibu Kaihatsu/Fabtek
+    Dynamite Duke                       (c) 1989 Seibu Kaihatsu/Fabtek
+    The Double Dynamites                (c) 1989 Seibu Kaihatsu/Fabtek
 
 
-	To access test mode, reset with both start buttons held.
+    To access test mode, reset with both start buttons held.
 
-	Coin inputs are handled by the sound CPU, so they don't work with sound
-	disabled. Just put the game in Free Play mode.
+    Coin inputs are handled by the sound CPU, so they don't work with sound
+    disabled. Just put the game in Free Play mode.
 
-	The background layer is 5bpp and I'm not 100% sure the colours are
-	correct on it, although the layer is 5bpp the palette data is 4bpp.
-	My current implementation looks pretty good though I've never seen
-	the real game.
+    The background layer is 5bpp and I'm not 100% sure the colours are
+    correct on it, although the layer is 5bpp the palette data is 4bpp.
+    My current implementation looks pretty good though I've never seen
+    the real game.
 
-	There is a country code byte in the program to select between
-	Seibu Kaihatsu/Fabtek/Taito licenses.
+    There is a country code byte in the program to select between
+    Seibu Kaihatsu/Fabtek/Taito licenses.
 
-	Emulation by Bryan McPhail, mish@tendril.co.uk
+    Emulation by Bryan McPhail, mish@tendril.co.uk
 
 ***************************************************************************/
 
@@ -25,6 +25,8 @@
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "sndhrdw/seibu.h"
+#include "sound/3812intf.h"
+#include "sound/okim6295.h"
 
 READ8_HANDLER( dynduke_background_r );
 READ8_HANDLER( dynduke_foreground_r );
@@ -240,7 +242,7 @@ static struct GfxDecodeInfo dynduke_gfxdecodeinfo[] =
 /******************************************************************************/
 
 /* Parameters: YM3812 frequency, Oki frequency, Oki memory region */
-SEIBU_SOUND_SYSTEM_YM3812_HARDWARE(14318180/4,8000,REGION_SOUND1);
+SEIBU_SOUND_SYSTEM_YM3812_HARDWARE
 
 static INTERRUPT_GEN( dynduke_interrupt )
 {
@@ -283,7 +285,7 @@ static MACHINE_DRIVER_START( dynduke )
 	MDRV_VIDEO_UPDATE(dynduke)
 
 	/* sound hardware */
-	SEIBU_SOUND_SYSTEM_YM3812_INTERFACE
+	SEIBU_SOUND_SYSTEM_YM3812_INTERFACE(14318180/4,8000,1)
 MACHINE_DRIVER_END
 
 /***************************************************************************/
