@@ -89,9 +89,9 @@ Hardware Deficiencies
 
   equites_8404rule(unsigned pc, int offset, int data) details:
 
-	    pc: 68000 code address where the program queries the MCU
-	offset: 8404 memory offset(in bytes) from where MCU data is read
-	  data: fake byte-value to return (negative numbers trigger special conditions)
+        pc: 68000 code address where the program queries the MCU
+    offset: 8404 memory offset(in bytes) from where MCU data is read
+      data: fake byte-value to return (negative numbers trigger special conditions)
 
 The following ROMs need redump:
 
@@ -145,13 +145,25 @@ SNK/Eastern  1985 (ACT) Gekisoh
 /* Common Hardware Start */
 #define EQUITES_ADD_SOUNDBOARD7 \
 	MDRV_CPU_ADD(8085A, 5000000) \
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU) \
+	/* audio CPU */ \
 	MDRV_CPU_PROGRAM_MAP(equites_s_readmem, equites_s_writemem) \
 	MDRV_CPU_IO_MAP(0, equites_s_writeport) \
 	MDRV_CPU_PERIODIC_INT(nmi_line_pulse, 4000) \
-	MDRV_SOUND_ADD(MSM5232, equites_5232intf) \
-	MDRV_SOUND_ADD(AY8910, equites_8910intf) \
-	MDRV_SOUND_ADD(DAC, equites_dacintf)
+	MDRV_SPEAKER_STANDARD_MONO("mono") \
+	\
+	MDRV_SOUND_ADD(MSM5232, 2500000) \
+	MDRV_SOUND_CONFIG(equites_5232intf) \
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75) \
+	\
+	MDRV_SOUND_ADD(AY8910, 6144444/4) \
+	MDRV_SOUND_CONFIG(equites_8910intf) \
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50) \
+	\
+	MDRV_SOUND_ADD(DAC, 0) \
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75) \
+	\
+	MDRV_SOUND_ADD(DAC, 0) \
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75) \
 
 extern void equites_8404init(void);
 extern void equites_8404rule(unsigned pc, int offset, int data);
@@ -166,7 +178,6 @@ extern WRITE8_HANDLER(equites_dac1_w);
 extern data16_t *equites_8404ram;
 extern struct MSM5232interface equites_5232intf;
 extern struct AY8910interface equites_8910intf;
-extern struct DACinterface equites_dacintf;
 
 static ADDRESS_MAP_START( equites_s_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_READ(MRA8_ROM) /* sound program */
@@ -464,7 +475,7 @@ INPUT_PORTS_START( bullfgtr )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x4000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x9000, 0x0000, DEF_STR( Coinage ) )
-/*	PORT_DIPSETTING(      0x9000, "A 1C/1C B 1C/1C" )		// More than 1 credit per player needed */
+/*  PORT_DIPSETTING(      0x9000, "A 1C/1C B 1C/1C" )       // More than 1 credit per player needed */
 	PORT_DIPSETTING(      0x0000, "A 1C/1C B 1C/1C" )
 	PORT_DIPSETTING(      0x8000, "A 1C/1C B 1C/4C" )
 	PORT_DIPSETTING(      0x1000, "A 1C/2C B 1C/3C" )
@@ -479,8 +490,8 @@ INPUT_PORTS_START( kouyakyu )
 	EQUITES_PLAYER_INPUT_MSB( IPT_BUTTON1, IPT_BUTTON2, IPT_BUTTON3, IPT_START2 )
 
 	PORT_START
-/*	PORT_BIT( 0x0100, IP_ACTIVE_HIGH, IPT_COIN1 ) */
-/*	PORT_BIT( 0x0200, IP_ACTIVE_HIGH, IPT_UNUSED ) */
+/*  PORT_BIT( 0x0100, IP_ACTIVE_HIGH, IPT_COIN1 ) */
+/*  PORT_BIT( 0x0200, IP_ACTIVE_HIGH, IPT_UNUSED ) */
 	PORT_BIT( 0x0300, IP_ACTIVE_HIGH, IPT_COIN1 )
 #if EASY_TEST_MODE
 	PORT_SERVICE( 0x0300, IP_ACTIVE_HIGH )
@@ -945,62 +956,119 @@ ROM_END
 /* Bull Fighter ROM Map */
 
 ROM_START( bullfgtr )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* 68000 ROMs */
+	ROM_LOAD16_BYTE( "hp1vr.bin",  0x00001, 0x2000, CRC(e5887586) SHA1(c06883f5c4a2e777b011199787bd4d52f48ceb41) )
+	ROM_LOAD16_BYTE( "hp5vr.bin",  0x00000, 0x2000, CRC(b49fa09f) SHA1(ee947f7b4fa96f887f9b14e7503f98b4d117d1c8) )
+	ROM_LOAD16_BYTE( "hp2vr.bin",  0x04001, 0x2000, CRC(845bdf28) SHA1(4eac9ca034aaa6a7db4061ad11587189fc843ca0) )
+	ROM_LOAD16_BYTE( "hp6vr.bin",  0x04000, 0x2000, CRC(3dfadcf4) SHA1(724d45df0be7073bbe2767f3c0d050c8b45c9d27) )
+	ROM_LOAD16_BYTE( "hp3vr.bin",  0x08001, 0x2000, CRC(d3a21f8a) SHA1(2b3135aaae798eeee5850e616ed6ad8987fbc01b) )
+	ROM_LOAD16_BYTE( "hp7vr.bin",  0x08000, 0x2000, CRC(665cc015) SHA1(17fe18c8f22808a102f48bc4cbc8e4a1f6f9eaf1) )
+	ROM_FILL(                      0x0c000, 0x4000, 0 )
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* Z80 ROMs */
+	ROM_LOAD( "hv1vr.bin", 0x00000, 0x2000, CRC(2a8e6fcf) SHA1(866903408e05938a982ffef4c9b849203c6cc060) )
+	ROM_LOAD( "hv2vr.bin", 0x02000, 0x2000, CRC(026e1533) SHA1(6271869a3faaafacfac35262746e87a83c158b93) )
+	ROM_LOAD( "hv3vr.bin", 0x04000, 0x2000, CRC(51ee751c) SHA1(60bf848dfdfe313ab05df5a5c05819b0fa87ca50) )
+	ROM_LOAD( "hv4vr.bin", 0x06000, 0x2000, CRC(62c7a25b) SHA1(237d3cbdfbf45b33c2f65d30faba151380866a93) )
+
+	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE ) /* chars */
+	ROM_LOAD( "h.bin", 0x000000, 0x1000, CRC(c6894c9a) SHA1(0d5a55cded4fd833211bdc733a78c6c8423897de) )
+
+	ROM_REGION( 0x8000, REGION_GFX2, ROMREGION_DISPOSE ) /* tile set1 */
+	ROM_LOAD_NIB_HIGH( "hb5vr.bin",  0x00000, 0x2000, CRC(6d05e9f2) SHA1(4b5c92b72bf73a08a2359fe889a327a696a45e8a) )
+	ROM_LOAD         ( "hb5vr.bin",  0x02000, 0x2000, CRC(6d05e9f2) SHA1(4b5c92b72bf73a08a2359fe889a327a696a45e8a) )
+	ROM_LOAD         ( "hb1vr.bin",  0x04000, 0x2000, CRC(4352d069) SHA1(bac687f050837b023da00cb53bb524b2a76310d4) )
+	ROM_LOAD         ( "hb2vr.bin",  0x06000, 0x2000, CRC(24edfd7d) SHA1(be8a40d8d5ccff06f37c1ab67341f56e41a5ea88) )
+
+	ROM_REGION( 0x8000, REGION_GFX3, ROMREGION_DISPOSE ) /* tile set2 */
+	ROM_LOAD_NIB_HIGH( "hb6vr.bin",  0x00000, 0x2000, CRC(016340ae) SHA1(f980d39337c711a15520388967ca4503e7970e18) )
+	ROM_LOAD         ( "hb6vr.bin",  0x02000, 0x2000, CRC(016340ae) SHA1(f980d39337c711a15520388967ca4503e7970e18) )
+	ROM_LOAD         ( "hb3vr.bin",  0x04000, 0x2000, CRC(4947114e) SHA1(822dc3f14b71dc9e5b69078aefbed6b438aa0690) )
+	ROM_LOAD         ( "hb4vr.bin",  0x06000, 0x2000, CRC(fa296cb3) SHA1(2ba864766655cb3dd2999a6cdf96dcefd6818135) )
+
+	ROM_REGION( 0x8000, REGION_GFX4, ROMREGION_DISPOSE ) /* sprite set1 */
+	ROM_LOAD_NIB_HIGH( "hs5vr.bin",  0x00000, 0x2000, CRC(48394389) SHA1(a5c6021b60226a775b2052909e8d21b5f79d9ec5) )
+	ROM_LOAD         ( "hs5vr.bin",  0x02000, 0x2000, CRC(48394389) SHA1(a5c6021b60226a775b2052909e8d21b5f79d9ec5) )
+	ROM_LOAD         ( "hs1vr.bin",  0x04000, 0x2000, CRC(7c69b473) SHA1(abc181b4e5b3f48c667a0bb4814c3818dfc6e9e2) )
+	ROM_LOAD         ( "hs2vr.bin",  0x06000, 0x2000, CRC(c3dc713f) SHA1(c2072cc71ea61e0c718c339bda1460d93343469e) )
+
+	ROM_REGION( 0x8000, REGION_GFX5, ROMREGION_DISPOSE ) /* sprite set2 */
+	ROM_LOAD_NIB_HIGH( "hs6vr.bin",  0x00000, 0x2000, CRC(141409ec) SHA1(3cc542fa34fdbd71e392c7c22da5d5120642be86) )
+	ROM_LOAD         ( "hs6vr.bin",  0x02000, 0x2000, CRC(141409ec) SHA1(3cc542fa34fdbd71e392c7c22da5d5120642be86) )
+	ROM_LOAD         ( "hs3vr.bin",  0x04000, 0x2000, CRC(883f93fd) SHA1(a96df701f82e62582522953830049d29bcb3d458) )
+	ROM_LOAD         ( "hs4vr.bin",  0x06000, 0x2000, CRC(578ace7b) SHA1(933e85d49db7b27fd85e4713f0984612bc29e134) )
+
+	ROM_REGION( 0x0300, REGION_PROMS, 0 ) /* RGB PROMs */
+	ROM_LOAD( "24s10n.a3", 0x00000, 0x100, CRC(e8a9d159) SHA1(d015149a39adcb5fc6d12d9afe7820ecef480039) )
+	ROM_LOAD( "24s10n.a1", 0x00100, 0x100, CRC(3956af86) SHA1(ccbb69535ece5e228622907d17c959b195b97a0a) )
+	ROM_LOAD( "24s10n.a2", 0x00200, 0x100, CRC(f50f8ec5) SHA1(ec2d934618e25e3471153f9fe7b34f978b113a47) )
+
+	ROM_REGION( 0x0100, REGION_USER1, 0 ) /* CLUT(same PROM x 4) */
+	ROM_LOAD( "24s10n.b6",  0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
+	ROM_LOAD( "24s10n.b7",  0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
+	ROM_LOAD( "24s10n.b9",  0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
+	ROM_LOAD( "24s10n.b10", 0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
+
+	ROM_REGION( 0x0020, REGION_USER2, 0 ) /* MSM5232 PROMs?(identical to bprom.3h in Equites) */
+	ROM_LOAD( "18s030.h3",  0x00000, 0x020, CRC(33b98466) SHA1(017c73cf8c17dc5047c89316ae5b45f8d22092e8) )
+ROM_END
+
+ROM_START( bullfgts )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* 68000 ROMs */
 	ROM_LOAD16_BYTE( "m_d13.bin",  0x00001, 0x2000, CRC(7c35dd4b) SHA1(6bd604ee32c0c5db17f90e24aa254ec7072d27dd) )
 	ROM_LOAD16_BYTE( "m_b13.bin",  0x00000, 0x2000, CRC(c4adddce) SHA1(48b6ddbad52a3941d3e651642b26d9adf70f71f5) )
 	ROM_LOAD16_BYTE( "m_d12.bin",  0x04001, 0x2000, CRC(5d51be2b) SHA1(55d2718479cb71ceefefbaf40c14285e5603e526) )
 	ROM_LOAD16_BYTE( "m_b12.bin",  0x04000, 0x2000, CRC(d98390ef) SHA1(17006503325627055c8b22052d7ed94e474f4ef7) )
-	ROM_LOAD16_BYTE( "m_dd10.bin", 0x08001, 0x2000, CRC(21875752) SHA1(016db4125b1a4584ae277af427370780d96a17c5) )
+	ROM_LOAD16_BYTE( "m_d10.bin",  0x08001, 0x2000, CRC(21875752) SHA1(016db4125b1a4584ae277af427370780d96a17c5) )
 	ROM_LOAD16_BYTE( "m_b10.bin",  0x08000, 0x2000, CRC(9d84f678) SHA1(32584d54788cb570bd5210992836f28ba9c87aac) )
 	ROM_FILL(                      0x0c000, 0x4000, 0 )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* Z80 ROMs */
-	ROM_LOAD( "s_m1.bin", 0x00000, 0x2000, CRC(2a8e6fcf) SHA1(866903408e05938a982ffef4c9b849203c6cc060) )
-	ROM_LOAD( "s_l2.bin", 0x02000, 0x2000, CRC(026e1533) SHA1(6271869a3faaafacfac35262746e87a83c158b93) )
-	ROM_LOAD( "s_k1.bin", 0x04000, 0x2000, CRC(51ee751c) SHA1(60bf848dfdfe313ab05df5a5c05819b0fa87ca50) )
-	ROM_LOAD( "s_h1.bin", 0x06000, 0x2000, CRC(62c7a25b) SHA1(237d3cbdfbf45b33c2f65d30faba151380866a93) )
+	ROM_LOAD( "hv1vr.bin", 0x00000, 0x2000, CRC(2a8e6fcf) SHA1(866903408e05938a982ffef4c9b849203c6cc060) )
+	ROM_LOAD( "hv2vr.bin", 0x02000, 0x2000, CRC(026e1533) SHA1(6271869a3faaafacfac35262746e87a83c158b93) )
+	ROM_LOAD( "hv3vr.bin", 0x04000, 0x2000, CRC(51ee751c) SHA1(60bf848dfdfe313ab05df5a5c05819b0fa87ca50) )
+	ROM_LOAD( "hv4vr.bin", 0x06000, 0x2000, CRC(62c7a25b) SHA1(237d3cbdfbf45b33c2f65d30faba151380866a93) )
 
 	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE ) /* chars */
-	ROM_LOAD( "m_e4.bin", 0x000000, 0x1000, CRC(c6894c9a) SHA1(0d5a55cded4fd833211bdc733a78c6c8423897de) )
+	ROM_LOAD( "h.bin", 0x000000, 0x1000, CRC(c6894c9a) SHA1(0d5a55cded4fd833211bdc733a78c6c8423897de) )
 
 	ROM_REGION( 0x8000, REGION_GFX2, ROMREGION_DISPOSE ) /* tile set1 */
-	ROM_LOAD_NIB_HIGH( "l_h7.bin",  0x00000, 0x2000, CRC(6d05e9f2) SHA1(4b5c92b72bf73a08a2359fe889a327a696a45e8a) )
-	ROM_LOAD         ( "l_h7.bin",  0x02000, 0x2000, CRC(6d05e9f2) SHA1(4b5c92b72bf73a08a2359fe889a327a696a45e8a) )
-	ROM_LOAD         ( "l_f7.bin",  0x04000, 0x2000, CRC(4352d069) SHA1(bac687f050837b023da00cb53bb524b2a76310d4) )
-	ROM_LOAD         ( "l_f9.bin",  0x06000, 0x2000, CRC(24edfd7d) SHA1(be8a40d8d5ccff06f37c1ab67341f56e41a5ea88) )
+	ROM_LOAD_NIB_HIGH( "hb5vr.bin",  0x00000, 0x2000, CRC(6d05e9f2) SHA1(4b5c92b72bf73a08a2359fe889a327a696a45e8a) )
+	ROM_LOAD         ( "hb5vr.bin",  0x02000, 0x2000, CRC(6d05e9f2) SHA1(4b5c92b72bf73a08a2359fe889a327a696a45e8a) )
+	ROM_LOAD         ( "hb1vr.bin",  0x04000, 0x2000, CRC(4352d069) SHA1(bac687f050837b023da00cb53bb524b2a76310d4) )
+	ROM_LOAD         ( "hb2vr.bin",  0x06000, 0x2000, CRC(24edfd7d) SHA1(be8a40d8d5ccff06f37c1ab67341f56e41a5ea88) )
 
 	ROM_REGION( 0x8000, REGION_GFX3, ROMREGION_DISPOSE ) /* tile set2 */
-	ROM_LOAD_NIB_HIGH( "l_h9.bin",  0x00000, 0x2000, CRC(016340ae) SHA1(f980d39337c711a15520388967ca4503e7970e18) )
-	ROM_LOAD         ( "l_h9.bin",  0x02000, 0x2000, CRC(016340ae) SHA1(f980d39337c711a15520388967ca4503e7970e18) )
-	ROM_LOAD         ( "l_f10.bin", 0x04000, 0x2000, CRC(4947114e) SHA1(822dc3f14b71dc9e5b69078aefbed6b438aa0690) )
-	ROM_LOAD         ( "l_f12.bin", 0x06000, 0x2000, CRC(fa296cb3) SHA1(2ba864766655cb3dd2999a6cdf96dcefd6818135) )
+	ROM_LOAD_NIB_HIGH( "hb6vr.bin",  0x00000, 0x2000, CRC(016340ae) SHA1(f980d39337c711a15520388967ca4503e7970e18) )
+	ROM_LOAD         ( "hb6vr.bin",  0x02000, 0x2000, CRC(016340ae) SHA1(f980d39337c711a15520388967ca4503e7970e18) )
+	ROM_LOAD         ( "hb3vr.bin",  0x04000, 0x2000, CRC(4947114e) SHA1(822dc3f14b71dc9e5b69078aefbed6b438aa0690) )
+	ROM_LOAD         ( "hb4vr.bin",  0x06000, 0x2000, CRC(fa296cb3) SHA1(2ba864766655cb3dd2999a6cdf96dcefd6818135) )
 
 	ROM_REGION( 0x8000, REGION_GFX4, ROMREGION_DISPOSE ) /* sprite set1 */
-	ROM_LOAD_NIB_HIGH( "l_h6.bin",  0x00000, 0x2000, CRC(48394389) SHA1(a5c6021b60226a775b2052909e8d21b5f79d9ec5) )
-	ROM_LOAD         ( "l_h6.bin",  0x02000, 0x2000, CRC(48394389) SHA1(a5c6021b60226a775b2052909e8d21b5f79d9ec5) )
-	ROM_LOAD         ( "l_f6.bin",  0x04000, 0x2000, CRC(7c69b473) SHA1(abc181b4e5b3f48c667a0bb4814c3818dfc6e9e2) )
-	ROM_LOAD         ( "l_f4.bin",  0x06000, 0x2000, CRC(c3dc713f) SHA1(c2072cc71ea61e0c718c339bda1460d93343469e) )
+	ROM_LOAD_NIB_HIGH( "hs5vr.bin",  0x00000, 0x2000, CRC(48394389) SHA1(a5c6021b60226a775b2052909e8d21b5f79d9ec5) )
+	ROM_LOAD         ( "hs5vr.bin",  0x02000, 0x2000, CRC(48394389) SHA1(a5c6021b60226a775b2052909e8d21b5f79d9ec5) )
+	ROM_LOAD         ( "hs1vr.bin",  0x04000, 0x2000, CRC(7c69b473) SHA1(abc181b4e5b3f48c667a0bb4814c3818dfc6e9e2) )
+	ROM_LOAD         ( "hs2vr.bin",  0x06000, 0x2000, CRC(c3dc713f) SHA1(c2072cc71ea61e0c718c339bda1460d93343469e) )
 
 	ROM_REGION( 0x8000, REGION_GFX5, ROMREGION_DISPOSE ) /* sprite set2 */
-	ROM_LOAD_NIB_HIGH( "l_h4.bin",  0x00000, 0x2000, CRC(141409ec) SHA1(3cc542fa34fdbd71e392c7c22da5d5120642be86) )
-	ROM_LOAD         ( "l_h4.bin",  0x02000, 0x2000, CRC(141409ec) SHA1(3cc542fa34fdbd71e392c7c22da5d5120642be86) )
-	ROM_LOAD         ( "l_f3.bin",  0x04000, 0x2000, CRC(883f93fd) SHA1(a96df701f82e62582522953830049d29bcb3d458) )
-	ROM_LOAD         ( "l_f1.bin",  0x06000, 0x2000, CRC(578ace7b) SHA1(933e85d49db7b27fd85e4713f0984612bc29e134) )
+	ROM_LOAD_NIB_HIGH( "hs6vr.bin",  0x00000, 0x2000, CRC(141409ec) SHA1(3cc542fa34fdbd71e392c7c22da5d5120642be86) )
+	ROM_LOAD         ( "hs6vr.bin",  0x02000, 0x2000, CRC(141409ec) SHA1(3cc542fa34fdbd71e392c7c22da5d5120642be86) )
+	ROM_LOAD         ( "hs3vr.bin",  0x04000, 0x2000, CRC(883f93fd) SHA1(a96df701f82e62582522953830049d29bcb3d458) )
+	ROM_LOAD         ( "hs4vr.bin",  0x06000, 0x2000, CRC(578ace7b) SHA1(933e85d49db7b27fd85e4713f0984612bc29e134) )
 
-	/* all color PROMs of current dump are bad and have wrong sizes */
 	ROM_REGION( 0x0300, REGION_PROMS, 0 ) /* RGB PROMs */
-	ROM_LOAD( "m_a3.bin", 0x00000, 0x100, BAD_DUMP CRC(8203ee60) SHA1(5bf5e54615c77945365c39d6ae95586ae187ebed)  ) /* R (made up, dump was bad) */
-	ROM_LOAD( "m_a1.bin", 0x00100, 0x100, BAD_DUMP CRC(2eb1a3de) SHA1(80b0e0f882210f2119d7ee307deb856dcc288352)  ) /* G (made up, dump was bad) */
-	ROM_LOAD( "m_a2.bin", 0x00200, 0x100, BAD_DUMP CRC(2e769d4c) SHA1(4de42319aed5073e88742c006b641efdd52cac80)  ) /* B (made up, dump was bad) */
+	ROM_LOAD( "24s10n.a3", 0x00000, 0x100, CRC(e8a9d159) SHA1(d015149a39adcb5fc6d12d9afe7820ecef480039) )
+	ROM_LOAD( "24s10n.a1", 0x00100, 0x100, CRC(3956af86) SHA1(ccbb69535ece5e228622907d17c959b195b97a0a) )
+	ROM_LOAD( "24s10n.a2", 0x00200, 0x100, CRC(f50f8ec5) SHA1(ec2d934618e25e3471153f9fe7b34f978b113a47) )
 
 	ROM_REGION( 0x0100, REGION_USER1, 0 ) /* CLUT(same PROM x 4) */
-	ROM_LOAD( "l_b6.bin",  0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
-	ROM_LOAD( "l_b7.bin",  0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
-	ROM_LOAD( "l_b9.bin",  0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
-	ROM_LOAD( "l_b10.bin", 0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
+	ROM_LOAD( "24s10n.b6",  0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
+	ROM_LOAD( "24s10n.b7",  0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
+	ROM_LOAD( "24s10n.b9",  0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
+	ROM_LOAD( "24s10n.b10", 0x0000, 0x100, CRC(8835a069) SHA1(bc8d4130d4fa0f16bb2511ac66b84d53218042a3) )
 
 	ROM_REGION( 0x0020, REGION_USER2, 0 ) /* MSM5232 PROMs?(identical to bprom.3h in Equites) */
-	ROM_LOAD( "s_h3.bin",  0x00000, 0x020, CRC(33b98466) SHA1(017c73cf8c17dc5047c89316ae5b45f8d22092e8) )
+	ROM_LOAD( "18s030.h3",  0x00000, 0x020, CRC(33b98466) SHA1(017c73cf8c17dc5047c89316ae5b45f8d22092e8) )
 ROM_END
 
 /******************************************************************************/
@@ -1159,6 +1227,16 @@ static DRIVER_INIT( bullfgtr )
 
 	equites_init_common();
 
+	equites_8404rule(0x0e7a, 0x601, 0x00); /* boot up */
+	equites_8404rule(0x3dc4, 0x201, 0x0c); /* goal in */
+}
+
+static DRIVER_INIT( bullfgts )
+{
+	equites_id = 0x8401;
+
+	equites_init_common();
+
 	equites_8404rule(0x0e7a, 0x601, 0x00); /* boot up */
 	equites_8404rule(0x3da4, 0x201, 0x0c); /* goal in */
 }
@@ -1287,7 +1365,8 @@ static DRIVER_INIT( hvoltage )
 /* Equites Hardware */
 GAMEX( 1984, equites,  0,        equites,  equites,  equites,  ROT90, "Alpha Denshi Co.",                "Equites", GAME_UNEMULATED_PROTECTION | GAME_NO_COCKTAIL )
 GAMEX( 1984, equitess, equites,  equites,  equites,  equites,  ROT90, "Alpha Denshi Co. (Sega license)", "Equites (Sega)", GAME_UNEMULATED_PROTECTION | GAME_NO_COCKTAIL )
-GAMEX( 1984, bullfgtr, 0,        equites,  bullfgtr, bullfgtr, ROT90, "Alpha Denshi Co. (Sega license)", "Bull Fighter", GAME_UNEMULATED_PROTECTION | GAME_WRONG_COLORS )
+GAMEX( 1984, bullfgtr, 0,        equites,  bullfgtr, bullfgtr, ROT90, "Alpha Denshi Co.",                "Bull Fighter", GAME_UNEMULATED_PROTECTION )
+GAMEX( 1984, bullfgts, bullfgtr, equites,  bullfgtr, bullfgts, ROT90, "Alpha Denshi Co. (Sega license)", "Bull Fighter (Sega)", GAME_UNEMULATED_PROTECTION )
 GAMEX( 1985, kouyakyu, 0,        equites,  kouyakyu, kouyakyu, ROT0,  "Alpha Denshi Co.",                "The Koukouyakyuh", GAME_UNEMULATED_PROTECTION )
 
 /* Splendor Blast Hardware */
