@@ -1,20 +1,20 @@
 /***************************************************************************
 
-						  -= ESD 16 Bit Games =-
+                          -= ESD 16 Bit Games =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
-Main  CPU	:	M68000
-Video Chips	:	2 x ACTEL A40MX04 (84 Pin Square Socketed)
+Main  CPU   :   M68000
+Video Chips :   2 x ACTEL A40MX04 (84 Pin Square Socketed)
 
-Sound CPU	:	Z80
-Sound Chips	:	M6295 (AD-65)  +  YM3812 (U6612)  +  YM3014 (U6614)
+Sound CPU   :   Z80
+Sound Chips :   M6295 (AD-65)  +  YM3812 (U6612)  +  YM3014 (U6614)
 
 ---------------------------------------------------------------------------
-Year + Game			PCB				Notes
+Year + Game         PCB             Notes
 ---------------------------------------------------------------------------
-98	Multi Champ		ESD 11-09-98
+98  Multi Champ     ESD 11-09-98
 00  Head Panic      ESD 08-26-1999 (with Fuuki)
 ---------------------------------------------------------------------------
 
@@ -29,6 +29,8 @@ Head Panic
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
+#include "sound/okim6295.h"
+#include "sound/3812intf.h"
 
 /* Variables defined in vidhrdw: */
 
@@ -54,7 +56,7 @@ data16_t* headpanic_platform_y;
 /***************************************************************************
 
 
-							Memory Maps - Main CPU
+                            Memory Maps - Main CPU
 
 
 ***************************************************************************/
@@ -139,7 +141,7 @@ static READ16_HANDLER( esd_eeprom_r )
 		return ((EEPROM_read_bit() & 0x01) << 15);
 	}
 
-/*	logerror("(0x%06x) unk EEPROM read: %04x\n", activecpu_get_pc(), mem_mask); */
+/*  logerror("(0x%06x) unk EEPROM read: %04x\n", activecpu_get_pc(), mem_mask); */
 	return 0;
 }
 
@@ -157,7 +159,7 @@ static WRITE16_HANDLER( esd_eeprom_w )
 		EEPROM_set_cs_line((data & 0x0100) ? CLEAR_LINE : ASSERT_LINE );
 	}
 
-/*	logerror("(0x%06x) Unk EEPROM write: %04x %04x\n", activecpu_get_pc(), data, mem_mask); */
+/*  logerror("(0x%06x) Unk EEPROM write: %04x %04x\n", activecpu_get_pc(), data, mem_mask); */
 }
 
 
@@ -183,11 +185,11 @@ static ADDRESS_MAP_START( hedpanic_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xb00004, 0xb00007) AM_WRITE(MWA16_RAM) AM_BASE(&esd16_scroll_1	)	/* */
 	AM_RANGE(0xb00008, 0xb00009) AM_WRITE(MWA16_RAM) AM_BASE(&headpanic_platform_x)
 	AM_RANGE(0xb0000a, 0xb0000b) AM_WRITE(MWA16_RAM) AM_BASE(&headpanic_platform_y)
-/*	AM_RANGE(0xb0000c, 0xb0000d) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown1) // ?? */
+/*  AM_RANGE(0xb0000c, 0xb0000d) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown1) // ?? */
 	AM_RANGE(0xb0000e, 0xb0000f) AM_WRITE(MWA16_RAM) AM_BASE(&head_layersize) /* ?? */
-/*	AM_RANGE(0xc00000, 0xc00001) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown3	)	// IRQ Ack */
-/*	AM_RANGE(0xc00008, 0xc00009) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown5		)	// Flip Screen + ? // not checked */
-/*	AM_RANGE(0xc0000a, 0xc0000b) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown4	)	// ? 2 not checked */
+/*  AM_RANGE(0xc00000, 0xc00001) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown3 )   // IRQ Ack */
+/*  AM_RANGE(0xc00008, 0xc00009) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown5     )   // Flip Screen + ? // not checked */
+/*  AM_RANGE(0xc0000a, 0xc0000b) AM_WRITE(MWA16_RAM) AM_BASE(&head_unknown4 )   // ? 2 not checked */
 	AM_RANGE(0xc0000c, 0xc0000d) AM_WRITE(esd16_sound_command_w			)	/* To Sound CPU // ok */
 	AM_RANGE(0xc0000e, 0xc0000f) AM_WRITE(esd_eeprom_w)
 	AM_RANGE(0xd00008, 0xd00009) AM_WRITE(hedpanic_platform_w)
@@ -197,7 +199,7 @@ ADDRESS_MAP_END
 /***************************************************************************
 
 
-							Memory Maps - Sound CPU
+                            Memory Maps - Sound CPU
 
 
 ***************************************************************************/
@@ -230,12 +232,14 @@ READ8_HANDLER( esd16_sound_command_r )
 }
 
 static ADDRESS_MAP_START( multchmp_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x02, 0x02) AM_READ(OKIM6295_status_0_r		)	/* M6295 */
 	AM_RANGE(0x03, 0x03) AM_READ(esd16_sound_command_r		)	/* From Main CPU */
 	AM_RANGE(0x06, 0x06) AM_READ(MRA8_NOP					)	/* ? At the start */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( multchmp_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM3812_control_port_0_w	)	/* YM3812 */
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM3812_write_port_0_w		)
 	AM_RANGE(0x02, 0x02) AM_WRITE(OKIM6295_data_0_w			)	/* M6295 */
@@ -248,7 +252,7 @@ ADDRESS_MAP_END
 /***************************************************************************
 
 
-								Input Ports
+                                Input Ports
 
 
 ***************************************************************************/
@@ -288,7 +292,7 @@ INPUT_PORTS_START( multchmp )
 	PORT_SERVICE( 0x0001, IP_ACTIVE_LOW )
 	PORT_DIPNAME( 0x0002, 0x0002, "Coinage Type" )	/* Not Supported */
 	PORT_DIPSETTING(      0x0002, "1" )
-/*	PORT_DIPSETTING(      0x0000, "2" ) */
+/*  PORT_DIPSETTING(      0x0000, "2" ) */
 	PORT_DIPNAME( 0x0004, 0x0000, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(      0x0004, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -306,7 +310,7 @@ INPUT_PORTS_START( multchmp )
 	PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )
 	PORT_DIPSETTING(      0x0080, DEF_STR( 1C_2C ) )
 
-/*	PORT_DIPNAME( 0x0300, 0x0300, DEF_STR( Difficulty" ) )	CRASH CPP?? */
+/*  PORT_DIPNAME( 0x0300, 0x0300, DEF_STR( Difficulty" ) )  CRASH CPP?? */
 	PORT_DIPNAME( 0x0300, 0x0300, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(      0x0200, DEF_STR( Easy ) )
 	PORT_DIPSETTING(      0x0300, DEF_STR( Normal ) )
@@ -367,7 +371,7 @@ INPUT_PORTS_END
 /***************************************************************************
 
 
-							Graphics Layouts
+                            Graphics Layouts
 
 
 ***************************************************************************/
@@ -455,27 +459,11 @@ static struct GfxDecodeInfo hedpanic_gfxdecodeinfo[] =
 /***************************************************************************
 
 
-								Machine Drivers
+                                Machine Drivers
 
 
 ***************************************************************************/
 
-static struct YM3812interface esd16_ym3812_intf =
-{
-	1,
-	4000000,	/* ? */
-	{ 40 },
-	{  0 },		/* IRQ Line */
-};
-
-static struct OKIM6295interface esd16_m6295_intf =
-{
-	1,
-	{ 8000 },	/* ? */
-	{ REGION_SOUND1 },
-	{ 80 }
-};
-
 static MACHINE_DRIVER_START( multchmp )
 
 	/* basic machine hardware */
@@ -484,7 +472,7 @@ static MACHINE_DRIVER_START( multchmp )
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ? */
+	/* audio CPU */	/* ? */
 	MDRV_CPU_PROGRAM_MAP(multchmp_sound_readmem,multchmp_sound_writemem)
 	MDRV_CPU_IO_MAP(multchmp_sound_readport,multchmp_sound_writeport)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,32)	/* IRQ By Main CPU */
@@ -503,8 +491,14 @@ static MACHINE_DRIVER_START( multchmp )
 	MDRV_VIDEO_UPDATE(esd16)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, esd16_ym3812_intf)
-	MDRV_SOUND_ADD(OKIM6295, esd16_m6295_intf)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 4000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( hedpanic )
@@ -527,14 +521,14 @@ MACHINE_DRIVER_END
 /***************************************************************************
 
 
-								ROMs Loading
+                                ROMs Loading
 
 
 ***************************************************************************/
 
 /***************************************************************************
 
-								Multi Champ
+                                Multi Champ
 
 (C) ESD 1998
 PCB No. ESD 11-09-98    (Probably the manufacture date)
@@ -663,7 +657,7 @@ ROM_END
 /***************************************************************************
 
 
-								Game Drivers
+                                Game Drivers
 
 
 ***************************************************************************/
