@@ -26,6 +26,8 @@ based on wich Coin input was connected.
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
 
 /* from vidhrdw */
 extern WRITE8_HANDLER( exctsccr_videoram_w );
@@ -52,7 +54,7 @@ WRITE8_HANDLER( exctsccr_DAC_data_w )
 
 /***************************************************************************
 
-	Memory definition(s)
+    Memory definition(s)
 
 ***************************************************************************/
 
@@ -102,6 +104,7 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x82, 0x82) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x83, 0x83) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x86, 0x86) AM_WRITE(AY8910_write_port_1_w)
@@ -158,7 +161,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************
 
-	Input port(s)
+    Input port(s)
 
 ***************************************************************************/
 
@@ -218,7 +221,7 @@ INPUT_PORTS_END
 
 /***************************************************************************
 
-	Graphic(s) decoding
+    Graphic(s) decoding
 
 ***************************************************************************/
 
@@ -293,50 +296,10 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-/***************************************************************************
-
-	Sound interface(s)
-
-***************************************************************************/
-
-static struct AY8910interface ay8910_interface =
-{
-	4,	/* 4 chips */
-	1500000,	/* 1.5 MHz ? */
-	{ 15, 15, 15, 15 }, /* volume */
-	{ 0, 0, 0, 0 },
-	{ 0, 0, 0, 0 },
-	{ 0, 0, 0, 0 }, /* it writes 0s thru port A, no clue what for */
-	{ 0, 0, 0, 0 }
-};
-
-static struct DACinterface dac_interface =
-{
-	2,
-	{ 50, 50 }
-};
-
-/* Bootleg */
-static struct AY8910interface bl_ay8910_interface =
-{
-	1,	/* 1 chip */
-	1500000,	/* 1.5 MHz ? */
-	{ 50 }, /* volume */
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-static struct DACinterface bl_dac_interface =
-{
-	1,
-	{ 100 }
-};
 
 /***************************************************************************
 
-	Machine driver(s)
+    Machine driver(s)
 
 ***************************************************************************/
 
@@ -368,8 +331,25 @@ static MACHINE_DRIVER_START( exctsccr )
 	MDRV_VIDEO_UPDATE(exctsccr)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 /* Bootleg */
@@ -399,8 +379,13 @@ static MACHINE_DRIVER_START( exctsccb )
 	MDRV_VIDEO_UPDATE(exctsccr)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, bl_ay8910_interface)
-	MDRV_SOUND_ADD(DAC, bl_dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /***************************************************************************
