@@ -1,27 +1,28 @@
 /***************************************************************************
 
-	Jaleco Exerion hardware
+    Jaleco Exerion hardware
 
 ****************************************************************************
 
-	Exerion is a unique driver in that it has idiosyncracies that are straight
-	out of Bizarro World. I submit for your approval:
+    Exerion is a unique driver in that it has idiosyncracies that are straight
+    out of Bizarro World. I submit for your approval:
 
-	* The mystery reads from $d802 - timer-based protection?
-	* The freakish graphics encoding scheme, which no other MAME-supported game uses
-	* The sprite-ram, and all the funky parameters that go along with it
+    * The mystery reads from $d802 - timer-based protection?
+    * The freakish graphics encoding scheme, which no other MAME-supported game uses
+    * The sprite-ram, and all the funky parameters that go along with it
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "exerion.h"
+#include "sound/ay8910.h"
 
 
 
 /*************************************
  *
- *	Interrupts & inputs
+ *  Interrupts & inputs
  *
  *************************************/
 
@@ -54,7 +55,7 @@ static INTERRUPT_GEN( exerion_interrupt )
 
 /*************************************
  *
- *	Protection??
+ *  Protection??
  *
  *************************************/
 
@@ -94,7 +95,7 @@ static READ8_HANDLER( exerion_protection_r )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -128,7 +129,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sub CPU memory handlers
+ *  Sub CPU memory handlers
  *
  *************************************/
 
@@ -150,7 +151,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -223,7 +224,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics layouts
+ *  Graphics layouts
  *
  *************************************/
 
@@ -285,26 +286,23 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound interfaces
+ *  Sound interfaces
  *
  *************************************/
 
 static struct AY8910interface ay8910_interface =
 {
-	2,  /* 2 chips */
-	10000000/6, /* 1.666 MHz */
-	{ 30, 30 },
-	{ 0, exerion_porta_r },
-	{ 0 },
-	{ 0 },
-	{ 0, exerion_portb_w }
+	exerion_porta_r,
+	0,
+	0,
+	exerion_portb_w
 };
 
 
 
 /*************************************
  *
- *	Machine drivers
+ *  Machine drivers
  *
  *************************************/
 
@@ -332,14 +330,21 @@ static MACHINE_DRIVER_START( exerion )
 	MDRV_VIDEO_UPDATE(exerion)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 10000000/6)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 10000000/6)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -436,7 +441,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver initialization
+ *  Driver initialization
  *
  *************************************/
 
@@ -508,7 +513,7 @@ static DRIVER_INIT( exerionb )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
