@@ -1,216 +1,216 @@
 /***************************************************************************
 
-	Exidy 440 hardware
+    Exidy 440 hardware
 
     driver by Aaron Giles
 
-	Currently implemented:
-		* Crossbow
-		* Cheyenne
-		* Combat/Catch-22
-		* Crackshot
-		* Chiller
-		* Top Secret
-		* Clay Pigeon
-		* Hit 'n Miss
-		* Who Dunit
-		* Showdown
+    Currently implemented:
+        * Crossbow
+        * Cheyenne
+        * Combat/Catch-22
+        * Crackshot
+        * Chiller
+        * Top Secret
+        * Clay Pigeon
+        * Hit 'n Miss
+        * Who Dunit
+        * Showdown
 
 
 ****************************************************************************
 
-	Memory map
+    Memory map
 
 ****************************************************************************
 
-	========================================================================
-	CPU #1
-	========================================================================
-	0000-1FFF   R/W   xxxxxxxx    Image RAM (64 images x 128 bytes, each image is 16x16x4bpp)
-	            R/W   xxxx----       (left pixel)
-	            R/W   ----xxxx       (right pixel)
-	2000-209F   R/W   xxxxxxxx    Sprite RAM (40 entries x 4 bytes)
-	            R/W   xxxxxxxx       (0: Y position, inverted)
-	            R/W   -------x       (1: X position, upper bit, inverted)
-	            R/W   xxxxxxxx       (2: X position, lower 8 bits, inverted)
-	            R/W   --xxxxxx       (3: image number, inverted)
-	20A0-29FF   R/W   xxxxxxxx    Stack RAM
-	2A00-2AFF   R/W   xxxxxxxx    Scanline I/O region
-	            R/W   xxxx----       (left pixel)
-	            R/W   ----xxxx       (right pixel)
-	2B00        R     xxxxxxxx    Current vertical beam position
-	2B01        R     xxxxxxxx    Latched horizontal collision/beam detect location
-	2B01        W     --------    Clear VBLANK FIRQ
-	2B02        R/W   xxxxxxxx    Scanline I/O selector
-	2B03        R     xxxxxxxx    Input port
-	            R     x-------       (VBLANK FIRQ latched, active low)
-	            R     -x------       (collision/beam detect FIRQ latched, active low)
-	            R     --xxxx--       (4 position DIP switch, active low)
-					R     ------x-       (trigger, active low)
-					R     -------x       (mirror of VBLANK FIRQ latch, Whodunit only)
-	2B03        W     xxxxxxxx    Control port
-	            W     xxxx----       (ROM bank select, 0-15)
-	            W     ----x---       (collision/beam detect FIRQ enable)
-	            W     -----x--       (select FIRQ source: 0=collision, 1=beam detect)
-	            W     ------x-       (select palette bank for I/O)
-	            W     -------x       (select palette bank for display)
-	2C00-2DFF   R/W   xxxxxxxx    Palette RAM (2 banks x 512 bytes)
-	            R/W   x-------       (0: collision trigger bit)
-	            R/W   -xxxxx--       (0: red component)
-	            R/W   ------xx       (0: green component, upper 2 bits)
-	            R/W   xxx-----       (1: green component, lower 3 bits)
-	            R/W   ---xxxxx       (1: blue component)
-	2E00-2E1F   R/W   xxxxxxxx    Sound command
-	2E20-2E3F   R     ----xxxx    Coin counter, clearing IRQ
-	            R     ----x---       (acknowledgement of sound command read, active high)
-	            R     -----x--       (unknown use, active low - gives "coin mech jammed" message)
-	            R     ------x-       (coin 2, active low)
-	            R     -------x       (coin 1, active low)
-	2E40-2E5F   W     -------x    Clear coin counter
-	2E60-2E7F   R     xxxxxxxx    8 position DIP switch, active low
-	2E80-2E9F   R     --xxxxxx    Player control bits
-	            R     -------x       (start button, active low)
-	2EA0-2EBF   R     ----xxxx    Coin counter, non-clearing
-	            R     ----x---       (acknowledgement of sound command read, active high)
-	            R     -----x--       (unknown use, active low - gives "coin mech jammed" message)
-	            R     ------x-       (coin 2, active low)
-	            R     -------x       (coin 1, active low)
-	2EC0-2EDF   R     xxxxxxxx    Copy protection check (Clay Pigeon)
-	2EC0-2EDF	R/W	xxxxxxxx		Copy protection and I/O space (Top Secret)
-	3000-3FFF   R/W   xxxxxxxx    RAM
-	4000-7FFF   R     xxxxxxxx    Banked ROM
-	6000-7FFF   R/W   xxxxxxxx    EEROM (when bank 15 is selected only)
-	8000-FFFF   R     xxxxxxxx    Program ROM
-	========================================================================
-	Interrupts:
-		NMI not connected
-		IRQ generated by coins, detect on audio PCB
-		FIRQ generated by VBLANK, collision detect, and beam detect
-	========================================================================
+    ========================================================================
+    CPU #1
+    ========================================================================
+    0000-1FFF   R/W   xxxxxxxx    Image RAM (64 images x 128 bytes, each image is 16x16x4bpp)
+                R/W   xxxx----       (left pixel)
+                R/W   ----xxxx       (right pixel)
+    2000-209F   R/W   xxxxxxxx    Sprite RAM (40 entries x 4 bytes)
+                R/W   xxxxxxxx       (0: Y position, inverted)
+                R/W   -------x       (1: X position, upper bit, inverted)
+                R/W   xxxxxxxx       (2: X position, lower 8 bits, inverted)
+                R/W   --xxxxxx       (3: image number, inverted)
+    20A0-29FF   R/W   xxxxxxxx    Stack RAM
+    2A00-2AFF   R/W   xxxxxxxx    Scanline I/O region
+                R/W   xxxx----       (left pixel)
+                R/W   ----xxxx       (right pixel)
+    2B00        R     xxxxxxxx    Current vertical beam position
+    2B01        R     xxxxxxxx    Latched horizontal collision/beam detect location
+    2B01        W     --------    Clear VBLANK FIRQ
+    2B02        R/W   xxxxxxxx    Scanline I/O selector
+    2B03        R     xxxxxxxx    Input port
+                R     x-------       (VBLANK FIRQ latched, active low)
+                R     -x------       (collision/beam detect FIRQ latched, active low)
+                R     --xxxx--       (4 position DIP switch, active low)
+                    R     ------x-       (trigger, active low)
+                    R     -------x       (mirror of VBLANK FIRQ latch, Whodunit only)
+    2B03        W     xxxxxxxx    Control port
+                W     xxxx----       (ROM bank select, 0-15)
+                W     ----x---       (collision/beam detect FIRQ enable)
+                W     -----x--       (select FIRQ source: 0=collision, 1=beam detect)
+                W     ------x-       (select palette bank for I/O)
+                W     -------x       (select palette bank for display)
+    2C00-2DFF   R/W   xxxxxxxx    Palette RAM (2 banks x 512 bytes)
+                R/W   x-------       (0: collision trigger bit)
+                R/W   -xxxxx--       (0: red component)
+                R/W   ------xx       (0: green component, upper 2 bits)
+                R/W   xxx-----       (1: green component, lower 3 bits)
+                R/W   ---xxxxx       (1: blue component)
+    2E00-2E1F   R/W   xxxxxxxx    Sound command
+    2E20-2E3F   R     ----xxxx    Coin counter, clearing IRQ
+                R     ----x---       (acknowledgement of sound command read, active high)
+                R     -----x--       (unknown use, active low - gives "coin mech jammed" message)
+                R     ------x-       (coin 2, active low)
+                R     -------x       (coin 1, active low)
+    2E40-2E5F   W     -------x    Clear coin counter
+    2E60-2E7F   R     xxxxxxxx    8 position DIP switch, active low
+    2E80-2E9F   R     --xxxxxx    Player control bits
+                R     -------x       (start button, active low)
+    2EA0-2EBF   R     ----xxxx    Coin counter, non-clearing
+                R     ----x---       (acknowledgement of sound command read, active high)
+                R     -----x--       (unknown use, active low - gives "coin mech jammed" message)
+                R     ------x-       (coin 2, active low)
+                R     -------x       (coin 1, active low)
+    2EC0-2EDF   R     xxxxxxxx    Copy protection check (Clay Pigeon)
+    2EC0-2EDF   R/W xxxxxxxx        Copy protection and I/O space (Top Secret)
+    3000-3FFF   R/W   xxxxxxxx    RAM
+    4000-7FFF   R     xxxxxxxx    Banked ROM
+    6000-7FFF   R/W   xxxxxxxx    EEROM (when bank 15 is selected only)
+    8000-FFFF   R     xxxxxxxx    Program ROM
+    ========================================================================
+    Interrupts:
+        NMI not connected
+        IRQ generated by coins, detect on audio PCB
+        FIRQ generated by VBLANK, collision detect, and beam detect
+    ========================================================================
 
 
-	========================================================================
-	CPU #2
-	========================================================================
-	0000-7FFF   R     xxxxxxxx    Banked ROM (never access because DMA switches constantly)
-	8000-8016   R/W   xxxxxxxx    MC6844 DMA controller I/O
-	8400-8407   R/W   xxxxxxxx    Volume control for each channel: left1, right1, left2, right2...
-	8800        R     xxxxxxxx    Sound command
-	9400-9403   W     xxxxxxxx    Bank select for each channel
-	            W     ----x---       (select bank 3, active high)
-	            W     -----x--       (select bank 2, active high)
-	            W     ------x-       (select bank 1, active high)
-	            W     -------x       (select bank 0, active high)
-	9800        W     --------    Clear sound IRQ
-	A000-BFFF   R/W   xxxxxxxx    RAM
-	E000-FFFF   R     xxxxxxxx    Program ROM
-	========================================================================
-	Interrupts:
-		NMI not connected
-		IRQ generated by VSYNC
-		FIRQ generated by write to sound command register
-	========================================================================
+    ========================================================================
+    CPU #2
+    ========================================================================
+    0000-7FFF   R     xxxxxxxx    Banked ROM (never access because DMA switches constantly)
+    8000-8016   R/W   xxxxxxxx    MC6844 DMA controller I/O
+    8400-8407   R/W   xxxxxxxx    Volume control for each channel: left1, right1, left2, right2...
+    8800        R     xxxxxxxx    Sound command
+    9400-9403   W     xxxxxxxx    Bank select for each channel
+                W     ----x---       (select bank 3, active high)
+                W     -----x--       (select bank 2, active high)
+                W     ------x-       (select bank 1, active high)
+                W     -------x       (select bank 0, active high)
+    9800        W     --------    Clear sound IRQ
+    A000-BFFF   R/W   xxxxxxxx    RAM
+    E000-FFFF   R     xxxxxxxx    Program ROM
+    ========================================================================
+    Interrupts:
+        NMI not connected
+        IRQ generated by VSYNC
+        FIRQ generated by write to sound command register
+    ========================================================================
 
 ***************************************************************************
 
-	Differences between machines (assuming Crossbow is the base)
+    Differences between machines (assuming Crossbow is the base)
 
-	Cheyenne (reports Hardware Error 5 if any of these are not true)
-		* a read from $2B03 must return 0 in bit 0
+    Cheyenne (reports Hardware Error 5 if any of these are not true)
+        * a read from $2B03 must return 0 in bit 0
 
-		conclusion: LS244 at 18J on main board needs to generate negative logic
+        conclusion: LS244 at 18J on main board needs to generate negative logic
 
-	Combat (reports Hardware Error 1 if any of these are not true)
-		* a read from $2E80 must return 0's in bits 1,2,3,4,5
-		* a read from $2B03 must return 0 in bit 0
+    Combat (reports Hardware Error 1 if any of these are not true)
+        * a read from $2E80 must return 0's in bits 1,2,3,4,5
+        * a read from $2B03 must return 0 in bit 0
 
-		conclusion: LS244 at 18J on main board needs to generate negative logic
-						LS367 at 1A on audio board needs to generate negative logic
+        conclusion: LS244 at 18J on main board needs to generate negative logic
+                        LS367 at 1A on audio board needs to generate negative logic
 
-	Crackshot (reports Hardware Error W if any of these are not true)
-		* a read from $2E20 must return 0 in bit 2
-		* a read from $2E80 must return 0's in bits 1,2,3,4,5
-		* a read from $2B03 must return 0 in bit 0
+    Crackshot (reports Hardware Error W if any of these are not true)
+        * a read from $2E20 must return 0 in bit 2
+        * a read from $2E80 must return 0's in bits 1,2,3,4,5
+        * a read from $2B03 must return 0 in bit 0
 
-		conclusion: LS244 at 18J on main board needs to generate negative logic
-						LS367 at 1A on audio board needs to generate negative logic
-						LS128 at 2A on audio board needs negative logic into pin 5
+        conclusion: LS244 at 18J on main board needs to generate negative logic
+                        LS367 at 1A on audio board needs to generate negative logic
+                        LS128 at 2A on audio board needs negative logic into pin 5
 
-	Chiller (reports Hardware Error R if any of these are not true)
-		* a read from $2E20 must return 0 in bit 2
-		* a read from $2E80 must return 0's in bits 1,2,3,4,5
-		* a read from $2B03 must return 0 in bit 0
+    Chiller (reports Hardware Error R if any of these are not true)
+        * a read from $2E20 must return 0 in bit 2
+        * a read from $2E80 must return 0's in bits 1,2,3,4,5
+        * a read from $2B03 must return 0 in bit 0
 
-		conclusion: LS244 at 18J on main board needs to generate negative logic
-						LS367 at 1A on audio board needs to generate negative logic
-						LS128 at 2A on audio board needs negative logic into pin 5
+        conclusion: LS244 at 18J on main board needs to generate negative logic
+                        LS367 at 1A on audio board needs to generate negative logic
+                        LS128 at 2A on audio board needs negative logic into pin 5
 
-	Top Secret (reports Hardware Error H if any of these are not true)
-		* a read from $2EC0 must return $00
-		* a read from $2E20 must return 0 in bit 2
-		* a read from $2E80 must return 0's in bits 2,3,4,5
-		* a read from $2B03 must return 0 in bit 0
+    Top Secret (reports Hardware Error H if any of these are not true)
+        * a read from $2EC0 must return $00
+        * a read from $2E20 must return 0 in bit 2
+        * a read from $2E80 must return 0's in bits 2,3,4,5
+        * a read from $2B03 must return 0 in bit 0
 
-		conclusion: LS244 at 18J on main board needs to generate negative logic
-								and must connect the inputs for bits 0 and 1
-						LS367 at 1A on audio board needs to generate negative logic
-						LS128 at 2A on audio board needs negative logic into pin 5
-						the I/O space at $2EC0 must be hooked up to something
+        conclusion: LS244 at 18J on main board needs to generate negative logic
+                                and must connect the inputs for bits 0 and 1
+                        LS367 at 1A on audio board needs to generate negative logic
+                        LS128 at 2A on audio board needs negative logic into pin 5
+                        the I/O space at $2EC0 must be hooked up to something
 
-	Clay Pigeon (reports Hardware Error N if any of these are not true)
-		* a read from $2EC3 must return $76
-		* a read from $2E20 must return 0 in bit 2
-		* a read from $2E80 must return 0's in bits 1,2,3,4,5
-		* a read from $2B03 must return 0 in bit 0
+    Clay Pigeon (reports Hardware Error N if any of these are not true)
+        * a read from $2EC3 must return $76
+        * a read from $2E20 must return 0 in bit 2
+        * a read from $2E80 must return 0's in bits 1,2,3,4,5
+        * a read from $2B03 must return 0 in bit 0
 
-		conclusion: LS244 at 18J on main board needs to generate negative logic
-						LS367 at 1A on audio board needs to generate negative logic
-						LS128 at 2A on audio board needs negative logic into pin 5
-						something must be hooked up to pin 7 of the LS42 at 3A on
-								the audio board to put $76 on the data lines going
-								back to the logic board when triggered
+        conclusion: LS244 at 18J on main board needs to generate negative logic
+                        LS367 at 1A on audio board needs to generate negative logic
+                        LS128 at 2A on audio board needs negative logic into pin 5
+                        something must be hooked up to pin 7 of the LS42 at 3A on
+                                the audio board to put $76 on the data lines going
+                                back to the logic board when triggered
 
-	Hit'N Miss (reports Hardware Error H if any of these are not true)
-		* a read from $2E20 must return 0 in bit 2
-		* a read from $2E80 must return 0's in bits 2,3,4,5
-		* a read from $2B03 must return the same value for bit 0 as for bit 1
+    Hit'N Miss (reports Hardware Error H if any of these are not true)
+        * a read from $2E20 must return 0 in bit 2
+        * a read from $2E80 must return 0's in bits 2,3,4,5
+        * a read from $2B03 must return the same value for bit 0 as for bit 1
 
-		conclusion: LS244 at 18J on main board needs to generate negative logic
-								and must connect the inputs for bits 0 and 1
-						LS367 at 1A on audio board needs to generate negative logic
-						LS128 at 2A on audio board needs negative logic into pin 5
+        conclusion: LS244 at 18J on main board needs to generate negative logic
+                                and must connect the inputs for bits 0 and 1
+                        LS367 at 1A on audio board needs to generate negative logic
+                        LS128 at 2A on audio board needs negative logic into pin 5
 
-	Who Dunit (reports Hardware Error H if any of these are not true)
-		* a read from $2E20 must return 0 in bit 2
-		* a read from $2E80 must return 0's in bits 2,3,4,5
-		* a read from $2B03 must return the same value for bit 0 as for bit 7
+    Who Dunit (reports Hardware Error H if any of these are not true)
+        * a read from $2E20 must return 0 in bit 2
+        * a read from $2E80 must return 0's in bits 2,3,4,5
+        * a read from $2B03 must return the same value for bit 0 as for bit 7
 
-		conclusion: LS244 at 18J on main board needs to generate negative logic
-								and must connect the inputs for bits 0 and 7
-						LS367 at 1A on audio board needs to generate negative logic
-						LS128 at 2A on audio board needs negative logic into pin 5
+        conclusion: LS244 at 18J on main board needs to generate negative logic
+                                and must connect the inputs for bits 0 and 7
+                        LS367 at 1A on audio board needs to generate negative logic
+                        LS128 at 2A on audio board needs negative logic into pin 5
 
-	Showdown
-		* a read from $2E20 must return 0 in bit 2
-		* a read from $2E80 must return 0's in bits 1,2,3,4,5
-		* a read from $2B03 must return 0 in bit 0
-		* the PLD at 1E on the logic board must recognize the sequence $0055,$00ed
-			and return the following data from reads in the first 24 bytes:
-				0x15,0x40,0xc1,0x8d,0x4c,0x84,0x0e,0xce,
-				0x52,0xd0,0x99,0x48,0x80,0x09,0xc9,0x45,
-				0xc4,0x8e,0x5a,0x92,0x18,0xd8,0x51,0xc0
-		* the PLD at 1E on the logic board must also recognize the sequence $0055,$1243
-			and return the following data from reads in the first 24 bytes:
-				0x11,0x51,0xc0,0x89,0x4d,0x85,0x0c,0xcc,
-				0x46,0xd2,0x98,0x59,0x91,0x08,0xc8,0x41,
-				0xc5,0x8c,0x4e,0x86,0x1a,0xda,0x50,0xd1
+    Showdown
+        * a read from $2E20 must return 0 in bit 2
+        * a read from $2E80 must return 0's in bits 1,2,3,4,5
+        * a read from $2B03 must return 0 in bit 0
+        * the PLD at 1E on the logic board must recognize the sequence $0055,$00ed
+            and return the following data from reads in the first 24 bytes:
+                0x15,0x40,0xc1,0x8d,0x4c,0x84,0x0e,0xce,
+                0x52,0xd0,0x99,0x48,0x80,0x09,0xc9,0x45,
+                0xc4,0x8e,0x5a,0x92,0x18,0xd8,0x51,0xc0
+        * the PLD at 1E on the logic board must also recognize the sequence $0055,$1243
+            and return the following data from reads in the first 24 bytes:
+                0x11,0x51,0xc0,0x89,0x4d,0x85,0x0c,0xcc,
+                0x46,0xd2,0x98,0x59,0x91,0x08,0xc8,0x41,
+                0xc5,0x8c,0x4e,0x86,0x1a,0xda,0x50,0xd1
 
-		conclusion: something must emulate this PLD; also, not sure where the
-								bytes to compare against came from, so it's possible
-								that the real machine isn't expecting the same values
-						LS244 at 18J on main board needs to generate negative logic
-						LS367 at 1A on audio board needs to generate negative logic
-						LS128 at 2A on audio board needs negative logic into pin 5
+        conclusion: something must emulate this PLD; also, not sure where the
+                                bytes to compare against came from, so it's possible
+                                that the real machine isn't expecting the same values
+                        LS244 at 18J on main board needs to generate negative logic
+                        LS367 at 1A on audio board needs to generate negative logic
+                        LS128 at 2A on audio board needs negative logic into pin 5
 
 ***************************************************************************/
 
@@ -239,7 +239,7 @@ static UINT8 showdown_bank_triggered;
 
 /*************************************
  *
- *	EEROM save/load
+ *  EEROM save/load
  *
  *************************************/
 
@@ -260,7 +260,7 @@ static NVRAM_HANDLER( exidy440 )
 
 /*************************************
  *
- *	Interrupt handling
+ *  Interrupt handling
  *
  *************************************/
 
@@ -305,7 +305,7 @@ MACHINE_INIT( exidy440 )
 
 /*************************************
  *
- *	Primary input port read
+ *  Primary input port read
  *
  *************************************/
 
@@ -331,7 +331,7 @@ static READ8_HANDLER( input_r )
 
 /*************************************
  *
- *	Banked RAM (actually EEROM)
+ *  Banked RAM (actually EEROM)
  *
  *************************************/
 
@@ -351,7 +351,7 @@ static WRITE8_HANDLER( bankram_w )
 
 /*************************************
  *
- *	Audio board I/O reads
+ *  Audio board I/O reads
  *
  *************************************/
 
@@ -421,7 +421,7 @@ static READ8_HANDLER( io1_r )
 
 /*************************************
  *
- *	Audio board I/O writes
+ *  Audio board I/O writes
  *
  *************************************/
 
@@ -477,7 +477,7 @@ static WRITE8_HANDLER( io1_w )
 
 /*************************************
  *
- *	Game-specific handlers
+ *  Game-specific handlers
  *
  *************************************/
 
@@ -539,7 +539,7 @@ READ8_HANDLER( showdown_pld_select2_r )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -579,7 +579,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
@@ -606,7 +606,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -1067,22 +1067,21 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Sound definitions
+ *  Sound definitions
  *
  *************************************/
 
 static struct CustomSound_interface custom_interface =
 {
 	exidy440_sh_start,
-	exidy440_sh_stop,
-	exidy440_sh_update
+	exidy440_sh_stop
 };
 
 
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -1094,7 +1093,7 @@ static MACHINE_DRIVER_START( exidy440 )
 	MDRV_CPU_VBLANK_INT(main_interrupt,1)
 
 	MDRV_CPU_ADD(M6809,12979200/4/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_cpu2,writemem_cpu2)
 	MDRV_CPU_VBLANK_INT(irq0_line_assert,1)
 
@@ -1115,15 +1114,19 @@ static MACHINE_DRIVER_START( exidy440 )
 	MDRV_VIDEO_UPDATE(exidy440)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(CUSTOM, custom_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_CONFIG(custom_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -1736,7 +1739,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver initialization
+ *  Driver initialization
  *
  *************************************/
 
@@ -1778,7 +1781,7 @@ static DRIVER_INIT( showdown )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
