@@ -22,6 +22,7 @@ f1gp2:
 #include "driver.h"
 #include "vidhrdw/konamiic.h"
 #include "f1gp.h"
+#include "sound/2610intf.h"
 
 
 
@@ -105,7 +106,7 @@ static ADDRESS_MAP_START( f1gp_readmem1, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xffd000, 0xffdfff) AM_READ(MRA16_RAM)
 	AM_RANGE(0xffe000, 0xffefff) AM_READ(MRA16_RAM)
 	AM_RANGE(0xfff000, 0xfff001) AM_READ(input_port_0_word_r)
-/*	AM_RANGE(0xfff002, 0xfff003)	analog wheel? */
+/*  AM_RANGE(0xfff002, 0xfff003)    analog wheel? */
 	AM_RANGE(0xfff004, 0xfff005) AM_READ(input_port_1_word_r)
 	AM_RANGE(0xfff006, 0xfff007) AM_READ(input_port_2_word_r)
 	AM_RANGE(0xfff008, 0xfff009) AM_READ(command_pending_r)
@@ -144,7 +145,7 @@ static ADDRESS_MAP_START( f1gp2_readmem1, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xffd000, 0xffdfff) AM_READ(MRA16_RAM)
 	AM_RANGE(0xffe000, 0xffefff) AM_READ(MRA16_RAM)
 	AM_RANGE(0xfff000, 0xfff001) AM_READ(input_port_0_word_r)
-/*	AM_RANGE(0xfff002, 0xfff003)	analog wheel? */
+/*  AM_RANGE(0xfff002, 0xfff003)    analog wheel? */
 	AM_RANGE(0xfff004, 0xfff005) AM_READ(input_port_1_word_r)
 	AM_RANGE(0xfff006, 0xfff007) AM_READ(input_port_2_word_r)
 	AM_RANGE(0xfff008, 0xfff009) AM_READ(command_pending_r)
@@ -191,12 +192,14 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x14, 0x14) AM_READ(soundlatch_r)
 	AM_RANGE(0x18, 0x18) AM_READ(YM2610_status_port_0_A_r)
 	AM_RANGE(0x1a, 0x1a) AM_READ(YM2610_status_port_0_B_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(f1gp_sh_bankswitch_w)	/* f1gp */
 	AM_RANGE(0x0c, 0x0c) AM_WRITE(f1gp_sh_bankswitch_w)	/* f1gp2 */
 	AM_RANGE(0x14, 0x14) AM_WRITE(pending_command_clear_w)
@@ -476,17 +479,9 @@ static void irqhandler(int irq)
 
 static struct YM2610interface ym2610_interface =
 {
-	1,
-	8000000,	/* 8 MHz??? */
-	{ 25 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler },
-	{ REGION_SOUND1 },
-	{ REGION_SOUND2 },
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) }
+	irqhandler,
+	REGION_SOUND1,
+	REGION_SOUND2
 };
 
 
@@ -503,7 +498,7 @@ static MACHINE_DRIVER_START( f1gp )
 	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,8000000/2)	/* 4 MHz ??? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 
@@ -521,8 +516,14 @@ static MACHINE_DRIVER_START( f1gp )
 	MDRV_VIDEO_UPDATE(f1gp)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2610, ym2610_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.25)
+	MDRV_SOUND_ROUTE(0, "right", 0.25)
+	MDRV_SOUND_ROUTE(1, "left",  1.0)
+	MDRV_SOUND_ROUTE(2, "right", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( f1gp2 )
