@@ -59,7 +59,8 @@ write:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
-
+#include "sound/3812intf.h"
+#include "sound/msm5205.h"
 
 
 extern unsigned char *firetrap_bg1videoram;
@@ -358,9 +359,9 @@ INPUT_PORTS_START( firetrap )
 
 	PORT_START      /* DSW0 */
 	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_A ) )
-/*	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(    0x07, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x06, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(    0x05, DEF_STR( 1C_3C ) )
@@ -441,9 +442,9 @@ INPUT_PORTS_START( firetpbl )
 
 	PORT_START      /* DSW0 */
 	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_A ) )
-/*	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(    0x07, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x06, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(    0x05, DEF_STR( 1C_3C ) )
@@ -533,20 +534,10 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct YM3526interface ym3526_interface =
-{
-	1,			/* 1 chip */
-	3000000,	/* 3.000000 MHz ? */
-	{ 100 }		/* volume */
-};
-
 static struct MSM5205interface msm5205_interface =
 {
-	1,					/* 1 chip             */
-	384000,				/* 384KHz ?           */
-	{ firetrap_adpcm_int },/* interrupt function */
-	{ MSM5205_S48_4B},	/* 8KHz ?             */
-	{ 30 }
+	firetrap_adpcm_int,	/* interrupt function */
+	MSM5205_S48_4B		/* 8KHz ?             */
 };
 
 static INTERRUPT_GEN( firetrap )
@@ -564,7 +555,7 @@ static INTERRUPT_GEN( firetrap )
 			latch=0;
 
 		/* Make sure coin IRQ's aren't generated when another command is pending, the main cpu
-			definitely doesn't expect them as it locks out the coin routine */
+            definitely doesn't expect them as it locks out the coin routine */
 		if (coin_command_pending && !i8751_current_command) {
 			i8751_return=coin_command_pending;
 			cpunum_set_input_line_and_vector(0,0,HOLD_LINE,0xff);
@@ -590,7 +581,7 @@ static MACHINE_DRIVER_START( firetrap )
 	MDRV_CPU_VBLANK_INT(firetrap,2)
 
 	MDRV_CPU_ADD(M6502,3072000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 1.536 MHz? */
+	/* audio CPU */	/* 1.536 MHz? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 							/* IRQs are caused by the ADPCM chip */
 							/* NMIs are caused by the main CPU */
@@ -610,8 +601,14 @@ static MACHINE_DRIVER_START( firetrap )
 	MDRV_VIDEO_UPDATE(firetrap)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3526, ym3526_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3526, 3000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( firetpbl )
@@ -622,7 +619,7 @@ static MACHINE_DRIVER_START( firetpbl )
 	MDRV_CPU_VBLANK_INT(bootleg,1)
 
 	MDRV_CPU_ADD(M6502,3072000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 1.536 MHz? */
+	/* audio CPU */	/* 1.536 MHz? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 							/* IRQs are caused by the ADPCM chip */
 							/* NMIs are caused by the main CPU */
@@ -641,8 +638,14 @@ static MACHINE_DRIVER_START( firetpbl )
 	MDRV_VIDEO_UPDATE(firetrap)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3526, ym3526_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3526, 3000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 
