@@ -3,11 +3,11 @@
 /* NIX or Novatecnia (both spanish) may have produced these
    its probably NIX due to somes similarities with Pirates
 
-	Supported Games                  Rip-off of
+    Supported Games                  Rip-off of
 
-	Fit of Fighting                  Art of Fighting (neogeo.c)
-	The History of Martial Arts      Fighter's History (deco32.c)
-	'BB' Untitled Prototype          -none, original-
+    Fit of Fighting                  Art of Fighting (neogeo.c)
+    The History of Martial Arts      Fighter's History (deco32.c)
+    'BB' Untitled Prototype          -none, original-
 
    'BB' Prototype isn't a game as such, 'BB' was the label on
    the prototype board. which appears to have been used simply
@@ -40,7 +40,7 @@ todo:
 
 fix scrolling
 sound
-fix sprite colour problems.
+fix s7prite colour problems.
 should these be considered clones or not since the game has
 been rewritten, they just use the gfx ...
 
@@ -82,6 +82,9 @@ Stephh's notes :
 */
 
 #include "driver.h"
+#include "cpu/upd7810/upd7810.h"
+#include "sound/okim6295.h"
+
 
 data16_t *fitfight_spriteram;
 data16_t *fof_100000, *fof_600000, *fof_700000, *fof_800000, *fof_900000, *fof_a00000;
@@ -141,18 +144,18 @@ static ADDRESS_MAP_START( fitfight_main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x500000, 0x500001) AM_READ(input_port_3_word_r)
 
 	AM_RANGE(0x600000, 0x600001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_600000)
-	/*	Is 0x600000 controlling the slave audio CPU? data is 0x1111000zzzzzzzzz (9 sign. bits) */
-	/*	Used by histryma/fitfight: */
-	/*		@0x000031ae/0x00002b3a: 0xF000, once, during POST */
-	/*		 0xe001ae/0xe00096 holds the address (0x600000), 0xe001b2/0xe0009a holds the word to output */
-	/*		@0x00003294/0x00002c1a: word content of 0xe001b2 */
-	/*		@0x000032cc/?: 0xF0dd byte from 0xe001b5, dd seems to be allways 0xFD */
-	/*		@0x000036bc/?: 0xF0FD when inserting coin */
-	/*		@0x000037a6/0x000030e6: 0x??dd byte from 0xe08c05, 0xF101 then 0xF001/0xF157 then 0xF057 */
+	/*  Is 0x600000 controlling the slave audio CPU? data is 0x1111000zzzzzzzzz (9 sign. bits) */
+	/*  Used by histryma/fitfight: */
+	/*      @0x000031ae/0x00002b3a: 0xF000, once, during POST */
+	/*       0xe001ae/0xe00096 holds the address (0x600000), 0xe001b2/0xe0009a holds the word to output */
+	/*      @0x00003294/0x00002c1a: word content of 0xe001b2 */
+	/*      @0x000032cc/?: 0xF0dd byte from 0xe001b5, dd seems to be allways 0xFD */
+	/*      @0x000036bc/?: 0xF0FD when inserting coin */
+	/*      @0x000037a6/0x000030e6: 0x??dd byte from 0xe08c05, 0xF101 then 0xF001/0xF157 then 0xF057 */
 
-/*	AM_RANGE(0x700000, 0x700001) AM_READ(xxxx)    see init    */
+/*  AM_RANGE(0x700000, 0x700001) AM_READ(xxxx)    see init    */
 	AM_RANGE(0x700000, 0x700001) AM_WRITE(fitfight_700000_w) AM_BASE(&fof_700000)
-	/*	kept at 0xe07900/0xe04c56 */
+	/*  kept at 0xe07900/0xe04c56 */
 
 	AM_RANGE(0x800000, 0x800001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_800000)
 	/*written at scanline 1, allways 0. Used by histryma/fitfight @0x00001d76/@0x00000f6a */
@@ -212,6 +215,67 @@ static ADDRESS_MAP_START( bbprot_main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xe00000, 0xe0ffff) AM_RAM
 ADDRESS_MAP_END
 
+
+/* 7810 (?) sound cpu */
+
+static ADDRESS_MAP_START( snd_mem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
+	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK1)	/* ??? External ROM */
+	AM_RANGE(0x8000, 0x87ff) AM_RAM
+	AM_RANGE(0xff00, 0xffff) AM_RAM
+ADDRESS_MAP_END
+
+static READ8_HANDLER(snd_porta_r)
+{
+	/*printf("PA R @%x\n",activecpu_get_pc()); */
+	return rand();
+}
+
+static READ8_HANDLER(snd_portb_r)
+{
+	/*printf("PB R @%x\n",activecpu_get_pc()); */
+	return rand();
+}
+
+static READ8_HANDLER(snd_portc_r)
+{
+	/*printf("PC R @%x\n",activecpu_get_pc()); */
+	return rand();
+}
+
+static WRITE8_HANDLER(snd_porta_w)
+{
+	/*printf("PA W %x @%x\n",data,activecpu_get_pc()); */
+}
+
+static WRITE8_HANDLER(snd_portb_w)
+{
+	/*printf("PB W %x @%x\n",data,activecpu_get_pc()); */
+}
+
+static WRITE8_HANDLER(snd_portc_w)
+{
+	/*printf("PC W %x @%x\n",data,activecpu_get_pc()); */
+}
+
+static ADDRESS_MAP_START( snd_io, ADDRESS_SPACE_IO, 8 )
+		AM_RANGE(UPD7810_PORTA, UPD7810_PORTA) AM_READ(snd_porta_r) AM_WRITE(snd_porta_w)
+		AM_RANGE(UPD7810_PORTB, UPD7810_PORTB) AM_READ(snd_portb_r) AM_WRITE(snd_portb_w)
+		AM_RANGE(UPD7810_PORTC, UPD7810_PORTC) AM_READ(snd_portc_r) AM_WRITE(snd_portc_w)
+ADDRESS_MAP_END
+
+static INTERRUPT_GEN( snd_irq )
+{
+	cpunum_set_input_line(1,UPD7810_INTF2,HOLD_LINE);
+}
+
+UPD7810_CONFIG sound_cpu_config =
+{
+    TYPE_7810,
+    0
+};
+
+
 /* I've put the inputs the same way they can be read in the "test mode" */
 
 INPUT_PORTS_START( fitfight )
@@ -303,8 +367,8 @@ INPUT_PORTS_START( fitfight )
 	PORT_DIPSETTING(      0x8000, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(      0x6000, DEF_STR( 1C_6C ) )
 	PORT_DIPNAME( 0x1c00, 0x1000, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(      0x1c00, "Easiest" )
-	PORT_DIPSETTING(      0x1800, "Easier" )
+	PORT_DIPSETTING(      0x1c00, DEF_STR( Easiest ) )
+	PORT_DIPSETTING(      0x1800, DEF_STR( Easier ) )
 	PORT_DIPSETTING(      0x1400, DEF_STR( Easy ) )
 	PORT_DIPSETTING(      0x1000, DEF_STR( Normal ) )
 	PORT_DIPSETTING(      0x0c00, DEF_STR( Medium ) )
@@ -320,7 +384,7 @@ INPUT_PORTS_START( fitfight )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0080, DEF_STR( On ) )
 	PORT_DIPNAME( 0x0070, 0x0060, "Needed Points/Maximum Rounds" )	/* see notes */
-/*	PORT_DIPSETTING(      0x0070, "Endless" ) */
+/*  PORT_DIPSETTING(      0x0070, "Endless" ) */
 	PORT_DIPSETTING(      0x0060, "1/2" )
 	PORT_DIPSETTING(      0x0050, "2/3" )
 	PORT_DIPSETTING(      0x0040, "2/4" )
@@ -387,9 +451,9 @@ INPUT_PORTS_START( histryma )
 	PORT_BIT(  0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN )			/* "Test" (duplicated) */
 	/* MSB : SW2 -> 0xe05874.b (cpl) */
 	PORT_DIPNAME( 0xf800, 0x0000, "Time" )
-/*	PORT_DIPSETTING(      0xf800, "15" )				// duplicated setting */
-/*	PORT_DIPSETTING(      0xf000, "15" )				// duplicated setting */
-/*	PORT_DIPSETTING(      0xe800, "15" )				// duplicated setting */
+/*  PORT_DIPSETTING(      0xf800, "15" )                // duplicated setting */
+/*  PORT_DIPSETTING(      0xf000, "15" )                // duplicated setting */
+/*  PORT_DIPSETTING(      0xe800, "15" )                // duplicated setting */
 	PORT_DIPSETTING(      0xe000, "15" )
 	PORT_DIPSETTING(      0xd800, "18" )
 	PORT_DIPSETTING(      0xd000, "21" )
@@ -441,8 +505,8 @@ INPUT_PORTS_START( histryma )
 	PORT_DIPSETTING(      0x6000, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(      0x4000, DEF_STR( 1C_6C ) )
 	PORT_DIPNAME( 0x1c00, 0x1000, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(      0x1c00, "Easiest" )
-	PORT_DIPSETTING(      0x1800, "Easier" )
+	PORT_DIPSETTING(      0x1c00, DEF_STR( Easiest ) )
+	PORT_DIPSETTING(      0x1800, DEF_STR( Easier ) )
 	PORT_DIPSETTING(      0x1400, DEF_STR( Easy ) )
 	PORT_DIPSETTING(      0x1000, DEF_STR( Normal ) )
 	PORT_DIPSETTING(      0x0c00, DEF_STR( Medium ) )
@@ -458,7 +522,7 @@ INPUT_PORTS_START( histryma )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0080, DEF_STR( On ) )
 	PORT_DIPNAME( 0x0070, 0x0060, "Needed Points/Maximum Points" )	/* see notes */
-/*	PORT_DIPSETTING(      0x0070, "Endless" )				// ends on a draw */
+/*  PORT_DIPSETTING(      0x0070, "Endless" )               // ends on a draw */
 	PORT_DIPSETTING(      0x0060, "1/2" )
 	PORT_DIPSETTING(      0x0050, "2/3" )
 	PORT_DIPSETTING(      0x0040, "2/4" )
@@ -529,9 +593,9 @@ INPUT_PORTS_START( bbprot )
 	PORT_BIT(  0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN )			/* "Test" (duplicated) */
 	/* MSB : SW2 -> 0xe07e84.b (cpl) */
 	PORT_DIPNAME( 0xf800, 0x0000, "Time" )
-/*	PORT_DIPSETTING(      0xf800, "15" )				// duplicated setting */
-/*	PORT_DIPSETTING(      0xf000, "15" )				// duplicated setting */
-/*	PORT_DIPSETTING(      0xe800, "15" )				// duplicated setting */
+/*  PORT_DIPSETTING(      0xf800, "15" )                // duplicated setting */
+/*  PORT_DIPSETTING(      0xf000, "15" )                // duplicated setting */
+/*  PORT_DIPSETTING(      0xe800, "15" )                // duplicated setting */
 	PORT_DIPSETTING(      0xe000, "15" )
 	PORT_DIPSETTING(      0xd800, "18" )
 	PORT_DIPSETTING(      0xd000, "21" )
@@ -583,8 +647,8 @@ INPUT_PORTS_START( bbprot )
 	PORT_DIPSETTING(      0x6000, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(      0x4000, DEF_STR( 1C_6C ) )
 	PORT_DIPNAME( 0x1c00, 0x1000, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(      0x1c00, "Easiest" )
-	PORT_DIPSETTING(      0x1800, "Easier" )
+	PORT_DIPSETTING(      0x1c00, DEF_STR( Easiest ) )
+	PORT_DIPSETTING(      0x1800, DEF_STR( Easier ) )
 	PORT_DIPSETTING(      0x1400, DEF_STR( Easy ) )
 	PORT_DIPSETTING(      0x1000, DEF_STR( Normal ) )
 	PORT_DIPSETTING(      0x0c00, DEF_STR( Medium ) )
@@ -683,21 +747,19 @@ static struct GfxDecodeInfo prot_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-/*
-static struct OKIM6295interface okim6295_interface =
-{
-	1,
-	{ 1333333/165 }, // ~8080Hz ??? TODO: find out the real frequency
-	{ REGION_SOUND1 },
-	{ 100 }
-};
-*/
 
 static MACHINE_DRIVER_START( fitfight )
 	MDRV_CPU_ADD_TAG("main",M68000, 12000000)
 	MDRV_CPU_PROGRAM_MAP(fitfight_main_map,0)
 	MDRV_CPU_VBLANK_INT(irq2_line_hold,1)
 
+	MDRV_CPU_ADD(UPD7810, 12000000)
+	/* audio CPU */
+	MDRV_CPU_CONFIG(sound_cpu_config)
+	MDRV_CPU_PROGRAM_MAP(snd_mem, 0)
+	MDRV_CPU_IO_MAP(snd_io, 0)
+	MDRV_CPU_VBLANK_INT(snd_irq,1)
+
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
@@ -711,7 +773,11 @@ static MACHINE_DRIVER_START( fitfight )
 	MDRV_VIDEO_START(fitfight)
 	MDRV_VIDEO_UPDATE(fitfight)
 
-/*	MDRV_SOUND_ADD(OKIM6295, okim6295_interface) */
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, 1333333/165) /* ~8080Hz ??? TODO: find out the real frequency */
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( bbprot )
@@ -732,7 +798,11 @@ static MACHINE_DRIVER_START( bbprot )
 	MDRV_VIDEO_START(fitfight)
 	MDRV_VIDEO_UPDATE(fitfight)
 
-/*	MDRV_SOUND_ADD(OKIM6295, okim6295_interface) */
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, 1333333/165) /* ~8080Hz ??? TODO: find out the real frequency */
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /***
@@ -762,13 +832,9 @@ ROM_START( fitfight )
 	ROM_LOAD16_BYTE( "u138_ff1.bin", 0x000001, 0x080000, CRC(165600fe) SHA1(b1987dbf34abdb6d08bdf7f71b256b62125e6517) )
 	ROM_LOAD16_BYTE( "u125_ff1.bin", 0x000000, 0x080000, CRC(2f9bdb66) SHA1(4c1ade349f1219d448453b27d4a7517966912ffa) )
 
-	ROM_REGION( 0x010000, REGION_CPU2, 0 ) /* Sound Program? */
-	ROM_LOAD( "u23_ff1.bin",  0x000000, 0x010000, CRC(e2d6d768) SHA1(233e5501ffda8db48341fa66f16b630544803a89) )
-	/* It sure doesn't look like Z80 code to me...
-	   Is it a H6280?
-	   It's also not encrypted as there are 2 similar readable text strings
-	   (in spanish, italian or brazilian portuguese?) starting at 0x9fb3 and 0xa071 
-	   "Completando de 0x797B a 0xFEFB (banco 0)"*/
+	ROM_REGION( 0x01c000, REGION_CPU2, 0 ) /* Sound Program */
+	ROM_LOAD( "u23_ff1.bin",  0x000000, 0x004000, CRC(e2d6d768) SHA1(233e5501ffda8db48341fa66f16b630544803a89) )
+	ROM_CONTINUE(          0x010000, 0x00c000 )
 
 	ROM_REGION( 0x100000, REGION_SOUND1, 0 ) /* OKI Samples? */
 	ROM_LOAD( "h7e_ff1.bin",  0x000000, 0x080000, CRC(3e12dfd8) SHA1(8f21abfc6a6aac9ad3fafe97d0279739c7b9fab9) ) /*seems to be a merge of 2 0x040000 roms */
@@ -820,8 +886,9 @@ ROM_START( histryma )
 	ROM_LOAD16_BYTE( "l_th.bin", 0x000001, 0x080000, CRC(5af9356a) SHA1(f3d797dcc528a3a2a4f0ebbf07d59bd2cc868622) )
 	ROM_LOAD16_BYTE( "r_th.bin", 0x000000, 0x080000, CRC(1a44b504) SHA1(621d95b67d413da3e8a90c0cde494b2529b92407) )
 
-	ROM_REGION( 0x010000, REGION_CPU2, 0 ) /* Sound Program? */
-	ROM_LOAD( "y61f.bin",  0x000000, 0x010000, CRC(b588525a) SHA1(b768bd75d6351430f9656289146119e9c0308554) )
+	ROM_REGION( 0x01c000, REGION_CPU2, 0 ) /* Sound Program */
+	ROM_LOAD( "y61f.bin",  0x000000, 0x004000, CRC(b588525a) SHA1(b768bd75d6351430f9656289146119e9c0308554) )
+	ROM_CONTINUE(          0x010000, 0x00c000 )
 
 	ROM_REGION( 0x100000, REGION_SOUND1, 0 ) /* OKI Samples? */
 	ROM_LOAD( "u7_th.bin",  0x000000, 0x080000, CRC(88b41ef5) SHA1(565e2c4554dde79cd2da8b8a181b3378818223cc) ) /*seems to be a merge of 2 0x040000 roms */
@@ -916,16 +983,16 @@ ROM_END
 
 static DRIVER_INIT( fitfight )
 {
-/*	data16_t *mem16 = (data16_t *)memory_region(REGION_CPU1); */
-/*	mem16[0x0165B2/2]=0x4e71; // for now so it boots */
+/*  data16_t *mem16 = (data16_t *)memory_region(REGION_CPU1); */
+/*  mem16[0x0165B2/2]=0x4e71; // for now so it boots */
 	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x700000, 0x700001, 0, 0, fitfight_700000_r);
 	bbprot_kludge = 0;
 }
 
 static DRIVER_INIT( histryma )
 {
-/*	data16_t *mem16 = (data16_t *)memory_region(REGION_CPU1); */
-/*	mem16[0x017FDC/2]=0x4e71; // for now so it boots */
+/*  data16_t *mem16 = (data16_t *)memory_region(REGION_CPU1); */
+/*  mem16[0x017FDC/2]=0x4e71; // for now so it boots */
 	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x700000, 0x700001, 0, 0, histryma_700000_r);
 	bbprot_kludge = 0;
 }
