@@ -39,6 +39,7 @@ TODO:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "machine/8255ppi.h"
+#include "sound/sn76496.h"
 
 
 extern data8_t *freek_videoram;
@@ -163,11 +164,13 @@ static ADDRESS_MAP_START( gigas_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( gigas_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(gigas_spinner_r)
 	AM_RANGE(0x01, 0x01) AM_READ(MRA8_NOP) /*unused dip 3 */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( gigas_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(spinner_select_w)
 ADDRESS_MAP_END
 
@@ -225,6 +228,7 @@ static READ8_HANDLER(oigas_2_r)
 }
 
 static ADDRESS_MAP_START( oigas_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(gigas_spinner_r)
 	AM_RANGE(0x01, 0x01) AM_READ(MRA8_NOP) /*unused dip 3 */
 	AM_RANGE(0x02, 0x02) AM_READ(oigas_2_r)
@@ -232,6 +236,7 @@ static ADDRESS_MAP_START( oigas_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( oigas_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(spinner_select_w)
 	AM_RANGE(0x05, 0x05) AM_WRITE(oigas_5_w)
 ADDRESS_MAP_END
@@ -309,10 +314,12 @@ static WRITE8_HANDLER (freekick_ff_w)
 }
 
 static ADDRESS_MAP_START( freekckb_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xff, 0xff) AM_READ(freekick_ff_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( freekckb_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xff, 0xff) AM_WRITE(freekick_ff_w)
 ADDRESS_MAP_END
 
@@ -803,7 +810,7 @@ PORT_START
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_COCKTAIL
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
-	
+
 	PORT_START
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON1 )
@@ -867,15 +874,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct SN76496interface sn76496_interface =
-{
-	4,	/* 4 chips */
-	{ 12000000/4, 12000000/4, 12000000/4, 12000000/4 },	/* 3 MHz??? */
-	{ 50, 50, 50, 50 }
-};
-
-
-
 static MACHINE_DRIVER_START( pbillrd )
 	MDRV_CPU_ADD(Z80, 12000000/2)	/* 6 MHz? */
 	MDRV_CPU_PROGRAM_MAP(pbillrd_readmem,pbillrd_writemem)
@@ -897,7 +895,19 @@ static MACHINE_DRIVER_START( pbillrd )
 	MDRV_VIDEO_UPDATE(pbillrd)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( freekckb )
@@ -923,7 +933,19 @@ static MACHINE_DRIVER_START( freekckb )
 	MDRV_VIDEO_UPDATE(freekick)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( gigas )
@@ -948,7 +970,19 @@ static MACHINE_DRIVER_START( gigas )
 	MDRV_VIDEO_UPDATE(gigas)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SN76496, 12000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( oigas )
@@ -1130,8 +1164,8 @@ ROM_END
 
 ROM_START( countrnb )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* Z80 Code */
-	ROM_LOAD( "rom_cpu.bin", 0x00000, 0x10000, CRC(f65639ae) SHA1(faa81607858d49559098c887ac847722df955a76) ) 
-	
+	ROM_LOAD( "rom_cpu.bin", 0x00000, 0x10000, CRC(f65639ae) SHA1(faa81607858d49559098c887ac847722df955a76) )
+
 	ROM_REGION( 0x08000, REGION_USER1, 0 ) /* sound data */
 	ROM_LOAD( "c-run.e1", 0x00000, 0x08000, CRC(2c3b6f8f) SHA1(ee7d71e6d8bb7138d5d029a10a95471d387b5f29) )
 
