@@ -1,18 +1,18 @@
 /******************************************************************************
 
-	Game Driver for Video System Mahjong series.
+    Game Driver for Video System Mahjong series.
 
-	Taisen Idol-Mahjong Final Romance 2 (Japan)
-	(c)1995 Video System Co.,Ltd.
+    Taisen Idol-Mahjong Final Romance 2 (Japan)
+    (c)1995 Video System Co.,Ltd.
 
-	Taisen Mahjong FinalRomance R (Japan)
-	(c)1995 Video System Co.,Ltd.
+    Taisen Mahjong FinalRomance R (Japan)
+    (c)1995 Video System Co.,Ltd.
 
-	Taisen Mahjong FinalRomance 4 (Japan)
-	(c)1998 Video System Co.,Ltd.
+    Taisen Mahjong FinalRomance 4 (Japan)
+    (c)1998 Video System Co.,Ltd.
 
-	Driver by Takahiro Nogi <nogi@kt.rim.or.jp> 2001/02/28 -
-	Special thanks to Uki.
+    Driver by Takahiro Nogi <nogi@kt.rim.or.jp> 2001/02/28 -
+    Special thanks to Uki.
 
 ******************************************************************************/
 /******************************************************************************
@@ -26,6 +26,7 @@ Memo:
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
+#include "sound/2610intf.h"
 
 
 VIDEO_UPDATE( fromanc2 );
@@ -81,7 +82,7 @@ static UINT8 fromanc2_sndcpu_nmi_flag;
 
 
 /* ---------------------------------------------------------------------------- */
-/* 	MACHINE INITIALYZE */
+/*  MACHINE INITIALYZE */
 /* ---------------------------------------------------------------------------- */
 
 static MACHINE_INIT( fromanc2 )
@@ -127,7 +128,7 @@ static DRIVER_INIT( fromanc4 )
 
 
 /* ---------------------------------------------------------------------------- */
-/* 	MAIN CPU Interrupt (fromanc2, fromancr, fromanc4)	TEST ROUTINE */
+/*  MAIN CPU Interrupt (fromanc2, fromancr, fromanc4)   TEST ROUTINE */
 /* ---------------------------------------------------------------------------- */
 
 static INTERRUPT_GEN( fromanc2_interrupt )
@@ -148,12 +149,12 @@ static INTERRUPT_GEN( fromanc2_interrupt )
 		usrintf_showmessage("PLAYER-%01X SIDE", fromanc2_playerside + 1);
 
 		if (!fromanc2_playerside) {
-			mixer_set_stereo_volume(3, 75, 75);	/* 1P (LEFT) */
-			mixer_set_stereo_volume(4,  0,  0);	/* 2P (RIGHT) */
+/*          mixer_set_stereo_volume(3, 75, 75); // 1P (LEFT) */
+/*          mixer_set_stereo_volume(4,  0,  0); // 2P (RIGHT) */
 		}
 		else {
-			mixer_set_stereo_volume(3,  0,  0);	/* 1P (LEFT) */
-			mixer_set_stereo_volume(4, 75, 75);	/* 2P (RIGHT) */
+/*          mixer_set_stereo_volume(3,  0,  0); // 1P (LEFT) */
+/*          mixer_set_stereo_volume(4, 75, 75); // 2P (RIGHT) */
 		}
 
 		fromanc2_set_dispvram_w(fromanc2_playerside);
@@ -164,7 +165,7 @@ static INTERRUPT_GEN( fromanc2_interrupt )
 
 
 /* ---------------------------------------------------------------------------- */
-/* 	Sound Command Interface (fromanc2, fromancr, fromanc4) */
+/*  Sound Command Interface (fromanc2, fromancr, fromanc4) */
 /* ---------------------------------------------------------------------------- */
 
 static WRITE16_HANDLER( fromanc2_sndcmd_w )
@@ -177,7 +178,7 @@ static WRITE16_HANDLER( fromanc2_sndcmd_w )
 }
 
 /* ---------------------------------------------------------------------------- */
-/* 	Input Port Interface (COIN, TEST, KEY MATRIX, EEPROM) */
+/*  Input Port Interface (COIN, TEST, KEY MATRIX, EEPROM) */
 /* ---------------------------------------------------------------------------- */
 
 static WRITE16_HANDLER( fromanc2_portselect_w )
@@ -273,7 +274,7 @@ static WRITE16_HANDLER( fromanc4_eeprom_w )
 }
 
 /* ---------------------------------------------------------------------------- */
-/* 	MAIN CPU, SUB CPU Communication Interface (fromanc2, fromancr) */
+/*  MAIN CPU, SUB CPU Communication Interface (fromanc2, fromancr) */
 /* ---------------------------------------------------------------------------- */
 
 static WRITE16_HANDLER( fromanc2_subcpu_w )
@@ -342,7 +343,7 @@ static WRITE8_HANDLER( fromanc2_subcpu_rombank_w )
 
 
 /* ---------------------------------------------------------------------------- */
-/*	MAIN Program (fromanc2, fromancr, fromanc4) */
+/*  MAIN Program (fromanc2, fromancr, fromanc4) */
 /* ---------------------------------------------------------------------------- */
 
 static ADDRESS_MAP_START( fromanc2_readmem_main, ADDRESS_SPACE_PROGRAM, 16 )
@@ -478,7 +479,7 @@ ADDRESS_MAP_END
 
 
 /* ---------------------------------------------------------------------------- */
-/* 	Z80 SUB Program (fromanc2, fromancr) */
+/*  Z80 SUB Program (fromanc2, fromancr) */
 /* ---------------------------------------------------------------------------- */
 
 static ADDRESS_MAP_START( fromanc2_readmem_sub, ADDRESS_SPACE_PROGRAM, 8 )
@@ -496,11 +497,13 @@ static ADDRESS_MAP_START( fromanc2_writemem_sub, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fromanc2_readport_sub, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x02, 0x02) AM_READ(fromanc2_maincpu_r_l)			/* to MAIN CPU */
 	AM_RANGE(0x04, 0x04) AM_READ(fromanc2_maincpu_r_h)			/* to MAIN CPU */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fromanc2_writeport_sub, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(fromanc2_subcpu_rombank_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(fromanc2_maincpu_w_l)			/* from MAIN CPU */
 	AM_RANGE(0x04, 0x04) AM_WRITE(fromanc2_maincpu_w_h)			/* from MAIN CPU */
@@ -509,7 +512,7 @@ ADDRESS_MAP_END
 
 
 /* ---------------------------------------------------------------------------- */
-/* 	Z80 Sound Program (fromanc2, fromancr, fromanc4) */
+/*  Z80 Sound Program (fromanc2, fromancr, fromanc4) */
 /* ---------------------------------------------------------------------------- */
 
 static ADDRESS_MAP_START( fromanc2_readmem_sound, ADDRESS_SPACE_PROGRAM, 8 )
@@ -523,6 +526,7 @@ static ADDRESS_MAP_START( fromanc2_writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fromanc2_readport_sound, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(soundlatch_r)					/* snd cmd (1P) */
 	AM_RANGE(0x04, 0x04) AM_READ(soundlatch2_r)					/* snd cmd (2P) */
 	AM_RANGE(0x09, 0x09) AM_READ(MRA8_NOP)						/* ? */
@@ -532,6 +536,7 @@ static ADDRESS_MAP_START( fromanc2_readport_sound, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fromanc2_writeport_sound, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(MWA8_NOP)						/* ? */
 	AM_RANGE(0x08, 0x08) AM_WRITE(YM2610_control_port_0_A_w)
 	AM_RANGE(0x09, 0x09) AM_WRITE(YM2610_data_port_0_A_w)
@@ -546,75 +551,75 @@ ADDRESS_MAP_END
 
 #define VSYSMJCTRL_PORT1 \
 	PORT_START_TAG("IN1")\
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 A") PORT_CODE(KEYCODE_A) \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 E") PORT_CODE(KEYCODE_E) \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 I") PORT_CODE(KEYCODE_I) \
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 M") PORT_CODE(KEYCODE_M) \
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Kan") PORT_CODE(KEYCODE_LCONTROL) \
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_A )\
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_E )\
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_I )\
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_M )\
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_KAN )\
 	PORT_BIT ( 0x0020, IP_ACTIVE_LOW, IPT_START1 ) \
 	PORT_BIT ( 0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 A") \
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 E") \
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 I") \
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 M") \
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 Kan") \
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_MAHJONG_A ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_MAHJONG_E ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_MAHJONG_I ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_MAHJONG_M ) PORT_PLAYER(2)\
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_MAHJONG_KAN ) PORT_PLAYER(2)\
 	PORT_BIT ( 0x2000, IP_ACTIVE_LOW, IPT_START2 ) \
 	PORT_BIT ( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 #define VSYSMJCTRL_PORT2 \
 	PORT_START_TAG("IN2")\
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 B") PORT_CODE(KEYCODE_B) \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 F") PORT_CODE(KEYCODE_F) \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 J") PORT_CODE(KEYCODE_J) \
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 N") PORT_CODE(KEYCODE_N) \
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Reach") PORT_CODE(KEYCODE_LSHIFT) \
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_B )\
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_F )\
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_J )\
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_N )\
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_REACH )\
 	PORT_BIT ( 0x0020, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 B") \
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 F") \
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 J") \
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 N") \
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 Reach") \
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_MAHJONG_B ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_MAHJONG_F ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_MAHJONG_J ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_MAHJONG_N ) PORT_PLAYER(2)\
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_MAHJONG_REACH ) PORT_PLAYER(2)\
 	PORT_BIT ( 0x2000, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 #define VSYSMJCTRL_PORT3 \
 	PORT_START_TAG("IN3")\
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 C") PORT_CODE(KEYCODE_C) \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 G") PORT_CODE(KEYCODE_G) \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 K") PORT_CODE(KEYCODE_K) \
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Chi") PORT_CODE(KEYCODE_SPACE) \
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Ron") PORT_CODE(KEYCODE_Z) \
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_C )\
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_G )\
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_K )\
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_CHI )\
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_RON )\
 	PORT_BIT ( 0x0020, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 C") \
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 G") \
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 K") \
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 Chi") \
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 Ron") \
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_MAHJONG_C ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_MAHJONG_G ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_MAHJONG_K ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_MAHJONG_CHI ) PORT_PLAYER(2)\
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_MAHJONG_RON ) PORT_PLAYER(2)\
 	PORT_BIT ( 0x2000, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 #define VSYSMJCTRL_PORT4 \
 	PORT_START_TAG("IN4") \
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 D") PORT_CODE(KEYCODE_D) \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 H") PORT_CODE(KEYCODE_H) \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 L") PORT_CODE(KEYCODE_L) \
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Pon") PORT_CODE(KEYCODE_LALT) \
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_D )\
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_H )\
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_L )\
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_PON )\
 	PORT_BIT ( 0x0010, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x0020, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 D") \
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 H") \
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 L") \
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 Pon") \
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_MAHJONG_D ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_MAHJONG_H ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_MAHJONG_L ) PORT_PLAYER(2)\
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_MAHJONG_PON ) PORT_PLAYER(2)\
 	PORT_BIT ( 0x1000, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x2000, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
@@ -726,17 +731,9 @@ static void irqhandler(int irq)
 
 static struct YM2610interface ym2610_interface =
 {
-	1,
-	8000000,
-	{ 50 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler },
-	{ 0 },
-	{ REGION_SOUND1 },
-	{ YM3012_VOL(75, MIXER_PAN_CENTER, 75, MIXER_PAN_CENTER) }
+	irqhandler,
+	0,
+	REGION_SOUND1
 };
 
 
@@ -752,7 +749,7 @@ static MACHINE_DRIVER_START( fromanc2 )
 	MDRV_CPU_VBLANK_INT(fromanc2_interrupt,1)
 
 	MDRV_CPU_ADD(Z80,32000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* 8.00 MHz */
+	/* audio CPU */		/* 8.00 MHz */
 	MDRV_CPU_PROGRAM_MAP(fromanc2_readmem_sound,fromanc2_writemem_sound)
 	MDRV_CPU_IO_MAP(fromanc2_readport_sound,fromanc2_writeport_sound)
 
@@ -777,7 +774,13 @@ static MACHINE_DRIVER_START( fromanc2 )
 	MDRV_VIDEO_UPDATE(fromanc2)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2610, ym2610_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.50)
+	MDRV_SOUND_ROUTE(1, "mono", 0.75)
+	MDRV_SOUND_ROUTE(2, "mono", 0.75)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( fromancr )
@@ -788,7 +791,7 @@ static MACHINE_DRIVER_START( fromancr )
 	MDRV_CPU_VBLANK_INT(fromanc2_interrupt,1)
 
 	MDRV_CPU_ADD(Z80,32000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* 8.00 MHz */
+	/* audio CPU */		/* 8.00 MHz */
 	MDRV_CPU_PROGRAM_MAP(fromanc2_readmem_sound,fromanc2_writemem_sound)
 	MDRV_CPU_IO_MAP(fromanc2_readport_sound,fromanc2_writeport_sound)
 
@@ -813,7 +816,13 @@ static MACHINE_DRIVER_START( fromancr )
 	MDRV_VIDEO_UPDATE(fromanc2)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2610, ym2610_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.50)
+	MDRV_SOUND_ROUTE(1, "mono", 0.75)
+	MDRV_SOUND_ROUTE(2, "mono", 0.75)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( fromanc4 )
@@ -824,7 +833,7 @@ static MACHINE_DRIVER_START( fromanc4 )
 	MDRV_CPU_VBLANK_INT(fromanc2_interrupt,1)
 
 	MDRV_CPU_ADD(Z80,32000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* 8.00 MHz */
+	/* audio CPU */		/* 8.00 MHz */
 	MDRV_CPU_PROGRAM_MAP(fromanc2_readmem_sound,fromanc2_writemem_sound)
 	MDRV_CPU_IO_MAP(fromanc2_readport_sound,fromanc2_writeport_sound)
 
@@ -845,7 +854,13 @@ static MACHINE_DRIVER_START( fromanc4 )
 	MDRV_VIDEO_UPDATE(fromanc2)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2610, ym2610_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.50)
+	MDRV_SOUND_ROUTE(1, "mono", 0.75)
+	MDRV_SOUND_ROUTE(2, "mono", 0.75)
 MACHINE_DRIVER_END
 
 
