@@ -1,33 +1,33 @@
 /******************************************************************************
 
-	Game Driver for Video System Mahjong series.
+    Game Driver for Video System Mahjong series.
 
-	Idol-Mahjong Final Romance (Japan)
-	(c)1991 Video System Co.,Ltd.
+    Idol-Mahjong Final Romance (Japan)
+    (c)1991 Video System Co.,Ltd.
 
-	Nekketsu Mahjong Sengen! AFTER 5 (Japan)
-	(c)1991 Video System Co.,Ltd.
+    Nekketsu Mahjong Sengen! AFTER 5 (Japan)
+    (c)1991 Video System Co.,Ltd.
 
-	Mahjong Daiyogen (Japan)
-	(c)1990 Video System Co.,Ltd.
+    Mahjong Daiyogen (Japan)
+    (c)1990 Video System Co.,Ltd.
 
-	Mahjong Fun Club - Idol Saizensen (Japan)
-	(c)1989 Video System Co.,Ltd.
+    Mahjong Fun Club - Idol Saizensen (Japan)
+    (c)1989 Video System Co.,Ltd.
 
-	Mahjong Natsu Monogatari (Mahjong Summer Story) (Japan)
-	(c)1989 Video System Co.,Ltd.
+    Mahjong Natsu Monogatari (Mahjong Summer Story) (Japan)
+    (c)1989 Video System Co.,Ltd.
 
-	Natsuiro Mahjong (Mahjong Summer Story) (Japan)
-	(c)1989 Video System Co.,Ltd.
+    Natsuiro Mahjong (Mahjong Summer Story) (Japan)
+    (c)1989 Video System Co.,Ltd.
 
-	Idol-Mahjong Housoukyoku (Japan)
-	(c)1988 System Service Co.,Ltd.
+    Idol-Mahjong Housoukyoku (Japan)
+    (c)1988 System Service Co.,Ltd.
 
-	Rettou Juudan Nekkyoku Janshi - Higashi Nippon Hen (Japan)
-	(c)1988 Video System Co.,Ltd.
+    Rettou Juudan Nekkyoku Janshi - Higashi Nippon Hen (Japan)
+    (c)1988 Video System Co.,Ltd.
 
-	Driver by Takahiro Nogi <nogi@kt.rim.or.jp> 2001/02/04 -
-	and Nicola Salmoria, Aaron Giles
+    Driver by Takahiro Nogi <nogi@kt.rim.or.jp> 2001/02/04 -
+    and Nicola Salmoria, Aaron Giles
 
 ******************************************************************************/
 /******************************************************************************
@@ -43,6 +43,9 @@ Memo:
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
 #include "fromance.h"
+#include "sound/ay8910.h"
+#include "sound/2413intf.h"
+#include "sound/msm5205.h"
 
 
 /* Local variables */
@@ -58,7 +61,7 @@ static UINT8 fromance_vclk_left;
 
 /*************************************
  *
- *	Machine init
+ *  Machine init
  *
  *************************************/
 
@@ -77,7 +80,7 @@ static MACHINE_INIT( fromance )
 
 /*************************************
  *
- *	Master/slave communication
+ *  Master/slave communication
  *
  *************************************/
 
@@ -127,7 +130,7 @@ static WRITE8_HANDLER( fromance_busycheck_sub_w )
 
 /*************************************
  *
- *	Slave CPU ROM banking
+ *  Slave CPU ROM banking
  *
  *************************************/
 
@@ -142,7 +145,7 @@ static WRITE8_HANDLER( fromance_rombank_w )
 
 /*************************************
  *
- *	ADPCM interface
+ *  ADPCM interface
  *
  *************************************/
 
@@ -185,7 +188,7 @@ static void fromance_adpcm_int(int irq)
 
 /*************************************
  *
- *	Input handlers
+ *  Input handlers
  *
  *************************************/
 
@@ -217,7 +220,7 @@ static READ8_HANDLER( fromance_keymatrix_r )
 
 /*************************************
  *
- *	Coin counters
+ *  Coin counters
  *
  *************************************/
 
@@ -230,7 +233,7 @@ static WRITE8_HANDLER( fromance_coinctr_w )
 
 /*************************************
  *
- *	Master CPU memory handlers
+ *  Master CPU memory handlers
  *
  *************************************/
 
@@ -279,7 +282,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Slave CPU memory handlers
+ *  Slave CPU memory handlers
  *
  *************************************/
 
@@ -320,17 +323,19 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Slave CPU port handlers
+ *  Slave CPU port handlers
  *
  *************************************/
 
 static ADDRESS_MAP_START( nekkyoku_readport_sub, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x12, 0x12) AM_READ(MRA8_NOP)				/* unknown */
 	AM_RANGE(0xe1, 0xe1) AM_READ(fromance_busycheck_sub_r)
 	AM_RANGE(0xe6, 0xe6) AM_READ(fromance_commanddata_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( nekkyoku_writeport_sub, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x10, 0x10) AM_WRITE(fromance_crtc_data_w)
 	AM_RANGE(0x11, 0x11) AM_WRITE(fromance_crtc_register_w)
 	AM_RANGE(0xe0, 0xe0) AM_WRITE(fromance_rombank_w)
@@ -344,12 +349,14 @@ static ADDRESS_MAP_START( nekkyoku_writeport_sub, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fromance_readport_sub, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x12, 0x12) AM_READ(MRA8_NOP)				/* unknown */
 	AM_RANGE(0x21, 0x21) AM_READ(fromance_busycheck_sub_r)
 	AM_RANGE(0x26, 0x26) AM_READ(fromance_commanddata_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( idolmj_writeport_sub, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x10, 0x10) AM_WRITE(fromance_crtc_data_w)
 	AM_RANGE(0x11, 0x11) AM_WRITE(fromance_crtc_register_w)
 	AM_RANGE(0x20, 0x20) AM_WRITE(fromance_rombank_w)
@@ -363,6 +370,7 @@ static ADDRESS_MAP_START( idolmj_writeport_sub, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fromance_writeport_sub, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x10, 0x10) AM_WRITE(fromance_crtc_data_w)
 	AM_RANGE(0x11, 0x11) AM_WRITE(fromance_crtc_register_w)
 	AM_RANGE(0x20, 0x20) AM_WRITE(fromance_rombank_w)
@@ -379,49 +387,49 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
 #define FROMANCE_KEYMATRIX1 \
 	PORT_START_TAG("IN4") \
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 A") PORT_CODE(KEYCODE_A) \
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 E") PORT_CODE(KEYCODE_E) \
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 I") PORT_CODE(KEYCODE_I) \
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 M") PORT_CODE(KEYCODE_M) \
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Kan") PORT_CODE(KEYCODE_LCONTROL) \
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_A ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_E ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_I ) \
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_M ) \
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_MAHJONG_KAN ) \
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 ) \
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 
 #define FROMANCE_KEYMATRIX2 \
 	PORT_START_TAG("IN5") \
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 B") PORT_CODE(KEYCODE_B) \
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 F") PORT_CODE(KEYCODE_F) \
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 J") PORT_CODE(KEYCODE_J) \
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 N") PORT_CODE(KEYCODE_N) \
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Reach") PORT_CODE(KEYCODE_LSHIFT) \
-	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet") PORT_CODE(KEYCODE_2) \
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_B ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_F ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_J ) \
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_N ) \
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_MAHJONG_REACH ) \
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_MAHJONG_BET ) \
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 
 #define FROMANCE_KEYMATRIX3 \
 	PORT_START_TAG("IN6") \
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 C") PORT_CODE(KEYCODE_C) \
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 G") PORT_CODE(KEYCODE_G) \
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 K") PORT_CODE(KEYCODE_K) \
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Chi") PORT_CODE(KEYCODE_SPACE) \
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Ron") PORT_CODE(KEYCODE_Z) \
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_C ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_G ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_K ) \
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_CHI ) \
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_MAHJONG_RON ) \
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 
 #define FROMANCE_KEYMATRIX4 \
 	PORT_START_TAG("IN7") \
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 D") PORT_CODE(KEYCODE_D) \
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 H") PORT_CODE(KEYCODE_H) \
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 L") PORT_CODE(KEYCODE_L) \
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Pon") PORT_CODE(KEYCODE_LALT) \
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_D ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_H ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_L ) \
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_PON ) \
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
@@ -429,12 +437,12 @@ ADDRESS_MAP_END
 
 #define FROMANCE_KEYMATRIX5 \
 	PORT_START_TAG("IN8") \
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Last Chance") PORT_CODE(KEYCODE_RALT) \
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Take Score") PORT_CODE(KEYCODE_RCONTROL) \
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Double Up") PORT_CODE(KEYCODE_RSHIFT) \
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Flip") PORT_CODE(KEYCODE_X) \
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Big") PORT_CODE(KEYCODE_ENTER) \
-	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Small") PORT_CODE(KEYCODE_BACKSPACE) \
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_LAST_CHANCE ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_SCORE ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_DOUBLE_UP ) \
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_FLIP_FLOP ) \
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_MAHJONG_BIG ) \
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_MAHJONG_SMALL ) \
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
@@ -1005,7 +1013,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -1032,52 +1040,20 @@ static struct GfxDecodeInfo fromance_gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound definitions
+ *  Sound definitions
  *
  *************************************/
 
-static struct YM2413interface ym2413_interface=
-{
-	1,						/* 1 chip */
-	3579545,				/* 3.579545 MHz ? */
-	{ YM2413_VOL(100,MIXER_PAN_CENTER,100,MIXER_PAN_CENTER) }
-};
-
-
-static struct AY8910interface ay8910_interface =
-{
-	1,						/* 1 chip */
-	12000000/6,				/* 1.5 MHz ? */
-	{ 15 },					/* volume */
-	{ 0 },					/* read port #0 */
-	{ 0 },					/* read port #1 */
-	{ 0 },					/* write port #0 */
-	{ 0 }					/* write port #1 */
-};
-
-
 static struct MSM5205interface msm5205_interface =
 {
-	1,						/* 1 chip */
-	384000,					/* 384 KHz */
-	{ fromance_adpcm_int },	/* IRQ handler */
-	{ MSM5205_S48_4B },		/* 8 KHz */
-	{ 80 }					/* volume */
-};
-
-static struct MSM5205interface fromance_msm5205_interface =
-{
-	1,						/* 1 chip */
-	384000,					/* 384 KHz */
-	{ fromance_adpcm_int },	/* IRQ handler */
-	{ MSM5205_S48_4B },		/* 8 KHz */
-	{ 10 }					/* volume */
+	fromance_adpcm_int,	/* IRQ handler */
+	MSM5205_S48_4B		/* 8 KHz */
 };
 
 
 /*************************************
  *
- *	Machine drivers
+ *  Machine drivers
  *
  *************************************/
 
@@ -1108,8 +1084,14 @@ static MACHINE_DRIVER_START( nekkyoku )
 	MDRV_VIDEO_UPDATE(fromance)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 12000000/6)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
 
@@ -1140,8 +1122,14 @@ static MACHINE_DRIVER_START( idolmj )
 	MDRV_VIDEO_UPDATE(fromance)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 12000000/6)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
 
@@ -1172,15 +1160,21 @@ static MACHINE_DRIVER_START( fromance )
 	MDRV_VIDEO_UPDATE(fromance)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2413, ym2413_interface)
-	MDRV_SOUND_ADD(MSM5205, fromance_msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2413, 3579545)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.90)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -1385,7 +1379,7 @@ ROM_END
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
