@@ -1,21 +1,21 @@
 /***************************************************************************
 
-						  -= Fuuki 32 Bit Games (FG-3) =-
+                          -= Fuuki 32 Bit Games (FG-3) =-
 
-				driver by Paul Priest and David Haywood
-				based on fuukifg2 by Luca Elia
+                driver by Paul Priest and David Haywood
+                based on fuukifg2 by Luca Elia
 
 Hardware is similar to FG-2 used for :
 "Go Go! Mile Smile", "Susume! Mile Smile (Japan)" & "Gyakuten!! Puzzle Bancho (Japan)"
 See fuukifg2.c
 
-Main  CPU	:	M68020
+Main  CPU   :   M68020
 
 ---------------------------------------------------------------------------
 Year + Game
 ---------------------------------------------------------------------------
 98  Asura Blade - Sword of Dynasty
-	Asura Buster - Eternal Warriors
+    Asura Buster - Eternal Warriors
 ---------------------------------------------------------------------------
 
 --
@@ -89,6 +89,8 @@ FG-3J ROM-J 507KA0301P04       Rev:1.3
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/262intf.h"
+#include "sound/ymf278b.h"
 
 static int fuuki32_raster_enable = 1; /* Enabled by default */
 static data8_t fuuki32_shared_ram[16];
@@ -150,26 +152,11 @@ static WRITE32_HANDLER( paletteram32_xRRRRRGGGGGBBBBB_dword_w )
 /***************************************************************************
 
 
-							Memory Maps - Main CPU
+                            Memory Maps - Main CPU
 
 
 ***************************************************************************/
 
-static WRITE32_HANDLER( fuuki32_sound_command_w )
-{
-	if (!(mem_mask & 0x00ff0000))
-	{
-		soundlatch_w(0,(data>>16) & 0xff);
-/*		cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE); */
-		cpu_spinuntil_time(TIME_IN_USEC(50));	/* Allow the other CPU to reply */
-	}
-}
-
-static READ32_HANDLER( fuuki32_sound_command_r )
-{
-	/* should this be synced? */
-	return soundlatch2_r(0) << 16;
-}
 
 #define FUUKI32_INPUT( _N_ ) \
 \
@@ -227,8 +214,8 @@ static ADDRESS_MAP_START( fuuki32_readmem, ADDRESS_SPACE_PROGRAM, 32 )
 /**/AM_RANGE(0x8e0000, 0x8e0003) AM_READ(MRA32_RAM) /* Controls layer order */
 
 	AM_RANGE(0x903fe0, 0x903fff) AM_READ(snd_020_r) /* Shared with Z80 */
-/*	AM_RANGE(0x903fe0, 0x903fe3) AM_READ(fuuki32_sound_command_r) // Shared with Z80 */
-/*	AM_RANGE(0x903fe4, 0x903fff) AM_READ(MRA32_RAM) // ?? */
+/*  AM_RANGE(0x903fe0, 0x903fe3) AM_READ(fuuki32_sound_command_r) // Shared with Z80 */
+/*  AM_RANGE(0x903fe4, 0x903fff) AM_READ(MRA32_RAM) // ?? */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fuuki32_writemem, ADDRESS_SPACE_PROGRAM, 32 )
@@ -259,7 +246,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************
 
-							Memory Maps - Sound CPU
+                            Memory Maps - Sound CPU
 
 ***************************************************************************/
 
@@ -295,10 +282,12 @@ static ADDRESS_MAP_START( fuuki32_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fuuki32_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x40, 0x40) AM_READ(YMF262_status_0_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( fuuki32_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(fuuki32_sound_bw_w)
 	AM_RANGE(0x30, 0x30) AM_WRITE(MWA8_NOP)
 	AM_RANGE(0x40, 0x40) AM_WRITE(YMF262_register_A_0_w)
@@ -313,7 +302,7 @@ ADDRESS_MAP_END
 /***************************************************************************
 
 
-								Input Ports
+                                Input Ports
 
 
 ***************************************************************************/
@@ -419,7 +408,7 @@ INPUT_PORTS_END
 /***************************************************************************
 
 
-							Graphics Layouts
+                            Graphics Layouts
 
 
 ***************************************************************************/
@@ -476,7 +465,7 @@ static struct GfxDecodeInfo fuuki32_gfxdecodeinfo[] =
 /***************************************************************************
 
 
-								Machine Drivers
+                                Machine Drivers
 
 
 ***************************************************************************/
@@ -512,20 +501,12 @@ static void irqhandler(int irq)
 
 static struct YMF278B_interface ymf278b_interface =
 {
-	1,
-	{ YMF278B_STD_CLOCK },
-	{ REGION_SOUND1 },
-	{ YM3012_VOL(50, MIXER_PAN_LEFT, 50, MIXER_PAN_RIGHT) },
-	{ 0 }
+	REGION_SOUND1
 };
 
 static struct YMF262interface ymf262_interface =
 {
-	1,					/* 1 chip */
-	14318180,			/* X1 ? */
-	{ YAC512_VOL(50,MIXER_PAN_LEFT,50,MIXER_PAN_RIGHT) },	/* channels A and B */
-	{ YAC512_VOL(50,MIXER_PAN_LEFT,50,MIXER_PAN_RIGHT) },	/* channels C and D */
-	{ irqhandler },		/* irq */
+	irqhandler		/* irq */
 };
 
 static MACHINE_DRIVER_START( fuuki32 )
@@ -554,22 +535,32 @@ static MACHINE_DRIVER_START( fuuki32 )
 	MDRV_VIDEO_EOF(fuuki32)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YMF262, ymf262_interface)
-	MDRV_SOUND_ADD(YMF278B, ymf278b_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YMF262, 14318180)
+	MDRV_SOUND_CONFIG(ymf262_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(1, "right", 0.50)
+	MDRV_SOUND_ROUTE(2, "left", 0.50)
+	MDRV_SOUND_ROUTE(3, "right", 0.50)
+
+	MDRV_SOUND_ADD(YMF278B, YMF278B_STD_CLOCK)
+	MDRV_SOUND_CONFIG(ymf278b_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(1, "right", 0.50)
 MACHINE_DRIVER_END
 
 /***************************************************************************
 
 
-								ROMs Loading
+                                ROMs Loading
 
 
 ***************************************************************************/
 
 /***************************************************************************
 
-								Asura Blade
+                                Asura Blade
 Fuuki, 1999
 
 This dump is taken from a ROM board with number FG-3J ROM-J
@@ -624,7 +615,7 @@ ROM_END
 /***************************************************************************
 
 
-								Game Drivers
+                                Game Drivers
 
 
 ***************************************************************************/
