@@ -1,8 +1,8 @@
 /***************************************************************************
 
-	Gaelco game hardware from 1991-1996
+    Gaelco game hardware from 1991-1996
 
-	Driver by Manuel Abadia
+    Driver by Manuel Abadia
 
 ***************************************************************************/
 
@@ -10,6 +10,8 @@
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/m68000/m68000.h"
+#include "sound/okim6295.h"
+#include "sound/3812intf.h"
 
 extern data16_t *gaelco_vregs;
 extern data16_t *gaelco_videoram;
@@ -49,7 +51,7 @@ WRITE16_HANDLER( gaelco_vram_w );
 }
 
 /*============================================================================
-							BIG KARNAK
+                            BIG KARNAK
   ============================================================================*/
 
 VIDEO_START( bigkarnk );
@@ -99,7 +101,7 @@ static ADDRESS_MAP_START( bigkarnk_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x100000, 0x101fff) AM_WRITE(gaelco_vram_w) AM_BASE(&gaelco_videoram)		/* Video RAM */
 	AM_RANGE(0x102000, 0x103fff) AM_WRITE(MWA16_RAM)								/* Screen RAM */
 	AM_RANGE(0x108000, 0x108007) AM_WRITE(MWA16_RAM) AM_BASE(&gaelco_vregs)				/* Video Registers */
-/*	AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)						   INT 6 ACK/Watchdog timer    */
+/*  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                        INT 6 ACK/Watchdog timer    */
 	AM_RANGE(0x200000, 0x2007ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)/* Palette */
 	AM_RANGE(0x440000, 0x440fff) AM_WRITE(MWA16_RAM) AM_BASE(&gaelco_spriteram)			/* Sprite RAM */
 	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(bigkarnk_sound_command_w)				/* Triggers a FIRQ on the sound CPU */
@@ -119,7 +121,7 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( bigkarnk_writemem_snd, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_WRITE(MWA8_RAM)				/* RAM */
 	AM_RANGE(0x0800, 0x0800) AM_WRITE(OKIM6295_data_0_w)		/* OKI6295 */
-/*	AM_RANGE(0x0900, 0x0900) AM_WRITE(MWA8_NOP)				   enable sound output?    */
+/*  AM_RANGE(0x0900, 0x0900) AM_WRITE(MWA8_NOP)                enable sound output?    */
 	AM_RANGE(0x0a00, 0x0a00) AM_WRITE(YM3812_control_port_0_w)/* YM3812 */
 	AM_RANGE(0x0a01, 0x0a01) AM_WRITE(YM3812_write_port_0_w)	/* YM3812 */
 	AM_RANGE(0x0c00, 0xffff) AM_WRITE(MWA8_ROM)				/* ROM */
@@ -210,23 +212,6 @@ TILELAYOUT16(0x100000);
 GFXDECODEINFO(0x100000,64);
 
 
-static struct YM3812interface bigkarnk_ym3812_interface =
-{
-	1,						/* 1 chip */
-	3580000,				/* 3.58 MHz? */
-	{ 100 },					/* volume */
-	{ 0 }					/* IRQ handler */
-};
-
-static struct OKIM6295interface bigkarnk_okim6295_interface =
-{
-	1,                  /* 1 chip */
-	{ 8000 },			/* 8000 KHz? */
-	{ REGION_SOUND1 },  /* memory region */
-	{ 100 }				/* volume */
-};
-
-
 static MACHINE_DRIVER_START( bigkarnk )
 
 	/* basic machine hardware */
@@ -235,7 +220,7 @@ static MACHINE_DRIVER_START( bigkarnk )
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
 	MDRV_CPU_ADD(M6809, 8867000/4)	/* 68B09, 2.21675 MHz? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(bigkarnk_readmem_snd,bigkarnk_writemem_snd)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -253,8 +238,14 @@ static MACHINE_DRIVER_START( bigkarnk )
 	MDRV_VIDEO_UPDATE(bigkarnk)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, bigkarnk_ym3812_interface)
-	MDRV_SOUND_ADD(OKIM6295, bigkarnk_okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 3580000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -282,7 +273,7 @@ ROM_END
 
 
 /*============================================================================
-					BIOMECHANICAL TOY & MANIAC SQUARE
+                    BIOMECHANICAL TOY & MANIAC SQUARE
   ============================================================================*/
 
 VIDEO_START( maniacsq );
@@ -317,7 +308,7 @@ static ADDRESS_MAP_START( maniacsq_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x100000, 0x101fff) AM_WRITE(gaelco_vram_w) AM_BASE(&gaelco_videoram)		/* Video RAM */
 	AM_RANGE(0x102000, 0x103fff) AM_WRITE(MWA16_RAM)								/* Screen RAM */
 	AM_RANGE(0x108000, 0x108007) AM_WRITE(MWA16_RAM) AM_BASE(&gaelco_vregs)				/* Video Registers */
-/*	AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)						   INT 6 ACK/Watchdog timer    */
+/*  AM_RANGE(0x10800c, 0x10800d) AM_WRITE(watchdog_reset_w)                        INT 6 ACK/Watchdog timer    */
 	AM_RANGE(0x200000, 0x2007ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)/* Palette */
 	AM_RANGE(0x440000, 0x440fff) AM_WRITE(MWA16_RAM) AM_BASE(&gaelco_spriteram)			/* Sprite RAM */
 	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(OKIM6295_bankswitch_w)					/* OKI6295 bankswitch */
@@ -474,14 +465,6 @@ static INPUT_PORTS_START( biomtoy )
 INPUT_PORTS_END
 
 
-static struct OKIM6295interface maniacsq_okim6295_interface =
-{
-	1,                  /* 1 chip */
-	{ 8000 },			/* 8000 KHz? */
-	{ REGION_SOUND1 },  /* memory region */
-	{ 100 }				/* volume */
-};
-
 static MACHINE_DRIVER_START( maniacsq )
 
 	/* basic machine hardware */
@@ -503,7 +486,11 @@ static MACHINE_DRIVER_START( maniacsq )
 	MDRV_VIDEO_UPDATE(maniacsq)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, maniacsq_okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -566,7 +553,7 @@ ROM_START( biomtoy )
 ROM_END
 
 /*============================================================================
-					SQUASH & THUNDER HOOP
+                    SQUASH & THUNDER HOOP
 ============================================================================*/
 
 static MACHINE_DRIVER_START( squash )
@@ -591,7 +578,11 @@ static MACHINE_DRIVER_START( squash )
 	MDRV_VIDEO_UPDATE(bigkarnk)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, bigkarnk_okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /* missing DS5002FP code and encrypted video ram */
@@ -618,16 +609,16 @@ ROM_END
 ROM_START( thoop )
 	ROM_REGION( 0x100000, REGION_CPU1, 0 )	/* 68000 code */
 	/*does it need to be half the size? */
-	ROM_LOAD16_BYTE( "th18dea1.040", 0x000000, 0x80000, CRC(59bad625) SHA1(28e058b2290bc5f7130b801014d026432f9e7fd5) ) 
-	ROM_LOAD16_BYTE( "th161eb4.020", 0x000001, 0x40000, CRC(6add61ed) SHA1(0e789d9a0ac19b6143044fbc04ab2227735b2a8f) ) 
-	
+	ROM_LOAD16_BYTE( "th18dea1.040", 0x000000, 0x80000, CRC(59bad625) SHA1(28e058b2290bc5f7130b801014d026432f9e7fd5) )
+	ROM_LOAD16_BYTE( "th161eb4.020", 0x000001, 0x40000, CRC(6add61ed) SHA1(0e789d9a0ac19b6143044fbc04ab2227735b2a8f) )
+
 
 	ROM_REGION( 0x400000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "c09", 0x000000, 0x100000, CRC(06f0edbf) SHA1(3cf2e5c29cd00b43d49a106084076f2ac0dbad98) )
 	ROM_LOAD( "c10", 0x100000, 0x100000, CRC(2d227085) SHA1(b224efd59ec83bb786fa92a23ef2d27ed36cab6c) )
 	ROM_LOAD( "c11", 0x200000, 0x100000, CRC(7403ef7e) SHA1(52a737816e25a07ada070ed3a5f40bbbd22ac8e0) )
 	ROM_LOAD( "c12", 0x300000, 0x100000, CRC(29a5ca36) SHA1(fdcfdefb3b02bfe34781fdd0295640caabe2a5fb) )
-	
+
 	ROM_REGION( 0x100000, REGION_SOUND1, 0 )	/* ADPCM samples - sound chip is OKIM6295 */
 	ROM_LOAD( "sound", 0x000000, 0x100000, CRC(99f80961) SHA1(de3a514a8f46dffd5f762e52aac1f4c3b08e2e18) )
 ROM_END
