@@ -1,25 +1,26 @@
 /***************************************************************************
 
-	Gaelco CG-1V/GAE1 based games
+    Gaelco CG-1V/GAE1 based games
 
-	Driver by Manuel Abadia <manu@teleline.es>
+    Driver by Manuel Abadia <manu@teleline.es>
 
-	Known games that run on this hardware:
-	======================================
-	Game           | Year | Chip      | Ref      |Protected
-	---------------+------+-----------+----------+--------------------
-	Alligator Hunt | 1994 | GAE1 449  | 940411   | DS5002FP, but unprotected version available
-	World Rally 2  | 1995 | GAE1 449  | 950510   | DS5002FP
-	Touch & Go     | 1995 | GAE1 501  | 950510-1 | DS5002FP
-	Maniac Square  | 1996 | Unknown   | ???      | DS5002FP, but unprotected version available
-	Snow Board     | 1996 | CG-1V 366 | 960419/1 | Lattice IspLSI 1016-80LJ
-	Bang!          | 1998 | CG-1V 388 | ???      | No
+    Known games that run on this hardware:
+    ======================================
+    Game           | Year | Chip      | Ref      |Protected
+    ---------------+------+-----------+----------+--------------------
+    Alligator Hunt | 1994 | GAE1 449  | 940411   | DS5002FP, but unprotected version available
+    World Rally 2  | 1995 | GAE1 449  | 950510   | DS5002FP
+    Touch & Go     | 1995 | GAE1 501  | 950510-1 | DS5002FP
+    Maniac Square  | 1996 | Unknown   | ???      | DS5002FP, but unprotected version available
+    Snow Board     | 1996 | CG-1V 366 | 960419/1 | Lattice IspLSI 1016-80LJ
+    Bang!          | 1998 | CG-1V 388 | ???      | No
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m68000/m68000.h"
+#include "sound/gaelco.h"
 
 extern data16_t *gaelco_sndregs;
 extern data16_t *gaelco2_vregs;
@@ -80,7 +81,7 @@ GFXDECODEINFO(0x0400000, 128);
 
 
 /*============================================================================
-							MANIAC SQUARE (FINAL)
+                            MANIAC SQUARE (FINAL)
   ============================================================================*/
 
 static ADDRESS_MAP_START( maniacsq_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -189,7 +190,6 @@ static struct gaelcosnd_interface maniacsq_snd_interface =
 {
 	REGION_GFX1, 							/* memory region */
 	{ 0*0x0080000, 1*0x0080000, 0, 0 },		/* start of each ROM bank */
-	{ 100, 100 }							/* volume */
 };
 
 static MACHINE_DRIVER_START( maniacsq )
@@ -213,8 +213,12 @@ static MACHINE_DRIVER_START( maniacsq )
 	MDRV_VIDEO_UPDATE(gaelco2)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(GAELCO_GAE1, maniacsq_snd_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(GAELCO_GAE1, 0)
+	MDRV_SOUND_CONFIG(maniacsq_snd_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -236,7 +240,7 @@ ROM_END
 
 
 /*============================================================================
-								BANG
+                                BANG
   ============================================================================*/
 
 static int clr_gun_int;
@@ -335,8 +339,7 @@ INPUT_PORTS_END
 static struct gaelcosnd_interface bang_snd_interface =
 {
 	REGION_GFX1, 											/* memory region */
-	{ 0*0x0200000, 1*0x0200000, 2*0x0200000, 3*0x0200000 },	/* start of each ROM bank */
-	{ 100, 100 }											/* volume */
+	{ 0*0x0200000, 1*0x0200000, 2*0x0200000, 3*0x0200000 }	/* start of each ROM bank */
 };
 
 static MACHINE_DRIVER_START( bang )
@@ -362,8 +365,12 @@ static MACHINE_DRIVER_START( bang )
 	MDRV_VIDEO_UPDATE(bang)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(GAELCO_CG1V, bang_snd_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(GAELCO_CG1V, 0)
+	MDRV_SOUND_CONFIG(bang_snd_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -425,7 +432,7 @@ ROM_END
 
 
 /*============================================================================
-							ALLIGATOR HUNT
+                            ALLIGATOR HUNT
   ============================================================================*/
 
 
@@ -534,8 +541,7 @@ INPUT_PORTS_END
 static struct gaelcosnd_interface alighunt_snd_interface =
 {
 	REGION_GFX1, 											/* memory region */
-	{ 0*0x0400000, 1*0x0400000, 2*0x0400000, 3*0x0400000 },	/* start of each ROM bank */
-	{ 100, 100 }											/* volume */
+	{ 0*0x0400000, 1*0x0400000, 2*0x0400000, 3*0x0400000 }	/* start of each ROM bank */
 };
 
 static MACHINE_DRIVER_START( alighunt )
@@ -559,8 +565,12 @@ static MACHINE_DRIVER_START( alighunt )
 	MDRV_VIDEO_UPDATE(gaelco2)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(GAELCO_GAE1, alighunt_snd_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(GAELCO_GAE1, 0)
+	MDRV_SOUND_CONFIG(alighunt_snd_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -636,7 +646,7 @@ ROM_END
 
 
 /*============================================================================
-							TOUCH & GO
+                            TOUCH & GO
   ============================================================================*/
 
 static WRITE16_HANDLER( touchgo_coin_w )
@@ -798,8 +808,7 @@ INPUT_PORTS_END
 static struct gaelcosnd_interface touchgo_snd_interface =
 {
 	REGION_GFX1, 							/* memory region */
-	{ 0*0x0400000, 1*0x0400000, 0, 0 },		/* start of each ROM bank */
-	{ 100, 100 }							/* volume */
+	{ 0*0x0400000, 1*0x0400000, 0, 0 }		/* start of each ROM bank */
 };
 
 static MACHINE_DRIVER_START( touchgo )
@@ -829,11 +838,14 @@ static MACHINE_DRIVER_START( touchgo )
 
 	/* sound hardware */
 	/* the chip is stereo, but the game sound is mono because the right channel
-	   output is for cabinet 1 and the left channel output is for cabinet 2 */
+       output is for cabinet 1 and the left channel output is for cabinet 2 */
 #ifndef ONE_MONITOR
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 #endif
-	MDRV_SOUND_ADD(GAELCO_GAE1, touchgo_snd_interface)
+	MDRV_SOUND_ADD(GAELCO_GAE1, 0)
+	MDRV_SOUND_CONFIG(touchgo_snd_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 /*
@@ -887,9 +899,9 @@ ROM_START( touchgo )
 	ROM_REGION( 0x1400000, REGION_GFX1, 0 ) /* GFX + Sound */
 	/* 0x0000000-0x0ffffff filled in in the DRIVER_INIT */
 	ROM_LOAD( "ic69",		0x1000000, 0x0200000, BAD_DUMP CRC(bba9aed5) SHA1(5ae1d082dafd82c406e0979f2884093deea17f86) )	/* GFX only */
-	/* 	the first 3/4 of this ROM contain gfx data for tiles 0x0000-0xbfff
-		 the last 1/4 of this ROM contain gfx data for tiles 0x8000-0xbfff
-		 it's a bad dump??? For now, we fill that area with 0 */
+	/*  the first 3/4 of this ROM contain gfx data for tiles 0x0000-0xbfff
+         the last 1/4 of this ROM contain gfx data for tiles 0x8000-0xbfff
+         it's a bad dump??? For now, we fill that area with 0 */
 	ROM_FILL(				0x1180000, 0x0280000, 0x0 )
 
 	ROM_REGION( 0x0c00000, REGION_GFX2, ROMREGION_DISPOSE ) /* Temporary storage */
@@ -902,7 +914,7 @@ ROM_END
 
 
 /*============================================================================
-							SNOW BOARD
+                            SNOW BOARD
   ============================================================================*/
 
 static ADDRESS_MAP_START( snowboar_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -969,8 +981,7 @@ INPUT_PORTS_END
 static struct gaelcosnd_interface snowboar_snd_interface =
 {
 	REGION_GFX1, 							/* memory region */
-	{ 0*0x0400000, 1*0x0400000, 0, 0 },		/* start of each ROM bank */
-	{ 100, 100 }							/* volume */
+	{ 0*0x0400000, 1*0x0400000, 0, 0 }		/* start of each ROM bank */
 };
 
 static MACHINE_DRIVER_START( snowboar )
@@ -996,8 +1007,12 @@ static MACHINE_DRIVER_START( snowboar )
 	MDRV_VIDEO_UPDATE(gaelco2)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(GAELCO_CG1V, snowboar_snd_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(GAELCO_CG1V, 0)
+	MDRV_SOUND_CONFIG(snowboar_snd_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1092,7 +1107,7 @@ ROM_END
 
 
 /*============================================================================
-							WORLD RALLY 2
+                            WORLD RALLY 2
   ============================================================================*/
 
 static ADDRESS_MAP_START( wrally2_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -1214,8 +1229,7 @@ INPUT_PORTS_END
 static struct gaelcosnd_interface wrally2_snd_interface =
 {
 	REGION_GFX1, 						/* memory region */
-	{ 0*0x0200000, 1*0x0200000, 0, 0 },	/* start of each ROM bank */
-	{ 100, 100 }						/* volume */
+	{ 0*0x0200000, 1*0x0200000, 0, 0 }	/* start of each ROM bank */
 };
 
 static MACHINE_DRIVER_START( wrally2 )
@@ -1247,11 +1261,14 @@ static MACHINE_DRIVER_START( wrally2 )
 
 	/* sound hardware */
 	/* the chip is stereo, but the game sound is mono because the right channel
-	   output is for cabinet 1 and the left channel output is for cabinet 2 */
+       output is for cabinet 1 and the left channel output is for cabinet 2 */
 #ifndef ONE_MONITOR
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 #endif
-	MDRV_SOUND_ADD(GAELCO_GAE1, wrally2_snd_interface)
+	MDRV_SOUND_ADD(GAELCO_GAE1, 0)
+	MDRV_SOUND_CONFIG(wrally2_snd_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 /*
