@@ -114,12 +114,12 @@ MG-Y.VO
 -----------------------------------------------
 
 Notes:
-	68k clock:		9.216 MHz (18.432 / 2)
-	Z80 clock:		4.000 MHz
-	YM2203 clock:		4.000 MHz
-	MSM6295 clock:	1.000 MHz (samplerate 7575Hz, i.e. / 132)
+    68k clock:      9.216 MHz (18.432 / 2)
+    Z80 clock:      4.000 MHz
+    YM2203 clock:       4.000 MHz
+    MSM6295 clock:  1.000 MHz (samplerate 7575Hz, i.e. / 132)
 
-	IOP8 manufactured by Ricoh. Full part number: RICOH EPLIOP8BP (PAL or PIC?)
+    IOP8 manufactured by Ricoh. Full part number: RICOH EPLIOP8BP (PAL or PIC?)
 
 ***************************************************************************/
 
@@ -128,6 +128,9 @@ Notes:
 #include "vidhrdw/generic.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
+#include "sound/2203intf.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 extern data16_t *gaiden_videoram,*gaiden_videoram2,*gaiden_videoram3;
 extern int gaiden_sprite_sizey;
@@ -168,7 +171,7 @@ static WRITE16_HANDLER( gaiden_sound_command_w )
 static WRITE16_HANDLER( drgnbowl_sound_command_w )
 {
 	if (ACCESSING_MSB)
-	{ 
+	{
 		soundlatch_w(0,data >> 8);
 		cpunum_set_input_line(1,0,PULSE_LINE);
 	}
@@ -196,7 +199,7 @@ static WRITE16_HANDLER( wildfang_protection_w )
 
 		data >>= 8;
 
-/*		logerror("PC %06x: prot = %02x\n",activecpu_get_pc(),data); */
+/*      logerror("PC %06x: prot = %02x\n",activecpu_get_pc(),data); */
 
 		switch (data & 0xf0)
 		{
@@ -234,7 +237,7 @@ static WRITE16_HANDLER( wildfang_protection_w )
 
 static READ16_HANDLER( wildfang_protection_r )
 {
-/*	logerror("PC %06x: read prot %02x\n",activecpu_get_pc(),prot); */
+/*  logerror("PC %06x: read prot %02x\n",activecpu_get_pc(),prot); */
 	return prot;
 }
 
@@ -324,7 +327,7 @@ static WRITE16_HANDLER( raiga_protection_w )
 
 		data >>= 8;
 
-/*		logerror("PC %06x: prot = %02x\n",activecpu_get_pc(),data); */
+/*      logerror("PC %06x: prot = %02x\n",activecpu_get_pc(),data); */
 
 		switch (data & 0xf0)
 		{
@@ -338,7 +341,7 @@ static WRITE16_HANDLER( raiga_protection_w )
 			case 0x20:	/* low 4 bits of jump code */
 				jumpcode |= data & 0x0f;
 				logerror("requested protection jumpcode %02x\n",jumpcode);
-/*				jumpcode = 0; */
+/*              jumpcode = 0; */
 				if (raiga_jumppoints[jumpcode] == -2)
 				{
 					raiga_jumppoints = jumppoints_other;
@@ -370,7 +373,7 @@ static WRITE16_HANDLER( raiga_protection_w )
 
 static READ16_HANDLER( raiga_protection_r )
 {
-/*	logerror("PC %06x: read prot %02x\n",activecpu_get_pc(),prot); */
+/*  logerror("PC %06x: read prot %02x\n",activecpu_get_pc(),prot); */
 	return prot;
 }
 
@@ -454,6 +457,7 @@ static ADDRESS_MAP_START( drgnbowl_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( drgnbowl_sound_port_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM2151_register_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_READWRITE(YM2151_status_port_0_r, YM2151_data_port_0_w)
 	AM_RANGE(0x80, 0x80) AM_READWRITE(OKIM6295_status_0_r, OKIM6295_data_0_w)
@@ -601,7 +605,7 @@ INPUT_PORTS_START( wildfang )
 	PORT_DIPSETTING(      0x8000, "1" )
 	PORT_DIPSETTING(      0xc000, "2" )
 	PORT_DIPSETTING(      0x4000, "3" )
-/*	PORT_DIPSETTING(      0x0000, "2" ) */
+/*  PORT_DIPSETTING(      0x0000, "2" ) */
 	/* When bit 0 is On,  use bits 4 and 5 for difficulty */
 	PORT_DIPNAME( 0x3000, 0x3000, "Difficulty (Tecmo Knight)" )
 	PORT_DIPSETTING(      0x3000, DEF_STR( Easy ) )
@@ -682,7 +686,7 @@ INPUT_PORTS_START( tknight )
 	PORT_DIPSETTING(      0x8000, "1" )
 	PORT_DIPSETTING(      0xc000, "2" )
 	PORT_DIPSETTING(      0x4000, "3" )
-/*	PORT_DIPSETTING(      0x0000, "2" ) */
+/*  PORT_DIPSETTING(      0x0000, "2" ) */
 	PORT_DIPNAME( 0x2000, 0x2000, DEF_STR( Unused ) )
 	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -957,29 +961,7 @@ static void irqhandler(int irq)
 
 static struct YM2203interface ym2203_interface =
 {
-	2,			/* 2 chips */
-	4000000,	/* 4 MHz ? (hand tuned) */
-	{ YM2203_VOL(60,15), YM2203_VOL(60,15) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
-};
-
-static struct YM2151interface ym2151_interface =
-{	1,
-	4000000,
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },
-	{ 0 }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,                  /* 1 chip */
-	{ 1000000/132 },			/* 7575Hz frequency */
-	{ REGION_SOUND1 },	/* memory region */
-	{ 20 }
+	0,0,0,0,irqhandler
 };
 
 static MACHINE_DRIVER_START( shadoww )
@@ -990,7 +972,7 @@ static MACHINE_DRIVER_START( shadoww )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)	/* 4 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 								/* IRQs are triggered by the YM2203 */
 	MDRV_FRAMES_PER_SECOND(60)
@@ -1009,8 +991,24 @@ static MACHINE_DRIVER_START( shadoww )
 	MDRV_VIDEO_UPDATE(gaiden)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.60)
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.60)
+
+	MDRV_SOUND_ADD(OKIM6295, 1000000/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( raiga )
@@ -1030,7 +1028,7 @@ static MACHINE_DRIVER_START( drgnbowl )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 12000000/2)	/* 6 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(drgnbowl_sound_map,0)
 	MDRV_CPU_IO_MAP(drgnbowl_sound_port_map,0)
 
@@ -1048,8 +1046,15 @@ static MACHINE_DRIVER_START( drgnbowl )
 	MDRV_VIDEO_UPDATE(drgnbowl)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface) /* probably wrong */
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 4000000)
+	MDRV_SOUND_ROUTE(0, "mono", 1.0)
+	MDRV_SOUND_ROUTE(1, "mono", 1.0)
+
+	MDRV_SOUND_ADD(OKIM6295, 1000000/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 MACHINE_DRIVER_END
 
 /***************************************************************************
@@ -1357,7 +1362,7 @@ Notes:
       68000 : Motorola MC68000P10 CPU running at 10.000MHz [20/2] (DIP64)
       Z80   : Goldstar Z8400B running at 6.000MHz [12/2] (DIP40)
       6295  : Oki M6295 running at 1.000MHz [12/12] (QFP44), sample rate = 1000000 / 132
-      3569  : Looks like YM3812 or YM3526 or some other YM compatible YM35xx DIP24 chip. 
+      3569  : Looks like YM3812 or YM3526 or some other YM compatible YM35xx DIP24 chip.
               Input clock is 4MHz on pin 24 and output clock is 2MHz on pin 23 (tied to DAC)
       7105  : Likely YM3012 compatible DAC (pin 2 has 2MHz clock)
       FPGA  : Unknown FPGA (x2, PLCC84)
