@@ -30,6 +30,8 @@ Driver by Takahiro Nogi (nogi@kt.rim.or.jp) 1999/12/17 -
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/dac.h"
+#include "sound/3812intf.h"
 
 WRITE8_HANDLER( galivan_scrollx_w );
 WRITE8_HANDLER( galivan_scrolly_w );
@@ -53,7 +55,7 @@ static MACHINE_INIT( galivan )
 	unsigned char *RAM = memory_region(REGION_CPU1);
 
 	cpu_setbank(1,&RAM[0x10000]);
-/*	layers = 0x60; */
+/*  layers = 0x60; */
 }
 
 static WRITE8_HANDLER( galivan_sound_command_w )
@@ -125,6 +127,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)
 	AM_RANGE(0x01, 0x01) AM_READ(input_port_1_r)
 	AM_RANGE(0x02, 0x02) AM_READ(input_port_2_r)
@@ -134,15 +137,17 @@ static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x40, 0x40) AM_WRITE(galivan_gfxbank_w)
 	AM_RANGE(0x41, 0x42) AM_WRITE(galivan_scrollx_w)
 	AM_RANGE(0x43, 0x44) AM_WRITE(galivan_scrolly_w)
 	AM_RANGE(0x45, 0x45) AM_WRITE(galivan_sound_command_w)
-/*	AM_RANGE(0x46, 0x46) AM_WRITE(MWA8_NOP) */
-/*	AM_RANGE(0x47, 0x47) AM_WRITE(MWA8_NOP) */
+/*  AM_RANGE(0x46, 0x46) AM_WRITE(MWA8_NOP) */
+/*  AM_RANGE(0x47, 0x47) AM_WRITE(MWA8_NOP) */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( ninjemak_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x80, 0x80) AM_READ(input_port_0_r)
 	AM_RANGE(0x81, 0x81) AM_READ(input_port_1_r)
 	AM_RANGE(0x82, 0x82) AM_READ(input_port_2_r)
@@ -152,10 +157,11 @@ static ADDRESS_MAP_START( ninjemak_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( ninjemak_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x80, 0x80) AM_WRITE(ninjemak_gfxbank_w)
 	AM_RANGE(0x85, 0x85) AM_WRITE(galivan_sound_command_w)
-/*	AM_RANGE(0x86, 0x86) AM_WRITE(MWA8_NOP)			// ?? */
-/*	AM_RANGE(0x87, 0x87) AM_WRITE(MWA8_NOP)			// ?? */
+/*  AM_RANGE(0x86, 0x86) AM_WRITE(MWA8_NOP)         // ?? */
+/*  AM_RANGE(0x87, 0x87) AM_WRITE(MWA8_NOP)         // ?? */
 ADDRESS_MAP_END
 
 
@@ -171,11 +177,13 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
-/*	AM_RANGE(0x04, 0x04) AM_READ(MRA8_NOP)    value read and *discarded*    */
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+/*  AM_RANGE(0x04, 0x04) AM_READ(MRA8_NOP)    value read and *discarded*    */
 	AM_RANGE(0x06, 0x06) AM_READ(galivan_sound_command_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM3526_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM3526_write_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(DAC_0_data_w)
@@ -232,12 +240,12 @@ ADDRESS_MAP_END
 	/* This is how the Bonus Life are defined in Service Mode */
 	/* However, to keep the way Bonus Life are defined in MAME, */
 	/* below are the same values, but using the MAME way */
-/*	PORT_DIPNAME( 0x04, 0x04, "1st Bonus Life" ) */
-/*	PORT_DIPSETTING(    0x04, "20k" ) */
-/*	PORT_DIPSETTING(    0x00, "50k" ) */
-/*	PORT_DIPNAME( 0x08, 0x08, "2nd Bonus Life" ) */
-/*	PORT_DIPSETTING(    0x08, "every 60k" ) */
-/*	PORT_DIPSETTING(    0x00, "every 90k" ) */
+/*  PORT_DIPNAME( 0x04, 0x04, "1st Bonus Life" ) */
+/*  PORT_DIPSETTING(    0x04, "20k" ) */
+/*  PORT_DIPSETTING(    0x00, "50k" ) */
+/*  PORT_DIPNAME( 0x08, 0x08, "2nd Bonus Life" ) */
+/*  PORT_DIPSETTING(    0x08, "every 60k" ) */
+/*  PORT_DIPSETTING(    0x00, "every 90k" ) */
 #define NIHON_BONUS_LIFE \
 	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Bonus_Life ) ) \
 	PORT_DIPSETTING(    0x0c, "20k and every 60k" ) \
@@ -551,20 +559,6 @@ static struct GfxDecodeInfo ninjemak_gfxdecodeinfo[] =
 
 
 
-static struct YM3526interface YM3526_interface =
-{
-	1,
-	8000000/2,	/* 4 MHz? */
-	{ 100 }
-};
-
-static struct DACinterface dac_interface =
-{
-	2,
-	{ 50, 50 }
-};
-
-
 static MACHINE_DRIVER_START( galivan )
 
 	/* basic machine hardware */
@@ -574,7 +568,7 @@ static MACHINE_DRIVER_START( galivan )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,8000000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* 4 MHz? */
+	/* audio CPU */		/* 4 MHz? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold,7250)  /* timed interrupt, ?? Hz */
@@ -597,8 +591,16 @@ static MACHINE_DRIVER_START( galivan )
 	MDRV_VIDEO_UPDATE(galivan)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3526, YM3526_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3526, 8000000/2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( ninjemak )
@@ -610,7 +612,7 @@ static MACHINE_DRIVER_START( ninjemak )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,8000000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* 4 MHz? */
+	/* audio CPU */		/* 4 MHz? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold,7250)	/* timed interrupt, ?? Hz */
@@ -633,8 +635,15 @@ static MACHINE_DRIVER_START( ninjemak )
 	MDRV_VIDEO_UPDATE(ninjemak)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3526, YM3526_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(YM3526, 8000000/2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
