@@ -109,7 +109,7 @@ The roms are piggy-backed in the same way.
 #include "machine/kaneko16.h"
 #include "machine/random.h"
 #include "vidhrdw/generic.h"
-
+#include "sound/okim6295.h"
 
 
 extern data16_t *galpanic_bgvideoram,*galpanic_fgvideoram;
@@ -235,7 +235,7 @@ static ADDRESS_MAP_START( comad_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x800000, 0x800001) AM_READ(input_port_0_word_r)
 	AM_RANGE(0x800002, 0x800003) AM_READ(input_port_1_word_r)
 	AM_RANGE(0x800004, 0x800005) AM_READ(input_port_2_word_r)
-/*	AM_RANGE(0x800006, 0x800007)	?? */
+/*  AM_RANGE(0x800006, 0x800007)    ?? */
 	AM_RANGE(0x80000a, 0x80000b) AM_READ(kludge)	/* bits 8-a = timer? palette update code waits for them to be 111 */
 	AM_RANGE(0x80000c, 0x80000d) AM_READ(kludge)	/* missw96 bits 8-a = timer? palette update code waits for them to be 111 */
 	AM_RANGE(0xc00000, 0xc0ffff) AM_READ(MRA16_RAM)	/* missw96 */
@@ -266,7 +266,7 @@ static ADDRESS_MAP_START( fantsia2_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x800000, 0x800001) AM_READ(input_port_0_word_r)
 	AM_RANGE(0x800002, 0x800003) AM_READ(input_port_1_word_r)
 	AM_RANGE(0x800004, 0x800005) AM_READ(input_port_2_word_r)
-/*	AM_RANGE(0x800006, 0x800007)	?? */
+/*  AM_RANGE(0x800006, 0x800007)    ?? */
 	AM_RANGE(0x800008, 0x800009) AM_READ(kludge)	/* bits 8-a = timer? palette update code waits for them to be 111 */
 	AM_RANGE(0xf80000, 0xf8ffff) AM_READ(MRA16_RAM)
 	AM_RANGE(0xc80000, 0xc80001) AM_READ(OKIM6295_status_0_msb_r)
@@ -374,17 +374,17 @@ INPUT_PORTS_START( galpanic )
 	PORT_DIPSETTING(      0x0040, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_6C ) )
 	/* Coinage - Japan (0x03ffff.b = 01) and US (0x03ffff.b = 02)
-	PORT_DIPNAME( 0x0030, 0x0030, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(      0x0010, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x0030, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(      0x0020, DEF_STR( 1C_2C ) )
-	PORT_DIPNAME( 0x00c0, 0x00c0, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(      0x0040, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x00c0, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(      0x0080, DEF_STR( 1C_2C ) )
-	*/
+    PORT_DIPNAME( 0x0030, 0x0030, DEF_STR( Coin_A ) )
+    PORT_DIPSETTING(      0x0010, DEF_STR( 2C_1C ) )
+    PORT_DIPSETTING(      0x0030, DEF_STR( 1C_1C ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )
+    PORT_DIPSETTING(      0x0020, DEF_STR( 1C_2C ) )
+    PORT_DIPNAME( 0x00c0, 0x00c0, DEF_STR( Coin_B ) )
+    PORT_DIPSETTING(      0x0040, DEF_STR( 2C_1C ) )
+    PORT_DIPSETTING(      0x00c0, DEF_STR( 1C_1C ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )
+    PORT_DIPSETTING(      0x0080, DEF_STR( 1C_2C ) )
+    */
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_4WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_4WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_4WAY PORT_PLAYER(1)
@@ -451,17 +451,17 @@ INPUT_PORTS_START( galpanib )
 	PORT_DIPSETTING(      0x0008, "Mode 1" )
 	PORT_DIPSETTING(      0x0000, "Mode 2" )
 	/* Coinage - Japan (0x03ffff.b = 01)
-	PORT_DIPNAME( 0x0030, 0x0030, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(      0x0010, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x0030, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(      0x0020, DEF_STR( 1C_2C ) )
-	PORT_DIPNAME( 0x00c0, 0x00c0, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(      0x0040, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x00c0, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(      0x0080, DEF_STR( 1C_2C ) )
-	*/
+    PORT_DIPNAME( 0x0030, 0x0030, DEF_STR( Coin_A ) )
+    PORT_DIPSETTING(      0x0010, DEF_STR( 2C_1C ) )
+    PORT_DIPSETTING(      0x0030, DEF_STR( 1C_1C ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )
+    PORT_DIPSETTING(      0x0020, DEF_STR( 1C_2C ) )
+    PORT_DIPNAME( 0x00c0, 0x00c0, DEF_STR( Coin_B ) )
+    PORT_DIPSETTING(      0x0040, DEF_STR( 2C_1C ) )
+    PORT_DIPSETTING(      0x00c0, DEF_STR( 1C_1C ) )
+    PORT_DIPSETTING(      0x0000, DEF_STR( 2C_3C ) )
+    PORT_DIPSETTING(      0x0080, DEF_STR( 1C_2C ) )
+    */
 	/* Coinage - US (0x03ffff.b = 02) and World (0x03ffff.b = 03) */
 	COMMON_COIN0
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_4WAY PORT_PLAYER(1)
@@ -750,14 +750,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct OKIM6295interface okim6295_interface =
-{
-	1,                  /* 1 chip */
-	{ 12000 },          /* 12000Hz frequency */
-	{ REGION_SOUND1 },  /* memory region */
-	{ 100 }
-};
-
 static MACHINE_DRIVER_START( galpanic )
 
 	/* basic machine hardware */
@@ -781,7 +773,11 @@ static MACHINE_DRIVER_START( galpanic )
 	MDRV_VIDEO_UPDATE(galpanic)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD_TAG("oki", OKIM6295, 12000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -843,6 +839,11 @@ static MACHINE_DRIVER_START( galhustl )
 
 	/* video hardware */
 	MDRV_VIDEO_UPDATE(comad)
+
+	/* sound hardware */
+	MDRV_SOUND_REPLACE("oki", OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /***************************************************************************
