@@ -68,6 +68,7 @@ TODO:
 #include "vidhrdw/generic.h"
 #include "machine/6532riot.h"
 #include "machine/6522via.h"
+#include "sound/ay8910.h"
 
 
 /***************************************************************************
@@ -142,8 +143,8 @@ static void via_irq_delayed(int state)
 static void via_irq(int state)
 {
 	/* Kaos sits in a tight loop polling the VIA irq flags register, but that register is
-	   cleared by the irq handler. Therefore, I wait a bit before triggering the irq to
-	   leave time for the program to see the flag change. */
+       cleared by the irq handler. Therefore, I wait a bit before triggering the irq to
+       leave time for the program to see the flag change. */
 	timer_set(TIME_IN_USEC(50), state, via_irq_delayed);
 }
 
@@ -933,13 +934,8 @@ static PALETTE_INIT( gameplan )
 
 static struct AY8910interface ay8910_interface =
 {
-	1,	/* 1 chips */
-	3579000 / 2,	/* 1.7895 MHz */
-	{ 50 },
-	{ input_port_6_r },
-	{ input_port_7_r },
-	{ 0 },
-	{ 0 }
+	input_port_6_r,
+	input_port_7_r,
 };
 
 
@@ -951,7 +947,7 @@ static MACHINE_DRIVER_START( gameplan )
 	MDRV_CPU_VBLANK_INT(gameplan_interrupt,1)
 
 	MDRV_CPU_ADD(M6502,3579000 / 4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* 894.750 kHz */
+	/* audio CPU */		/* 894.750 kHz */
 	MDRV_CPU_PROGRAM_MAP(readmem_snd,writemem_snd)
 
 	MDRV_FRAMES_PER_SECOND(57)
@@ -971,7 +967,12 @@ static MACHINE_DRIVER_START( gameplan )
 	MDRV_VIDEO_START(generic_bitmapped)
 	MDRV_VIDEO_UPDATE(generic_bitmapped)
 
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	/* sound hardware */
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 3579000 / 2)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
