@@ -3,7 +3,7 @@
 Gangbusters(GX878) (c) 1988 Konami
 
 Preliminary driver by:
-	Manuel Abadia <manu@teleline.es>
+    Manuel Abadia <manu@teleline.es>
 
 ***************************************************************************/
 
@@ -11,6 +11,8 @@ Preliminary driver by:
 #include "vidhrdw/generic.h"
 #include "cpu/konami/konami.h" /* for the callback and the firq irq definition */
 #include "vidhrdw/konamiic.h"
+#include "sound/2151intf.h"
+#include "sound/k007232.h"
 
 /* prototypes */
 static MACHINE_INIT( gbusters );
@@ -82,7 +84,7 @@ static WRITE8_HANDLER( gbusters_coin_counter_w )
 		char baf[40];
 		logerror("%04x: (ccount) write %02x\n",activecpu_get_pc(), data);
 		sprintf(baf,"ccnt = %02x", data);
-/*		usrintf_showmessage(baf); */
+/*      usrintf_showmessage(baf); */
 	}
 }
 
@@ -93,7 +95,7 @@ static WRITE8_HANDLER( gbusters_unknown_w )
 {
 char baf[40];
 	sprintf(baf,"??? = %02x", data);
-/*	usrintf_showmessage(baf); */
+/*  usrintf_showmessage(baf); */
 }
 }
 
@@ -164,7 +166,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************
 
-	Input Ports
+    Input Ports
 
 ***************************************************************************/
 
@@ -203,7 +205,7 @@ INPUT_PORTS_START( gbusters )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )
@@ -276,7 +278,7 @@ INPUT_PORTS_END
 
 /***************************************************************************
 
-	Machine Driver
+    Machine Driver
 
 ***************************************************************************/
 
@@ -288,20 +290,8 @@ static void volume_callback(int v)
 
 static struct K007232_interface k007232_interface =
 {
-	1,		/* number of chips */
-	3579545,	/* clock */
-	{ REGION_SOUND1 },	/* memory regions */
-	{ K007232_VOL(30,MIXER_PAN_CENTER,30,MIXER_PAN_CENTER) },	/* volume */
-	{ volume_callback }	/* external port callback */
-};
-
-static struct YM2151interface ym2151_interface =
-{
-	1, /* 1 chip */
-	3579545, /* 3.579545 MHz */
-	{ YM3012_VOL(60,MIXER_PAN_LEFT,60,MIXER_PAN_RIGHT) },
-	{ 0 },
-	{ 0 }
+	REGION_SOUND1,	/* memory regions */
+	volume_callback	/* external port callback */
 };
 
 static MACHINE_DRIVER_START( gbusters )
@@ -312,7 +302,7 @@ static MACHINE_DRIVER_START( gbusters )
 	MDRV_CPU_VBLANK_INT(gbusters_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* ? */
+	/* audio CPU */		/* ? */
 	MDRV_CPU_PROGRAM_MAP(gbusters_readmem_sound,gbusters_writemem_sound)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -330,8 +320,16 @@ static MACHINE_DRIVER_START( gbusters )
 	MDRV_VIDEO_UPDATE(gbusters)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(K007232, k007232_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_ROUTE(0, "mono", 0.60)
+	MDRV_SOUND_ROUTE(1, "mono", 0.60)
+
+	MDRV_SOUND_ADD(K007232, 3579545)
+	MDRV_SOUND_CONFIG(k007232_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.30)
+	MDRV_SOUND_ROUTE(1, "mono", 0.30)
 MACHINE_DRIVER_END
 
 
