@@ -19,6 +19,7 @@ Notes:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2203intf.h"
 
 VIDEO_START( goindol );
 WRITE8_HANDLER( goindol_fg_videoram_w );
@@ -202,7 +203,7 @@ GOINDOL_INPUT_BITS
 	PORT_DIPSETTING(    0x01, "4" )
 	PORT_DIPSETTING(    0x00, "5" )
 	PORT_DIPNAME( 0x1c, 0x0c, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x1c, "Easiest" )
+	PORT_DIPSETTING(    0x1c, DEF_STR( Easiest ) )
 	PORT_DIPSETTING(    0x18, "Very Very Easy" )
 	PORT_DIPSETTING(    0x14, DEF_STR( Very_Easy) )
 	PORT_DIPSETTING(    0x10, DEF_STR( Easy ) )
@@ -217,7 +218,7 @@ GOINDOL_INPUT_BITS
 	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
-	
+
 GOINDOL_DSW1
 INPUT_PORTS_END
 
@@ -231,7 +232,7 @@ GOINDOL_INPUT_BITS
 	PORT_DIPSETTING(    0x01, "4" )
 	PORT_DIPSETTING(    0x00, "5" )
 	PORT_DIPNAME( 0x1c, 0x0c, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x1c, "Easiest" )
+	PORT_DIPSETTING(    0x1c, DEF_STR( Easiest ) )
 	PORT_DIPSETTING(    0x18, "Very Very Easy" )
 	PORT_DIPSETTING(    0x14, DEF_STR( Very_Easy) )
 	PORT_DIPSETTING(    0x10, DEF_STR( Easy ) )
@@ -270,18 +271,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct YM2203interface ym2203_interface =
-{
-	1,		/* 1 chip */
-	2000000,	/* 2 MHz (?) */
-	{ YM2203_VOL(25,25) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
 
 static MACHINE_DRIVER_START( goindol )
 
@@ -291,7 +280,7 @@ static MACHINE_DRIVER_START( goindol )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 4 MHz (?) */
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
 
@@ -310,7 +299,10 @@ static MACHINE_DRIVER_START( goindol )
 	MDRV_VIDEO_UPDATE(goindol)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -434,12 +426,12 @@ DRIVER_INIT( goindol )
 	rom[0x1964] = 0x00; /* ROM 9 error (MCU?) */
 	rom[0x1965] = 0x00; /* */
 	rom[0x1966] = 0x00; /* */
-/*	rom[0x17c7] = 0x00;	// c421 == 3f */
-/*	rom[0x17c8] = 0x00;	// */
-/*	rom[0x16f0] = 0x18;	// c425 == 06 */
-/*	rom[0x172c] = 0x18;	// c423 == 06 */
-/*	rom[0x1779] = 0x00;	// c419 == 5b 3f 6d */
-/*	rom[0x177a] = 0x00;	// */
+/*  rom[0x17c7] = 0x00; // c421 == 3f */
+/*  rom[0x17c8] = 0x00; // */
+/*  rom[0x16f0] = 0x18; // c425 == 06 */
+/*  rom[0x172c] = 0x18; // c423 == 06 */
+/*  rom[0x1779] = 0x00; // c419 == 5b 3f 6d */
+/*  rom[0x177a] = 0x00; // */
 	rom[0x063f] = 0x18;	/*->fc55 */
 	rom[0x0b30] = 0x00;	/* verify code at 0601-064b */
 	rom[0x1bdf] = 0x18;	/*->fc49 */
