@@ -6,8 +6,8 @@ driver by Nicola Salmoria
 
 Yam! Yam!? runs on the same hardware but has a protection device which can
            access RAM at e000. Program writes to e000 and expects a value back
-		   at e001, then jumps to subroutines at e010 and e020. Also, the
-		   player and coin inputs appear magically at e004-e006.
+           at e001, then jumps to subroutines at e010 and e020. Also, the
+           player and coin inputs appear magically at e004-e006.
 
 0000-7fff ROM
 8000-bfff ROM (banked)
@@ -47,6 +47,7 @@ Runs in interrupt mode 0, the interrupt vectors are 0xcf (RST 08h) and
 ***************************************************************************/
 
 #include "driver.h"
+#include "sound/2203intf.h"
 
 
 extern unsigned char *gundealr_bg_videoram,*gundealr_fg_videoram;
@@ -104,12 +105,12 @@ logerror("e000 = %02x\n",RAM[0xe000]);
 	if (data == 0x03)
 	{
 		/*
-		read dip switches
-		3a 00 c0  ld   a,($c000)
-		47        ld   b,a
-		3a 01 c0  ld   a,($c001)
-		c9        ret
-		*/
+        read dip switches
+        3a 00 c0  ld   a,($c000)
+        47        ld   b,a
+        3a 01 c0  ld   a,($c001)
+        c9        ret
+        */
 		RAM[0xe010] = 0x3a;
 		RAM[0xe011] = 0x00;
 		RAM[0xe012] = 0xc0;
@@ -122,14 +123,14 @@ logerror("e000 = %02x\n",RAM[0xe000]);
 	if (data == 0x05)
 	{
 		/*
-		add a to hl
-		c5        push    bc
-		010000    ld      bc,#0000
-		4f        ld      c,a
-		09        add     hl,bc
-		c1        pop     bc
-		c9        ret
-		*/
+        add a to hl
+        c5        push    bc
+        010000    ld      bc,#0000
+        4f        ld      c,a
+        09        add     hl,bc
+        c1        pop     bc
+        c9        ret
+        */
 		RAM[0xe020] = 0xc5;
 		RAM[0xe021] = 0x01;
 		RAM[0xe022] = 0x00;
@@ -139,11 +140,11 @@ logerror("e000 = %02x\n",RAM[0xe000]);
 		RAM[0xe026] = 0xc1;
 		RAM[0xe027] = 0xc9;
 		/*
-		lookup data in table
-		cd20e0    call    #e020
-		7e        ld      a,(hl)
-		c9        ret
-		*/
+        lookup data in table
+        cd20e0    call    #e020
+        7e        ld      a,(hl)
+        c9        ret
+        */
 		RAM[0xe010] = 0xcd;
 		RAM[0xe011] = 0x20;
 		RAM[0xe012] = 0xe0;
@@ -178,10 +179,12 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x01, 0x01) AM_READ(YM2203_read_port_0_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM2203_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM2203_write_port_0_w)
 ADDRESS_MAP_END
@@ -383,18 +386,18 @@ INPUT_PORTS_START( yamyam )
 	PORT_DIPSETTING(    0x06, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x05, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 2C_1C ) )
-/*	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPNAME( 0x38, 0x00, DEF_STR( Coin_B ) )
 	PORT_DIPSETTING(    0x38, DEF_STR( 5C_1C ) )
 	PORT_DIPSETTING(    0x30, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x28, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( 2C_1C ) )
-/*	PORT_DIPSETTING(    0x18, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x10, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x08, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x18, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x10, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x08, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Free_Play ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
@@ -467,18 +470,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct YM2203interface ym2203_interface =
-{
-	1,			/* 1 chip */
-	1500000,	/* 1.5 MHz ?????? */
-	{ YM2203_VOL(25,25) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
 
 static MACHINE_DRIVER_START( gundealr )
 
@@ -502,7 +493,10 @@ static MACHINE_DRIVER_START( gundealr )
 	MDRV_VIDEO_UPDATE(gundealr)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
