@@ -1,16 +1,16 @@
 /***************************************************************************
 
-	Gun.Smoke
-	Capcom
+    Gun.Smoke
+    Capcom
 
-	driver by Paul Leaman
+    driver by Paul Leaman
+
+    Games supported:
+        * Gun.Smoke (World)
+        * Gun.Smoke (Japan)
+        * Gun.Smoke (US set 1)
+        * Gun.Smoke (US set 2)
 
-	Games supported:
-		* Gun.Smoke (World)
-		* Gun.Smoke (Japan)
-		* Gun.Smoke (US set 1)
-		* Gun.Smoke (US set 2)
-		
 ****************************************************************************
 
   GUNSMOKE
@@ -68,6 +68,7 @@ Stephh's notes (based on the games Z80 code and some tests) :
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2203intf.h"
 
 extern UINT8 *gunsmoke_scrollx;
 extern UINT8 *gunsmoke_scrolly;
@@ -86,18 +87,18 @@ extern VIDEO_UPDATE( gunsmoke );
 static READ8_HANDLER( gunsmoke_protection_r )
 {
     /*
-	    The routine at 0x0e69 tries to read data starting at 0xc4c9.
-	    If this value is zero, it interprets the next two bytes as a
-	    jump address.
-	
-	    This was resulting in a reboot which happens at the end of level 3
-	    if you go too far to the right of the screen when fighting the level boss.
-	
-	    A non-zero for the first byte seems to be harmless  
-	    (although it may not be the correct behaviour).
-	
-	    This could be some devious protection or it could be a bug in the
-	    arcade game.  It's hard to tell without pulling the code apart.
+        The routine at 0x0e69 tries to read data starting at 0xc4c9.
+        If this value is zero, it interprets the next two bytes as a
+        jump address.
+
+        This was resulting in a reboot which happens at the end of level 3
+        if you go too far to the right of the screen when fighting the level boss.
+
+        A non-zero for the first byte seems to be harmless
+        (although it may not be the correct behaviour).
+
+        This could be some devious protection or it could be a bug in the
+        arcade game.  It's hard to tell without pulling the code apart.
     */
 
 	static int gunsmoke_fixed_data[] = { 0xff, 0x00, 0x00 };
@@ -283,19 +284,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 	{ -1 }
 };
 
-/* Sound Interfaces */
-
-static struct YM2203interface ym2203_interface =
-{
-	2,			/* 2 chips */
-	1500000,	/* 1.5 MHz */
-	{ YM2203_VOL(14,22), YM2203_VOL(14,22) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 /* Machine Driver */
 
 static MACHINE_DRIVER_START( gunsmoke )
@@ -305,7 +293,7 @@ static MACHINE_DRIVER_START( gunsmoke )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
 
 	MDRV_CPU_ADD(Z80, 3000000)	/* 3 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_map, 0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 4)
 
@@ -325,7 +313,19 @@ static MACHINE_DRIVER_START( gunsmoke )
 	MDRV_VIDEO_UPDATE(gunsmoke)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("ym2203", YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.22)
+	MDRV_SOUND_ROUTE(1, "mono", 0.22)
+	MDRV_SOUND_ROUTE(2, "mono", 0.22)
+	MDRV_SOUND_ROUTE(3, "mono", 0.14)
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.22)
+	MDRV_SOUND_ROUTE(1, "mono", 0.22)
+	MDRV_SOUND_ROUTE(2, "mono", 0.22)
+	MDRV_SOUND_ROUTE(3, "mono", 0.14)
 MACHINE_DRIVER_END
 
 /* ROMs */
