@@ -58,6 +58,8 @@ and 1 SFX channel controlled by an 8039:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/i8039/i8039.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
 
 
 void konami1_decode_cpu2(void);
@@ -144,6 +146,7 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x01, 0x01) AM_READ(AY8910_read_port_0_r)
   	AM_RANGE(0x05, 0x05) AM_READ(AY8910_read_port_1_r)
 	AM_RANGE(0x09, 0x09) AM_READ(AY8910_read_port_2_r)
@@ -152,6 +155,7 @@ static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x04, 0x04) AM_WRITE(AY8910_control_port_1_w)
@@ -351,24 +355,25 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct AY8910interface ay8910_interface =
+static struct AY8910interface ay8910_interface_1 =
 {
-	5,	/* 5 chips */
-	14318180/8,	/* 1.789772727 MHz */
-	{ MIXERG(10,MIXER_GAIN_4x,MIXER_PAN_RIGHT), MIXERG(10,MIXER_GAIN_4x,MIXER_PAN_LEFT),
-			MIXERG(20,MIXER_GAIN_4x,MIXER_PAN_RIGHT), MIXERG(20,MIXER_GAIN_4x,MIXER_PAN_RIGHT), MIXERG(20,MIXER_GAIN_4x,MIXER_PAN_LEFT) },
-	/*  R       L   |   R       R       L */
-	/*   effects    |         music       */
-	{ 0, 0, gyruss_portA_r },
-	{ 0 },
-	{ 0 },
-	{ gyruss_filter0_w, gyruss_filter1_w }
+	0,
+	0,
+	0,
+	gyruss_filter0_w
 };
 
-static struct DACinterface dac_interface =
+static struct AY8910interface ay8910_interface_2 =
 {
-	1,
-	{ MIXER(50,MIXER_PAN_LEFT) }
+	0,
+	0,
+	0,
+	gyruss_filter1_w
+};
+
+static struct AY8910interface ay8910_interface_3 =
+{
+	gyruss_portA_r
 };
 
 
@@ -385,12 +390,12 @@ static MACHINE_DRIVER_START( gyruss )
 	MDRV_CPU_VBLANK_INT(gyruss_6809_interrupt,256)
 
 	MDRV_CPU_ADD(Z80,14318180/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 3.579545 MHz */
+	/* audio CPU */	/* 3.579545 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 
 	MDRV_CPU_ADD(I8039,8000000/15)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 8MHz crystal */
+	/* audio CPU */	/* 8MHz crystal */
 	MDRV_CPU_PROGRAM_MAP(i8039_readmem,i8039_writemem)
 	MDRV_CPU_IO_MAP(i8039_readport,i8039_writeport)
 
@@ -410,9 +415,46 @@ static MACHINE_DRIVER_START( gyruss )
 	MDRV_VIDEO_UPDATE(gyruss)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(AY8910, 14318180/8)
+	MDRV_SOUND_CONFIG(ay8910_interface_1)
+	MDRV_SOUND_ROUTE(0, "filter.0.0", 0.22)
+	MDRV_SOUND_ROUTE(1, "filter.0.1", 0.22)
+	MDRV_SOUND_ROUTE(2, "filter.0.2", 0.22)
+
+	MDRV_SOUND_ADD(AY8910, 14318180/8)
+	MDRV_SOUND_CONFIG(ay8910_interface_2)
+	MDRV_SOUND_ROUTE(0, "filter.1.0", 0.22)
+	MDRV_SOUND_ROUTE(1, "filter.1.1", 0.22)
+	MDRV_SOUND_ROUTE(2, "filter.1.2", 0.22)
+
+	MDRV_SOUND_ADD(AY8910, 14318180/8)
+	MDRV_SOUND_CONFIG(ay8910_interface_3)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.44)
+
+	MDRV_SOUND_ADD(AY8910, 14318180/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.44)
+
+	MDRV_SOUND_ADD(AY8910, 14318180/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.44)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.28)
+
+	MDRV_SOUND_ADD_TAG("filter.0.0", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.0.1", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.0.2", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD_TAG("filter.1.0", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.1.1", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.1.2", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
 MACHINE_DRIVER_END
 
 
