@@ -21,7 +21,7 @@ d001      AY8910 write
 d008      bit0/1 = flip screen x/y
           bit 4 = ROM bank??
           bit 5 = char bank
-		  other bits????????
+          other bits????????
 d010      watchdog reset, or IRQ acknowledge, or both
 f000      ????????
 
@@ -33,6 +33,7 @@ NOTES:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
 
 
 
@@ -124,13 +125,8 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 static struct AY8910interface ay8910_interface =
 {
-	1,	/* 1 chip */
-	1500000,	/* 1.5 MHz ???? */
-	{ 50 },
-	{ input_port_0_r },
-	{ input_port_1_r },
-	{ 0 },
-	{ 0 }
+	input_port_0_r,
+	input_port_1_r,
 };
 
 
@@ -157,7 +153,10 @@ static MACHINE_DRIVER_START( hexa )
 	MDRV_VIDEO_UPDATE(hexa)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
