@@ -87,7 +87,7 @@ Board:  A77-PWB-A-(A)
 CPU:    68B09E Z80-A
 Sound:  SN76489AN DAC
 OSC:    9.000MHz 16.000MHz
-Custom:	GX61A01
+Custom: GX61A01
 
 ----------------------------------------------------------------------------
 Mahjong Hourouki Gaiden
@@ -98,7 +98,7 @@ Board:  A77-PWB-A-(A)
 CPU:    68B09E Z80-A
 Sound:  SN76489AN DAC
 OSC:    9.000MHz 16.000MHz
-Custom:	GX61A01
+Custom: GX61A01
 
 ----------------------------------------------------------------------------
 Mahjong Hourouki Okite
@@ -221,7 +221,9 @@ Custom: GX61A01
 #include "cpu/m6809/m6809.h"
 #include "cpu/upd7810/upd7810.h"
 #include "homedata.h"
-
+#include "sound/dac.h"
+#include "sound/2203intf.h"
+#include "sound/sn76496.h"
 
 
 /********************************************************************************/
@@ -271,9 +273,9 @@ static READ8_HANDLER( mrokumei_keyboard_r )
 	if (offset == 0)
 	{
 		/* bit 7: visible page
-		 * bit 6: vblank
-		 * other bits are inputs
-		 */
+         * bit 6: vblank
+         * other bits are inputs
+         */
 		res |= homedata_visible_page << 7;
 
 		if (vblank) res |= 0x40;
@@ -304,8 +306,8 @@ static READ8_HANDLER( mrokumei_sound_io_r )
 static WRITE8_HANDLER( mrokumei_sound_bank_w )
 {
 	/* bit 0 = ROM bank
-	   bit 2 = ROM or soundlatch
-	 */
+       bit 2 = ROM or soundlatch
+     */
 	sndbank = data;
 }
 
@@ -352,16 +354,16 @@ static WRITE8_HANDLER( reikaids_upd7807_porta_w )
 static WRITE8_HANDLER( reikaids_upd7807_portc_w )
 {
 	/* port C layout:
-	   7 coin counter
-	   6 to main CPU (data)
-	   5 YM2203 write clock
-	   4 YM2203 read clock
-	   3 YM2203 address (0 = register select 1 = data)
-	   2 to main CPU (status)
-	   1 \ ROM bank
-	   0 /
-	  */
-/*	logerror("%04x: port C wr %02x (STATUS %d DATA %d)\n",activecpu_get_pc(),data,BIT(data,2),BIT(data,6)); */
+       7 coin counter
+       6 to main CPU (data)
+       5 YM2203 write clock
+       4 YM2203 read clock
+       3 YM2203 address (0 = register select 1 = data)
+       2 to main CPU (status)
+       1 \ ROM bank
+       0 /
+      */
+/*  logerror("%04x: port C wr %02x (STATUS %d DATA %d)\n",activecpu_get_pc(),data,BIT(data,2),BIT(data,6)); */
 
 
 	cpu_setbank(2,memory_region(REGION_CPU2) + 0x10000 * (data & 0x03));
@@ -451,9 +453,9 @@ static READ8_HANDLER( pteacher_snd_r )
 static READ8_HANDLER( pteacher_io_r )
 {
 	/* bit 6: !vblank
-	 * bit 7: visible page
-	 * other bits seem unused
-	 */
+     * bit 7: visible page
+     * other bits seem unused
+     */
 
 	int res = (homedata_visible_page ^ 1) << 7;
 
@@ -468,7 +470,7 @@ static READ8_HANDLER( pteacher_keyboard_r )
 {
 	int dips = readinputport(0);
 
-/*	logerror("%04x: keyboard_r with port A = %02x\n",activecpu_get_pc(),upd7807_porta); */
+/*  logerror("%04x: keyboard_r with port A = %02x\n",activecpu_get_pc(),upd7807_porta); */
 
 	if (upd7807_porta & 0x80)
 	{
@@ -510,17 +512,17 @@ static WRITE8_HANDLER( pteacher_upd7807_porta_w )
 static WRITE8_HANDLER( pteacher_upd7807_portc_w )
 {
 	/* port C layout:
-	   7 coin counter
-	   6 enable message from main CPU on port A
-	   5 clock latch for 76489 command
-	   4
-	   3 \ ROM bank
-	   2 /
-	   1 input (service)
-	   0 input (coin)
-	  */
+       7 coin counter
+       6 enable message from main CPU on port A
+       5 clock latch for 76489 command
+       4
+       3 \ ROM bank
+       2 /
+       1 input (service)
+       0 input (coin)
+      */
 
-/*	logerror("%04x: port C wr %02x\n",activecpu_get_pc(),data); */
+/*  logerror("%04x: port C wr %02x\n",activecpu_get_pc(),data); */
 
 	cpu_setbank(2,memory_region(REGION_CPU2) + 0x10000 * ((data & 0x0c) >> 2));
 
@@ -784,34 +786,34 @@ INPUT_PORTS_START( mjhokite )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("A") PORT_CODE(KEYCODE_A)
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("E") PORT_CODE(KEYCODE_E)
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("I") PORT_CODE(KEYCODE_I)
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("M") PORT_CODE(KEYCODE_M)
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Kan") PORT_CODE(KEYCODE_LCONTROL)
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_A )
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_E )
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_I )
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_M )
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_MAHJONG_KAN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1                              )
 
 	PORT_START
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("B") PORT_CODE(KEYCODE_B)
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("F") PORT_CODE(KEYCODE_F)
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("J") PORT_CODE(KEYCODE_J)
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("N") PORT_CODE(KEYCODE_N)
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Reach") PORT_CODE(KEYCODE_LSHIFT)
-	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Bet") PORT_CODE(KEYCODE_RCONTROL)
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_B )
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_F )
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_J )
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_N )
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_MAHJONG_REACH )
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_MAHJONG_BET )
 
 	PORT_START
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("C") PORT_CODE(KEYCODE_C)
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("G") PORT_CODE(KEYCODE_G)
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("K") PORT_CODE(KEYCODE_K)
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Chi") PORT_CODE(KEYCODE_SPACE)
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Ron") PORT_CODE(KEYCODE_Z)
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_C )
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_G )
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_K )
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_CHI )
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_MAHJONG_RON )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("D") PORT_CODE(KEYCODE_D)
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("H") PORT_CODE(KEYCODE_H)
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("L") PORT_CODE(KEYCODE_L)
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Pon") PORT_CODE(KEYCODE_LALT)
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_D )
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_H )
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_L )
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_PON )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
@@ -819,7 +821,7 @@ INPUT_PORTS_START( mjhokite )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Flip") PORT_CODE(KEYCODE_X)
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_FLIP_FLOP )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
@@ -980,45 +982,45 @@ INPUT_PORTS_END
 
 #define MJ_KEYBOARD																				\
 	PORT_START																					\
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("A") PORT_CODE(KEYCODE_A)					\
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("B") PORT_CODE(KEYCODE_B)					\
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("C") PORT_CODE(KEYCODE_C)					\
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("D") PORT_CODE(KEYCODE_D)					\
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_A ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_B ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_C ) \
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_D ) \
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )												\
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* dip switch (handled separately */		\
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )													\
 																								\
 	PORT_START																					\
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("E") PORT_CODE(KEYCODE_E)					\
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("F") PORT_CODE(KEYCODE_F)					\
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("G") PORT_CODE(KEYCODE_G)					\
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("H") PORT_CODE(KEYCODE_H)					\
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_E ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_F ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_G ) \
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_H ) \
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )												\
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* dip switch (handled separately */		\
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )													\
 																								\
 	PORT_START																					\
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("I") PORT_CODE(KEYCODE_I)					\
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("J") PORT_CODE(KEYCODE_J)					\
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("K") PORT_CODE(KEYCODE_K)					\
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("L") PORT_CODE(KEYCODE_L)					\
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_I ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_J ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_K ) \
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_L ) \
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )												\
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* dip switch (handled separately */		\
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )													\
 																								\
 	PORT_START																					\
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("M") PORT_CODE(KEYCODE_M)					\
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("N") PORT_CODE(KEYCODE_N)					\
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Chi") PORT_CODE(KEYCODE_SPACE)						\
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Pon") PORT_CODE(KEYCODE_LALT)						\
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Flip") PORT_CODE(KEYCODE_X)					\
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_M ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_N ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_CHI ) \
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_MAHJONG_PON ) \
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_MAHJONG_FLIP_FLOP ) \
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* dip switch (handled separately */		\
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )													\
 																								\
 	PORT_START																					\
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Kan") PORT_CODE(KEYCODE_LCONTROL)					\
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Reach") PORT_CODE(KEYCODE_LSHIFT)					\
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Ron") PORT_CODE(KEYCODE_Z)						\
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_KAN ) \
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_REACH ) \
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_RON ) \
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )												\
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )												\
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* dip switch (handled separately */		\
@@ -1026,7 +1028,7 @@ INPUT_PORTS_END
 																								\
 	PORT_START																					\
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )													\
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Bet") PORT_CODE(KEYCODE_RCONTROL)					\
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_BET ) \
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )												\
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )												\
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )												\
@@ -1254,20 +1256,6 @@ static struct GfxDecodeInfo lemnangl_gfxdecodeinfo[] =
 
 
 
-static struct SN76496interface sn76496_interface =
-{
-	1,
-	{ 16000000/4 },	 /* 4MHz ? */
-	{ 50 }
-};
-
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 100 }
-};
-
-
 static MACHINE_DRIVER_START( mrokumei )
 
 	/* basic machine hardware */
@@ -1276,7 +1264,7 @@ static MACHINE_DRIVER_START( mrokumei )
 	MDRV_CPU_VBLANK_INT(homedata_irq,1)	/* also triggered by the blitter */
 
 	MDRV_CPU_ADD(Z80, 16000000/4)	/* 4MHz ? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU | CPU_16BIT_PORT)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(mrokumei_sound_readmem,mrokumei_sound_writemem)
 	MDRV_CPU_IO_MAP(mrokumei_sound_readport,mrokumei_sound_writeport)
 
@@ -1297,8 +1285,13 @@ static MACHINE_DRIVER_START( mrokumei )
 	MDRV_VIDEO_EOF(homedata)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)	/* SN76489 actually */
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 16000000/4)	/* SN76489 actually */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1307,21 +1300,8 @@ MACHINE_DRIVER_END
 
 static struct YM2203interface ym2203_interface =
 {
-	1,
-	3000000,	/* ? */
-	{ YM2203_VOL(100,25) },
-	{ input_port_3_r },
-	{ input_port_4_r },
-	{ 0	},
-	{ 0 },
-	{ NULL }
-};
-
-
-static struct DACinterface reikaids_dac_interface =
-{
-	1,
-	{ 40 }
+	input_port_3_r,
+	input_port_4_r
 };
 
 
@@ -1365,8 +1345,17 @@ static MACHINE_DRIVER_START( reikaids )
 	MDRV_VIDEO_EOF(homedata)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(DAC, reikaids_dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.25)
+	MDRV_SOUND_ROUTE(1, "mono", 0.25)
+	MDRV_SOUND_ROUTE(2, "mono", 0.25)
+	MDRV_SOUND_ROUTE(3, "mono", 1.0)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 MACHINE_DRIVER_END
 
 
@@ -1406,8 +1395,13 @@ static MACHINE_DRIVER_START( pteacher )
 	MDRV_VIDEO_EOF(homedata)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)	/* SN76489 actually */
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 16000000/4)	/* SN76489 actually */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( mjkinjas )
@@ -1829,8 +1823,8 @@ ROM_END
 static DRIVER_INIT( jogakuen )
 {
 	/* it seems that Mahjong Jogakuen runs on the same board as the others,
-	   but with just these two addresses swapped. Instead of creating a new
-	   MachineDriver, I just fix them here. */
+       but with just these two addresses swapped. Instead of creating a new
+       MachineDriver, I just fix them here. */
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8007, 0x8007, 0, 0, pteacher_blitter_bank_w);
 	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8005, 0x8005, 0, 0, pteacher_gfx_bank_w);
 }
