@@ -1,14 +1,14 @@
 /******************************************************************************
 
-	Game Driver for Nichibutsu Mahjong series.
+    Game Driver for Nichibutsu Mahjong series.
 
-	Taisen Quiz HYHOO
-	(c)1987 Nihon Bussan Co.,Ltd.
+    Taisen Quiz HYHOO
+    (c)1987 Nihon Bussan Co.,Ltd.
 
-	Taisen Quiz HYHOO 2
-	(c)1987 Nihon Bussan Co.,Ltd.
+    Taisen Quiz HYHOO 2
+    (c)1987 Nihon Bussan Co.,Ltd.
 
-	Driver by Takahiro Nogi <nogi@kt.rim.or.jp> 2000/01/28 -
+    Driver by Takahiro Nogi <nogi@kt.rim.or.jp> 2000/01/28 -
 
 ******************************************************************************/
 /******************************************************************************
@@ -24,6 +24,8 @@ Memo:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "nb1413m3.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
 
 
 #define	SIGNED_DAC	0		/* 0:unsigned DAC, 1:signed DAC */
@@ -70,6 +72,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( readport_hyhoo, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x7f) AM_READ(nb1413m3_sndrom_r)
 	AM_RANGE(0x81, 0x81) AM_READ(AY8910_read_port_0_r)
 	AM_RANGE(0x90, 0x90) AM_READ(nb1413m3_inputport0_r)
@@ -82,7 +85,8 @@ static ADDRESS_MAP_START( readport_hyhoo, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport_hyhoo, ADDRESS_SPACE_IO, 8 )
-/*	AM_RANGE(0x00, 0x00) AM_WRITE(nb1413m3_nmi_clock_w) */
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+/*  AM_RANGE(0x00, 0x00) AM_WRITE(nb1413m3_nmi_clock_w) */
 	AM_RANGE(0x82, 0x82) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x83, 0x83) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x90, 0x97) AM_WRITE(hyhoo_blitter_w)
@@ -91,7 +95,7 @@ static ADDRESS_MAP_START( writeport_hyhoo, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0xc0, 0xcf) AM_WRITE(hyhoo_clut_w)
 	AM_RANGE(0xd0, 0xd0) AM_WRITE(DAC_0_WRITE)
 	AM_RANGE(0xe0, 0xe0) AM_WRITE(hyhoo_romsel_w)
-/*	AM_RANGE(0xf0, 0xf0) AM_WRITE(MWA8_NOP) */
+/*  AM_RANGE(0xf0, 0xf0) AM_WRITE(MWA8_NOP) */
 ADDRESS_MAP_END
 
 
@@ -127,9 +131,9 @@ INPUT_PORTS_START( hyhoo )
 	PORT_DIPNAME( 0x04, 0x04, "Picture Quiz" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x08, "Max Players" )
-	PORT_DIPSETTING(    0x00, "2" )
-	PORT_DIPSETTING(    0x08, "4" )
+	PORT_DIPNAME( 0x08, 0x08, "Play Mode" )
+	PORT_DIPSETTING(    0x00, "2 Players" )
+	PORT_DIPSETTING(    0x08, "4 Players" )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_DIPNAME( 0x20, 0x20, "Commemoration Medal Payout" )
 	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
@@ -259,19 +263,8 @@ INPUT_PORTS_END
 
 static struct AY8910interface ay8910_interface =
 {
-	1,								/* 1 chip */
-	1250000,						/* 1.25 MHz ?? */
-	{ 35 },
-	{ input_port_0_r },				/* DIPSW-A read */
-	{ input_port_1_r },				/* DIPSW-B read */
-	{ 0 },
-	{ 0 }
-};
-
-static struct DACinterface dac_interface =
-{
-	1,								/* 1 channels */
-	{ 50 }
+	input_port_0_r,				/* DIPSW-A read */
+	input_port_1_r				/* DIPSW-B read */
 };
 
 
@@ -301,8 +294,14 @@ static MACHINE_DRIVER_START( hyhoo )
 	MDRV_VIDEO_UPDATE(hyhoo)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1250000)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.35)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
