@@ -7,6 +7,8 @@ Based on drivers from Juno First emulator by Chris Hardy (chrish@kcbbs.gen.nz)
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
+#include "sound/vlm5030.h"
+#include "sound/dac.h"
 
 
 extern void konami1_decode(void);
@@ -28,9 +30,6 @@ extern READ8_HANDLER( hyperspt_sh_timer_r );
 extern WRITE8_HANDLER( hyperspt_sound_w );
 
 /* these routines lurk in sndhrdw/trackfld.c */
-extern struct VLM5030interface konami_vlm5030_interface;
-extern struct SN76496interface konami_sn76496_interface;
-extern struct DACinterface konami_dac_interface;
 extern WRITE8_HANDLER( konami_SN76496_latch_w );
 extern WRITE8_HANDLER( konami_SN76496_0_w );
 
@@ -138,7 +137,7 @@ static ADDRESS_MAP_START( hyperspt_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x1000, 0x10ff) AM_READ(MRA8_RAM)
 	AM_RANGE(0x1600, 0x1600) AM_READ(input_port_4_r) /* DIP 2 */
 	AM_RANGE(0x1680, 0x1680) AM_READ(input_port_0_r) /* IO Coin */
-/*	AM_RANGE(0x1681, 0x1681) AM_READ(input_port_1_r)    P1 IO    */
+/*  AM_RANGE(0x1681, 0x1681) AM_READ(input_port_1_r)    P1 IO    */
 	AM_RANGE(0x1681, 0x1681) AM_READ(konami_IN1_r) /* P1 IO and handle fake button for cheating */
 	AM_RANGE(0x1682, 0x1682) AM_READ(input_port_2_r) /* P2 IO */
 	AM_RANGE(0x1683, 0x1683) AM_READ(input_port_3_r) /* DIP 1 */
@@ -211,7 +210,7 @@ INPUT_PORTS_START( hyperspt )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-/*	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN ) */
+/*  PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN ) */
 	/* Fake button to press buttons 1 and 3 impossibly fast. Handle via konami_IN1_r */
 	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_NAME("Run Like Hell (Cheat)") PORT_PLAYER(1)
 
@@ -220,7 +219,7 @@ INPUT_PORTS_START( hyperspt )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2  ) PORT_PLAYER(3) /*PORT_COCKTAIL  before the system changed. */
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON1  ) PORT_PLAYER(3) /*PORT_COCKTAIL  Why? */
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START4 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON3  ) PORT_PLAYER(4) /*PORT_COCKTAIL  */
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON3  ) PORT_PLAYER(4) /*PORT_COCKTAIL */
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2  ) PORT_PLAYER(4) /*PORT_COCKTAIL */
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1  ) PORT_PLAYER(4) /*PORT_COCKTAIL */
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -458,10 +457,8 @@ static struct GfxDecodeInfo roadf_gfxdecodeinfo[] =
 
 struct VLM5030interface hyperspt_vlm5030_interface =
 {
-	3580000,	/* master clock  */
-	100,		/* volume		 */
 	REGION_SOUND1,	/* memory region  */
-	0		   /* memory size	 */
+	0		   /* memory size    */
 };
 
 
@@ -473,7 +470,7 @@ static MACHINE_DRIVER_START( hyperspt )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,14318180/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU) /* Z80 Clock is derived from a 14.31818 MHz crystal */
+	/* audio CPU */ /* Z80 Clock is derived from a 14.31818 MHz crystal */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -494,9 +491,17 @@ static MACHINE_DRIVER_START( hyperspt )
 	MDRV_VIDEO_UPDATE(hyperspt)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, konami_dac_interface)
-	MDRV_SOUND_ADD(SN76496, konami_sn76496_interface)
-	MDRV_SOUND_ADD(VLM5030, hyperspt_vlm5030_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+
+	MDRV_SOUND_ADD(SN76496, 14318180/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(VLM5030, 3580000)
+	MDRV_SOUND_CONFIG(hyperspt_vlm5030_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -548,7 +553,7 @@ ROM_START( hyperspt )
 	ROM_LOAD( "j12_c28.bin",  0x0020, 0x0100, CRC(2c891d59) SHA1(79050fbe058c24349927edc7937ec68a77f450f1) )
 	ROM_LOAD( "a09_c29.bin",  0x0120, 0x0100, CRC(811a3f3f) SHA1(474f03345847cd9791ff6b7161286bbfef3f990a) )
 
-	ROM_REGION( 0x10000, REGION_SOUND1, 0 )	/*	64k for speech rom	  */
+	ROM_REGION( 0x10000, REGION_SOUND1, 0 )	/*  64k for speech rom    */
 	ROM_LOAD( "c08",          0x0000, 0x2000, CRC(e8f8ea78) SHA1(8d37818e5a2740c96696f37996f2a3f870386690) )
 ROM_END
 
@@ -586,7 +591,7 @@ ROM_START( hpolym84 )
 	ROM_LOAD( "j12_c28.bin",  0x0020, 0x0100, CRC(2c891d59) SHA1(79050fbe058c24349927edc7937ec68a77f450f1) )
 	ROM_LOAD( "a09_c29.bin",  0x0120, 0x0100, CRC(811a3f3f) SHA1(474f03345847cd9791ff6b7161286bbfef3f990a) )
 
-	ROM_REGION( 0x10000, REGION_SOUND1, 0 )	/*	64k for speech rom	  */
+	ROM_REGION( 0x10000, REGION_SOUND1, 0 )	/*  64k for speech rom    */
 	ROM_LOAD( "c08",          0x0000, 0x2000, CRC(e8f8ea78) SHA1(8d37818e5a2740c96696f37996f2a3f870386690) )
 ROM_END
 
