@@ -22,6 +22,8 @@ sub68k is performing not only processing of sound but assistance of main68k.
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 #define RASTER_LINES 262
 #define FIRST_VISIBLE_LINE 0
@@ -48,7 +50,7 @@ VIDEO_START( hyprduel_14220 );
 VIDEO_UPDATE( hyprduel );
 
 /***************************************************************************
-								Interrupts
+                                Interrupts
 ***************************************************************************/
 
 static int blitter_bit;
@@ -204,15 +206,15 @@ MACHINE_INIT( hyprduel )
 
 
 /***************************************************************************
-								Banked ROM access
+                                Banked ROM access
 ***************************************************************************/
 
 /*
-	The main CPU has access to the ROMs that hold the graphics through
-	a banked window of 64k. Those ROMs also usually store the tables for
-	the virtual tiles set. The tile codes to be written to the tilemap
-	memory to render the backgrounds are also stored here, in a format
-	that the blitter can readily use (which is a form of compression)
+    The main CPU has access to the ROMs that hold the graphics through
+    a banked window of 64k. Those ROMs also usually store the tables for
+    the virtual tiles set. The tile codes to be written to the tilemap
+    memory to render the backgrounds are also stored here, in a format
+    that the blitter can readily use (which is a form of compression)
 */
 
 static data16_t *hyprduel_rombank;
@@ -232,45 +234,45 @@ READ16_HANDLER( hyprduel_bankedrom_r )
 
 /***************************************************************************
 
-									Blitter
+                                    Blitter
 
-	[ Registers ]
+    [ Registers ]
 
-		Offset:		Value:
+        Offset:     Value:
 
-		0.l			Destination Tilemap      (1,2,3)
-		4.l			Blitter Data Address     (byte offset into the gfx ROMs)
-		8.l			Destination Address << 7 (byte offset into the tilemap)
+        0.l         Destination Tilemap      (1,2,3)
+        4.l         Blitter Data Address     (byte offset into the gfx ROMs)
+        8.l         Destination Address << 7 (byte offset into the tilemap)
 
-		The Blitter reads a byte and looks at the most significative
-		bits for the opcode, while the remaining bits define a value
-		(usually how many bytes to write). The opcode byte may be
-		followed by a number of other bytes:
+        The Blitter reads a byte and looks at the most significative
+        bits for the opcode, while the remaining bits define a value
+        (usually how many bytes to write). The opcode byte may be
+        followed by a number of other bytes:
 
-			76------			Opcode
-			--543210			N
-			(at most N+1 bytes follow)
+            76------            Opcode
+            --543210            N
+            (at most N+1 bytes follow)
 
 
-		The blitter is designed to write every other byte (e.g. it
-		writes a byte and skips the next). Hence 2 blits are needed
-		to fill a tilemap (first even, then odd addresses)
+        The blitter is designed to write every other byte (e.g. it
+        writes a byte and skips the next). Hence 2 blits are needed
+        to fill a tilemap (first even, then odd addresses)
 
-	[ Opcodes ]
+    [ Opcodes ]
 
-			0		Copy the following N+1 bytes. If the whole byte
-					is $00:	stop and generate an IRQ
+            0       Copy the following N+1 bytes. If the whole byte
+                    is $00: stop and generate an IRQ
 
-			1		Fill N+1 bytes with a sequence, starting with
-					the  value in the following byte
+            1       Fill N+1 bytes with a sequence, starting with
+                    the  value in the following byte
 
-			2		Fill N+1 bytes with the value in the following
-					byte
+            2       Fill N+1 bytes with the value in the following
+                    byte
 
-			3		Skip N+1 bytes. If the whole byte is $C0:
-					skip to the next row of the tilemap (+0x200 bytes)
-					but preserve the column passed at the start of the
-					blit (destination address % 0x200)
+            3       Skip N+1 bytes. If the whole byte is $C0:
+                    skip to the next row of the tilemap (+0x200 bytes)
+                    but preserve the column passed at the start of the
+                    blit (destination address % 0x200)
 
 ***************************************************************************/
 
@@ -295,7 +297,7 @@ INLINE void blt_write(const int tmap, const offs_t offs, const data16_t data, co
 		case 2:	hyprduel_vram_1_w(offs,data,mask);	break;
 		case 3:	hyprduel_vram_2_w(offs,data,mask);	break;
 	}
-/*	logerror("CPU #0 PC %06X : Blitter %X] %04X <- %04X & %04X\n",activecpu_get_pc(),tmap,offs,data,mask); */
+/*  logerror("CPU #0 PC %06X : Blitter %X] %04X <- %04X & %04X\n",activecpu_get_pc(),tmap,offs,data,mask); */
 }
 
 
@@ -320,7 +322,7 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
 		int shift			=	(dst_offs & 0x80) ? 0 : 8;
 		data16_t mask		=	(dst_offs & 0x80) ? 0xff00 : 0x00ff;
 
-/*		logerror("CPU #0 PC %06X : Blitter regs %08X, %08X, %08X\n",activecpu_get_pc(),tmap,src_offs,dst_offs); */
+/*      logerror("CPU #0 PC %06X : Blitter regs %08X, %08X, %08X\n",activecpu_get_pc(),tmap,src_offs,dst_offs); */
 
 		dst_offs >>= 7+1;
 		switch( tmap )
@@ -340,7 +342,7 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
 
 			src_offs %= src_len;
 			b1 = blt_read(src,src_offs);
-/*			logerror("CPU #0 PC %06X : Blitter opcode %02X at %06X\n",activecpu_get_pc(),b1,src_offs); */
+/*          logerror("CPU #0 PC %06X : Blitter opcode %02X at %06X\n",activecpu_get_pc(),b1,src_offs); */
 			src_offs++;
 
 			count = ((~b1) & 0x3f) + 1;
@@ -350,10 +352,10 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
 				case 0:
 
 					/* Stop and Generate an IRQ. We can't generate it now
-					   both because it's unlikely that the blitter is so
-					   fast and because some games (e.g. lastfort) need to
-					   complete the blitter irq service routine before doing
-					   another blit. */
+                       both because it's unlikely that the blitter is so
+                       fast and because some games (e.g. lastfort) need to
+                       complete the blitter irq service routine before doing
+                       another blit. */
 					if (b1 == 0)
 					{
 						timer_set(TIME_IN_USEC(500),0,hyprduel_blit_done);
@@ -434,7 +436,7 @@ static WRITE16_HANDLER( hyprduel_blitter_w )
 }
 
 /***************************************************************************
-								Memory Maps
+                                Memory Maps
 ***************************************************************************/
 
 static ADDRESS_MAP_START( hyprduel_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -504,7 +506,7 @@ static ADDRESS_MAP_START( hyprduel_writemem2, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 /***************************************************************************
-								Input Ports
+                                Input Ports
 ***************************************************************************/
 
 #define JOY_LSB(_n_, _b1_, _b2_, _b3_, _b4_) \
@@ -592,7 +594,7 @@ INPUT_PORTS_START( hyprduel )
 INPUT_PORTS_END
 
 /***************************************************************************
-							Graphics Layouts
+                            Graphics Layouts
 ***************************************************************************/
 
 /* 8x8x4 tiles */
@@ -627,7 +629,7 @@ static struct GfxDecodeInfo gfxdecodeinfo_14220[] =
 };
 
 /***************************************************************************
-							Sound Communication
+                            Sound Communication
 ***************************************************************************/
 
 static void sound_irq(int state)
@@ -637,23 +639,11 @@ static void sound_irq(int state)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	4000000,	/* 4 MHz */
-	{ YM3012_VOL(80,MIXER_PAN_LEFT,80,MIXER_PAN_RIGHT) },
-	{ sound_irq },
-	{ 0 }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,
-	{ 4000000/16/16 },	/* 15625 Hz */
-	{ REGION_SOUND1 },
-	{ 57 }
+	sound_irq
 };
 
 /***************************************************************************
-								Machine Drivers
+                                Machine Drivers
 ***************************************************************************/
 
 static MACHINE_DRIVER_START( hyprduel )
@@ -682,14 +672,22 @@ static MACHINE_DRIVER_START( hyprduel )
 	MDRV_VIDEO_UPDATE(hyprduel)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 4000000)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.80)
+	MDRV_SOUND_ROUTE(1, "right", 0.80)
+
+	MDRV_SOUND_ADD(OKIM6295, 4000000/16/16)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.57)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.57)
 MACHINE_DRIVER_END
 
 
 /***************************************************************************
-								ROMs Loading
+                                ROMs Loading
 ***************************************************************************/
 
 static DRIVER_INIT( hyprduel )
@@ -698,16 +696,16 @@ static DRIVER_INIT( hyprduel )
 	data8_t *ROM = memory_region(REGION_GFX1);
 
 	/*
-	  Tiles can be either 4-bit or 8-bit, and both depths can be used at the same
-	  time. The transparent pen is the last one, that is 15 or 255. To make
-	  tilemap.c handle that, we invert gfx data so the transparent pen becomes 0
-	  for both tile depths.
-	*/
+      Tiles can be either 4-bit or 8-bit, and both depths can be used at the same
+      time. The transparent pen is the last one, that is 15 or 255. To make
+      tilemap.c handle that, we invert gfx data so the transparent pen becomes 0
+      for both tile depths.
+    */
 	for (i = 0;i < memory_region_length(REGION_GFX1);i++)
 		ROM[i] ^= 0xff;
 
-/*	ROM[(0x174b9*0x20)+0x1f] |= 0x0e;		   I    */
-/*	ROM[(0x174e9*0x20)+0x1f] |= 0x0e; */
+/*  ROM[(0x174b9*0x20)+0x1f] |= 0x0e;          I    */
+/*  ROM[(0x174e9*0x20)+0x1f] |= 0x0e; */
 
 	memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0xc00000, 0xc07fff, 0, 0, hypr_sharedram1_w);
 	memory_install_write16_handler(1, ADDRESS_SPACE_PROGRAM, 0xc00000, 0xc07fff, 0, 0, hypr_sharedram1_w);
@@ -730,10 +728,10 @@ ROM_START( hyprduel )
 	ROM_REGION( 0x8000, REGION_CPU2, 0 )
 
 	ROM_REGION( 0x400000, REGION_GFX1, 0 )	/* Gfx + Prg + Data (Addressable by CPU & Blitter) */
-	ROMX_LOAD( "hd_m1.rom", 0x000000, 0x100000, BAD_DUMP CRC(582aab46) SHA1(b94bd7aee717c5e449c9138fd82ca9a6423cd382) , ROM_GROUPWORD | ROM_SKIP(6) )	/* BAD ADDRESS LINES (mask=000100) */
-	ROMX_LOAD( "hd_m2.rom", 0x000002, 0x100000, BAD_DUMP CRC(63da509e) SHA1(b7254fab2d6d68bf52b0cdbf4e32d990420e4627) , ROM_GROUPWORD | ROM_SKIP(6) )	/* BAD ADDRESS LINES (mask=000100) */
-	ROMX_LOAD( "hd_m3.rom", 0x000004, 0x100000, BAD_DUMP CRC(4dbb5a79) SHA1(5df5cfe7ab404ec97822c3edd86728b03aeb33d1) , ROM_GROUPWORD | ROM_SKIP(6) )	/* BAD ADDRESS LINES (mask=000100) */
-	ROMX_LOAD( "hd_m4.rom", 0x000006, 0x100000, BAD_DUMP CRC(8061d5dd) SHA1(1d953ba8d85e0513683e0094eb1f5bbfda4576bf) , ROM_GROUPWORD | ROM_SKIP(6) )	/* BAD ADDRESS LINES (mask=000100) */
+	ROMX_LOAD( "hyper-1.4", 0x000000, 0x100000, CRC(4b3b2d3c) SHA1(5e9e8ec853f71aeff3910b93dadbaeae2b61717b) , ROM_GROUPWORD | ROM_SKIP(6) )
+	ROMX_LOAD( "hyper-2.6", 0x000002, 0x100000, CRC(dc230116) SHA1(a3c447657d8499764f52c81382961f425c56037b) , ROM_GROUPWORD | ROM_SKIP(6) )
+	ROMX_LOAD( "hyper-3.3", 0x000004, 0x100000, CRC(2d770dd0) SHA1(27f9e7f67e96210d3710ab4f940c5d7ae13f8bbf) , ROM_GROUPWORD | ROM_SKIP(6) )
+	ROMX_LOAD( "hyper-4.5", 0x000006, 0x100000, CRC(f88c6d33) SHA1(277b56df40a17d7dd9f1071b0d498635a5b783cd) , ROM_GROUPWORD | ROM_SKIP(6) )
 
 	ROM_REGION( 0x40000, REGION_SOUND1, 0 )	/* Samples */
 	ROM_LOAD( "97.11", 0x00000, 0x40000, CRC(bf3f8574) SHA1(9e743f05e53256c886d43e1f0c43d7417134b9b3) )
@@ -757,6 +755,6 @@ ROM_START( hyprdelj )
 ROM_END
 
 
-GAMEX( 1993, hyprduel, 0,        hyprduel, hyprduel, hyprduel, ROT0, "Technosoft", "Hyper Duel (World)", GAME_NOT_WORKING )
-GAME ( 1993, hyprdelj, hyprduel, hyprduel, hyprduel, hyprduel, ROT0, "Technosoft", "Hyper Duel (Japan)" )
+GAME( 1993, hyprduel, 0,        hyprduel, hyprduel, hyprduel, ROT0, "Technosoft", "Hyper Duel (Japan set 1)" )
+GAME( 1993, hyprdelj, hyprduel, hyprduel, hyprduel, hyprduel, ROT0, "Technosoft", "Hyper Duel (Japan set 2)" )
 
