@@ -2,14 +2,15 @@
 
 Ikki (c) 1985 Sun Electronics
 
-	Driver by Uki
+    Driver by Uki
 
-	20/Jun/2001 -
+    20/Jun/2001 -
 
 *****************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/sn76496.h"
 
 PALETTE_INIT( ikki );
 VIDEO_UPDATE( ikki );
@@ -187,14 +188,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct SN76496interface sn76496_interface =
-{
-	2,	/* 2 chips */
-	{ 8000000/4, 8000000/2 },
-	{ 75, 75 }
-};
-
-
 static MACHINE_DRIVER_START( ikki )
 
 	/* basic machine hardware */
@@ -222,7 +215,13 @@ static MACHINE_DRIVER_START( ikki )
 	MDRV_VIDEO_UPDATE(ikki)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 8000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
+
+	MDRV_SOUND_ADD(SN76496, 8000000/2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
 MACHINE_DRIVER_END
 
 /****************************************************************************/
