@@ -9,15 +9,17 @@ ernesto@imagina.com
 
 /*
 
-	TODO:
+    TODO:
 
-	- coin counters
+    - coin counters
 
 */
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
+#include "sound/sn76496.h"
+#include "sound/vlm5030.h"
 
 
 void konami1_decode(void);
@@ -222,17 +224,8 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct SN76496interface sn76496_interface =
-{
-	1,	/* 1 chip */
-	{ 1500000 },	/*  1.5 MHz ? (hand tuned) */
-	{ 100 }
-};
-
 static struct VLM5030interface vlm5030_interface =
 {
-	3580000,    /* master clock */
-	100,        /* volume       */
 	REGION_SOUND1,	/* memory region of speech rom */
 	0           /* memory size of speech rom */
 };
@@ -261,8 +254,14 @@ static MACHINE_DRIVER_START( jailbrek )
 	MDRV_VIDEO_UPDATE(jailbrek)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
-	MDRV_SOUND_ADD(VLM5030, vlm5030_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(VLM5030, 3580000)
+	MDRV_SOUND_CONFIG(vlm5030_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
