@@ -1,36 +1,36 @@
 /***************************************************************************
 
-	Atari Return of the Jedi hardware
+    Atari Return of the Jedi hardware
 
-	driver by Dan Boris
+    driver by Dan Boris
 
-	Games supported:
-		* Return of the Jedi
+    Games supported:
+        * Return of the Jedi
 
-	Known bugs:
-		* none at this time
+    Known bugs:
+        * none at this time
 
 ****************************************************************************
 
-	Memory map
+    Memory map
 
 ****************************************************************************
 
-	========================================================================
-	CPU #1
-	========================================================================
-	0000-07FF   R/W   xxxxxxxx    Z-page Working RAM
-	0800-08FF   R/W   xxxxxxxx    NVRAM
-	0C00        R     xxxx-xxx    Switch inputs #1
-	            R     x-------       (right coin)
-	            R     -x------       (left coin)
-	            R     --x-----       (aux coin)
-	            R     ---x----       (self test)
-	            R     -----x--       (left thumb switch)
-	            R     ------x-       (fire switches)
-	            R     -------x       (right thumb switch)
-	0C01        R     xxx--x--    Communications
-	            R     x-------       (VBLANK)
+    ========================================================================
+    CPU #1
+    ========================================================================
+    0000-07FF   R/W   xxxxxxxx    Z-page Working RAM
+    0800-08FF   R/W   xxxxxxxx    NVRAM
+    0C00        R     xxxx-xxx    Switch inputs #1
+                R     x-------       (right coin)
+                R     -x------       (left coin)
+                R     --x-----       (aux coin)
+                R     ---x----       (self test)
+                R     -----x--       (left thumb switch)
+                R     ------x-       (fire switches)
+                R     -------x       (right thumb switch)
+    0C01        R     xxx--x--    Communications
+                R     x-------       (VBLANK)
                 R     -x------       (sound CPU communications latch full flag)
                 R     --x-----       (sound CPU acknowledge latch flag)
                 R     -----x--       (slam switch)
@@ -76,41 +76,43 @@
     3E00-3FFF     W   xxxxxxxx    PIXI graphics expander RAM
     4000-7FFF   R     xxxxxxxx    Banked program ROM
     8000-FFFF   R     xxxxxxxx    Fixed program ROM
-	========================================================================
-	Interrupts:
-		NMI not connected
-		IRQ generated by 32V
-	========================================================================
+    ========================================================================
+    Interrupts:
+        NMI not connected
+        IRQ generated by 32V
+    ========================================================================
 
 
-	========================================================================
-	CPU #2
-	========================================================================
-	0000-07FF   R/W   xxxxxxxx    Z-page working RAM
-	0800-083F   R/W   xxxxxxxx    Custom I/O
-	1000          W   --------    Interrupt acknowledge
-	1100          W   xxxxxxxx    Speech data
-	1200          W   --------    Speech write strobe on
-	1300          W   --------    Speech write strobe off
-	1400          W   xxxxxxxx    Main CPU acknowledge latch
-	1500          W   -------x    Speech chip reset
-	1800        R     xxxxxxxx    Main CPU communication latch
-	1C00        R     x-------    Speech chip ready
-	1C01        R     xx------    Communications
-	            R     x-------       (sound CPU communication latch full flag)
-	            R     -x------       (sound CPU acknowledge latch full flag)
-	8000-FFFF   R     xxxxxxxx    Program ROM
-	========================================================================
-	Interrupts:
-		NMI not connected
-		IRQ generated by 32V
-	========================================================================
+    ========================================================================
+    CPU #2
+    ========================================================================
+    0000-07FF   R/W   xxxxxxxx    Z-page working RAM
+    0800-083F   R/W   xxxxxxxx    Custom I/O
+    1000          W   --------    Interrupt acknowledge
+    1100          W   xxxxxxxx    Speech data
+    1200          W   --------    Speech write strobe on
+    1300          W   --------    Speech write strobe off
+    1400          W   xxxxxxxx    Main CPU acknowledge latch
+    1500          W   -------x    Speech chip reset
+    1800        R     xxxxxxxx    Main CPU communication latch
+    1C00        R     x-------    Speech chip ready
+    1C01        R     xx------    Communications
+                R     x-------       (sound CPU communication latch full flag)
+                R     -x------       (sound CPU acknowledge latch full flag)
+    8000-FFFF   R     xxxxxxxx    Program ROM
+    ========================================================================
+    Interrupts:
+        NMI not connected
+        IRQ generated by 32V
+    ========================================================================
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "cpu/m6502/m6502.h"
 #include "vidhrdw/generic.h"
+#include "sound/5220intf.h"
+#include "sound/pokey.h"
 #include "jedi.h"
 
 
@@ -131,7 +133,7 @@ static UINT8 nvram_enabled;
 
 /*************************************
  *
- *	Interrupt handling
+ *  Interrupt handling
  *
  *************************************/
 
@@ -180,7 +182,7 @@ static MACHINE_INIT( jedi )
 
 /*************************************
  *
- *	Main program ROM banking
+ *  Main program ROM banking
  *
  *************************************/
 
@@ -197,7 +199,7 @@ static WRITE8_HANDLER( rom_banksel_w )
 
 /*************************************
  *
- *	Main CPU -> Sound CPU communications
+ *  Main CPU -> Sound CPU communications
  *
  *************************************/
 
@@ -230,7 +232,7 @@ static READ8_HANDLER( sound_latch_r )
 
 /*************************************
  *
- *	Sound CPU -> Main CPU communications
+ *  Sound CPU -> Main CPU communications
  *
  *************************************/
 
@@ -251,7 +253,7 @@ static WRITE8_HANDLER( sound_ack_latch_w )
 
 /*************************************
  *
- *	I/O ports
+ *  I/O ports
  *
  *************************************/
 
@@ -294,7 +296,7 @@ static WRITE8_HANDLER( jedi_coin_counter_w )
 
 /*************************************
  *
- *	Speech access
+ *  Speech access
  *
  *************************************/
 
@@ -323,7 +325,7 @@ static READ8_HANDLER( speech_ready_r )
 
 /*************************************
  *
- *	NVRAM
+ *  NVRAM
  *
  *************************************/
 
@@ -343,7 +345,7 @@ static WRITE8_HANDLER( nvram_enable_w )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -392,7 +394,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
@@ -426,7 +428,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -459,7 +461,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics layouts
+ *  Graphics layouts
  *
  *************************************/
 
@@ -482,8 +484,7 @@ static struct GfxLayout pflayout =
 	4,
 	{ 0, 4, RGN_FRAC(1,2), RGN_FRAC(1,2)+4 },
 	{ 0, 1, 2, 3, 8+0, 8+1, 8+2, 8+3 },
-	{ 0*16, 1*16, 2*16, 3*16, 4*16, 5*16, 6*16, 7*16,
-			8*16, 9*16, 10*16, 11*16, 12*16, 13*16, 14*16, 15*16 },
+	{ 0*16, 1*16, 2*16, 3*16, 4*16, 5*16, 6*16, 7*16 },
 	16*8
 };
 
@@ -513,41 +514,7 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound definitions
- *
- *************************************/
-
-static struct POKEYinterface pokey_interface =
-{
-	4,
-	SOUND_CPU_OSC/2/4,	/* 1.5MHz */
-	{ 30, 30, MIXER(30,MIXER_PAN_LEFT), MIXER(30,MIXER_PAN_RIGHT) },
-	/* The 8 pot handlers */
-	{ 0, 0, 0, 0 },
-	{ 0, 0, 0, 0 },
-	{ 0, 0, 0, 0 },
-	{ 0, 0, 0, 0 },
-	{ 0, 0, 0, 0 },
-	{ 0, 0, 0, 0 },
-	{ 0, 0, 0, 0 },
-	{ 0, 0, 0, 0 },
-	/* The allpot handler */
-	{ 0, 0, 0, 0 }
-};
-
-
-static struct TMS5220interface tms5220_interface =
-{
-	SOUND_CPU_OSC/2/9,
-	100,
-	0
-};
-
-
-
-/*************************************
- *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -563,7 +530,7 @@ static MACHINE_DRIVER_START( jedi )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(4)
-	
+
 	MDRV_MACHINE_INIT(jedi)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
@@ -578,16 +545,32 @@ static MACHINE_DRIVER_START( jedi )
 	MDRV_VIDEO_UPDATE(jedi)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(POKEY,   pokey_interface)
-	MDRV_SOUND_ADD(TMS5220, tms5220_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(POKEY, SOUND_CPU_OSC/2/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.30)
+
+	MDRV_SOUND_ADD(POKEY, SOUND_CPU_OSC/2/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.30)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.30)
+
+	MDRV_SOUND_ADD(POKEY, SOUND_CPU_OSC/2/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.30)
+
+	MDRV_SOUND_ADD(POKEY, SOUND_CPU_OSC/2/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.30)
+
+	MDRV_SOUND_ADD(TMS5220, SOUND_CPU_OSC/2/9)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -625,7 +608,7 @@ ROM_END
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
