@@ -64,6 +64,9 @@ IO ports and memory map changes. Dip switches differ too.
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
+#include "sound/msm5205.h"
 
 
 /* from vidhrdw */
@@ -138,6 +141,7 @@ static WRITE8_HANDLER( sound_msm_w ) {
 }
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r) /* Player 1 controls - ACTIVE LOW */
 	AM_RANGE(0x40, 0x40) AM_READ(input_port_1_r) /* Player 2 controls - ACTIVE LOW */
 	AM_RANGE(0x80, 0x80) AM_READ(input_port_2_r) /* Coins & Start - ACTIVE LOW */
@@ -145,6 +149,7 @@ static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(kchamp_flipscreen_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(control_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(sound_reset_w)
@@ -152,10 +157,12 @@ static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x01, 0x01) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(AY8910_write_port_1_w)
@@ -204,11 +211,12 @@ static READ8_HANDLER( sound_reset_r ) {
 static WRITE8_HANDLER( kc_sound_control_w ) {
 	if ( offset == 0 )
 		sound_nmi_enable = ( ( data >> 7 ) & 1 );
-/*	else */
-/*		DAC_set_volume(0,( data == 1 ) ? 255 : 0,0); */
+/*  else */
+/*      DAC_set_volume(0,( data == 1 ) ? 255 : 0,0); */
 }
 
 static ADDRESS_MAP_START( kc_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x90, 0x90) AM_READ(input_port_0_r) /* Player 1 controls - ACTIVE LOW */
 	AM_RANGE(0x98, 0x98) AM_READ(input_port_1_r) /* Player 2 controls - ACTIVE LOW */
 	AM_RANGE(0xa0, 0xa0) AM_READ(input_port_2_r) /* Coins & Start - ACTIVE LOW */
@@ -217,16 +225,19 @@ static ADDRESS_MAP_START( kc_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( kc_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x80, 0x80) AM_WRITE(kchamp_flipscreen_w)
 	AM_RANGE(0x81, 0x81) AM_WRITE(control_w)
 	AM_RANGE(0xa8, 0xa8) AM_WRITE(sound_command_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( kc_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x06, 0x06) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( kc_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(AY8910_write_port_1_w)
@@ -412,24 +423,10 @@ static void msmint( int data ) {
 	}
 }
 
-static struct AY8910interface ay8910_interface =
-{
-	2, /* 2 chips */
-	1500000,			/* 12 MHz / 8 = 1.5 MHz */
-	{ 30, 30 },			/* Modified by T.Nogi 1999/11/08 */
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static struct MSM5205interface msm_interface =
 {
-	1,				/* 1 chip */
-	375000,				/* 12MHz / 16 / 2 */
-	{ msmint },			/* interrupt function */
-	{ MSM5205_S96_4B },		/* 1 / 96 = 3906.25Hz playback */
-	{ 100 }
+	msmint,			/* interrupt function */
+	MSM5205_S96_4B	/* 1 / 96 = 3906.25Hz playback */
 };
 
 /********************
@@ -442,12 +439,6 @@ static INTERRUPT_GEN( sound_int ) {
 		cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE);
 }
 
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 50 }
-};
-
 
 static MACHINE_DRIVER_START( kchampvs )
 
@@ -458,7 +449,7 @@ static MACHINE_DRIVER_START( kchampvs )
 	MDRV_CPU_VBLANK_INT(kc_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 3000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 12MHz / 4 = 3.0 MHz */
+	/* audio CPU */	/* 12MHz / 4 = 3.0 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 			/* irq's triggered from main cpu */
@@ -479,8 +470,17 @@ static MACHINE_DRIVER_START( kchampvs )
 	MDRV_VIDEO_UPDATE(kchampvs)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(MSM5205, msm_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(MSM5205, 375000)
+	MDRV_SOUND_CONFIG(msm_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /********************
@@ -496,7 +496,7 @@ static MACHINE_DRIVER_START( kchamp )
 	MDRV_CPU_VBLANK_INT(kc_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 3000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 12MHz / 4 = 3.0 MHz */
+	/* audio CPU */	/* 12MHz / 4 = 3.0 MHz */
 	MDRV_CPU_PROGRAM_MAP(kc_sound_readmem,kc_sound_writemem)
 	MDRV_CPU_IO_MAP(kc_sound_readport,kc_sound_writeport)
 	MDRV_CPU_PERIODIC_INT(sound_int, 125) /* Hz */
@@ -518,8 +518,16 @@ static MACHINE_DRIVER_START( kchamp )
 	MDRV_VIDEO_UPDATE(kchamp)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -710,14 +718,14 @@ static DRIVER_INIT( kchampvs )
 		rom[A+diff] = (rom[A] & 0x55) | ((rom[A] & 0x88) >> 2) | ((rom[A] & 0x22) << 2);
 
 	/*
-		Note that the first 4 opcodes that the program
-		executes aren't encrypted for some obscure reason.
-		The address for the 2nd opcode (a jump) is encrypted too.
-		It's not clear what the 3rd and 4th opcode are supposed to do,
-		they just write to a RAM location. This write might be what
-		turns the encryption on, but this doesn't explain the
-		encrypted address for the jump.
-	 */
+        Note that the first 4 opcodes that the program
+        executes aren't encrypted for some obscure reason.
+        The address for the 2nd opcode (a jump) is encrypted too.
+        It's not clear what the 3rd and 4th opcode are supposed to do,
+        they just write to a RAM location. This write might be what
+        turns the encryption on, but this doesn't explain the
+        encrypted address for the jump.
+     */
 	rom[0+diff] = rom[0];	/* this is a jump */
 	A = rom[1] + 256 * rom[2];
 	rom[A+diff] = rom[A];	/* fix opcode on first jump address (again, a jump) */
