@@ -1,33 +1,34 @@
 /***************************************************************************
 
-	Kyugo hardware games
+    Kyugo hardware games
 
-	driver by:
-	Ernesto Corvi
-	someone@secureshell.com
+    driver by:
+    Ernesto Corvi
+    someone@secureshell.com
 
-	Games supported:
-		* Gyrodine - (c) 1984 Taito Corporation.
-		* Son of Phoenix - (c) 1985 Associated Overseas MFR, Inc.
-		* Repulse - (c) 1985 Sega
-		* '99 The last war - (c) 1985 Proma
-		* Flashgal - (c) 1985 Sega
-		* SRD Mission - (c) 1986 Taito Corporation.
-		* Legend - no copyright, but readme says: (c) 1986 SEGA/Coreland
-		* Airwolf - (c) 1987 Kyugo
+    Games supported:
+        * Gyrodine - (c) 1984 Taito Corporation.
+        * Son of Phoenix - (c) 1985 Associated Overseas MFR, Inc.
+        * Repulse - (c) 1985 Sega
+        * '99 The last war - (c) 1985 Proma
+        * Flashgal - (c) 1985 Sega
+        * SRD Mission - (c) 1986 Taito Corporation.
+        * Legend - no copyright, but readme says: (c) 1986 SEGA/Coreland
+        * Airwolf - (c) 1987 Kyugo
 
-	Known issues:
-		* attract mode in Son of Phoenix doesn't work
+    Known issues:
+        * attract mode in Son of Phoenix doesn't work
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "kyugo.h"
+#include "sound/ay8910.h"
 
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -55,12 +56,13 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Main CPU port handlers
+ *  Main CPU port handlers
  *
  *************************************/
 
 #define Main_PortMap( name, base )							\
 static ADDRESS_MAP_START( name##_writeport, ADDRESS_SPACE_IO, 8 )					\
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )										\
 	AM_RANGE(base+0, base+0) AM_WRITE(interrupt_enable_w)					\
 	AM_RANGE(base+1, base+1) AM_WRITE(kyugo_flipscreen_w)					\
 	AM_RANGE(base+2, base+2) AM_WRITE(kyugo_sub_cpu_control_w)			\
@@ -74,7 +76,7 @@ Main_PortMap( srdmissn, 0x08 )
 
 /*************************************
  *
- *	Sub CPU memory handlers
+ *  Sub CPU memory handlers
  *
  *************************************/
 
@@ -101,16 +103,18 @@ Sub_MemMap( flashgla, 0x7fff, 0xe000, 0xc040, 0xc080, 0xc0c0 )
 
 /*************************************
  *
- *	Sub CPU port handlers
+ *  Sub CPU port handlers
  *
  *************************************/
 
 #define Sub_PortMap( name, ay0_base, ay1_base )				\
 static ADDRESS_MAP_START( name##_sub_readport, ADDRESS_SPACE_IO, 8 )				\
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )									\
 	AM_RANGE(ay0_base+2, ay0_base+2) AM_READ(AY8910_read_port_0_r)		\
 ADDRESS_MAP_END													\
 															\
 static ADDRESS_MAP_START( name##_sub_writeport, ADDRESS_SPACE_IO, 8 )				\
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )									\
 	AM_RANGE(ay0_base+0, ay0_base+0) AM_WRITE(AY8910_control_port_0_w)	\
 	AM_RANGE(ay0_base+1, ay0_base+1) AM_WRITE(AY8910_write_port_0_w)		\
 	AM_RANGE(ay1_base+0, ay1_base+0) AM_WRITE(AY8910_control_port_1_w)	\
@@ -125,7 +129,7 @@ Sub_PortMap( flashgla, 0x40, 0x80 )
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -181,7 +185,7 @@ Sub_PortMap( flashgla, 0x40, 0x80 )
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unused ) )\
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )\
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	
+
 #define COMMON_END \
 	PORT_START_TAG("IN0")\
 	START_COINS\
@@ -419,7 +423,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -469,25 +473,20 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound definition
+ *  Sound definition
  *
  *************************************/
 
 static struct AY8910interface ay8910_interface =
 {
-	2,      /* 2 chips */
-	1500000,        /* 1.5 MHz ? */
-	{ 30, 30 },
-	{ input_port_0_r, 0 },
-	{ input_port_1_r, 0 },
-	{ 0, 0 },
-	{ 0, 0 }
+	input_port_0_r,
+	input_port_1_r
 };
 
 
 /*************************************
  *
- *	Machine drivers
+ *  Machine drivers
  *
  *************************************/
 
@@ -522,7 +521,14 @@ static MACHINE_DRIVER_START( gyrodine )
 	MDRV_VIDEO_UPDATE(kyugo)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( sonofphx )
@@ -578,7 +584,7 @@ MACHINE_DRIVER_END
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -659,7 +665,7 @@ ROM_START( gyrodinc )
 	ROM_LOAD( "a21.17", 0x0100, 0x0100, CRC(ca054448) SHA1(4bad8147905cbe9ec8bb5bcd8016e9950c5d95a9) ) /* green */
 	ROM_LOAD( "a21.18", 0x0200, 0x0100, CRC(23c0c449) SHA1(4a37821a6a16ae0cfdcfb0fa64733c03ba9e4815) ) /* blue */
 	ROM_LOAD( "a21.20", 0x0300, 0x0020, CRC(efc4985e) SHA1(b2fa02e388fbbe1077e79699efccb2d47cb83ba5) ) /* char lookup table */
-	ROM_LOAD( "m1.2c",  0x0320, 0x0020, CRC(83a39201) SHA1(4fdc722c9e20ee152c890342ef0dce18e35e2ef8) ) /* timing? (not used) */	
+	ROM_LOAD( "m1.2c",  0x0320, 0x0020, CRC(83a39201) SHA1(4fdc722c9e20ee152c890342ef0dce18e35e2ef8) ) /* timing? (not used) */
 ROM_END
 
 
@@ -1127,7 +1133,7 @@ ROM_END
 
 /*************************************
  *
- *	Game specific initialization
+ *  Game specific initialization
  *
  *************************************/
 
@@ -1151,7 +1157,7 @@ static DRIVER_INIT( srdmissn )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
