@@ -2,14 +2,14 @@
 
  Lasso and similar hardware
 
-		driver by Phil Stroffolino, Nicola Salmoria, Luca Elia
+        driver by Phil Stroffolino, Nicola Salmoria, Luca Elia
 
 ---------------------------------------------------------------------------
-Year + Game					By				CPUs		Sound Chips
+Year + Game                 By              CPUs        Sound Chips
 ---------------------------------------------------------------------------
-82	Lasso					SNK				3 x 6502	2 x SN76489
-83	Chameleon				Jaleco			2 x 6502	2 x SN76489
-84	Wai Wai Jockey Gate-In!	Jaleco/Casio	2 x 6502	2 x SN76489 + DAC
+82  Lasso                   SNK             3 x 6502    2 x SN76489
+83  Chameleon               Jaleco          2 x 6502    2 x SN76489
+84  Wai Wai Jockey Gate-In! Jaleco/Casio    2 x 6502    2 x SN76489 + DAC
 84  Pinbo                   Jaleco          6502 + Z80  2 x AY-8910
 ---------------------------------------------------------------------------
 
@@ -23,6 +23,9 @@ Notes:
 #include "driver.h"
 #include "cpu/z80/z80.h"
 #include "lasso.h"
+#include "sound/dac.h"
+#include "sound/sn76496.h"
+#include "sound/ay8910.h"
 
 
 /* IRQ = VBlank, NMI = Coin Insertion */
@@ -74,7 +77,7 @@ static WRITE8_HANDLER( sound_command_w )
 
 static READ8_HANDLER( sound_status_r )
 {
-	/*	0x01: chip#0 ready; 0x02: chip#1 ready */
+	/*  0x01: chip#0 ready; 0x02: chip#1 ready */
 	return 0x03;
 }
 
@@ -251,12 +254,14 @@ static ADDRESS_MAP_START( pinbo_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( pinbo_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x02, 0x02) AM_READ(AY8910_read_port_0_r)
 	AM_RANGE(0x06, 0x06) AM_READ(AY8910_read_port_1_r)
 	AM_RANGE(0x08, 0x08) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( pinbo_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x04, 0x04) AM_WRITE(AY8910_control_port_1_w)
@@ -298,14 +303,14 @@ INPUT_PORTS_START( lasso )
 	PORT_DIPSETTING(	0x08, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(	0x04, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(	0x0c, DEF_STR( 1C_6C ) )
-/*	PORT_DIPSETTING(	0x06, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x00, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x0a, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x06, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0a, DEF_STR( 1C_1C ) ) */
 	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x30, "3" )
 	PORT_DIPSETTING(    0x10, "4" )
 	PORT_DIPSETTING(    0x20, "5" )
-/*	PORT_DIPSETTING(    0x00, "3" ) */
+/*  PORT_DIPSETTING(    0x00, "3" ) */
 	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Coin_B ) )
 	PORT_DIPSETTING(	0x40, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( 1C_1C ) )
@@ -363,13 +368,13 @@ INPUT_PORTS_START( chameleo )
 	PORT_DIPSETTING(	0x08, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(	0x04, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(	0x0c, DEF_STR( 1C_6C ) )
-/*	PORT_DIPSETTING(	0x06, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x00, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x0a, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x06, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0a, DEF_STR( 1C_1C ) ) */
 	PORT_DIPNAME( 0x30, 0x00, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x30, "5" )
-/*	PORT_DIPSETTING(    0x10, "5" ) */
+/*  PORT_DIPSETTING(    0x10, "5" ) */
 	PORT_DIPSETTING(    0x20, "Infinite (Cheat)")
 	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Coin_B ) )
 	PORT_DIPSETTING(	0x40, DEF_STR( 2C_1C ) )
@@ -428,9 +433,9 @@ INPUT_PORTS_START( wwjgtin )
 	PORT_DIPSETTING(	0x08, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(	0x04, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(	0x0c, DEF_STR( 1C_6C ) )
-/*	PORT_DIPSETTING(	0x06, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x00, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x0a, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x06, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0a, DEF_STR( 1C_1C ) ) */
 	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )	/* probably unused */
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -494,9 +499,9 @@ INPUT_PORTS_START( pinbo )
 	PORT_DIPSETTING(	0x08, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(	0x04, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(	0x0c, DEF_STR( 1C_6C ) )
-/*	PORT_DIPSETTING(	0x06, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x00, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(	0x0a, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x06, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0a, DEF_STR( 1C_1C ) ) */
 	PORT_DIPNAME( 0x30, 0x00, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x10, "4" )
@@ -610,30 +615,6 @@ static struct GfxDecodeInfo pinbo_gfxdecodeinfo[] =
 
 
 
-static struct SN76496interface sn76496_interface =
-{
-	2,	/* 2 chips */
-	{ 2000000, 2000000 },	/* ? MHz */
-	{ 100, 100 }
-};
-
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 100 }
-};
-
-static struct AY8910interface ay8910_interface =
-{
-	2,		/* 2 chips */
-	1250000,	/* 1.25 MHz? */
-	{ 25, 25 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 }
-};
-
 static MACHINE_DRIVER_START( lasso )
 
 	/* basic machine hardware */
@@ -642,7 +623,7 @@ static MACHINE_DRIVER_START( lasso )
 	MDRV_CPU_VBLANK_INT(lasso_interrupt,2)		/* IRQ = VBlank, NMI = Coin Insertion */
 
 	MDRV_CPU_ADD_TAG("audio", M6502, 600000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* ?? (controls music tempo) */
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(lasso_sound_readmem,lasso_sound_writemem)
 
 	MDRV_CPU_ADD_TAG("blitter", M6502, 2000000)	/* 2 MHz (?) */
@@ -664,7 +645,13 @@ static MACHINE_DRIVER_START( lasso )
 	MDRV_VIDEO_UPDATE(lasso)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("sn76496", SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD_TAG("sn76496.1", SN76496, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD_TAG("sn76496.2", SN76496, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( chameleo )
@@ -706,7 +693,8 @@ static MACHINE_DRIVER_START( wwjgtin )
 	MDRV_VIDEO_UPDATE(wwjgtin)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( pinbo )
@@ -731,8 +719,14 @@ static MACHINE_DRIVER_START( pinbo )
 	MDRV_VIDEO_UPDATE(chameleo)
 
 	/* sound hardware */
-	MDRV_SOUND_REMOVE("sn76496")
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SOUND_REMOVE("sn76496.1")
+	MDRV_SOUND_REMOVE("sn76496.2")
+
+	MDRV_SOUND_ADD(AY8910, 1250000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1250000)
+
+	MDRV_SOUND_ADD(AY8910, 1250000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1250000)
 MACHINE_DRIVER_END
 
 
@@ -881,6 +875,49 @@ ROM_START( pinbo )
 	ROM_LOAD( "blue.n10",    0x0200, 0x0100, CRC(e41250ad) SHA1(2e9a2babbacb1753057d46cf1dd6dc183611747e) )
 ROM_END
 
+ROM_START( pinboa )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
+	ROM_LOAD( "rom2.b7",     0x2000, 0x2000, CRC(9a185338) SHA1(4029cf927686b5e14ef7600b17ea3056cc58b15b) )
+	ROM_LOAD( "6.bin",       0x6000, 0x2000, CRC(f80b204c) SHA1(ee9b4ae1d8ea2fc062022fcfae67df87ed7aff41) )
+	ROM_LOAD( "5.bin",       0x8000, 0x2000, CRC(c57fe503) SHA1(11b7371c07c9b2c73ab61420a2cc609653c48d37) )
+	ROM_LOAD( "4.bin",       0xa000, 0x2000, CRC(d632b598) SHA1(270a5a790a66eaf3d90bf8081ab144fd1af9db3d) )
+	ROM_RELOAD(              0xe000, 0x2000 )
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 )  /* 64K for sound */
+	ROM_LOAD( "8.bin",       0x0000, 0x2000, CRC(32d1df14) SHA1(c0d4181378bbd6f2c594e923e2f8b21647c7fb0e) )
+
+	ROM_REGION( 0xc000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "rom6.a1",     0x0000, 0x0800, CRC(74fe8e98) SHA1(3c9ac38d7054b2831a515786b6f204b1804aaea3) )	/* tiles   */
+	ROM_CONTINUE(       	 0x2000, 0x0800             )	/* sprites */
+	ROM_CONTINUE(       	 0x0800, 0x0800             )
+	ROM_CONTINUE(       	 0x2800, 0x0800             )
+	ROM_CONTINUE(       	 0x1000, 0x0800             )
+	ROM_CONTINUE(       	 0x3000, 0x0800             )
+	ROM_CONTINUE(       	 0x1800, 0x0800             )
+	ROM_CONTINUE(       	 0x3800, 0x0800             )
+	ROM_LOAD( "rom8.c1",     0x4000, 0x0800, CRC(5a800fe7) SHA1(375269ec73fab7f0cf017a79e002e31b006f5ad7) )	/* 2nd bitplane */
+	ROM_CONTINUE(       	 0x6000, 0x0800             )
+	ROM_CONTINUE(       	 0x4800, 0x0800             )
+	ROM_CONTINUE(       	 0x6800, 0x0800             )
+	ROM_CONTINUE(       	 0x5000, 0x0800             )
+	ROM_CONTINUE(       	 0x7000, 0x0800             )
+	ROM_CONTINUE(       	 0x5800, 0x0800             )
+	ROM_CONTINUE(       	 0x7800, 0x0800             )
+	ROM_LOAD( "2.bin",       0x8000, 0x0800, CRC(33cac92e) SHA1(55d4ff3ae9c9519a59bd6021a53584c873b4d327) ) /* 3rd bitplane */
+	ROM_CONTINUE(       	 0xa000, 0x0800             )
+	ROM_CONTINUE(       	 0x8800, 0x0800             )
+	ROM_CONTINUE(       	 0xa800, 0x0800             )
+	ROM_CONTINUE(       	 0x9000, 0x0800             )
+	ROM_CONTINUE(       	 0xb000, 0x0800             )
+	ROM_CONTINUE(       	 0x9800, 0x0800             )
+	ROM_CONTINUE(       	 0xb800, 0x0800             )
+
+	ROM_REGION( 0x00300, REGION_PROMS, 0 ) /* Color PROMs */
+	ROM_LOAD( "red.l10",     0x0000, 0x0100, CRC(e6c9ba52) SHA1(6ea96f9bd71de6181d675b0f2d59a8c5e1be5aa3) )
+	ROM_LOAD( "green.k10",   0x0100, 0x0100, CRC(1bf2d335) SHA1(dcb074d3de939dfc652743e25bc66bd6fbdc3289) )
+	ROM_LOAD( "blue.n10",    0x0200, 0x0100, CRC(e41250ad) SHA1(2e9a2babbacb1753057d46cf1dd6dc183611747e) )
+ROM_END
+
 ROM_START( pinbos )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
 	ROM_LOAD( "b4.bin",      0x2000, 0x2000, CRC(d9452d4f) SHA1(c744ee037275b880c0ddc2fd83b3c05eb0a53621) )
@@ -925,14 +962,16 @@ ROM_START( pinbos )
 ROM_END
 
 
+
 /***************************************************************************
 
-								Game Drivers
+                                Game Drivers
 
 ***************************************************************************/
 
 GAME( 1982, lasso,    0,     lasso,    lasso,    0, ROT90, "SNK", "Lasso"                   )
 GAME( 1983, chameleo, 0,     chameleo, chameleo, 0, ROT0,  "Jaleco", "Chameleon"               )
 GAME( 1984, wwjgtin,  0,     wwjgtin,  wwjgtin,  0, ROT0,  "Jaleco / Casio", "Wai Wai Jockey Gate-In!" )
-GAME( 1984, pinbo,    0,     pinbo,    pinbo,    0, ROT90, "Jaleco", "Pinbo" )
-GAME( 1984, pinbos,   pinbo, pinbo,    pinbo,   0, ROT90, "bootleg?", "Pinbo (Strike)" )
+GAME( 1984, pinbo,    0,     pinbo,    pinbo,    0, ROT90, "Jaleco", "Pinbo (set 1)" )
+GAME( 1984, pinboa,   pinbo, pinbo,    pinbo,   0, ROT90, "Jaleco", "Pinbo (set 2)" )
+GAME( 1985, pinbos,   pinbo, pinbo,    pinbo,   0, ROT90, "bootleg?", "Pinbo (Strike)" )
