@@ -1,7 +1,7 @@
 /**************************************************************************
 
-  Last Duel 			          - Capcom, 1988
-  LED Storm 			          - Capcom, 1988
+  Last Duel                       - Capcom, 1988
+  LED Storm                       - Capcom, 1988
   Mad Gear                        - Capcom, 1989
 
   Emulation by Bryan McPhail, mish@tendril.co.uk
@@ -18,6 +18,8 @@ TODO:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2203intf.h"
+#include "sound/okim6295.h"
 
 WRITE16_HANDLER( lastduel_vram_w );
 WRITE16_HANDLER( lastduel_flip_w );
@@ -237,24 +239,9 @@ static void irqhandler(int irq)
 	cpunum_set_input_line(1,0,irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static struct OKIM6295interface okim6295_interface =
-{
-	1,              	/* 1 chip */
-	{ 7759 },           /* 7759Hz frequency */
-	{ REGION_SOUND1 },	/* memory region 3 */
-	{ 98 }
-};
-
 static struct YM2203interface ym2203_interface =
 {
-	2,			/* 2 chips */
-	3579545, /* Accurate */
-	{ YM2203_VOL(40,40), YM2203_VOL(40,40) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
+	0,0,0,0,irqhandler
 };
 
 static INTERRUPT_GEN( lastduel_interrupt )
@@ -277,7 +264,7 @@ static MACHINE_DRIVER_START( lastduel )
 	MDRV_CPU_VBLANK_INT(lastduel_interrupt,3)	/* 1 for vbl, 2 for control reads?? */
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU) /* Accurate */
+	/* audio CPU */ /* Accurate */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -295,7 +282,14 @@ static MACHINE_DRIVER_START( lastduel )
 	MDRV_VIDEO_UPDATE(lastduel)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3579545)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+
+	MDRV_SOUND_ADD(YM2203, 3579545)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 MACHINE_DRIVER_END
 
 
@@ -307,7 +301,7 @@ static MACHINE_DRIVER_START( madgear )
 	MDRV_CPU_VBLANK_INT(madgear_interrupt,3)	/* 1 for vbl, 2 for control reads?? */
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU) /* Accurate */
+	/* audio CPU */ /* Accurate */
 	MDRV_CPU_PROGRAM_MAP(mg_sound_readmem,mg_sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -325,8 +319,18 @@ static MACHINE_DRIVER_START( madgear )
 	MDRV_VIDEO_UPDATE(lastduel)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3579545)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+
+	MDRV_SOUND_ADD(YM2203, 3579545)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+
+	MDRV_SOUND_ADD(OKIM6295, 7759)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.98)
 MACHINE_DRIVER_END
 
 /******************************************************************************/
@@ -451,7 +455,7 @@ INPUT_PORTS_START( madgear )
 	PORT_DIPSETTING(      0x0030, "Upright One Player" )
 	PORT_DIPSETTING(      0x0000, "Upright Two Players" )
 	PORT_DIPSETTING(      0x0010, DEF_STR( Cocktail ) )
-/* 	PORT_DIPSETTING(      0x0020, "Upright One Player" ) */
+/*  PORT_DIPSETTING(      0x0020, "Upright One Player" ) */
 	PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0040, DEF_STR( On ) )
@@ -492,7 +496,7 @@ INPUT_PORTS_START( madgear )
 	PORT_DIPSETTING(      0x0300, DEF_STR( 5C_3C ) )
 	PORT_DIPSETTING(      0x0600, DEF_STR( 3C_2C ) )
 	PORT_DIPSETTING(      0x0f00, DEF_STR( 1C_1C ) )
-/*	PORT_DIPSETTING(      0x0000, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(      0x0000, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(      0x0800, DEF_STR( 2C_3C ) )
 	PORT_DIPSETTING(      0x0e00, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(      0x0d00, DEF_STR( 1C_3C ) )
