@@ -1,22 +1,23 @@
 /*******************************************************************************
 
-	Pro Soccer						(c) 1983 Data East Corporation
-	Pro Sport						(c) 1983 Data East Corporation
-	Boomer Rang'R / Genesis			(c) 1983 Data East Corporation
-	Kamikaze Cabbie / Yellow Cab	(c) 1984 Data East Corporation
-	Liberation						(c) 1984 Data East Corporation
+    Pro Soccer                      (c) 1983 Data East Corporation
+    Pro Sport                       (c) 1983 Data East Corporation
+    Boomer Rang'R / Genesis         (c) 1983 Data East Corporation
+    Kamikaze Cabbie / Yellow Cab    (c) 1984 Data East Corporation
+    Liberation                      (c) 1984 Data East Corporation
 
-	Liberation was available on two pcbs - a dedicated twin pcb set and
-	a version on the Genesis/Yellow Cab pcb that had an extra cpu pcb attached
-	for the different protection.  The program is the same on both versions.
+    Liberation was available on two pcbs - a dedicated twin pcb set and
+    a version on the Genesis/Yellow Cab pcb that had an extra cpu pcb attached
+    for the different protection.  The program is the same on both versions.
 
-	Emulation by Bryan McPhail, mish@tendril.co.uk
+    Emulation by Bryan McPhail, mish@tendril.co.uk
 
 *******************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/ay8910.h"
 
 PALETTE_INIT( liberate );
 VIDEO_UPDATE( prosoccr );
@@ -699,17 +700,6 @@ static INTERRUPT_GEN( deco16_interrupt )
 	}
 }
 
-static struct AY8910interface ay8910_interface =
-{
-	2, /* 2 chips */
-	1500000,     /* 12 Mhz / 8 = 1.5 Mhz */
-	{ 30, 50 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static MACHINE_DRIVER_START( prosoccr )
 
 	/* basic machine hardware */
@@ -718,7 +708,7 @@ static MACHINE_DRIVER_START( prosoccr )
 	MDRV_CPU_IO_MAP(deco16_readport,deco16_writeport)
 
 	MDRV_CPU_ADD(M6502, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(prosoccr_sound_readmem,prosoccr_sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,16)
 
@@ -738,7 +728,13 @@ static MACHINE_DRIVER_START( prosoccr )
 	MDRV_VIDEO_UPDATE(prosoccr)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( prosport )
@@ -749,7 +745,7 @@ static MACHINE_DRIVER_START( prosport )
 	MDRV_CPU_IO_MAP(deco16_readport,deco16_writeport)
 
 	MDRV_CPU_ADD(M6502, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,16)
 
@@ -768,7 +764,13 @@ static MACHINE_DRIVER_START( prosport )
 	MDRV_VIDEO_UPDATE(prosport)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( boomrang )
@@ -780,7 +782,7 @@ static MACHINE_DRIVER_START( boomrang )
 	MDRV_CPU_VBLANK_INT(deco16_interrupt,1)
 
 	MDRV_CPU_ADD(M6502, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,16)
 
@@ -800,7 +802,13 @@ static MACHINE_DRIVER_START( boomrang )
 	MDRV_VIDEO_UPDATE(boomrang)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+		MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( liberate )
@@ -812,7 +820,7 @@ static MACHINE_DRIVER_START( liberate )
 	MDRV_CPU_VBLANK_INT(deco16_interrupt,1)
 
 	MDRV_CPU_ADD(M6502, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,16)
 
@@ -832,7 +840,13 @@ static MACHINE_DRIVER_START( liberate )
 	MDRV_VIDEO_UPDATE(liberate)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( liberatb )
@@ -843,7 +857,7 @@ static MACHINE_DRIVER_START( liberatb )
 	MDRV_CPU_VBLANK_INT(deco16_interrupt,1)
 
 	MDRV_CPU_ADD(M6502, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,16)
 
@@ -863,7 +877,13 @@ static MACHINE_DRIVER_START( liberatb )
 	MDRV_VIDEO_UPDATE(liberate)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 /***************************************************************************/
