@@ -30,6 +30,7 @@ Take the following observations with a grain of salt (might not be true):
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m6805/m6805.h"
+#include "sound/2203intf.h"
 
 
 extern unsigned char *lkage_scroll, *lkage_vreg;
@@ -95,7 +96,7 @@ static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf084, 0xf084) AM_READ(input_port_4_r)	/* P1 controls */
 	AM_RANGE(0xf086, 0xf086) AM_READ(input_port_5_r)	/* P2 controls */
 	AM_RANGE(0xf087, 0xf087) AM_READ(lkage_mcu_status_r)
-/*	AM_RANGE(0xf0a3, 0xf0a3) AM_READ(MRA8_NOP)    unknown    */
+/*  AM_RANGE(0xf0a3, 0xf0a3) AM_READ(MRA8_NOP)    unknown    */
 	AM_RANGE(0xf0c0, 0xf0c5) AM_READ(MRA8_RAM)
 	AM_RANGE(0xf100, 0xf15f) AM_READ(MRA8_RAM)
 	AM_RANGE(0xf400, 0xffff) AM_READ(MRA8_RAM)
@@ -105,16 +106,16 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xdfff) AM_WRITE(MWA8_ROM)
 	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0xe800, 0xefff) AM_WRITE(MWA8_RAM) AM_BASE(&paletteram)
-/*	paletteram_xxxxRRRRGGGGBBBB_w, &paletteram }, */
+/*  paletteram_xxxxRRRRGGGGBBBB_w, &paletteram }, */
 	AM_RANGE(0xf000, 0xf003) AM_WRITE(MWA8_RAM) AM_BASE(&lkage_vreg) /* video registers */
 	AM_RANGE(0xf060, 0xf060) AM_WRITE(lkage_sound_command_w)
 	AM_RANGE(0xf061, 0xf061) AM_WRITE(MWA8_NOP) /* unknown */
 	AM_RANGE(0xf062, 0xf062) AM_WRITE(lkage_mcu_w)
-/*	AM_RANGE(0xf063, 0xf063) AM_WRITE(MWA8_NOP)    unknown    */
-/*	AM_RANGE(0xf0a2, 0xf0a2) AM_WRITE(MWA8_NOP)    unknown    */
-/*	AM_RANGE(0xf0a3, 0xf0a3) AM_WRITE(MWA8_NOP)    unknown    */
+/*  AM_RANGE(0xf063, 0xf063) AM_WRITE(MWA8_NOP)    unknown    */
+/*  AM_RANGE(0xf0a2, 0xf0a2) AM_WRITE(MWA8_NOP)    unknown    */
+/*  AM_RANGE(0xf0a3, 0xf0a3) AM_WRITE(MWA8_NOP)    unknown    */
 	AM_RANGE(0xf0c0, 0xf0c5) AM_WRITE(MWA8_RAM) AM_BASE(&lkage_scroll) /* scrolling */
-/*	AM_RANGE(0xf0e1, 0xf0e1) AM_WRITE(MWA8_NOP)    unknown    */
+/*  AM_RANGE(0xf0e1, 0xf0e1) AM_WRITE(MWA8_NOP)    unknown    */
 	AM_RANGE(0xf100, 0xf15f) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) /* spriteram */
 	AM_RANGE(0xf400, 0xffff) AM_WRITE(lkage_videoram_w) AM_BASE(&videoram) /* videoram */
 ADDRESS_MAP_END
@@ -244,7 +245,7 @@ INPUT_PORTS_START( lkage )
 
 	PORT_START_TAG("DSW3")
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x03, "Easiest" ) /* unconfirmed */
+	PORT_DIPSETTING(    0x03, DEF_STR( Easiest ) )  /* unconfirmed */
 	PORT_DIPSETTING(    0x02, DEF_STR( Easy ) )    /* unconfirmed */
 	PORT_DIPSETTING(    0x01, DEF_STR( Normal ) )  /* unconfirmed */
 	PORT_DIPSETTING(    0x00, DEF_STR( Hard ) )    /* unconfirmed */
@@ -341,14 +342,11 @@ static void irqhandler(int irq)
 
 static struct YM2203interface ym2203_interface =
 {
-	2,          /* 2 chips */
-	4000000,    /* 4 MHz ? (hand tuned) */
-	{ YM2203_VOL(40,15), YM2203_VOL(40,15) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
+	0,
+	0,
+	0,
+	0,
+	irqhandler
 };
 
 
@@ -357,13 +355,12 @@ static MACHINE_DRIVER_START( lkage )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80,6000000)
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)	/* ??? */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
 	MDRV_CPU_IO_MAP(readport,0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 6000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ??? */
+	/* audio CPU */	/* ??? */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 								/* IRQs are triggered by the YM2203 */
 	MDRV_CPU_ADD(M68705,4000000/2)	/* ??? */
@@ -379,15 +376,28 @@ static MACHINE_DRIVER_START( lkage )
 	MDRV_GFXDECODE(gfxdecodeinfo)
 	MDRV_PALETTE_LENGTH(176)
 		/*
-			there are actually 1024 colors in paletteram, however, we use a 100% correct
-			reduced "virtual palette" to achieve some optimizations in the video driver.
-		*/
+            there are actually 1024 colors in paletteram, however, we use a 100% correct
+            reduced "virtual palette" to achieve some optimizations in the video driver.
+        */
 
 	MDRV_VIDEO_START(lkage)
 	MDRV_VIDEO_UPDATE(lkage)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.40)
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.40)
 MACHINE_DRIVER_END
 
 
@@ -395,13 +405,12 @@ static MACHINE_DRIVER_START( lkageb )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80,6000000)
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)	/* ??? */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
 	MDRV_CPU_IO_MAP(readport,0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 6000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ??? */
+	/* audio CPU */	/* ??? */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 								/* IRQs are triggered by the YM2203 */
 	MDRV_FRAMES_PER_SECOND(60)
@@ -414,15 +423,28 @@ static MACHINE_DRIVER_START( lkageb )
 	MDRV_GFXDECODE(gfxdecodeinfo)
 	MDRV_PALETTE_LENGTH(176)
 		/*
-			there are actually 1024 colors in paletteram, however, we use a 100% correct
-			reduced "virtual palette" to achieve some optimizations in the video driver.
-		*/
+            there are actually 1024 colors in paletteram, however, we use a 100% correct
+            reduced "virtual palette" to achieve some optimizations in the video driver.
+        */
 
 	MDRV_VIDEO_START(lkage)
 	MDRV_VIDEO_UPDATE(lkage)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.40)
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.40)
 MACHINE_DRIVER_END
 
 
@@ -540,7 +562,7 @@ static READ8_HANDLER( fake_mcu_r )
 static WRITE8_HANDLER( fake_mcu_w )
 {
 	/*if(data != 1 && data != 0xa6 && data != 0x34 && data != 0x48) */
-	/*	usrintf_showmessage("PC = %04x %02x",activecpu_get_pc(),data); */
+	/*  usrintf_showmessage("PC = %04x %02x",activecpu_get_pc(),data); */
 
 	mcu_val = data;
 }
