@@ -26,6 +26,8 @@ TODO:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/2203intf.h"
 
 /* in vidhrdw/lsasquad.c */
 extern unsigned char *lsasquad_scrollram;
@@ -311,30 +313,14 @@ static WRITE8_HANDLER( unk )
 
 }
 
-/* actually there is one AY8910 and one YM2203, but the sound core doesn't */
-/* support that so we use 2 YM2203. I think this has been corrected now,  */
-/* can this comment be removed?											*/
+
 static struct YM2203interface ym2203_interface =
 {
-	1,			/* 1 chips */
-	3000000,	/* 3 MHz???? */
-	{ YM2203_VOL(100,20) },
-	{ 0 },
-	{ 0 },
-	{ unk },
-	{ unk },
-	{ irqhandler }
-};
-
-static struct AY8910interface ay8910_interface =
-{
-	1, /* 1 chips */
-	3000000,	 /* 3 MHz ??? */
-	{ 20 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
+	0,
+	0,
+	unk,
+	unk,
+	irqhandler
 };
 
 
@@ -346,7 +332,7 @@ static MACHINE_DRIVER_START( lsasquad )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 4 MHz? */
+	/* audio CPU */	/* 4 MHz? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 								/* IRQs are triggered by the YM2203 */
 	MDRV_CPU_ADD(M68705,4000000/2)	/* ? */
@@ -369,8 +355,17 @@ static MACHINE_DRIVER_START( lsasquad )
 	MDRV_VIDEO_UPDATE(lsasquad)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 3000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+	MDRV_SOUND_ROUTE(2, "mono", 0.20)
+	MDRV_SOUND_ROUTE(3, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -451,8 +446,8 @@ static void init_common(void)
 	unsigned char *ROM = memory_region(REGION_CPU1);
 
 	/* an instruction at $7FFF straddles the bank switch boundary at
-	   $8000 into rom bank #0 and then continues into the bank so
-	   copy this bank as the CPU bank switching won't catch it */
+       $8000 into rom bank #0 and then continues into the bank so
+       copy this bank as the CPU bank switching won't catch it */
 	memcpy(&ROM[0x08000], &ROM[0x10000], 0x2000);
 }
 
