@@ -12,24 +12,24 @@ After you get into Check Mode (F2), press the Hit key to switch pages.
 
 Memory Mapped:
 
-0000-5fff   R	ROM
+0000-5fff   R   ROM
 6000-67ff   RW  Battery Backed RAM
 8000-83ff   RW  Video RAM
 8400-87ff   RW  Color RAM
-				Bits 0-3 - color
- 				Bits 4-5 - character bank
-				Bit  6   - flip x
-				Bit  7   - Is it used?
-a000		R	Input Port 0
-a001		R	Input Port 1
-a002		R	Input Port 2
-a001		 W  Control Port 0
-a002		 W  Control Port 1
+                Bits 0-3 - color
+                Bits 4-5 - character bank
+                Bit  6   - flip x
+                Bit  7   - Is it used?
+a000        R   Input Port 0
+a001        R   Input Port 1
+a002        R   Input Port 2
+a001         W  Control Port 0
+a002         W  Control Port 1
 
 I/O Ports:
-00			RW  YM2149 Data	Port
-				Port A - DSW #1
-				Port B - DSW #2
+00          RW  YM2149 Data Port
+                Port A - DSW #1
+                Port B - DSW #2
 01           W  YM2149 Control Port
 
 
@@ -47,6 +47,7 @@ that these switches be set 'always on'
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
 
 
 extern WRITE8_HANDLER( lvcards_videoram_w );
@@ -85,6 +86,7 @@ static ADDRESS_MAP_START( lvcards_map, ADDRESS_SPACE_PROGRAM, 8  )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( lvcards_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READWRITE(AY8910_read_port_0_r, AY8910_write_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_control_port_0_w)
 ADDRESS_MAP_END
@@ -195,13 +197,8 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 static struct AY8910interface lcay8910_interface =
 {
-	1,	 /* 1 chip */
-	18432000/12, /* 1.536 MHz */
-	{ 25, 25 },
-	{ input_port_3_r },
-	{ input_port_4_r },
-	{ 0 },
-	{ 0 },
+	input_port_3_r,
+	input_port_4_r
 };
 
 
@@ -229,7 +226,11 @@ static MACHINE_DRIVER_START( lvcards )
 	MDRV_VIDEO_UPDATE(lvcards)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, lcay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 18432000/12)
+	MDRV_SOUND_CONFIG(lcay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
