@@ -8,10 +8,10 @@
   Driver provided by Paul Leaman
 
 To Do:
--	sectionz does "false contacts" on the coin counters, causing them to
-	increment twice per coin.
--	clean up Avengers protection; it currently checks against hard-coded program
-	counter rather than behaving as a memory-mapped black box.
+-   sectionz does "false contacts" on the coin counters, causing them to
+    increment twice per coin.
+-   clean up Avengers protection; it currently checks against hard-coded program
+    counter rather than behaving as a memory-mapped black box.
 
 
 Change Log:
@@ -48,6 +48,8 @@ Notes:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "lwings.h"
+#include "sound/2203intf.h"
+#include "sound/msm5205.h"
 
 /* Avengers runs on hardware almost identical to Trojan, but with a protection
  * device and some small changes to the memory map and videohardware.
@@ -99,13 +101,6 @@ static INTERRUPT_GEN( lwings_interrupt )
 		cpunum_set_input_line_and_vector(0,0,HOLD_LINE,0xd7); /* RST 10h */
 }
 
-static INTERRUPT_GEN( avengers_interrupt )
-{
-	if( cpu_getiloops()==0 )
-		irq0_line_hold();
-	else
-		nmi_line_pulse();
-}
 
 static WRITE8_HANDLER( avengers_protection_w )
 {
@@ -236,11 +231,11 @@ static READ8_HANDLER( avengers_protection_r )
 		return avengers_fetch_paldata();
 	}
 
-	/*	Point to Angle Function
+	/*  Point to Angle Function
 
-		Input: two cartesian points
-		Output: direction code (north,northeast,east,...)
-	 */
+        Input: two cartesian points
+        Output: direction code (north,northeast,east,...)
+     */
 	x = avengers_param[0] - avengers_param[2];
 	y = avengers_param[1] - avengers_param[3];
 	for( dir=0; dir<8; dir++ )
@@ -371,19 +366,22 @@ ADDRESS_MAP_END
 
 /* Yes, _no_ ram */
 static ADDRESS_MAP_START( adpcm_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-/*	AM_RANGE(0x0000, 0xffff) AM_WRITE(MWA8_ROM) avoid cluttering up error.log */
+/*  AM_RANGE(0x0000, 0xffff) AM_WRITE(MWA8_ROM) avoid cluttering up error.log */
 	AM_RANGE(0x0000, 0xffff) AM_WRITE(MWA8_NOP)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( avengers_adpcm_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(avengers_adpcm_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( adpcm_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( adpcm_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x01, 0x01) AM_WRITE(msm5205_w)
 ADDRESS_MAP_END
 
@@ -851,24 +849,10 @@ static struct GfxDecodeInfo gfxdecodeinfo_trojan[] =
 	{ -1 } /* end of array */
 };
 
-static struct YM2203interface ym2203_interface =
-{
-	2,			/* 2 chips */
-	1500000,	/* 1.5 MHz (?) */
-	{ YM2203_VOL(10,20), YM2203_VOL(10,20) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static struct MSM5205interface msm5205_interface =
 {
-	1,					/* 1 chip */
-	384000,				/* 384KHz ? */
-	{ 0 },				/* interrupt function */
-	{ MSM5205_SEX_4B },	/* slave mode */
-	{ 50 }
+	0,				/* interrupt function */
+	MSM5205_SEX_4B	/* slave mode */
 };
 
 static MACHINE_DRIVER_START( lwings )
@@ -879,7 +863,7 @@ static MACHINE_DRIVER_START( lwings )
 	MDRV_CPU_VBLANK_INT(lwings_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)        /* 3 MHz (?) */
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
 
@@ -898,7 +882,19 @@ static MACHINE_DRIVER_START( lwings )
 	MDRV_VIDEO_UPDATE(lwings)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+	MDRV_SOUND_ROUTE(2, "mono", 0.20)
+	MDRV_SOUND_ROUTE(3, "mono", 0.10)
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+	MDRV_SOUND_ROUTE(2, "mono", 0.20)
+	MDRV_SOUND_ROUTE(3, "mono", 0.10)
 MACHINE_DRIVER_END
 
 
@@ -910,12 +906,12 @@ static MACHINE_DRIVER_START( trojan )
 	MDRV_CPU_VBLANK_INT(lwings_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)        /* 3 MHz (?) */
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
 
 	MDRV_CPU_ADD(Z80, 4000000) /* 3.579545 Mhz (?) */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ? */
+	/* audio CPU */	/* ? */
 	MDRV_CPU_PROGRAM_MAP(adpcm_readmem,adpcm_writemem)
 	MDRV_CPU_IO_MAP(adpcm_readport,adpcm_writeport)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold,4000)
@@ -935,8 +931,23 @@ static MACHINE_DRIVER_START( trojan )
 	MDRV_VIDEO_UPDATE(trojan)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+	MDRV_SOUND_ROUTE(2, "mono", 0.20)
+	MDRV_SOUND_ROUTE(3, "mono", 0.10)
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+	MDRV_SOUND_ROUTE(2, "mono", 0.20)
+	MDRV_SOUND_ROUTE(3, "mono", 0.10)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -948,12 +959,12 @@ static MACHINE_DRIVER_START( avengers )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1) /* RST 38h triggered by software */
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)        /* 3 MHz (?) */
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
 
 	MDRV_CPU_ADD(Z80, 4000000) /* 3.579545 Mhz (?) */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ? */
+	/* audio CPU */	/* ? */
 	MDRV_CPU_PROGRAM_MAP(adpcm_readmem,adpcm_writemem)
 	MDRV_CPU_IO_MAP(avengers_adpcm_readport,adpcm_writeport)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold,4000)
@@ -973,8 +984,23 @@ static MACHINE_DRIVER_START( avengers )
 	MDRV_VIDEO_UPDATE(trojan)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+	MDRV_SOUND_ROUTE(2, "mono", 0.20)
+	MDRV_SOUND_ROUTE(3, "mono", 0.10)
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+	MDRV_SOUND_ROUTE(2, "mono", 0.20)
+	MDRV_SOUND_ROUTE(3, "mono", 0.10)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 /***************************************************************************
