@@ -1,15 +1,15 @@
 /*******************************************************************************
 
-	Irem M107 games:
+    Irem M107 games:
 
-	Fire Barrel 							(c) 1993 Irem Corporation
-	Dream Soccer '94						(c) 1994 Data East Corporation
-	World PK Soccer							(c) 1995 Jaleco
+    Fire Barrel                             (c) 1993 Irem Corporation
+    Dream Soccer '94                        (c) 1994 Data East Corporation
+    World PK Soccer                         (c) 1995 Jaleco
 
 
-	Graphics glitches in both games.
+    Graphics glitches in both games.
 
-	Emulation by Bryan McPhail, mish@tendril.co.uk
+    Emulation by Bryan McPhail, mish@tendril.co.uk
 
 *******************************************************************************/
 
@@ -17,6 +17,8 @@
 #include "vidhrdw/generic.h"
 #include "m92.h"
 #include "machine/irem_cpu.h"
+#include "sound/2151intf.h"
+#include "sound/iremga20.h"
 
 extern unsigned char *m107_vram_data;
 extern int m107_spritesystem;
@@ -97,7 +99,7 @@ static WRITE8_HANDLER( m92_soundlatch_w )
 	{
 		timer_set(TIME_NOW,V30_ASSERT,setvector_callback);
 		soundlatch_w(0,data);
-/*		logerror("soundlatch_w %02x\n",data); */
+/*      logerror("soundlatch_w %02x\n",data); */
 	}
 }
 
@@ -113,7 +115,7 @@ static READ8_HANDLER( m92_soundlatch_r )
 	if (offset == 0)
 	{
 		int res = soundlatch_r(offset);
-/*		logerror("soundlatch_r %02x\n",res); */
+/*      logerror("soundlatch_r %02x\n",res); */
 		return res;
 	}
 	else return 0xff;
@@ -131,7 +133,7 @@ static WRITE8_HANDLER( m92_sound_status_w )
 {
 	if (offset == 0)
 	{
-/*		usrintf_showmessage("sound answer %02x",data); */
+/*      usrintf_showmessage("sound answer %02x",data); */
 		sound_status = data;
 	}
 }
@@ -446,17 +448,12 @@ static void sound_irq(int state)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	14318180/4,
-	{ YM3012_VOL(40,MIXER_PAN_LEFT,40,MIXER_PAN_RIGHT) },
-	{ sound_irq }
+	sound_irq
 };
 
 static struct IremGA20_interface iremGA20_interface =
 {
-	14318180/4,
-	REGION_SOUND1,
-	{ MIXER(100,MIXER_PAN_LEFT), MIXER(100,MIXER_PAN_RIGHT) },
+	REGION_SOUND1
 };
 
 /***************************************************************************/
@@ -519,7 +516,7 @@ static MACHINE_DRIVER_START( firebarr )
 	MDRV_CPU_VBLANK_INT(m107_raster_interrupt,256) /* 8 prelines, 240 visible lines, 8 for vblank? */
 
 	MDRV_CPU_ADD(V30, 14318000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 14.318 MHz */
+	/* audio CPU */	/* 14.318 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -536,9 +533,17 @@ static MACHINE_DRIVER_START( firebarr )
 	MDRV_VIDEO_UPDATE(m107)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(IREMGA20, iremGA20_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 14318180/4)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.40)
+	MDRV_SOUND_ROUTE(1, "right", 0.40)
+
+	MDRV_SOUND_ADD(IREMGA20, 14318180/4)
+	MDRV_SOUND_CONFIG(iremGA20_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -551,7 +556,7 @@ static MACHINE_DRIVER_START( dsoccr94 )
 	MDRV_CPU_VBLANK_INT(m107_interrupt,1)
 
 	MDRV_CPU_ADD(V30, 14318000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 14.318 MHz */
+	/* audio CPU */	/* 14.318 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -568,9 +573,17 @@ static MACHINE_DRIVER_START( dsoccr94 )
 	MDRV_VIDEO_UPDATE(m107)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(IREMGA20, iremGA20_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 14318180/4)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.40)
+	MDRV_SOUND_ROUTE(1, "right", 0.40)
+
+	MDRV_SOUND_ADD(IREMGA20, 14318180/4)
+	MDRV_SOUND_CONFIG(iremGA20_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 /***************************************************************************/
