@@ -1,6 +1,6 @@
 /***************************************************************************
 
-  Mad Motor								(c) 1989 Mitchell Corporation
+  Mad Motor                             (c) 1989 Mitchell Corporation
 
   But it's really a Data East game..  Bad Dudes era graphics hardware with
   Dark Seal era sound hardware.  Maybe a license for a specific territory?
@@ -15,6 +15,9 @@
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/h6280/h6280.h"
+#include "sound/2203intf.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 VIDEO_START( madmotor );
 VIDEO_UPDATE( madmotor );
@@ -271,25 +274,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /******************************************************************************/
 
-static struct OKIM6295interface okim6295_interface =
-{
-	2,              /* 2 chips */
-	{ 7757, 15514 },/* ?? Frequency */
-	{ REGION_SOUND1, REGION_SOUND2 },	/* memory regions */
-	{ 50, 25 }		/* Note!  Keep chip 1 (voices) louder than chip 2 */
-};
-
-static struct YM2203interface ym2203_interface =
-{
-	1,
-	21470000/6,	/* ?? Audio section crystal is 21.470 MHz */
-	{ YM2203_VOL(40,40) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static void sound_irq(int state)
 {
 	cpunum_set_input_line(1,1,state); /* IRQ 2 */
@@ -297,10 +281,7 @@ static void sound_irq(int state)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	21470000/6, /* ?? Audio section crystal is 21.470 MHz */
-	{ YM3012_VOL(45,MIXER_PAN_LEFT,45,MIXER_PAN_RIGHT) },
-	{ sound_irq }
+	sound_irq
 };
 
 static MACHINE_DRIVER_START( madmotor )
@@ -311,7 +292,7 @@ static MACHINE_DRIVER_START( madmotor )
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)/* VBL */
 
 	MDRV_CPU_ADD(H6280, 8053000/2) /* Custom chip 45, Crystal near CPU is 8.053 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(58)
@@ -328,9 +309,23 @@ static MACHINE_DRIVER_START( madmotor )
 	MDRV_VIDEO_UPDATE(madmotor)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 21470000/6)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+
+	MDRV_SOUND_ADD(YM2151, 21470000/6)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.45)
+	MDRV_SOUND_ROUTE(1, "mono", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 7757)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(OKIM6295, 15514)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 /******************************************************************************/
