@@ -24,6 +24,9 @@ Notes:
 #include "vidhrdw/generic.h"
 #include "vidhrdw/konamiic.h"
 #include "cpu/m6809/m6809.h"
+#include "sound/2151intf.h"
+#include "sound/k007232.h"
+#include "sound/upd7759.h"
 
 
 VIDEO_UPDATE( mainevt );
@@ -64,7 +67,7 @@ WRITE8_HANDLER( mainevt_bankswitch_w )
 	cpu_setbank(1,&RAM[bankaddress]);
 
 	/* TODO: bit 5 = select work RAM or palette? */
-/*	palette_selected = data & 0x20; */
+/*  palette_selected = data & 0x20; */
 
 	/* bit 6 = enable char ROM reading through the video RAM */
 	K052109_set_RMRD_line((data & 0x40) ? ASSERT_LINE : CLEAR_LINE);
@@ -91,8 +94,8 @@ WRITE8_HANDLER( mainevt_sh_irqtrigger_w )
 
 WRITE8_HANDLER( mainevt_sh_irqcontrol_w )
 {
-	UPD7759_reset_w(0, data & 2);
-	UPD7759_start_w(0, data & 1);
+	upd7759_reset_w(0, data & 2);
+	upd7759_start_w(0, data & 1);
 
 	interrupt_enable_w(0,data & 4);
 }
@@ -114,7 +117,7 @@ WRITE8_HANDLER( mainevt_sh_bankswitch_w )
 	K007232_set_bank( 0, bank_A, bank_B );
 
 	/* bits 4-5 select the UPD7759 bank */
-	UPD7759_set_bank_base(0, ((data >> 4) & 0x03) * 0x20000);
+	upd7759_set_bank_base(0, ((data >> 4) & 0x03) * 0x20000);
 }
 
 WRITE8_HANDLER( dv_sh_bankswitch_w )
@@ -195,14 +198,14 @@ static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0x83ff) AM_READ(MRA8_RAM)
 	AM_RANGE(0xa000, 0xa000) AM_READ(soundlatch_r)
 	AM_RANGE(0xb000, 0xb00d) AM_READ(K007232_read_port_0_r)
-	AM_RANGE(0xd000, 0xd000) AM_READ(UPD7759_0_busy_r)
+	AM_RANGE(0xd000, 0xd000) AM_READ(upd7759_0_busy_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
 	AM_RANGE(0x8000, 0x83ff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0xb000, 0xb00d) AM_WRITE(K007232_write_port_0_w)
-	AM_RANGE(0x9000, 0x9000) AM_WRITE(UPD7759_0_port_w)
+	AM_RANGE(0x9000, 0x9000) AM_WRITE(upd7759_0_port_w)
 	AM_RANGE(0xe000, 0xe000) AM_WRITE(mainevt_sh_irqcontrol_w)
 	AM_RANGE(0xf000, 0xf000) AM_WRITE(mainevt_sh_bankswitch_w)
 ADDRESS_MAP_END
@@ -531,7 +534,7 @@ INPUT_PORTS_START( devstors )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
  	PORT_START
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )
@@ -642,7 +645,7 @@ INPUT_PORTS_START( devstor2 )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
  	PORT_START
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )
@@ -691,28 +694,14 @@ static void volume_callback(int v)
 
 static struct K007232_interface k007232_interface =
 {
-	1,		/* number of chips */
-	3579545,	/* clock */
-	{ REGION_SOUND1 },	/* memory regions */
-	{ K007232_VOL(20,MIXER_PAN_CENTER,20,MIXER_PAN_CENTER) },	/* volume */
-	{ volume_callback }	/* external port callback */
+	REGION_SOUND1,	/* memory regions */
+	volume_callback	/* external port callback */
 };
 
-static struct UPD7759_interface upd7759_interface =
+static struct upd7759_interface upd7759_interface =
 {
-	1,		/* number of chips */
-	{ 50 }, /* volume */
-	{ REGION_SOUND2 },		/* memory region */
-	UPD7759_STANDALONE_MODE,		/* chip mode */
-	{0}
-};
-
-static struct YM2151interface ym2151_interface =
-{
-	1,			/* 1 chip */
-	3579545,	/* 3.579545 MHz */
-	{ YM3012_VOL(30,MIXER_PAN_CENTER,30,MIXER_PAN_CENTER) },
-	{ 0 }
+	REGION_SOUND2,		/* memory region */
+	0
 };
 
 static MACHINE_DRIVER_START( mainevt )
@@ -723,7 +712,7 @@ static MACHINE_DRIVER_START( mainevt )
 	MDRV_CPU_VBLANK_INT(mainevt_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 3.579545 MHz */
+	/* audio CPU */	/* 3.579545 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,8)	/* ??? */
 
@@ -740,8 +729,16 @@ static MACHINE_DRIVER_START( mainevt )
 	MDRV_VIDEO_UPDATE(mainevt)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(K007232, k007232_interface)
-	MDRV_SOUND_ADD(UPD7759, upd7759_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(K007232, 3579545)
+	MDRV_SOUND_CONFIG(k007232_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+
+	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
+	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -753,7 +750,7 @@ static MACHINE_DRIVER_START( devstors )
 	MDRV_CPU_VBLANK_INT(dv_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 3.579545 MHz */
+	/* audio CPU */	/* 3.579545 MHz */
 	MDRV_CPU_PROGRAM_MAP(dv_sound_readmem,dv_sound_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
 
@@ -770,8 +767,16 @@ static MACHINE_DRIVER_START( devstors )
 	MDRV_VIDEO_UPDATE(dv)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(K007232, k007232_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_ROUTE(0, "mono", 0.30)
+	MDRV_SOUND_ROUTE(1, "mono", 0.30)
+
+	MDRV_SOUND_ADD(K007232, 3579545)
+	MDRV_SOUND_CONFIG(k007232_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
 MACHINE_DRIVER_END
 
 
