@@ -72,6 +72,9 @@ write:
 #include "vidhrdw/generic.h"
 #include "cpu/i8039/i8039.h"
 #include "state.h"
+#include "sound/dac.h"
+#include "sound/ay8910.h"
+#include "sound/samples.h"
 
 static int p[8] = { 0,0xf0,0,0,0,0,0,0 };
 static int t[2] = { 0,0 };
@@ -167,7 +170,7 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x7f00, 0x7f07) AM_WRITE(mario_sh3_w) /* Misc discrete samples */
 	AM_RANGE(0x7e00, 0x7e00) AM_WRITE(mario_sh_tuneselect_w)
 	AM_RANGE(0x7000, 0x73ff) AM_WRITE(MWA8_NOP)	/* ??? */
-/*	AM_RANGE(0x7e85, 0x7e85) AM_WRITE(MWA8_RAM)	   Sets alternative 1 and 0    */
+/*  AM_RANGE(0x7e85, 0x7e85) AM_WRITE(MWA8_RAM)    Sets alternative 1 and 0    */
 	AM_RANGE(0xf000, 0xffff) AM_WRITE(MWA8_ROM)
 ADDRESS_MAP_END
 
@@ -188,6 +191,7 @@ static ADDRESS_MAP_START( masao_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( mario_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(MWA8_NOP)  /* unknown... is this a trigger? */
 ADDRESS_MAP_END
 
@@ -340,12 +344,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 100 }
-};
-
 static const char *mario_sample_names[] =
 {
 	"*mario",
@@ -367,19 +365,12 @@ static const char *mario_sample_names[] =
 static struct Samplesinterface samples_interface =
 {
 	3,	/* 3 channels */
-	25,	/* volume */
 	mario_sample_names
 };
 
 static struct AY8910interface ay8910_interface =
 {
-	1,      /* 1 chip */
-	14318000/6,	/* ? */
-	{ 50 },
-	{ soundlatch_r },
-	{ 0 },
-	{ 0 },
-	{ 0 }
+	soundlatch_r
 };
 
 static ADDRESS_MAP_START( masao_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -405,7 +396,7 @@ static MACHINE_DRIVER_START( mario )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(I8039, 730000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)         /* 730 kHz */
+	/* audio CPU */         /* 730 kHz */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 	MDRV_CPU_IO_MAP(readport_sound,writeport_sound)
 
@@ -425,8 +416,14 @@ static MACHINE_DRIVER_START( mario )
 	MDRV_VIDEO_UPDATE(mario)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, dac_interface)
-	MDRV_SOUND_ADD(SAMPLES, samples_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -438,7 +435,7 @@ static MACHINE_DRIVER_START( masao )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(Z80,24576000/16)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ???? */
+	/* audio CPU */	/* ???? */
 	MDRV_CPU_PROGRAM_MAP(masao_sound_readmem,masao_sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -457,7 +454,11 @@ static MACHINE_DRIVER_START( masao )
 	MDRV_VIDEO_UPDATE(mario)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 14318000/6)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
