@@ -7,10 +7,10 @@ various early SNK games (1983-1985)
 driver by Phil Stroffolino
 
 Known Issues:
-	Mad Crasher fails the ROM test, but ROMs are verified to be good (reason's unknown)
-	Mad Crasher sound effects aren't being played (fixed)
-	Vanguard II crashes under dos with sound enabled (cannot verify)
-	Marvin's maze crashes under dos with sound enabled, hangs with sound disabled (cannot verify)
+    Mad Crasher fails the ROM test, but ROMs are verified to be good (reason's unknown)
+    Mad Crasher sound effects aren't being played (fixed)
+    Vanguard II crashes under dos with sound enabled (cannot verify)
+    Marvin's maze crashes under dos with sound enabled, hangs with sound disabled (cannot verify)
 
 
 Change Log
@@ -28,13 +28,15 @@ AT08XX03:
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "snk.h"
+#include "sound/ay8910.h"
+#include "sound/namco.h"
 
 #define CREDITS "Phil Stroffolino\nTim Lindquist\nCarlos A. Lozano"
 
 
 /***************************************************************************
 **
-**	CPUA and CPUB communicate through shared RAM.
+**  CPUA and CPUB communicate through shared RAM.
 **
 ***************************************************************************/
 
@@ -66,10 +68,10 @@ extern WRITE8_HANDLER( marvins_palette_bank_w );
 
 /***************************************************************************
 **
-**	Interrupt Handling
+**  Interrupt Handling
 **
-**	CPUA can trigger an interrupt on CPUB, and CPUB can trigger an interrupt
-**	on CPUA.  Each CPU must re-enable interrupts on itself.
+**  CPUA can trigger an interrupt on CPUB, and CPUB can trigger an interrupt
+**  on CPUA.  Each CPU must re-enable interrupts on itself.
 **
 ***************************************************************************/
 
@@ -78,21 +80,21 @@ extern WRITE8_HANDLER( marvins_palette_bank_w );
 
 /***************************************************************************
 **
-**	Sound System
+**  Sound System
 **
-**	The sound CPU is a slave, with communication.
+**  The sound CPU is a slave, with communication.
 **
-**	Sound Chips: PSGX2 + "Wave Generater"
+**  Sound Chips: PSGX2 + "Wave Generater"
 **
-**	The Custom Wave Generator is controlled by 6 bytes
+**  The Custom Wave Generator is controlled by 6 bytes
 **
-**	The first pair of registers (0x8002, 0x8003) appear to define frequency
-**	as a fraction: RAM[0x8003]/RAM[0x8002].
+**  The first pair of registers (0x8002, 0x8003) appear to define frequency
+**  as a fraction: RAM[0x8003]/RAM[0x8002].
 **
-**	(0x8004, 0x8005, 0x8006, 0x8007) are currently unmapped.  Probably they
-**	control the shape of the wave being played.
+**  (0x8004, 0x8005, 0x8006, 0x8007) are currently unmapped.  Probably they
+**  control the shape of the wave being played.
 **
-**	snkwave_interface is currently implemented with the "namco" sound component.
+**  snkwave_interface is currently implemented with the "namco" sound component.
 **
 ***************************************************************************/
 
@@ -102,23 +104,10 @@ static int sound_cpu_busy;
 
 static struct namco_interface snkwave_interface =
 {
-	8000000/256,	/* (wave generator has a 8MHz clock near it) */
 	1,				/* number of voices */
-	10,				/* playback volume */
 	-1				/* memory region */
 };
 
-static struct AY8910interface ay8910_interface =
-{
-	2,			/* number of chips */
-	2000000,	/* 2 MHz */
-	{ 25,25 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static void init_sound( int busy_bit )
 {
 	snk_sound_busy_bit = busy_bit;
@@ -168,18 +157,19 @@ static ADDRESS_MAP_START( writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport_sound, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x0000, 0x0000) AM_READ(MRA8_NOP)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x00, 0x00) AM_READ(MRA8_NOP)
 ADDRESS_MAP_END
 
 
 /***************************************************************************
 **
-**	Memory Maps for CPUA, CPUB
+**  Memory Maps for CPUA, CPUB
 **
-**	Shared RAM is shuffled in Mad Crasher/Vanguard II compared to
-**	Marvin's Maze.
+**  Shared RAM is shuffled in Mad Crasher/Vanguard II compared to
+**  Marvin's Maze.
 **
-**	A few ports are mapped differently for each game.
+**  A few ports are mapped differently for each game.
 **
 ***************************************************************************/
 
@@ -241,7 +231,7 @@ static ADDRESS_MAP_START( madcrash_writemem_CPUA, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8300, 0x8300) AM_WRITE(sound_command_w)
 	AM_RANGE(0x8600, 0x86ff) AM_WRITE(MWA8_RAM)	/* video attribute */
 	AM_RANGE(0x8700, 0x8700) AM_WRITE(snk_cpuA_nmi_ack_w)
-/*	AM_RANGE(0xc800, 0xc800) AM_WRITE(marvins_palette_bank_w)	// palette bank switch (c8f1 for Vanguard) */
+/*  AM_RANGE(0xc800, 0xc800) AM_WRITE(marvins_palette_bank_w)   // palette bank switch (c8f1 for Vanguard) */
 	AM_RANGE(0xc800, 0xc8ff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0xc000, 0xcfff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram)
 	AM_RANGE(0xd000, 0xdfff) AM_WRITE(marvins_background_ram_w) AM_BASE(&spriteram_3)
@@ -472,7 +462,7 @@ INPUT_PORTS_START( madcrash )
 	PORT_DIPSETTING(    0x04, "3" )
 	PORT_DIPSETTING(    0x00, "5" )
 	PORT_DIPNAME( 0x38, 0x38, DEF_STR( Coinage ) )
-/*	PORT_DIPSETTING(    0x08, DEF_STR( 5C_1C ) ) */
+/*  PORT_DIPSETTING(    0x08, DEF_STR( 5C_1C ) ) */
 	PORT_DIPSETTING(    0x10, DEF_STR( 5C_1C ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0x18, DEF_STR( 2C_1C ) )
@@ -514,7 +504,7 @@ INPUT_PORTS_END
 
 /***************************************************************************
 **
-**	Graphics Layout
+**  Graphics Layout
 **
 ***************************************************************************/
 
@@ -558,7 +548,7 @@ static struct GfxDecodeInfo marvins_gfxdecodeinfo[] =
 
 /***************************************************************************
 **
-**	Machine Driver
+**  Machine Driver
 **
 ***************************************************************************/
 
@@ -574,7 +564,7 @@ static MACHINE_DRIVER_START( marvins )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)	/* 4.0 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 	MDRV_CPU_IO_MAP(readport_sound,0)
 	MDRV_CPU_PERIODIC_INT(nmi_line_assert, 244)	/* schematics show a separate 244Hz timer */
@@ -594,8 +584,17 @@ static MACHINE_DRIVER_START( marvins )
 	MDRV_VIDEO_UPDATE(marvins)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(NAMCO, snkwave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(NAMCO, 8000000/256)
+	MDRV_SOUND_CONFIG(snkwave_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 MACHINE_DRIVER_END
 
 
@@ -611,7 +610,7 @@ static MACHINE_DRIVER_START( vangrd2 )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)	/* 4.0 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 	MDRV_CPU_IO_MAP(readport_sound,0)
 	MDRV_CPU_PERIODIC_INT(nmi_line_assert, 244)
@@ -631,8 +630,17 @@ static MACHINE_DRIVER_START( vangrd2 )
 	MDRV_VIDEO_UPDATE(madcrash)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(NAMCO, snkwave_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(NAMCO, 8000000/256)
+	MDRV_SOUND_CONFIG(snkwave_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 MACHINE_DRIVER_END
 
 
@@ -656,11 +664,11 @@ MACHINE_DRIVER_END
 
 /***************************************************************************
 **
-**	ROM Loading
+**  ROM Loading
 **
-**	note:
-**		Mad Crasher doesn't pass its internal checksum
-**		Also, some of the background graphics look to be incorrect.
+**  note:
+**      Mad Crasher doesn't pass its internal checksum
+**      Also, some of the background graphics look to be incorrect.
 **
 ***************************************************************************/
 
@@ -782,12 +790,12 @@ static DRIVER_INIT( marvins )
 static DRIVER_INIT( madcrash )
 {
 /*
-	The following lines patch out the ROM test (which fails - probably
-	because of bit rot, so the rest of the test mode (what little there
-	is) can be explored.
+    The following lines patch out the ROM test (which fails - probably
+    because of bit rot, so the rest of the test mode (what little there
+    is) can be explored.
 
-	unsigned char *mem = memory_region(REGION_CPU1);
-	mem[0x3a5d] = 0; mem[0x3a5e] = 0; mem[0x3a5f] = 0;
+    unsigned char *mem = memory_region(REGION_CPU1);
+    mem[0x3a5d] = 0; mem[0x3a5e] = 0; mem[0x3a5f] = 0;
 */
 	init_sound( 0x20 );
 	snk_gamegroup = 1;
