@@ -14,7 +14,8 @@
 
  Hardware Overview:
 
- Board Name : LINDA5 (Magical Cat) / LINDA25 (Nostradamus)
+Magical Cat (C) 1993 Wintechno
+Board Name: LINDA5
 
  Main CPU: 68000-16
  Sound CPU: Z80
@@ -23,6 +24,83 @@
  Custom: FACE FX1037 x1
          038 x2 (As in Cave)
 
+
+Nostradamus (C) 1993 FACE
+Board Name: LINDA25
+
+  Main CPU: MC68000P12F 16MHz
+ Sound CPU: Z8400B PS (Goldstar)
+Sound chip: YMF286-K & Y3016-F
+
+Graphics chips:
+176 Pin PQFP 038 9330EX705
+176 Pin PQFP 038 9320EX702
+176 Pin PQFP FX1037 FACE FA01-2075 (Face Custom)
+
+OSC 28.000 MHz - SEOAN SX0-T100
+OSC 16.000 MHz - Sunny SC0-010T
+
+8 Way DIP Switch x 2
+Push Button Test Switch
+
+Roms:
+NOS-PO-U 2740000PC-15 (68k Program) U29 - Odd
+NOS-PE-U 2740000PC-15 (68k Program) U30 - Even
+NOS-PS     D27C020-15 (Z80 program) U9
+
+As labelled on PCB, with location:
+NOS-SO-00.U83-
+NOS-SO-01.U85 \
+NOS-SO-02.U87  | Sprites Odd/Even (These are 27C8001)
+NOS-SE-00.U82  |
+NOS-SE-01.U84 /
+NOS-SE-02.U86-
+U92 & U93 are unpopulated
+
+NOS-SN-00.U53 Sound samples (Near the YMF286-K)
+
+NOS-B0-00.U58-
+NOS-B0-01.U59 \ Background (Seperate for each 038 chip?)
+NOS-B1-00.U60 /
+NOS-B1-01.U61-
+
+YMF286-K is compatible to YM2610 - see psikyo.c driver
+038 9320EX702 / 038 9330EX705    - see Cave.c driver
+
+Note # = Pin #1    PCB Layout:
+
++----------------------------------------------------------------------------+
+| ___________                                                                |_
+|| NOS-B1-00 |                                                                J|
+|#___________|                ________   ________                             A|
+| ___________   __________   |NOS-PO-U| |NOS-PE-U|                            M|
+|| NOS-B1-01 | |          |  #________| #________|                            M|
+|#___________| | 038      |   ___________________    _______                  A|
+|              | 9330EX705|  |   MC68000P12F     |  |NOS-PS |                  |
+|              |__________#  |   16MHz           |  #_______|                 C|
+|                            #___________________|  ___________               o|
+| ___________   __________                         | Z8400B PS |              n|
+|| NOS-B0-00 | |          |                        #___________|              n|
+|#___________| | 038      |                        ______________             e|
+| ___________  | 9320EX702|                   SW1 |   YMF286-K   |            c|
+|| NOS-B0-01 | |__________#     _________         #______________|            t|
+|#___________|                 |FX1037   #  SW2                    _______    i|
+|                              |(C) Face |         ___________    |Y3016-F#   o|
+|                              |FA01-2075|        | NOS-SN-00 |   |_______|   n|
+|                              |_________|        #___________|               _|
+| ______                   ___  ___  ___       ___  ___  ___                 |
+||OSC 28|                 # N |# N |# N |  E  # N |# N |# N | E              |
+|#______|                 | O || O || O |  m  | O || O || O | m              |
+|                         | S || S || S |  p  | S || S || S | p              |
+| Empty                   | | || | || | |  t  | | || | || | | t              |
+|  OSC                    | S || S || S |  y  | S || S || S | y              |
+| ______                  | E || E || E |     | O || O || O |                |
+||OSC 16|                 | | || | || | |  S  | | || | || | | S              |
+|#______|                 | 0 || 0 || 0 |  C  | 0 || 0 || 0 | C              |
+|                         | 0 || 1 || 2 |  K  | 0 || 1 || 2 | K              |
+|    PUSHBTN              |___||___||___|  T  |___||___||___| T              |
++----------------------------------------------------------------------------+
+
 *******************************************************************************
 
 Stephh's notes (based on the games M68000 code and some tests) :
@@ -59,6 +137,7 @@ Stephh's notes (based on the games M68000 code and some tests) :
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2610intf.h"
 
 VIDEO_UPDATE( mcatadv );
 VIDEO_START( mcatadv );
@@ -86,6 +165,7 @@ static WRITE16_HANDLER( mcat_soundlatch_w )
 	cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE);
 }
 
+#if 0 /* mcat only.. install read handler? */
 static WRITE16_HANDLER( mcat_coin_w )
 {
 	if(ACCESSING_MSB16)
@@ -96,6 +176,7 @@ static WRITE16_HANDLER( mcat_coin_w )
 		coin_lockout_w(1, ~data & 0x8000);
 	}
 }
+#endif
 
 static READ16_HANDLER( mcat_wd_r )
 {
@@ -111,7 +192,7 @@ static ADDRESS_MAP_START( mcatadv_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x200000, 0x200005) AM_READ(MRA16_RAM)
 	AM_RANGE(0x300000, 0x300005) AM_READ(MRA16_RAM)
 
-/*	AM_RANGE(0x180018, 0x18001f) AM_READ(MRA16_NOP) // ? */
+/*  AM_RANGE(0x180018, 0x18001f) AM_READ(MRA16_NOP) // ? */
 
 	AM_RANGE(0x400000, 0x401fff) AM_READ(MRA16_RAM) /* Tilemap 0 */
 	AM_RANGE(0x500000, 0x501fff) AM_READ(MRA16_RAM) /* Tilemap 1 */
@@ -147,7 +228,7 @@ static ADDRESS_MAP_START( mcatadv_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x700000, 0x707fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size) /* Sprites, two halves for double buffering */
 	AM_RANGE(0x708000, 0x70ffff) AM_WRITE(MWA16_RAM) /* Tests more than is needed? */
 
-/*	AM_RANGE(0x900000, 0x900001) AM_WRITE(mcat_coin_w) // Lockout / Counter MCAT Only */
+/*  AM_RANGE(0x900000, 0x900001) AM_WRITE(mcat_coin_w) // Lockout / Counter MCAT Only */
 	AM_RANGE(0xb00000, 0xb0000f) AM_WRITE(MWA16_RAM) AM_BASE(&mcatadv_vidregs)
 	AM_RANGE(0xb00018, 0xb00019) AM_WRITE(watchdog_reset16_w) /* NOST Only */
 	AM_RANGE(0xc00000, 0xc00001) AM_WRITE(mcat_soundlatch_w)
@@ -183,10 +264,12 @@ static ADDRESS_MAP_START( mcatadv_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( mcatadv_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x80, 0x80) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( mcatadv_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x80, 0x80) AM_WRITE(soundlatch2_w)
 ADDRESS_MAP_END
 
@@ -204,12 +287,14 @@ static ADDRESS_MAP_START( nost_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( nost_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x04, 0x05) AM_READ(YM2610_status_port_0_A_r)
 	AM_RANGE(0x06, 0x07) AM_READ(YM2610_status_port_0_B_r)
 	AM_RANGE(0x80, 0x80) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( nost_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM2610_control_port_0_A_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM2610_data_port_0_A_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(YM2610_control_port_0_B_w)
@@ -294,7 +379,7 @@ INPUT_PORTS_START( mcatadv )
 	PORT_DIPSETTING(    0x40, "Upright 1 Player" )
 	PORT_DIPSETTING(    0xc0, "Upright 2 Players" )
 	PORT_DIPSETTING(    0x80, DEF_STR( Cocktail ) )
-/*	PORT_DIPSETTING(    0x00, "Upright 2 Players" )		// duplicated setting (NEVER tested) */
+/*  PORT_DIPSETTING(    0x00, "Upright 2 Players" )     // duplicated setting (NEVER tested) */
 INPUT_PORTS_END
 
 INPUT_PORTS_START( nost )
@@ -401,17 +486,9 @@ static void sound_irq( int irq )
 }
 struct YM2610interface mcatadv_ym2610_interface =
 {
-	1,
-	16000000/2,	/* ? */
-	{ MIXERG(8,MIXER_GAIN_4x,MIXER_PAN_CENTER) }, /* volume of AY-3-8910 voices */
-	{ 0 },	/* A_r */
-	{ 0 },	/* B_r */
-	{ 0 },	/* A_w */
-	{ 0 },	/* B_w */
-	{ sound_irq },	/* irq */
-	{ REGION_SOUND1 },	/* delta_t */
-	{ REGION_SOUND1 },	/* adpcm */
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) }
+	sound_irq,	/* irq */
+	REGION_SOUND1,	/* delta_t */
+	REGION_SOUND1	/* adpcm */
 };
 
 static MACHINE_INIT( mcatadv )
@@ -448,8 +525,14 @@ static MACHINE_DRIVER_START( mcatadv )
 	MDRV_VIDEO_UPDATE(mcatadv)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2610, mcatadv_ym2610_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2610, 16000000/2)
+	MDRV_SOUND_CONFIG(mcatadv_ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.32)
+	MDRV_SOUND_ROUTE(0, "right", 0.32)
+	MDRV_SOUND_ROUTE(1, "left",  1.0)
+	MDRV_SOUND_ROUTE(2, "right", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( nost )
@@ -527,6 +610,35 @@ ROM_START( mcatadvj )
 	ROM_LOAD( "mca-u53.bin", 0x00000, 0x80000, CRC(64c76e05) SHA1(379cef5e0cba78d0e886c9cede41985850a3afb7) )
 ROM_END
 
+ROM_START( catt )
+	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* M68000 */
+	ROM_LOAD16_BYTE( "catt-u30.bin",  0x00000, 0x80000, CRC(8c921e1e) SHA1(2fdaa9b743e1731f3cfe9d8334f1b759cf46855d) )
+	ROM_LOAD16_BYTE( "catt-u29.bin",  0x00001, 0x80000, CRC(e725af6d) SHA1(78c08fa5744a6a953e13c0ff39736ccd4875fb72) )
+
+	ROM_REGION( 0x030000, REGION_CPU2, 0 ) /* Z80-A */
+	ROM_LOAD( "u9.bin", 0x00000, 0x20000, CRC(fda05171) SHA1(2c69292573ec35034572fa824c0cae2839d23919) )
+	ROM_RELOAD( 0x10000, 0x20000 )
+
+	ROM_REGION( 0x500000, REGION_GFX1, 0 ) /* Sprites */
+	ROM_LOAD16_BYTE( "mca-u82.bin", 0x000000, 0x100000, CRC(5f01d746) SHA1(11b241456e15299912ee365eedb8f9d5e5ca875d) )
+	ROM_LOAD16_BYTE( "mca-u83.bin", 0x000001, 0x100000, CRC(4e1be5a6) SHA1(cb19aad42dba54d6a4a33859f27254c2a3271e8c) )
+	ROM_LOAD16_BYTE( "u84.bin",     0x200000, 0x100000, CRC(843fd624) SHA1(2e16d8a909fe9447da37a87428bff0734af59a00) )
+	ROM_LOAD16_BYTE( "u85.bin",     0x200001, 0x100000, CRC(5ee7b628) SHA1(feedc212ed4893d784dc6b3361930b9199c6876d) )
+	ROM_LOAD16_BYTE( "mca-u86e",    0x400000, 0x080000, CRC(017bf1da) SHA1(f6446a7219275c0eff62129f59fdfa3a6a3e06c8) )
+	ROM_LOAD16_BYTE( "mca-u87e",    0x400001, 0x080000, CRC(bc9dc9b9) SHA1(f525c9f994d5107752aa4d3a499ee376ec75f42b) )
+
+	ROM_REGION( 0x100000, REGION_GFX2, 0 ) /* BG0 */
+	ROM_LOAD( "u58.bin",     0x00000, 0x100000, CRC(73c9343a) SHA1(9efdddbad6244c1ed267bd954563ab43a1017c96) )
+
+	ROM_REGION( 0x280000, REGION_GFX3, 0 ) /* BG1 */
+	ROM_LOAD( "mca-u60.bin", 0x000000, 0x100000, CRC(c8942614) SHA1(244fccb9abbb04e33839dd2cd0e2de430819a18c) )
+	ROM_LOAD( "mca-u61.bin", 0x100000, 0x100000, CRC(51af66c9) SHA1(1055cf78ea286f02003b0d1bf08c2d7829b36f90) )
+	ROM_LOAD( "mca-u100",    0x200000, 0x080000, CRC(b273f1b0) SHA1(39318fe2aaf2792b85426ec6791b3360ac964de3) )
+
+	ROM_REGION( 0x100000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_LOAD( "u53.bin",     0x00000, 0x100000, CRC(99f2a624) SHA1(799e8e40e8bdcc8fa4cd763a366cc32473038a49) )
+ROM_END
+
 ROM_START( nost )
 	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* M68000 */
 	ROM_LOAD16_BYTE( "nos-pe-u.bin", 0x00000, 0x80000, CRC(4b080149) SHA1(e1dbbe5bf554c7c5731cc3079850f257417e3caa) )
@@ -616,6 +728,7 @@ ROM_END
 
 GAMEX( 1993, mcatadv,  0,       mcatadv, mcatadv, mcatadv, ROT0,   "Wintechno", "Magical Cat Adventure", GAME_NO_COCKTAIL )
 GAMEX( 1993, mcatadvj, mcatadv, mcatadv, mcatadv, mcatadv, ROT0,   "Wintechno", "Magical Cat Adventure (Japan)", GAME_NO_COCKTAIL )
+GAMEX( 1993, catt,     mcatadv, mcatadv, mcatadv, mcatadv, ROT0,   "Wintechno", "Catt (Japan)", GAME_NO_COCKTAIL )
 GAMEX( 1993, nost,     0,       nost,    nost,    mcatadv, ROT270, "Face",      "Nostradamus", GAME_NO_COCKTAIL )
 GAMEX( 1993, nostj,    nost,    nost,    nost,    mcatadv, ROT270, "Face",      "Nostradamus (Japan)", GAME_NO_COCKTAIL )
 GAMEX( 1993, nostk,    nost,    nost,    nost,    mcatadv, ROT270, "Face",      "Nostradamus (Korea)", GAME_NO_COCKTAIL )
