@@ -11,6 +11,9 @@ To enter service mode, keep 1&2 pressed on reset
 #include "cpu/m6809/m6809.h"
 #include "cpu/i8039/i8039.h"
 #include "cpu/z80/z80.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
+#include "sound/flt_rc.h"
 
 
 void konami1_decode(void);
@@ -69,7 +72,7 @@ static WRITE8_HANDLER( megazone_portB_w )
 		if (data & 1) C +=  10000;	/*  10000pF = 0.01uF */
 		if (data & 2) C += 220000;	/* 220000pF = 0.22uF */
 		data >>= 2;
-		set_RC_filter(i,1000,2200,200,C);
+		filter_rc_set_RC(i,1000,2200,200,C);
 	}
 }
 
@@ -162,10 +165,12 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x02) AM_READ(AY8910_read_port_0_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(AY8910_write_port_0_w)
 ADDRESS_MAP_END
@@ -315,19 +320,10 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 static struct AY8910interface ay8910_interface =
 {
-	1,	/* 1 chip */
-	14318000/8,	/* 1.78975 MHz */
-	{ 30 },
-	{ megazone_portA_r },
-	{ 0 },
-	{ 0 },
-	{ megazone_portB_w }
-};
-
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 50 }
+	megazone_portA_r,
+	0,
+	0,
+	megazone_portB_w
 };
 
 
@@ -345,7 +341,7 @@ static MACHINE_DRIVER_START( megazone )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(I8039,(14318000/2)/I8039_CLOCK_DIVIDER)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 1/2 14MHz crystal */
+	/* audio CPU */	/* 1/2 14MHz crystal */
 	MDRV_CPU_PROGRAM_MAP(i8039_readmem,i8039_writemem)
 	MDRV_CPU_IO_MAP(i8039_readport,i8039_writeport)
 
@@ -366,8 +362,23 @@ static MACHINE_DRIVER_START( megazone )
 	MDRV_VIDEO_UPDATE(megazone)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 14318000/8)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(0, "filter.0.0", 0.30)
+	MDRV_SOUND_ROUTE(1, "filter.0.1", 0.30)
+	MDRV_SOUND_ROUTE(2, "filter.0.2", 0.30)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD_TAG("filter.0.0", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.0.1", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.0.2", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
