@@ -36,28 +36,28 @@ Revision:
   My investigation so far has dismissed the following possibilities:
 
  1) Hidden IRQ's - RST38 and NMI are the only interrupts operatubg in mode 1
-	and they both work as supposed to.
+    and they both work as supposed to.
 
  2) Collision code missing - I've located collision routines responsible for
-	over 90% of the enemies. They're called by individual sprite handlers
-	everytime after VRAM update - except those with collision problems.
+    over 90% of the enemies. They're called by individual sprite handlers
+    everytime after VRAM update - except those with collision problems.
 
  3) Collision data missing - Sprite information is stored at $D800. Data of
-	 the questionable sprites is further formatted, tagged and copied to the
-	 memory area shared with the MCU.
+     the questionable sprites is further formatted, tagged and copied to the
+     memory area shared with the MCU.
 
  4) MCU not working - The MCU latches specially formatted sprite data at
-	$E820 byte-by-byte, one after another into the accumulator, but does
-	not process nor store them into memory. It then asserts $E8A3 when
-	the reading is done. The code is about a kilobyte long and I checked
-	everywhere including IRQ services but no sign of collision functions.
-	The main CPU expects a result at $E8A2 however. The problrm is quite
-	similar to the randomization at $C07C in Bubble Bobble.
+    $E820 byte-by-byte, one after another into the accumulator, but does
+    not process nor store them into memory. It then asserts $E8A3 when
+    the reading is done. The code is about a kilobyte long and I checked
+    everywhere including IRQ services but no sign of collision functions.
+    The main CPU expects a result at $E8A2 however. The problrm is quite
+    similar to the randomization at $C07C in Bubble Bobble.
 
-	Kiki Kaikai is likely to have extra circuitary connected to the MCU. I've
-	added a function in machine\mexico86.c to simulate its I/O behavior but we
-	need real board owners to verify. Mexico86 and Kick'n Run don't use
-	$E8A2-$E8A3 so they're not affected in any way.
+    Kiki Kaikai is likely to have extra circuitary connected to the MCU. I've
+    added a function in machine\mexico86.c to simulate its I/O behavior but we
+    need real board owners to verify. Mexico86 and Kick'n Run don't use
+    $E8A2-$E8A3 so they're not affected in any way.
 
 - Modified VIDEO_UPDATE. The orignal is a Mexico86 duplicate which produces
   graphics artifacts especially beyond stage 3.
@@ -68,6 +68,7 @@ Revision:
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
+#include "sound/2203intf.h"
 
 /* in machine/mexico86.c */
 extern unsigned char *mexico86_protection_ram;
@@ -89,7 +90,7 @@ VIDEO_UPDATE( kikikai );
 /*AT */
 static READ8_HANDLER( kiki_2203_r )
 {
-	return(YM2203Read(0,0) & 0x7f);
+	return(YM2203_status_port_0_r(0) & 0x7f);
 }
 /*ZT */
 
@@ -137,7 +138,6 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_WRITE(MWA8_ROM)
 	AM_RANGE(0xc000, 0xe7ff) AM_WRITE(shared_w) AM_BASE(&shared)  /* shared with sound cpu */
-	/*AM_RANGE(0xc000, 0xcfff) AM_WRITE(MWA8_RAM) AM_BASE(&mexico86_videoram) */
 	AM_RANGE(0xc000, 0xd4ff) AM_WRITE(MWA8_RAM) AM_BASE(&mexico86_videoram) /*AT: corrected size */
 	AM_RANGE(0xd500, 0xd7ff) AM_WRITE(MWA8_RAM) AM_BASE(&mexico86_objectram) AM_SIZE(&mexico86_objectram_size)
 	AM_RANGE(0xe800, 0xe8ff) AM_WRITE(MWA8_RAM) AM_BASE(&mexico86_protection_ram)  /* shared with mcu */
@@ -152,7 +152,6 @@ static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
 	AM_RANGE(0x8000, 0xa7ff) AM_READ(shared_r)
 	AM_RANGE(0xa800, 0xbfff) AM_READ(MRA8_RAM)
-	/*AM_RANGE(0xc000, 0xc000) AM_READ(YM2203_status_port_0_r) */
 	AM_RANGE(0xc000, 0xc000) AM_READ(kiki_2203_r) /*AT */
 	AM_RANGE(0xc001, 0xc001) AM_READ(YM2203_read_port_0_r)
 ADDRESS_MAP_END
@@ -186,7 +185,9 @@ static ADDRESS_MAP_START( m68705_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0080, 0x07ff) AM_WRITE(MWA8_ROM)
 ADDRESS_MAP_END
 
-
+static ADDRESS_MAP_START( sub_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
+ADDRESS_MAP_END
 
 INPUT_PORTS_START( mexico86 )
 	PORT_START      /* IN0 */
@@ -223,14 +224,14 @@ INPUT_PORTS_START( mexico86 )
 	/* When Bit 1 is On, the machine waits a signal from another one */
 	/* Seems like if you can join two cabinets, one as master */
 	/* and the other as slave, probably to play four players */
-	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
+	PORT_DIPNAME( 0x01, 0x01, "System Selection" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Unknown ) )
+	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Unknown ) ) /* Screen ? */
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) ) /* this should be Demo Sounds, but doesn't work? */
 	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Coin_A ) )
@@ -245,28 +246,27 @@ INPUT_PORTS_START( mexico86 )
 	PORT_DIPSETTING(    0x80, DEF_STR( 1C_2C ) )
 
 	PORT_START
-	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0c, 0x08, "Timer" )
-	PORT_DIPSETTING(    0x04, "Slow" )
-	PORT_DIPSETTING(    0x08, DEF_STR( Normal ) )
-	PORT_DIPSETTING(    0x0c, "Fast" )
-	PORT_DIPSETTING(    0x00, "Fastest" )
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x03, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Medium ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Hard ) )
+	PORT_DIPNAME( 0x0c, 0x08, "Playing Time" )
+	PORT_DIPSETTING(    0x00, "40 Seconds" )
+	PORT_DIPSETTING(    0x0c, "One Minute" )
+	PORT_DIPSETTING(    0x08, "One Minute and 20 Sec." )
+	PORT_DIPSETTING(    0x04, "One Minute and 40 Sec." )
 	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	/* The following dip seems to be related with the first one */
-	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )
+	PORT_DIPNAME( 0x20, 0x20, "System Selection" )
 	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x80, "Max Players" )
+	PORT_DIPNAME( 0x40, 0x00, "Number of Matches" )
+	PORT_DIPSETTING(    0x00, "2" )
+	PORT_DIPSETTING(    0x40, "6" )
+	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Players ) )
 	PORT_DIPSETTING(    0x80, "2" )
 	PORT_DIPSETTING(    0x00, "4" )
 
@@ -409,13 +409,8 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 static struct YM2203interface ym2203_interface =
 {
-	1,          /* 1 chip */
-	3000000,    /* 3 MHz ??? */
-	{ YM2203_VOL(40,40) },
-	{ input_port_3_r },
-	{ input_port_4_r },
-	{ 0 },
-	{ 0 }
+	input_port_3_r,
+	input_port_4_r
 };
 
 
@@ -434,6 +429,10 @@ static MACHINE_DRIVER_START( mexico86 )
 	MDRV_CPU_PROGRAM_MAP(m68705_readmem,m68705_writemem)
 	MDRV_CPU_VBLANK_INT(mexico86_m68705_interrupt,2)
 
+	MDRV_CPU_ADD(Z80, 6000000)      /* 6 MHz??? */
+	MDRV_CPU_PROGRAM_MAP(sub_cpu_map,0)
+	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)  /* frames per second, vblank duration */
 	MDRV_INTERLEAVE(100)    /* 100 CPU slices per frame - an high value to ensure proper */
@@ -450,7 +449,11 @@ static MACHINE_DRIVER_START( mexico86 )
 	MDRV_VIDEO_UPDATE(mexico86)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 MACHINE_DRIVER_END
 
 
@@ -508,6 +511,9 @@ ROM_START( kicknrun )
 	ROM_REGION( 0x0800, REGION_CPU3, 0 )    /* 2k for the microcontroller */
 	ROM_LOAD( "knrmcu.bin",   0x0000, 0x0800, BAD_DUMP CRC(8e821fa0) SHA1(331f5da31d8767674e2b5bf0e7f5b5ad2535e044)  )  /* manually crafted from the Mexico '86 one */
 
+	ROM_REGION( 0x10000, REGION_CPU4, 0 )    /* 64k for the cpu on the sub board */
+	ROM_LOAD( "9.bin",        0x0000, 0x4000, CRC(6a2ad32f) SHA1(42d4b97b25d219902ad215793f1d2c006ffe94dc) )
+
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "a87-05.bin", 0x08000, 0x08000, CRC(4eee3a8a) SHA1(2f0e4c2fb6cba48d0e2b95927fc14f0038557371) )
 	ROM_CONTINUE(           0x00000, 0x08000 )
@@ -537,6 +543,9 @@ ROM_START( mexico86 )
 	ROM_REGION( 0x0800, REGION_CPU3, 0 )    /* 2k for the microcontroller */
 	ROM_LOAD( "68_h.bin",   0x0000, 0x0800, CRC(ff92f816) SHA1(0015c3f2ed014052b3fa376409e3a7cca36fac72) )
 
+	ROM_REGION( 0x10000, REGION_CPU4, 0 )    /* 64k for the cpu on the sub board */
+	ROM_LOAD( "9.bin",      0x0000, 0x4000, CRC(6a2ad32f) SHA1(42d4b97b25d219902ad215793f1d2c006ffe94dc) )
+
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "4_d.bin",    0x08000, 0x08000, CRC(57cfdbca) SHA1(89c305c380c3de14a956ee4bc85d3a0d343b638e) )
 	ROM_CONTINUE(           0x00000, 0x08000 )
