@@ -1,20 +1,20 @@
 /*************************************************************************
 
-	Driver for Midway V-Unit games
+    Driver for Midway V-Unit games
 
-	driver by Aaron Giles
+    driver by Aaron Giles
 
-	Games supported:
-		* Cruis'n USA (1994) [3 sets]
-		* Cruis'n World (1996) [3 sets]
-		* War Gods (1996)
-		* Off Road Challenge (1997)
+    Games supported:
+        * Cruis'n USA (1994) [3 sets]
+        * Cruis'n World (1996) [3 sets]
+        * War Gods (1996)
+        * Off Road Challenge (1997)
 
-	Known bugs:
-		* textures for automatic/manual selection get overwritten in Cruis'n World
-		* rendering needs to be looked at a little more closely to fix some holes
-		* in Cruis'n World attract mode, right side of sky looks like it has wrapped
-		* Off Road Challenge has polygon sorting issues, among other problems
+    Known bugs:
+        * textures for automatic/manual selection get overwritten in Cruis'n World
+        * rendering needs to be looked at a little more closely to fix some holes
+        * in Cruis'n World attract mode, right side of sky looks like it has wrapped
+        * Off Road Challenge has polygon sorting issues, among other problems
 
 **************************************************************************/
 
@@ -50,7 +50,7 @@ static data32_t *midvplus_misc;
 
 /*************************************
  *
- *	Machine init
+ *  Machine init
  *
  *************************************/
 
@@ -83,7 +83,7 @@ static MACHINE_INIT( midvplus )
 
 /*************************************
  *
- *	Input ports
+ *  Input ports
  *
  *************************************/
 
@@ -124,7 +124,7 @@ static READ32_HANDLER( port2_r )
 
 /*************************************
  *
- *	ADC input ports
+ *  ADC input ports
  *
  *************************************/
 
@@ -162,7 +162,7 @@ WRITE32_HANDLER( midvunit_adc_w )
 
 /*************************************
  *
- *	CMOS access
+ *  CMOS access
  *
  *************************************/
 
@@ -188,7 +188,7 @@ static READ32_HANDLER( midvunit_cmos_r )
 
 /*************************************
  *
- *	System controls
+ *  System controls
  *
  *************************************/
 
@@ -242,7 +242,7 @@ static WRITE32_HANDLER( midvunit_sound_w )
 
 /*************************************
  *
- *	TMS32031 I/O accesses
+ *  TMS32031 I/O accesses
  *
  *************************************/
 
@@ -254,7 +254,7 @@ READ32_HANDLER( tms32031_control_r )
 		/* timer is clocked at 100ns */
 		int which = (offset >> 4) & 1;
 		INT32 result = timer_timeelapsed(timer[which]) * timer_rate;
-/*		logerror("%06X:tms32031_control_r(%02X) = %08X\n", activecpu_get_pc(), offset, result); */
+/*      logerror("%06X:tms32031_control_r(%02X) = %08X\n", activecpu_get_pc(), offset, result); */
 		return result;
 	}
 
@@ -278,7 +278,7 @@ WRITE32_HANDLER( tms32031_control_w )
 	else if (offset == 0x20 || offset == 0x30)
 	{
 		int which = (offset >> 4) & 1;
-/*	logerror("%06X:tms32031_control_w(%02X) = %08X\n", activecpu_get_pc(), offset, data); */
+/*  logerror("%06X:tms32031_control_w(%02X) = %08X\n", activecpu_get_pc(), offset, data); */
 		if (data & 0x40)
 			timer_adjust(timer[which], TIME_NEVER, 0, TIME_NEVER);
 
@@ -296,10 +296,11 @@ WRITE32_HANDLER( tms32031_control_w )
 
 /*************************************
  *
- *	Serial number access
+ *  Serial number access
  *
  *************************************/
 
+#if 0
 static READ32_HANDLER( crusnwld_serial_status_r )
 {
 	int status = midway_serial_pic_status_r();
@@ -322,13 +323,13 @@ static WRITE32_HANDLER( crusnwld_serial_data_w )
 	}
 	midway_serial_pic_w(data >> 16);
 }
-
+#endif
 
 
 /*************************************
  *
- *	Some kind of protection-like
- *	device
+ *  Some kind of protection-like
+ *  device
  *
  *************************************/
 
@@ -360,7 +361,7 @@ static WRITE32_HANDLER( bit_reset_w )
 
 /*************************************
  *
- *	Off Road Challenge PIC access
+ *  Off Road Challenge PIC access
  *
  *************************************/
 
@@ -386,7 +387,7 @@ static WRITE32_HANDLER( offroadc_serial_data_w )
 
 /*************************************
  *
- *	War Gods I/O ASICs
+ *  War Gods I/O ASICs
  *
  *************************************/
 
@@ -446,14 +447,14 @@ static WRITE32_HANDLER( midvplus_misc_w )
 
 /*************************************
  *
- *	War Gods RAM grossness
+ *  War Gods RAM grossness
  *
  *************************************/
 
 static void midvplus_xf1_w(UINT8 val)
 {
 	static int lastval;
-/*	printf("xf1_w = %d\n", val); */
+/*  printf("xf1_w = %d\n", val); */
 
 	if (lastval && !val)
 		memcpy(ram_base, fastram_base, 0x20000*4);
@@ -465,7 +466,7 @@ static void midvplus_xf1_w(UINT8 val)
 
 /*************************************
  *
- *	Memory maps
+ *  Memory maps
  *
  *************************************/
 
@@ -484,7 +485,7 @@ static ADDRESS_MAP_START( midvunit_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x980082, 0x980083) AM_READ(midvunit_dma_trigger_r)
 	AM_RANGE(0x990000, 0x990000) AM_READ(MRA32_NOP)	/* link PAL (low 4 bits must == 4) */
 	AM_RANGE(0x991030, 0x991030) AM_READ(port1_r)
-/*	AM_RANGE(0x991050, 0x991050) AM_READ(MRA32_RAM)	// seems to be another port */
+/*  AM_RANGE(0x991050, 0x991050) AM_READ(MRA32_RAM) // seems to be another port */
 	AM_RANGE(0x991060, 0x991060) AM_READ(port0_r)
 	AM_RANGE(0x992000, 0x992000) AM_READ(port2_r)
 	AM_RANGE(0x993000, 0x993000) AM_READWRITE(midvunit_adc_r, midvunit_adc_w)
@@ -529,7 +530,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Input ports
+ *  Input ports
  *
  *************************************/
 
@@ -981,7 +982,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Machine drivers
+ *  Machine drivers
  *
  *************************************/
 
@@ -1026,7 +1027,7 @@ MACHINE_DRIVER_START( midvplus )
 
 	MDRV_MACHINE_INIT(midvplus)
 	MDRV_NVRAM_HANDLER(midway_serial_pic2)
-	
+
 	/* sound hardware */
 	MDRV_IMPORT_FROM(dcs2_audio)
 MACHINE_DRIVER_END
@@ -1035,7 +1036,7 @@ MACHINE_DRIVER_END
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -1283,7 +1284,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver init
+ *  Driver init
  *
  *************************************/
 
@@ -1331,9 +1332,10 @@ static void init_crusnwld_common(offs_t speedup)
 		generic_speedup = memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, speedup, speedup + 1, 0, 0, generic_speedup_r);
 }
 static DRIVER_INIT( crusnwld ) { init_crusnwld_common(0xd4c0); }
+#if 0
 static DRIVER_INIT( crusnw20 ) { init_crusnwld_common(0xd49c); }
 static DRIVER_INIT( crusnw13 ) { init_crusnwld_common(0); }
-
+#endif
 
 static DRIVER_INIT( offroadc )
 {
@@ -1368,7 +1370,7 @@ static DRIVER_INIT( wargods )
 	ide_controller_init(0, &ide_intf);
 	midway_ioasic_init(0, 452/* no alternates */, 94, NULL);
 	adc_shift = 16;
-	
+
 	/* we need proper VRAM */
 	memset(default_nvram, 0xff, sizeof(default_nvram));
 	default_nvram[0x0e] = default_nvram[0x2e] = 0x67;
@@ -1388,7 +1390,7 @@ static DRIVER_INIT( wargods )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
