@@ -15,6 +15,8 @@ OKI M6295 sound ROM dump is bad.
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/okim6295.h"
+#include "sound/3812intf.h"
 
 UINT8 *bg_paletteram, *missb2_bgvram;
 
@@ -352,23 +354,12 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 static void irqhandler(int irq)
 {
 	logerror("YM3526 firing an IRQ\n");
-/*	cpunum_set_input_line(2,0,irq ? ASSERT_LINE : CLEAR_LINE); */
+/*  cpunum_set_input_line(2,0,irq ? ASSERT_LINE : CLEAR_LINE); */
 }
 
 static struct YM3526interface ym3526_interface =
 {
-	1,				/* 1 chip (no more supported) */
-	MAIN_XTAL/8,	/* 3 MHz */
-	{ 50 },			/* volume */
-	{ irqhandler }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,					/* 1 chip */
-	{ 8000 },			/* ??? frequency */
-	{ REGION_SOUND1 },	/* memory region */
-	{ 100 }
+	irqhandler
 };
 
 /* Interrupt Generator */
@@ -391,9 +382,9 @@ static MACHINE_DRIVER_START( missb2 )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
 
 	MDRV_CPU_ADD(Z80, MAIN_XTAL/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 3 MHz */
+	/* audio CPU */	/* 3 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_map, 0)
-/*	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1) */
+/*  MDRV_CPU_VBLANK_INT(irq0_line_hold, 1) */
 	MDRV_CPU_VBLANK_INT(missb2_interrupt, 1)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -410,8 +401,15 @@ static MACHINE_DRIVER_START( missb2 )
 	MDRV_VIDEO_UPDATE(missb2)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3526, ym3526_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3526, MAIN_XTAL/8)
+	MDRV_SOUND_CONFIG(ym3526_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /* ROMs */
@@ -455,7 +453,7 @@ static DRIVER_INIT( missb2 )
 	UINT8 *ROM = memory_region(REGION_CPU1);
 
 	/* in Bubble Bobble, bank 0 has code falling from 7fff to 8000,
-	   so I have to copy it there because bank switching wouldn't catch it */
+       so I have to copy it there because bank switching wouldn't catch it */
 	memcpy(ROM+0x08000,ROM+0x10000,0x4000);
 
 }
