@@ -10,6 +10,7 @@ TODO:
 ***************************************************************************/
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2203intf.h"
 
 WRITE8_HANDLER( mnight_bgvideoram_w );
 WRITE8_HANDLER( mnight_fgvideoram_w );
@@ -112,14 +113,14 @@ static ADDRESS_MAP_START( snd_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( snd_writeport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x0000, 0x0000) AM_WRITE(YM2203_control_port_0_w)
-	AM_RANGE(0x0001, 0x0001) AM_WRITE(YM2203_write_port_0_w)
-	AM_RANGE(0x0080, 0x0080) AM_WRITE(YM2203_control_port_1_w)
-	AM_RANGE(0x0081, 0x0081) AM_WRITE(YM2203_write_port_1_w)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x00, 0x00) AM_WRITE(YM2203_control_port_0_w)
+	AM_RANGE(0x01, 0x01) AM_WRITE(YM2203_write_port_0_w)
+	AM_RANGE(0x80, 0x80) AM_WRITE(YM2203_control_port_1_w)
+	AM_RANGE(0x81, 0x81) AM_WRITE(YM2203_write_port_1_w)
 ADDRESS_MAP_END
 
 
-
 INPUT_PORTS_START( mnight )
 	PORT_START /* Player 1 controls */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
@@ -339,18 +340,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct YM2203interface ym2203_interface =
-{
-	2,	 /* 2 chips */
-	12000000/8, /* lax 11/03/1999  (1250000 -> 1500000 ???) */
-	{ YM2203_VOL(25,25), YM2203_VOL(25,25)},
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
 static MACHINE_DRIVER_START( mnight )
 
 	/* basic machine hardware */
@@ -359,7 +348,7 @@ static MACHINE_DRIVER_START( mnight )
 	MDRV_CPU_VBLANK_INT(mnight_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 5000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* 5mhz crystal ??? */
+	/* audio CPU */		/* 5mhz crystal ??? */
 	MDRV_CPU_PROGRAM_MAP(snd_readmem,snd_writemem)
 	MDRV_CPU_IO_MAP(0,snd_writeport)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,2)
@@ -381,7 +370,13 @@ static MACHINE_DRIVER_START( mnight )
 	MDRV_VIDEO_UPDATE(mnight)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 12000000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(YM2203, 12000000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
