@@ -1,5 +1,5 @@
 /* Mug Smashers (c)199? Electronic Devices (Italy) / 3D Games (England)
-	driver by David Haywood - Dip Switches and Inputs by Stephane Humbert
+    driver by David Haywood - Dip Switches and Inputs by Stephane Humbert
 
  a side scrolling beat-em-up, borrows ideas from Combatribes, including
  the music (apparently) and sound hardware!
@@ -40,6 +40,8 @@ behavior we use .
 */
 
 #include "driver.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 data16_t *mugsmash_videoram1, *mugsmash_videoram2, *mugs_spriteram;
 data16_t *mugsmash_regs1, *mugsmash_regs2;
@@ -54,7 +56,7 @@ WRITE16_HANDLER( mugsmash_videoram1_w );
 static WRITE16_HANDLER( mugsmash_reg2_w )
 {
 	mugsmash_regs2[offset] = data;
-/*	usrintf_showmessage	("Regs2 %04x, %04x, %04x, %04x", mugsmash_regs2[0], mugsmash_regs2[1],mugsmash_regs2[2], mugsmash_regs2[3]); */
+/*  usrintf_showmessage ("Regs2 %04x, %04x, %04x, %04x", mugsmash_regs2[0], mugsmash_regs2[1],mugsmash_regs2[2], mugsmash_regs2[3]); */
 
 	switch (offset)
 	{
@@ -72,79 +74,79 @@ static WRITE16_HANDLER( mugsmash_reg2_w )
 
 /* Ports mapping :
 
-	$180000.w : 0123456789ABCDEF
-	            x---------------	right     (player 1)
-	            -x--------------	left      (player 1)
-	            --x-------------	up        (player 1)
-	            ---x------------	down      (player 1)
-	            ----x-----------	button 1  (player 1)
-	            -----x----------	button 2  (player 1)
-	            ------x---------	button 3  (player 1)
-	            -------x--------	start     (player 1)
-	            --------x-------	coin 1
-	            ---------x------	coin 2
-	            ----------x-----	unused
-	            -----------x----	unused
-	            ------------x---	SW1-7     ("Color Test")     *
-	            -------------x--	SW1-8     ("Draw SF.")       *
-	            --------------x-	unused
-	            ---------------x	unused
+    $180000.w : 0123456789ABCDEF
+                x---------------    right     (player 1)
+                -x--------------    left      (player 1)
+                --x-------------    up        (player 1)
+                ---x------------    down      (player 1)
+                ----x-----------    button 1  (player 1)
+                -----x----------    button 2  (player 1)
+                ------x---------    button 3  (player 1)
+                -------x--------    start     (player 1)
+                --------x-------    coin 1
+                ---------x------    coin 2
+                ----------x-----    unused
+                -----------x----    unused
+                ------------x---    SW1-7     ("Color Test")     *
+                -------------x--    SW1-8     ("Draw SF.")       *
+                --------------x-    unused
+                ---------------x    unused
 
-	$180002.w : 0123456789ABCDEF
-	            x---------------	right     (player 2)
-	            -x--------------	left      (player 2)
-	            --x-------------	up        (player 2)
-	            ---x------------	down      (player 2)
-	            ----x-----------	button 1  (player 2)
-	            -----x----------	button 2  (player 2)
-	            ------x---------	button 3  (player 2)
-	            -------x--------	start     (player 2)
-	            --------x-------	SW1-1     ("Test Mode")
-	            ---------x------	SW1-2     ("Coin/Credit")
-	            ----------x-----	SW1-3     ("Coin/Credit")
-	            -----------x----	SW1-4     ("Coin/Credit")
-	            ------------x---	SW1-5     ("Continue")
-	            -------------x--	SW1-6     ("Sound Test")     *
-	            --------------x-	unused
-	            ---------------x	unused
+    $180002.w : 0123456789ABCDEF
+                x---------------    right     (player 2)
+                -x--------------    left      (player 2)
+                --x-------------    up        (player 2)
+                ---x------------    down      (player 2)
+                ----x-----------    button 1  (player 2)
+                -----x----------    button 2  (player 2)
+                ------x---------    button 3  (player 2)
+                -------x--------    start     (player 2)
+                --------x-------    SW1-1     ("Test Mode")
+                ---------x------    SW1-2     ("Coin/Credit")
+                ----------x-----    SW1-3     ("Coin/Credit")
+                -----------x----    SW1-4     ("Coin/Credit")
+                ------------x---    SW1-5     ("Continue")
+                -------------x--    SW1-6     ("Sound Test")     *
+                --------------x-    unused
+                ---------------x    unused
 
-	$180004.w : 0123456789ABCDEF
-	            x---------------	unused
-	            -x--------------	unused
-	            --x-------------	unused
-	            ---x------------	unused
-	            ----x-----------	unused
-	            -----x----------	unused
-	            ------x---------	unused
-	            -------x--------	unused
-	            --------x-------	SW2-1     ("Sound Demo")
-	            ---------x------	SW2-2     ("Lives Num")
-	            ----------x-----	SW2-3     ("Lives Num")
-	            -----------x----	SW2-4     ("Not Used")
-	            ------------x---	SW2-5     ("Diff Level")
-	            -------------x--	SW2-6     ("Diff Level")
-	            --------------x-	unused
-	            ---------------x	unused
+    $180004.w : 0123456789ABCDEF
+                x---------------    unused
+                -x--------------    unused
+                --x-------------    unused
+                ---x------------    unused
+                ----x-----------    unused
+                -----x----------    unused
+                ------x---------    unused
+                -------x--------    unused
+                --------x-------    SW2-1     ("Sound Demo")
+                ---------x------    SW2-2     ("Lives Num")
+                ----------x-----    SW2-3     ("Lives Num")
+                -----------x----    SW2-4     ("Not Used")
+                ------------x---    SW2-5     ("Diff Level")
+                -------------x--    SW2-6     ("Diff Level")
+                --------------x-    unused
+                ---------------x    unused
 
-	$180006.w : 0123456789ABCDEF
-	            x---------------	unused
-	            -x--------------	unused
-	            --x-------------	unused
-	            ---x------------	unused
-	            ----x-----------	unused
-	            -----x----------	unused
-	            ------x---------	unused
-	            -------x--------	unused
-	            --------x-------	SW2-7     ("Draw Obj")       *
-	            ---------x------	SW2-8     ("Screen Pause")
-	            ----------x-----	unused
-	            -----------x----	unused
-	            ------------x---	unused
-	            -------------x--	unused
-	            --------------x-	unused
-	            ---------------x	unused
+    $180006.w : 0123456789ABCDEF
+                x---------------    unused
+                -x--------------    unused
+                --x-------------    unused
+                ---x------------    unused
+                ----x-----------    unused
+                -----x----------    unused
+                ------x---------    unused
+                -------x--------    unused
+                --------x-------    SW2-7     ("Draw Obj")       *
+                ---------x------    SW2-8     ("Screen Pause")
+                ----------x-----    unused
+                -----------x----    unused
+                ------------x---    unused
+                -------------x--    unused
+                --------------x-    unused
+                ---------------x    unused
 
-	* only available when you are in "test mode"
+    * only available when you are in "test mode"
 
 */
 
@@ -423,18 +425,7 @@ static void irq_handler(int irq)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	3579545,	/* Guess */
-	{ YM3012_VOL(45,MIXER_PAN_LEFT,45,MIXER_PAN_RIGHT) },
-	{ irq_handler }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,				/* 1 chip */
-	{ 8500 },		/* frequency (Hz) */
-	{ REGION_SOUND1 },	/* memory region */
-	{ 47 }
+	irq_handler
 };
 
 static MACHINE_DRIVER_START( mugsmash )
@@ -443,7 +434,7 @@ static MACHINE_DRIVER_START( mugsmash )
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Guess */
+	/* audio CPU */	/* Guess */
 	MDRV_CPU_PROGRAM_MAP(snd_readmem,snd_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -459,9 +450,17 @@ static MACHINE_DRIVER_START( mugsmash )
 	MDRV_VIDEO_START(mugsmash)
 	MDRV_VIDEO_UPDATE(mugsmash)
 
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 8500)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.47)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.47)
 MACHINE_DRIVER_END
 
 ROM_START( mugsmash )
