@@ -1,5 +1,5 @@
 /*
-	Sega Multi System 32 hardware
+    Sega Multi System 32 hardware
 
  preliminary support by Jason Lo aka fbff
 
@@ -154,6 +154,8 @@ Stadium Cross EPR15093  EPR15094  EPR15018  EPR15019  EPR15192  EPR15020  EPR150
 #include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "machine/random.h"
+#include "sound/multipcm.h"
+#include "sound/2612intf.h"
 
 #define OSC_A	(32215900)	/* System 32 master crystal is 32215900 Hz */
 #define Z80_CLOCK (OSC_A/4)
@@ -243,25 +245,6 @@ static NVRAM_HANDLER( system32 )
 	}
 }
 
-static READ16_HANDLER(system32_eeprom_r)
-{
-	return (EEPROM_read_bit() << 7) | input_port_0_r(0);
-}
-
-static WRITE16_HANDLER(system32_eeprom_w)
-{
-	if(ACCESSING_LSB) {
-		EEPROM_write_bit(data & 0x80);
-		EEPROM_set_cs_line((data & 0x20) ? CLEAR_LINE : ASSERT_LINE);
-		EEPROM_set_clock_line((data & 0x40) ? ASSERT_LINE : CLEAR_LINE);
-	}
-}
-
-
-static READ16_HANDLER(sys32_read_ff)
-{
-	return 0xffff;
-}
 
 static READ16_HANDLER(sys32_read_random)
 {
@@ -278,9 +261,9 @@ void multi32_set_colour (int offset, int monitor)
 	UINT16 r_bright, g_bright, b_bright;
 
 	/* Although the hardware writes to all 65536 colours on both monitors, the
-	   games do not use more than 16384 colours per monitor.  We discard any
-	   colours that are written above MAX_COLOURS(16384).
-	*/
+       games do not use more than 16384 colours per monitor.  We discard any
+       colours that are written above MAX_COLOURS(16384).
+    */
 
 	if (offset<MAX_COLOURS) {
 		if (monitor) {
@@ -398,10 +381,10 @@ extern int analogSwitch;
 static READ16_HANDLER( multi32_io_analog_r )
 {
 /*
-	{ 0xc00050, 0xc00057, system32_io_analog_r },
+    { 0xc00050, 0xc00057, system32_io_analog_r },
 
-	 Read the value of each analog control port, one bit at a time, 8 times.
-	 Analog Input Set B is requested by the hardware using "analogSwitch"
+     Read the value of each analog control port, one bit at a time, 8 times.
+     Analog Input Set B is requested by the hardware using "analogSwitch"
 */
 	int retdata;
 	if (offset<=3) {
@@ -433,12 +416,12 @@ static READ16_HANDLER( multi32_io_r )
 {
 /* I/O Control port at 0xc00000
 
-	{ 0xc00000, 0xc00001, input_port_1_word_r },
-	{ 0xc00002, 0xc00003, input_port_2_word_r },
-	{ 0xc00004, 0xc00007, sys32_read_ff },
-	{ 0xc00008, 0xc00009, input_port_3_word_r },
-	{ 0xc0000a, 0xc0000b, system32_eeprom_r },
-	{ 0xc0000c, 0xc0004f, sys32_read_ff },
+    { 0xc00000, 0xc00001, input_port_1_word_r },
+    { 0xc00002, 0xc00003, input_port_2_word_r },
+    { 0xc00004, 0xc00007, sys32_read_ff },
+    { 0xc00008, 0xc00009, input_port_3_word_r },
+    { 0xc0000a, 0xc0000b, system32_eeprom_r },
+    { 0xc0000c, 0xc0004f, sys32_read_ff },
 */
 	switch(offset) {
 	case 0x00:
@@ -472,12 +455,12 @@ static WRITE16_HANDLER( multi32_io_w )
 {
 /* I/O Control port at 0xc00000
 
-	{ 0xc00006, 0xc00007, system32_eeprom_w },
-	{ 0xc0000c, 0xc0000d, jp_v60_write_cab },
-	{ 0xc00008, 0xc0000d, MWA16_RAM }, // Unknown c00008=f1lap , c0000c=titlef
-	{ 0xc0000e, 0xc0000f, MWA16_RAM, &sys32_tilebank_external }, // tilebank per layer on multi32
-	{ 0xc0001c, 0xc0001d, MWA16_RAM, &sys32_displayenable },
-	{ 0xc0001e, 0xc0001f, MWA16_RAM }, // Unknown
+    { 0xc00006, 0xc00007, system32_eeprom_w },
+    { 0xc0000c, 0xc0000d, jp_v60_write_cab },
+    { 0xc00008, 0xc0000d, MWA16_RAM }, // Unknown c00008=f1lap , c0000c=titlef
+    { 0xc0000e, 0xc0000f, MWA16_RAM, &sys32_tilebank_external }, // tilebank per layer on multi32
+    { 0xc0001c, 0xc0001d, MWA16_RAM, &sys32_displayenable },
+    { 0xc0001e, 0xc0001f, MWA16_RAM }, // Unknown
 */
 
 	COMBINE_DATA(&control[offset]);
@@ -516,10 +499,10 @@ static READ16_HANDLER( multi32_io_2_r )
 {
 /* I/O Control port at 0xc00060
 
-	{ 0xc00060, 0xc00061, input_port_4_word_r },
-	{ 0xc00062, 0xc00063, input_port_5_word_r },
-	{ 0xc00064, 0xc00065, input_port_6_word_r },
-	{ 0xc00066, 0xc000ff, sys32_read_ff },
+    { 0xc00060, 0xc00061, input_port_4_word_r },
+    { 0xc00062, 0xc00063, input_port_5_word_r },
+    { 0xc00064, 0xc00065, input_port_6_word_r },
+    { 0xc00066, 0xc000ff, sys32_read_ff },
 */
 	switch(offset) {
 	case 0x00:
@@ -538,8 +521,8 @@ static WRITE16_HANDLER( multi32_io_2_w )
 {
 /* I/O Control port at 0xc00060
 
-	{ 0xc00060, 0xc00061, MWA16_RAM }, // Analog switch
-	{ 0xc00074, 0xc00075, MWA16_RAM }, // Unknown
+    { 0xc00060, 0xc00061, MWA16_RAM }, // Analog switch
+    { 0xc00074, 0xc00075, MWA16_RAM }, // Unknown
 */
 
 	switch(offset) {
@@ -625,7 +608,7 @@ static ADDRESS_MAP_START( multi32_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x300000, 0x31ffff) AM_READ(sys32_videoram_r) /* Tile Ram */
 	AM_RANGE(0x400000, 0x41ffff) AM_READ(MRA16_RAM) /* sprite RAM */
 	AM_RANGE(0x500000, 0x50000d) AM_READ(MRA16_RAM)	/* Unknown */
-/*	AM_RANGE(0x500002, 0x500003) AM_READ(jp_v60_read_cab) */
+/*  AM_RANGE(0x500002, 0x500003) AM_READ(jp_v60_read_cab) */
 
 	AM_RANGE(0x600000, 0x6100ff) AM_READ(MRA16_RAM) /* Palette + mixer registers (Monitor A) */
 	AM_RANGE(0x680000, 0x69004f) AM_READ(MRA16_RAM) /* Palette + mixer registers (Monitor B) */
@@ -786,46 +769,38 @@ static WRITE8_HANDLER( sys32_soundbank_w )
 }
 
 static ADDRESS_MAP_START( multi32_sound_readport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x80, 0x80) AM_READ(YM2612_status_port_0_A_r)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x80, 0x80) AM_READ(YM3438_status_port_0_A_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( multi32_sound_writeport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x80, 0x80) AM_WRITE(YM2612_control_port_0_A_w)
-	AM_RANGE(0x81, 0x81) AM_WRITE(YM2612_data_port_0_A_w)
-	AM_RANGE(0x82, 0x82) AM_WRITE(YM2612_control_port_0_B_w)
-	AM_RANGE(0x83, 0x83) AM_WRITE(YM2612_data_port_0_B_w)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x80, 0x80) AM_WRITE(YM3438_control_port_0_A_w)
+	AM_RANGE(0x81, 0x81) AM_WRITE(YM3438_data_port_0_A_w)
+	AM_RANGE(0x82, 0x82) AM_WRITE(YM3438_control_port_0_B_w)
+	AM_RANGE(0x83, 0x83) AM_WRITE(YM3438_data_port_0_B_w)
 	AM_RANGE(0xa0, 0xa0) AM_WRITE(sys32_soundbank_w)
 	AM_RANGE(0xb0, 0xb0) AM_WRITE(MultiPCM_bank_0_w)
 	AM_RANGE(0xc1, 0xc1) AM_WRITE(MWA8_NOP)
 ADDRESS_MAP_END
 
-struct YM2612interface mul32_ym3438_interface =
+struct YM3438interface mul32_ym3438_interface =
 {
-	1,
-	Z80_CLOCK,
-	{ 60,60 },
-	{ 0 },	{ 0 },	{ 0 },	{ 0 },
-	{ irq_handler }
+	irq_handler
 };
 
 static struct MultiPCM_interface mul32_multipcm_interface =
 {
-	1,		/* 1 chip */
-	{ Z80_CLOCK },	/* clock */
-	{ MULTIPCM_MODE_MULTI32 },	/* banking mode */
-	{ (512*1024) },	/* bank size */
-	{ REGION_SOUND1 },	/* sample region */
-	{ YM3012_VOL(100, MIXER_PAN_CENTER, 100, MIXER_PAN_CENTER) }
+	MULTIPCM_MODE_MULTI32,	/* banking mode */
+	(512*1024),	/* bank size */
+	REGION_SOUND1,	/* sample region */
 };
 
 static struct MultiPCM_interface scross_multipcm_interface =
 {
-	1,		/* 1 chip */
-	{ Z80_CLOCK },	/* clock */
-	{ MULTIPCM_MODE_STADCROSS },	/* banking mode */
-	{ (512*1024) },	/* bank size */
-	{ REGION_SOUND1 },	/* sample region */
-	{ YM3012_VOL(100, MIXER_PAN_CENTER, 100, MIXER_PAN_CENTER) }
+	MULTIPCM_MODE_STADCROSS,	/* banking mode */
+	(512*1024),	/* bank size */
+	REGION_SOUND1	/* sample region */
 };
 
 static MACHINE_DRIVER_START( base )
@@ -856,18 +831,28 @@ static MACHINE_DRIVER_START( base )
 	MDRV_VIDEO_START(system32)
 	MDRV_VIDEO_UPDATE(system32)
 
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM3438, mul32_ym3438_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM3438, Z80_CLOCK)
+	MDRV_SOUND_CONFIG(mul32_ym3438_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.60)
+	MDRV_SOUND_ROUTE(1, "right", 0.60)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( multi32 )
 	MDRV_IMPORT_FROM(base)
-	MDRV_SOUND_ADD(MULTIPCM, mul32_multipcm_interface)
+	MDRV_SOUND_ADD(MULTIPCM, Z80_CLOCK)
+	MDRV_SOUND_CONFIG(mul32_multipcm_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( scross )
 	MDRV_IMPORT_FROM(base)
-	MDRV_SOUND_ADD(MULTIPCM, scross_multipcm_interface)
+	MDRV_SOUND_ADD(MULTIPCM, Z80_CLOCK)
+	MDRV_SOUND_CONFIG(scross_multipcm_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 static DRIVER_INIT(orunners)
