@@ -7,16 +7,17 @@
   15 MHz crystal
 
   Known Issues:
-	- sprite priority problems
-	- it's unclear if mirroring the videoram chunks is correct behavior
-	- several unmapped registers
-	- sustained sounds (when there should be silence)
+    - sprite priority problems
+    - it's unclear if mirroring the videoram chunks is correct behavior
+    - several unmapped registers
+    - sustained sounds (when there should be silence)
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
 
 
 extern UINT8 *mnchmobl_vreg;
@@ -126,17 +127,6 @@ static ADDRESS_MAP_START( writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(MWA8_RAM)
 ADDRESS_MAP_END
 
-static struct AY8910interface ay8910_interface =
-{
-	2,	/* 2 chips */
-	1500000,	/* 1.5 MHz? */
-	{ 50, 50 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 INPUT_PORTS_START( mnchmobl )
 	PORT_START
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -172,14 +162,14 @@ INPUT_PORTS_START( mnchmobl )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
 	PORT_DIPNAME( 0x1e, 0x00, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(    0x14, DEF_STR( 3C_1C ) )
-/*	PORT_DIPSETTING(    0x12, DEF_STR( 2C_1C ) ) */
+/*  PORT_DIPSETTING(    0x12, DEF_STR( 2C_1C ) ) */
 	PORT_DIPSETTING(    0x10, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x16, DEF_STR( 3C_2C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
-/*	PORT_DIPSETTING(    0x1e, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x1c, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x1a, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x18, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x1e, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x1c, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x1a, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x18, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x06, DEF_STR( 1C_4C ) )
@@ -301,7 +291,7 @@ static MACHINE_DRIVER_START( munchmo )
 	MDRV_CPU_VBLANK_INT(mnchmobl_interrupt,2)
 
 	MDRV_CPU_ADD(Z80, 3750000) /* ? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 	MDRV_CPU_VBLANK_INT(nmi_line_assert,1)
 
@@ -320,7 +310,13 @@ static MACHINE_DRIVER_START( munchmo )
 	MDRV_VIDEO_UPDATE(mnchmobl)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
