@@ -15,6 +15,7 @@ Notes:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
 
 
 extern UINT8 *mystston_videoram2;
@@ -194,18 +195,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct AY8910interface ay8910_interface =
-{
-	2,				/* 2 chips */
-	12000000/8,		/* 1.5 MHz */
-	{ 30, 30 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
 static INTERRUPT_GEN( mystston_interrupt )
 {
 	int scanline = 271 - cpu_getiloops();
@@ -232,7 +221,7 @@ static INTERRUPT_GEN( mystston_interrupt )
 		VBLK = 0x80;
 
 	/* IMS is triggered every time VLOC line 3 is raised,
-	   as VLOC counter starts at 16, effectively every 16 scanlines */
+       as VLOC counter starts at 16, effectively every 16 scanlines */
 	if ((scanline % 16) == 0)
 		cpunum_set_input_line(0, 0, HOLD_LINE);
 }
@@ -260,7 +249,13 @@ static MACHINE_DRIVER_START( mystston )
 	MDRV_VIDEO_UPDATE(mystston)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 12000000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(AY8910, 12000000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 
