@@ -131,7 +131,7 @@ static READ16_HANDLER( mweeprom_r )
 		return res;
 	}
 
-/*	logerror("msb access to eeprom port\n"); */
+/*  logerror("msb access to eeprom port\n"); */
 
 	return 0;
 }
@@ -151,7 +151,7 @@ static READ16_HANDLER( vseeprom_r )
 		return res;
 	}
 
-/*	logerror("msb access to eeprom port\n"); */
+/*  logerror("msb access to eeprom port\n"); */
 
 	return 0;
 }
@@ -166,7 +166,7 @@ static WRITE16_HANDLER( mweeprom_w )
 		return;
 	}
 
-/*	logerror("unknown LSB write %x to eeprom\n", data); */
+/*  logerror("unknown LSB write %x to eeprom\n", data); */
 
 }
 
@@ -310,7 +310,7 @@ static WRITE16_HANDLER( irq_ack_w )
 	{
 		mw_irq_control = data&0xff;
 
-/*		if ((data &0xf0) != 0xd0) logerror("Unknown write to IRQ reg: %x\n", data); */
+/*      if ((data &0xf0) != 0xd0) logerror("Unknown write to IRQ reg: %x\n", data); */
 
 	}
 }
@@ -378,7 +378,7 @@ static WRITE16_HANDLER( K053247_scattered_word_w )
 {
 	if (offset & 0x0078)
 	{
-/*		printf("spr write %x to %x (PC=%x)\n", data, offset, activecpu_get_pc()); */
+/*      printf("spr write %x to %x (PC=%x)\n", data, offset, activecpu_get_pc()); */
 		COMBINE_DATA(spriteram16+offset);
 	}
 	else
@@ -592,11 +592,11 @@ static WRITE16_HANDLER( mccontrol_w )
 
 		K053246_set_OBJCHA_line((data&0x04) ? ASSERT_LINE : CLEAR_LINE);
 
-/*		if (data & 0xf8) logerror("Unk write %x to mccontrol\n", data); */
+/*      if (data & 0xf8) logerror("Unk write %x to mccontrol\n", data); */
 
 	}
 
-/*	else logerror("write %x to LSB of mccontrol\n", data); */
+/*  else logerror("write %x to LSB of mccontrol\n", data); */
 
 }
 
@@ -816,11 +816,7 @@ ADDRESS_MAP_END
 
 static struct K054539interface k054539_interface =
 {
-	2,			/* 2 chips */
-	48000,
-	{ REGION_SOUND1, REGION_SOUND1 },
-	{ { 100, 100 }, { 100, 100 } },
-	{ NULL }
+	REGION_SOUND1
 };
 
 /**********************************************************************************/
@@ -859,6 +855,69 @@ static struct GfxDecodeInfo gfxdecodeinfo_dadandrn[] =
 	{ -1 } /* end of array */
 };
 
+static MACHINE_INIT(mystwarr)
+{
+	int i;
+
+	/* soften chorus(chip 0 channel 0-3), boost voice(chip 0 channel 4-7) */
+	for (i=0; i<=3; i++)
+	{
+		K054539_set_gain(0, i, 0.8);
+		K054539_set_gain(0, i+4, 2.0);
+	}
+
+	/* soften percussions(chip 1 channel 0-7) */
+	for (i=0; i<=7; i++) K054539_set_gain(1, i, 0.5);
+}
+
+static MACHINE_INIT(dadandrn)
+{
+	int i;
+
+	/* boost voice(chip 0 channel 4-7) */
+	for (i=4; i<=7; i++) K054539_set_gain(0, i, 2.0);
+}
+
+static MACHINE_INIT(viostorm)
+{
+	int i;
+
+	/* boost voice(chip 0 channel 4-7) */
+	for (i=4; i<=7; i++) K054539_set_gain(0, i, 2.0);
+}
+
+static MACHINE_INIT(metamrph)
+{
+	int i;
+
+	/* boost voice(chip 0 channel 4-7) and soften other channels */
+	for (i=0; i<=3; i++)
+	{
+		K054539_set_gain(0, i,   0.8);
+		K054539_set_gain(0, i+4, 1.8);
+		K054539_set_gain(1, i,   0.8);
+		K054539_set_gain(1, i+4, 0.8);
+	}
+}
+
+static MACHINE_INIT(martchmp)
+{
+	int i;
+
+	K054539_init_flags(0, K054539_REVERSE_STEREO);
+
+	/* boost voice(chip 0 channel 4-7) */
+	for (i=4; i<=7; i++) K054539_set_gain(0, i, 1.4);
+}
+
+static MACHINE_INIT(gaiapols)
+{
+	int i;
+
+	/* boost voice(chip 0 channel 5-7) */
+	for (i=5; i<=7; i++) K054539_set_gain(0, i, 2.0);
+}
+
 static MACHINE_DRIVER_START( mystwarr )
 
 	/* basic machine hardware */
@@ -867,7 +926,7 @@ static MACHINE_DRIVER_START( mystwarr )
 	MDRV_CPU_VBLANK_INT(mystwarr_interrupt, 3)
 
 	MDRV_CPU_ADD_TAG("sound", Z80, 8000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_PERIODIC_INT(nmi_line_pulse, 480)
 
@@ -876,6 +935,7 @@ static MACHINE_DRIVER_START( mystwarr )
 	MDRV_VBLANK_DURATION(600)
 
 	MDRV_NVRAM_HANDLER(mystwarr)
+	MDRV_MACHINE_INIT(mystwarr)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS | VIDEO_RGB_DIRECT | VIDEO_UPDATE_AFTER_VBLANK)
@@ -887,13 +947,24 @@ static MACHINE_DRIVER_START( mystwarr )
 	MDRV_VIDEO_UPDATE(mystwarr)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD_TAG("539", K054539, k054539_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(K054539, 48000)
+	MDRV_SOUND_CONFIG(k054539_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+
+	MDRV_SOUND_ADD(K054539, 48000)
+	MDRV_SOUND_CONFIG(k054539_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( viostorm )
 	MDRV_IMPORT_FROM(mystwarr)
 
+	MDRV_MACHINE_INIT(viostorm)
+
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
 	MDRV_CPU_PROGRAM_MAP(vsreadmem,vswritemem)
@@ -910,6 +981,8 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( metamrph )
 	MDRV_IMPORT_FROM(mystwarr)
 
+	MDRV_MACHINE_INIT(metamrph)
+
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
 	MDRV_CPU_PROGRAM_MAP(mmreadmem,mmwritemem)
@@ -926,6 +999,8 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( dadandrn )
 	MDRV_IMPORT_FROM(mystwarr)
 
+	MDRV_MACHINE_INIT(dadandrn)
+
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
 	MDRV_CPU_PROGRAM_MAP(dddreadmem, dddwritemem)
@@ -944,6 +1019,8 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( gaiapols )
 	MDRV_IMPORT_FROM(mystwarr)
 
+	MDRV_MACHINE_INIT(gaiapols)
+
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
 	MDRV_CPU_PROGRAM_MAP(gaiareadmem,gaiawritemem)
@@ -964,6 +1041,8 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( martchmp )
 	MDRV_IMPORT_FROM(mystwarr)
 
+	MDRV_MACHINE_INIT(martchmp)
+
 	/* basic machine hardware */
 	MDRV_CPU_MODIFY("main")
 	MDRV_CPU_PROGRAM_MAP(mcreadmem,mcwritemem)
@@ -1844,9 +1923,9 @@ static void init_common(void)
 	while( s<pFinish )
 	{
 		/* convert the whole mess to 5bpp planar in System GX's format
-		   (p3 p1 p2 p0 p5)
-		   (the original ROMs are stored as chunky for the first 4 bits
-		   and the 5th bit is planar, which is undecodable as-is) */
+           (p3 p1 p2 p0 p5)
+           (the original ROMs are stored as chunky for the first 4 bits
+           and the 5th bit is planar, which is undecodable as-is) */
 		int d0 = ((s[0]&0x80)   )|((s[0]&0x08)<<3)|((s[1]&0x80)>>2)|((s[1]&0x08)<<1)|
 		         ((s[2]&0x80)>>4)|((s[2]&0x08)>>1)|((s[3]&0x80)>>6)|((s[3]&0x08)>>3);
 		int d1 = ((s[0]&0x40)<<1)|((s[0]&0x04)<<4)|((s[1]&0x40)>>1)|((s[1]&0x04)<<2)|
@@ -1875,96 +1954,32 @@ static void init_common(void)
 	state_save_register_func_postload(reset_sound_region);
 }
 
-static DRIVER_INIT(mystwarr)
-{
-	int i;
-
-	init_common();
-
-	/* soften chorus(chip 0 channel 0-3), boost voice(chip 0 channel 4-7) */
-	for (i=0; i<=3; i++)
-	{
-		K054539_set_gain(0, i, 0.8);
-		K054539_set_gain(0, i+4, 2.0);
-	}
-
-	/* soften percussions(chip 1 channel 0-7) */
-	for (i=0; i<=7; i++) K054539_set_gain(1, i, 0.5);
-}
-
-static DRIVER_INIT(dadandrn)
-{
-	int i;
-
-	init_common();
-
-	/* boost voice(chip 0 channel 4-7) */
-	for (i=4; i<=7; i++) K054539_set_gain(0, i, 2.0);
-}
-
-static DRIVER_INIT(viostorm)
-{
-	int i;
-
-	init_common();
-
-	/* boost voice(chip 0 channel 4-7) */
-	for (i=4; i<=7; i++) K054539_set_gain(0, i, 2.0);
-}
-
 static DRIVER_INIT(metamrph)
 {
-	int i;
-
 	init_common();
 
 	K053250_unpack_pixels(REGION_GFX3);
-
-	/* boost voice(chip 0 channel 4-7) and soften other channels */
-	for (i=0; i<=3; i++)
-	{
-		K054539_set_gain(0, i,   0.8);
-		K054539_set_gain(0, i+4, 1.8);
-		K054539_set_gain(1, i,   0.8);
-		K054539_set_gain(1, i+4, 0.8);
-	}
 }
 
-static DRIVER_INIT(martchmp)
+static DRIVER_INIT(mwcommon)
 {
-	int i;
-
 	init_common();
-
-	K054539_init_flags(K054539_REVERSE_STEREO);
-
-	/* boost voice(chip 0 channel 4-7) */
-	for (i=4; i<=7; i++) K054539_set_gain(0, i, 1.4);
-}
-
-static DRIVER_INIT(gaiapols)
-{
-	int i;
-
-	init_common();
-
-	/* boost voice(chip 0 channel 5-7) */
-	for (i=5; i<=7; i++) K054539_set_gain(0, i, 2.0);
 }
 
 
 /*           ROM       parent    machine   inp       init */
-GAMEX( 1993, mystwarr, 0,        mystwarr, mystwarr, mystwarr, ROT0,  "Konami", "Mystic Warriors (Europe ver EAA)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, mystwaru, mystwarr, mystwarr, mystwarr, mystwarr, ROT0,  "Konami", "Mystic Warriors (US ver UAA)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, mmaulers, 0,        dadandrn, dadandrn, dadandrn, ROT0,  "Konami", "Monster Maulers (Europe ver EAA)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, dadandrn, mmaulers, dadandrn, dadandrn, dadandrn, ROT0,  "Konami", "Kyukyoku Sentai Dadandarn (Japan ver JAA)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, viostorm, 0,        viostorm, viostorm, viostorm, ROT0,  "Konami", "Violent Storm (Europe ver EAB)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, viostrmu, viostorm, viostorm, viostorm, viostorm, ROT0,  "Konami", "Violent Storm (US ver UAB)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, viostrmj, viostorm, viostorm, viostorm, viostorm, ROT0,  "Konami", "Violent Storm (Japan ver JAC)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, viostrma, viostorm, viostorm, viostorm, viostorm, ROT0,  "Konami", "Violent Storm (Asia ver AAC)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, mystwarr, 0,        mystwarr, mystwarr, mwcommon, ROT0,  "Konami", "Mystic Warriors (Europe ver EAA)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, mystwaru, mystwarr, mystwarr, mystwarr, mwcommon, ROT0,  "Konami", "Mystic Warriors (US ver UAA)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, mmaulers, 0,        dadandrn, dadandrn, mwcommon, ROT0,  "Konami", "Monster Maulers (Europe ver EAA)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, dadandrn, mmaulers, dadandrn, dadandrn, mwcommon, ROT0,  "Konami", "Kyukyoku Sentai Dadandarn (Japan ver JAA)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, viostorm, 0,        viostorm, viostorm, mwcommon, ROT0,  "Konami", "Violent Storm (Europe ver EAB)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, viostrmu, viostorm, viostorm, viostorm, mwcommon, ROT0,  "Konami", "Violent Storm (US ver UAB)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, viostrmj, viostorm, viostorm, viostorm, mwcommon, ROT0,  "Konami", "Violent Storm (Japan ver JAC)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, viostrma, viostorm, viostorm, viostorm, mwcommon, ROT0,  "Konami", "Violent Storm (Asia ver AAC)", GAME_IMPERFECT_GRAPHICS )
 GAMEX( 1993, metamrph, 0,        metamrph, metamrph, metamrph, ROT0,  "Konami", "Metamorphic Force (US ver UAA)", GAME_IMPERFECT_GRAPHICS )
 GAMEX( 1993, metamrpj, metamrph, metamrph, metamrph, metamrph, ROT0,  "Konami", "Metamorphic Force (Japan ver JAA)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, mtlchamp, 0,        martchmp, martchmp, martchmp, ROT0,  "Konami", "Martial Champion (Europe ver EAA)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, mtlchmpu, mtlchamp, martchmp, martchmp, martchmp, ROT0,  "Konami", "Martial Champion (US ver UAD)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, mtlchmpj, mtlchamp, martchmp, martchmp, martchmp, ROT0,  "Konami", "Martial Champion (Japan ver JAA)", GAME_IMPERFECT_GRAPHICS )
-GAMEX( 1993, gaiapols, 0,        gaiapols, dadandrn, gaiapols, ROT90, "Konami", "Gaiapolis (Japan ver JAF)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, mtlchamp, 0,        martchmp, martchmp, mwcommon, ROT0,  "Konami", "Martial Champion (Europe ver EAA)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, mtlchmpu, mtlchamp, martchmp, martchmp, mwcommon, ROT0,  "Konami", "Martial Champion (US ver UAD)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, mtlchmpj, mtlchamp, martchmp, martchmp, mwcommon, ROT0,  "Konami", "Martial Champion (Japan ver JAA)", GAME_IMPERFECT_GRAPHICS )
+GAMEX( 1993, gaiapols, 0,        gaiapols, dadandrn, mwcommon, ROT90, "Konami", "Gaiapolis (Japan ver JAF)", GAME_IMPERFECT_GRAPHICS )
+
