@@ -54,7 +54,7 @@ Notes:
       C416    : Namco custom QFP176
       H8/3002 : Hitachi H8/3002 HD6413002F16 QFP100 microcontroller (H8/3002 has no internal ROM capability)
       MACH210 : PLCC44 CPLD, Namco KEYCUS, stamped 'KC001'
-      62256   : 32K x8 SOJ28 SRAM 
+      62256   : 32K x8 SOJ28 SRAM
       *       : Unpopulated position for SOP44 Mask ROM 'CG1'
 
       NC1_MAIN0B.14D: 512K x16 EPROM type 27C240
@@ -70,26 +70,20 @@ Notes:
 #include "vidhrdw/ygv608.h"
 #include "cpu/h83002/h83002.h"
 #include "namcond1.h"
+#include "sound/c352.h"
+#include "machine/at28c16.h"
 
 /*************************************************************/
 
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x400000, 0x40ffff) AM_READ(namcond1_shared_ram_r)  /* shared ram */
-	AM_RANGE(0x800000, 0x80000f) AM_READ(ygv608_r)
-	AM_RANGE(0xA00000, 0xA03FFF) AM_READ(MRA16_RAM)              /* EEPROM */
+static ADDRESS_MAP_START( namcond1_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
+	AM_RANGE(0x400000, 0x40ffff) AM_READWRITE(namcond1_shared_ram_r,namcond1_shared_ram_w) AM_BASE(&namcond1_shared_ram)
+	AM_RANGE(0x800000, 0x80000f) AM_READWRITE(ygv608_r,ygv608_w)
+	AM_RANGE(0xa00000, 0xa00fff) AM_READWRITE(at28c16_16msb_0_r,at28c16_16msb_0_w)
 #ifdef MAME_DEBUG
-	AM_RANGE(0xB00000, 0xB00001) AM_READ(debug_trigger)
+	AM_RANGE(0xb00000, 0xb00001) AM_READ(debug_trigger)
 #endif
-	AM_RANGE(0xc3ff00, 0xc3ffff) AM_READ(namcond1_cuskey_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x400000, 0x40ffff) AM_WRITE(namcond1_shared_ram_w) AM_BASE(&namcond1_shared_ram)        /* shared ram? */
-	AM_RANGE(0x800000, 0x80000f) AM_WRITE(ygv608_w)
-	AM_RANGE(0xA00000, 0xA03FFF) AM_WRITE(MWA16_RAM) AM_BASE(&namcond1_eeprom)
-	AM_RANGE(0xc3ff00, 0xc3ff0f) AM_WRITE(namcond1_cuskey_w)
+	AM_RANGE(0xc3ff00, 0xc3ffff) AM_READWRITE(namcond1_cuskey_r,namcond1_cuskey_w)
 ADDRESS_MAP_END
 
 /*************************************************************/
@@ -256,9 +250,7 @@ ADDRESS_MAP_END
 
 static struct C352interface c352_interface =
 {
-	YM3012_VOL(50, MIXER_PAN_LEFT, 50, MIXER_PAN_RIGHT),
-	YM3012_VOL(50, MIXER_PAN_LEFT, 50, MIXER_PAN_RIGHT),
-	REGION_SOUND1,
+	REGION_SOUND1
 };
 
 static INTERRUPT_GEN( mcu_interrupt )
@@ -281,7 +273,7 @@ static MACHINE_DRIVER_START( namcond1 )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(M68000, 12288000)
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_PROGRAM_MAP(namcond1_map,0)
 	MDRV_CPU_VBLANK_INT(irq1_line_hold, 1)
 	MDRV_CPU_PERIODIC_INT(ygv608_timed_interrupt, 1000)
 
@@ -295,7 +287,7 @@ static MACHINE_DRIVER_START( namcond1 )
 	MDRV_INTERLEAVE(100)
 
 	MDRV_MACHINE_INIT(namcond1)
-	MDRV_NVRAM_HANDLER(namcond1)
+	MDRV_NVRAM_HANDLER(at28c16_0)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN)
@@ -309,10 +301,15 @@ static MACHINE_DRIVER_START( namcond1 )
 	MDRV_VIDEO_STOP(ygv608)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES( SOUND_SUPPORTS_STEREO )
-	MDRV_SOUND_ADD(C352, c352_interface)
-MACHINE_DRIVER_END
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
+	MDRV_SOUND_ADD(C352, 0)
+	MDRV_SOUND_CONFIG(c352_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(1, "right", 0.50)
+	MDRV_SOUND_ROUTE(2, "left", 0.50)
+	MDRV_SOUND_ROUTE(3, "right", 0.50)
+MACHINE_DRIVER_END
 
 ROM_START( ncv1 )
 	ROM_REGION( 0x100000,REGION_CPU1, 0 )		/* 16MB for Main CPU */
@@ -364,7 +361,6 @@ ROM_START( ncv2 )
 	ROM_LOAD16_WORD( "ncs1mn0.14e", 0x00000, 0x80000, CRC(fb8a4123) SHA1(47acdfe9b5441d0e3649aaa9780e676f760c4e42) )
 	ROM_LOAD16_WORD( "ncs1mn1.13e", 0x80000, 0x80000, CRC(7a5ef23b) SHA1(0408742424a6abad512b5baff63409fe44353e10) )
 
-
 	ROM_REGION( 0x80000,REGION_CPU2, 0 )		/* sub CPU */
 	ROM_LOAD( "ncs1sub.1d",          0x00000, 0x80000, CRC(365cadbf) SHA1(7263220e1630239e3e88b828c00389d02628bd7d) )
 
