@@ -1,11 +1,11 @@
 /*
-	Namco (Super) System 23
-	Stub driver
+    Namco (Super) System 23
+    Stub driver
 
-	Hardware: R4650 (MIPS III) main CPU @ 166 MHz
-	          H8/3002 MCU for sound/inputs
-		  Custom polygon hardware
-		  Tilemaps?  Sprites?
+    Hardware: R4650 (MIPS III) main CPU @ 166 MHz
+              H8/3002 MCU for sound/inputs
+          Custom polygon hardware
+          Tilemaps?  Sprites?
 */
 
 /*
@@ -13,6 +13,50 @@
 PCB Layouts
 -----------
 
+SYSTEM23 MAIN PCB 8660962302 8660971105 (8660961105)
+|----------------------------------------------------------------------------|
+|       J5                    3V_BATT                                        |
+|                     LED1-8         *R4543     *MAX734          ADM485JR    |
+|  |-------| LED10-11         LC35256                 CXA1779P  *3414 *3414  |
+|  |H8/3002|          *2061ASC-1                                             |
+|  |       |       SW4                                *LM358                 |
+|  |-------|                    DS8921                *MB88347  *MB87078     |
+|J18                                                  *LC78832  *LC78832     |
+|              SW3  14.7456MHz                  |----|   |----|  CXD1178Q    |
+|             |------| |----| |----||---------| |C435|   |C435|              |
+|    N341256  | C416 | |C422| |IDT ||         | |----|   |----|              |
+|             |      | |----| |7200||   C403  |                              |
+|    N341256  |      |        |----||         |                 |---------|  |
+|             |------|        |----||         | PAL(2)  N341256 |         |  |
+|   |----| *PST575            |IDT ||---------|                 |  C417   |  |
+|   |C352|           CY7C182  |7200|                            |         |  |
+|   |----| LED9               |----|                    N341256 |         |  |
+|                            J12                                |---------|  |
+|     KM416S1020            |-------|   PAL(3)  M5M4V4265                    |
+|                           |XILINX |                                        |
+|J16                        |XC95108|                                     J17|
+|     KM416S1020            |-------|       |---------|  |---------| N341256 |
+|                                           |         |  |         |         |
+|                                           |   C421  |  |   C404  | N341256 |
+|       |---------|              N341256    |         |  |         |         |
+|       |         |                         |         |  |         | N341256 |
+|       |   C413  |              N341256    |---------|  |---------|         |
+|       |         |                                                          |
+|       |         |                           M5M4V4265                      |
+|       |---------| SW2    LC321664                                          |
+|               *PST575                                                      |
+|                                                             *KM681000      |
+|       |----------|    |---------|                        |-------------|   |
+|       |NKK       |    |         |                        |             |   |
+|       |NR4650-138|    |   C361  |           CY2291       |    C412     |   |
+|J14    |          |    |         |                        |             |J15|
+|       |          |    |         |           14.31818MHz  |             |   |
+|       |----------|    |---------|  PAL(1)                |-------------|   |
+|                                                             *KM681000      |
+|                                                       HM5216165  HM5216165 |
+|----------------------------------------------------------------------------|
+
+
 SystemSuper23 MAIN(1) PCB 8672960904 8672960104 (8672970104)
 |----------------------------------------------------------------------------|
 |       J5                    3V_BATT                                        |
@@ -75,12 +119,17 @@ Notes:
           71V124     - IDT 128K x8 SRAM (x2, SOJ32)
           CY7C1399   - Cypress 32K x8 SRAM (x4, SOJ28)
           CY7C182    - Cypress 8K x9 SRAM (SOJ28)
+          M5M4V4265  - Mitsubishi 256K x16 DRAM (x2, TSOP40/44)
+          HM5216165  - Hitachi 1M x16 SDRAM (x2, TSOP48)
+          KM681000   - Samsung 128K x8 SRAM (x2, SOP32)
 
       Namco Customs
       -------------
                     C352 (QFP100)
                     C361 (QFP120)
+                    C403 (QFP136)
                     C404 (QFP208)
+                    C412 (QFP256)
                     C413 (QFP208)
                     C416 (QFP176)
                     C417 (QFP208)
@@ -92,9 +141,13 @@ Notes:
 
       Other ICs
       ---------
+               XC95108  - Xilinx XC95108 In-System Programmable CPLD (QFP100, labelled 'S23MA9B')
                EPM7064  - Altera MAX EPM7064STC100-10 CPLD (TQFP100, labelled 'SS23MA4A')
                DS8921   - National RS422/423 Differential Line Driver and Receiver Pair (SOIC8)
                CXD1178Q - SONY CXD1178Q  8-bit RGB 3-channel D/A converter (QFP48)
+               PAL(1)   - PALCE16V8H (PLCC20, stamped 'PAD23')
+               PAL(2)   - PALCE22V10H (PLCC28, stamped 'S23MA5')
+               PAL(3)   - PALCE22V10H (PLCC28, stamped 'SS23MA6B')
                PAL(1)   - PALCE16V8H (PLCC20, stamped 'SS23MA1B')
                PAL(2)   - PALCE22V10H (PLCC28, stamped 'SS23MA2A')
                PAL(3)   - PALCE22V10H (PLCC28, stamped 'SS23MA3A')
@@ -104,11 +157,12 @@ Notes:
                LM358    - National LM358 Low Power Dual Operational Amplifier (SOIC8)
                MB87078  - Fujitsu MB87078 Electronic Volume Control IC (SOIC24)
                MB88347  - Fujitsu MB88347 8bit 8 channel D/A converter with OP AMP output buffers (SOIC16)
-               ADM485   - Low Power EIA RS485 transceiver (SOIC8)
+               ADM485   - Analog Devices Low Power EIA RS485 transceiver (SOIC8)
                CXA1779P - SONY CXA1779P TV/Video circuit RGB Pre-Driver (DIP28)
                CY2291   - Cypress CY2291 Three-PLL General Purpose EPROM Programmable Clock Generator (SOIC20)
-               2061ASC-1- IC Designs 2061ASC-1 clock? IC (SOIC16, also found on Namco System 11 PCBs)
+               2061ASC-1- IC Designs 2061ASC-1 clock generator IC (SOIC16, also found on Namco System 11 PCBs)
                R4543    - EPSON Real Time Clock Module (SOIC14)
+               IDT7200  - Integrated Devices Technology IDT7200 256 x9 CMOS Asynchronous FIFO
 
       Misc
       ----
@@ -126,8 +180,29 @@ Notes:
 Program ROM PCB
 ---------------
 
+MSPM(FRA) PCB 8699017500 (8699017400)
+|--------------------------|
+|            J1            |
+|                          |
+|  IC3               IC1   |
+|                          |
+|                          |
+|                    IC2   |
+|--------------------------|
+Notes:
+      J1 -  Connector to plug into Main PCB
+      IC1 \
+      IC2 / Main Program  (Fujitsu 29F016 16MBit FlashROM, TSOP48)
+      IC3 - Sound Program (Fujitsu 29F400T 4MBit FlashROM, TSOP48)
+
+      Games that use this PCB include...
+
+      Game           Code and revision
+      --------------------------------
+      Time Crisis 2  TSS3 Ver.B
+
+
 MSPM(FRA) PCB 8699017501 (8699017401)
-sticker on top says '5GP3 Ver.C'
 |--------------------------|
 |            J1            |
 |                          |
@@ -139,37 +214,44 @@ sticker on top says '5GP3 Ver.C'
 Notes:
       J1 -  Connector to plug into Main PCB
       IC1 \
-      IC2 - Main Program  (Fujitsu 29F016 16MBit FlashROM, TSOP48)
+      IC2 / Main Program  (Fujitsu 29F016 16MBit FlashROM, TSOP48)
       IC3 - Sound Program (ST M29F400T 4MBit FlashROM, TSOP48)
 
+      Games that use this PCB include...
+
+      Game           Code and revision
+      --------------------------------
+      GP500          5GP3 Ver.C
+
 
 ROM PCB
 -------
 
-8660960601 (8660970601) SYSTEM23 MEM(M) PCB
-sticker - 8672961100
+Printed on the PCB      - 8660960601 (8660970601) SYSTEM23 MEM(M) PCB
+Sticker (GP500)         - 8672961100
+Sticker (Time Crisis 2) - 8660962302
 |----------------------------------------------------------------------------|
-| KEYCUS  5GP1MTBH.2M  5GP1CGLL.4M     5GP1CGLL.5M     5GP1CCRL.7M    PAL(3) |
+| KEYCUS    MTBH.2M      CGLL.4M        CGLL.5M         CCRL.7M       PAL(3) |
 |                                                                            |
 |                                                                            |
-|J1    5GP1MTAH.2J     5GP1CGLM.4K     5GP1CGLM.5K     5GP1CCRH.7K         J4|
+|J1         MTAH.2J      CGLM.4K        CGLM.5K         CCRH.7K            J4|
 |                                                                            |
-|   *                                                 JP5                    |
-|                      5GP1CGUM.4J     5GP1CGUM.5J    JP4                    |
-|      5GP1MTAL.2H                                    JP3                    |
+|   PAL(4)                                            JP5                    |
+|                        CGUM.4J        CGUM.5J       JP4                    |
+|           MTAL.2H                                   JP3                    |
 |                                                     JP2                    |
-|                      5GP1CGUU.4F     5GP1CGUU.5F                           |
-|                                                      5GP1CCRL.7F           |
-|      5GP1MTBL.2F                                                           |
+|                        CGUU.4F        CGUU.5F                              |
+|                                                       CCRL.7F              |
+|           MTBL.2F                                                          |
 |                            PAL(1)    PAL(2)                                |
-|                                                      5GP1CCRH.7E           |
+|                                                       CCRH.7E              |
 |                                                                            |
 |         JP1                                                                |
 |                                                                            |
-|     5GP1WAVEL.2C  5GP1PT3L.3C  5GP1PT2L.4C  5GP1PT1L.5C  5GP1PT0L.7C       |
+|       WAVEL.2C      PT3L.3C      PT2L.4C      PT1L.5C      PT0L.7C         |
 |J2                                                                        J3|
 |                                                                            |
-|     5GP1WAVEH.2A  5GP1PT3H.3A  5GP1PT2H.4A  5GP1PT1H.5A  5GP1PT0H.7A       |
+|       WAVEH.2A      PT3H.3A      PT2H.4A      PT1H.5A      PT0H.7A         |
 |                                                                            |
 |                                                                            |
 |----------------------------------------------------------------------------|
@@ -189,15 +271,23 @@ Notes:
                            PT*  - size fixed at 32M
                            MT*  - size fixed at 64M
 
-      KEYCUS   - Mach211 CPLD (PLCC44, labelled 'KC029')
+      KEYCUS   - Mach211 CPLD (PLCC44)
       PAL(1)   - PALCE20V8H  (PLCC28, stamped 'SS22M2')  \ Both identical
       PAL(2)   - PALCE20V8H  (PLCC28, stamped 'SS22M2')  /
       PAL(3)   - PALCE16V8H  (PLCC20, stamped 'SS22M1')
-           *   - Unpopulated position for PAL (PLCC20, labelled 'SS23M1')
+      PAL(4)   - PALCE16V8H  (PLCC20, labelled 'SS23MM1')
+                 Note this PAL is not populated when used on Super System 23
 
       All ROMs are SOP44 MaskROMs
       Note: ROMs at locations 7M, 7K, 5M, 5K, 5J & 5F are not included in the archive since they're copies of
             other ROMs which are included in the archive.
+            Each ROM is stamped with the Namco game code, then the ROM-use code (such as CCRL, CCRH, PT* or MT*).
+
+                           MaskROM
+            Game           Code     Keycus
+            ------------------------------
+            GP500          5GP1     KC029
+            Time Crisis 2  TSS1     KC010
 */
 
 
@@ -212,6 +302,7 @@ VIDEO_START( ss23 )
 	return 0;
 }
 
+#if 0
 static double
 Normalize( UINT32 data )
 {
@@ -301,6 +392,7 @@ DrawPoly( struct mame_bitmap *bitmap, const UINT32 *pSource, int n, int bNew )
 		}
 	}
 }
+#endif
 
 VIDEO_UPDATE( ss23 )
 {
@@ -353,6 +445,50 @@ VIDEO_UPDATE( ss23 )
 #endif
 }
 
+static READ32_HANDLER( keycus_KC010_r ) /* KC010 for Time Crisis 2 */
+{
+	logerror("Read keycus @ offset %x, PC=%x\n", offset, activecpu_get_pc());
+
+	switch (offset)
+	{
+		case 0:
+			return 0x7f454c46;
+			break;
+
+		case 1:
+			return 0x01020000;
+			break;
+
+		case 4:
+			return 8;
+			break;
+
+		case 8:
+			return 1;
+			break;
+
+/*      case 9: // maybe not a good idea, makes program crash earlier */
+/*          return 0x20000000; */
+/*          break; */
+
+		case 10:
+			return 0x20;
+			break;
+
+		case 11:
+			if (activecpu_get_pc() == 0xbfc0215c)
+				return 0;
+			else
+				return 0x00280028;
+			break;
+
+		default:
+			break;
+	}
+
+	return 0;
+}
+
 static READ32_HANDLER( keycus_KC029_r ) /* KC029 for GP500 */
 {
 	logerror("Read keycus @ offset %x, PC=%x\n", offset, activecpu_get_pc());
@@ -375,9 +511,9 @@ static READ32_HANDLER( keycus_KC029_r ) /* KC029 for GP500 */
 			return 1;
 			break;
 
-/*		case 9:	// maybe not a good idea, makes program crash earlier */
-/*			return 0x20000000; */
-/*			break; */
+/*      case 9: // maybe not a good idea, makes program crash earlier */
+/*          return 0x20000000; */
+/*          break; */
 
 		case 10:
 			return 0x20;
@@ -403,6 +539,13 @@ static READ32_HANDLER( ss23_vstat_r )
 	return ss23_vstat;
 }
 
+static ADDRESS_MAP_START( s23_map, ADDRESS_SPACE_PROGRAM, 32 )
+	AM_RANGE(0x00000000, 0x003fffff) AM_RAM AM_SHARE(1)
+	AM_RANGE(0x80000000, 0x803fffff) AM_RAM AM_SHARE(1)
+	AM_RANGE(0xa0000000, 0xa03fffff) AM_RAM AM_SHARE(1)
+	AM_RANGE(0xbfc00000, 0xbfc7ffff) AM_WRITENOP AM_ROM AM_SHARE(2) AM_REGION(REGION_USER1, 0)
+ADDRESS_MAP_END
+
 static ADDRESS_MAP_START( ss23_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x003fffff) AM_RAM AM_SHARE(1)
 	AM_RANGE(0x80000000, 0x803fffff) AM_RAM AM_SHARE(1)
@@ -421,13 +564,13 @@ INPUT_PORTS_END
 DRIVER_INIT(ss23)
 {
 /*
-	data32_t * pSrc = (data32_t *)memory_region(REGION_GFX4);
-	int i;
-	for( i=0; i<0x200000; i++ )
-	{
-		if( (i&0xf)==0 ) logerror( "\n%08x:", i );
-		logerror( " %08x", *pSrc++ );
-	}
+    data32_t * pSrc = (data32_t *)memory_region(REGION_GFX4);
+    int i;
+    for( i=0; i<0x200000; i++ )
+    {
+        if( (i&0xf)==0 ) logerror( "\n%08x:", i );
+        logerror( " %08x", *pSrc++ );
+    }
 */
 }
 #if 0
@@ -464,6 +607,29 @@ static struct mips3_config config =
 	16384				/* data cache size - guess */
 };
 
+MACHINE_DRIVER_START( s23 )
+
+	/* basic machine hardware */
+	MDRV_CPU_ADD(R4600BE, 166000000)  /* actually R4650 */
+	MDRV_CPU_CONFIG(config)
+	MDRV_CPU_PROGRAM_MAP(ss23_map, 0)
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(256,256)
+	MDRV_VISIBLE_AREA(0, 255, 0, 255)
+/*  MDRV_SCREEN_SIZE(768, 512) */
+/*  MDRV_VISIBLE_AREA(0, 767, 0, 511) */
+	MDRV_PALETTE_LENGTH(0x2000)
+
+/*  MDRV_GFXDECODE(gfxdecodeinfo) */
+
+	MDRV_VIDEO_START(ss23)
+	MDRV_VIDEO_UPDATE(ss23)
+MACHINE_DRIVER_END
+
 MACHINE_DRIVER_START( ss23 )
 
 	/* basic machine hardware */
@@ -477,16 +643,55 @@ MACHINE_DRIVER_START( ss23 )
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(256,256)
 	MDRV_VISIBLE_AREA(0, 255, 0, 255)
-/*	MDRV_SCREEN_SIZE(768, 512) */
-/*	MDRV_VISIBLE_AREA(0, 767, 0, 511) */
+/*  MDRV_SCREEN_SIZE(768, 512) */
+/*  MDRV_VISIBLE_AREA(0, 767, 0, 511) */
 	MDRV_PALETTE_LENGTH(0x2000)
 
-/*	MDRV_GFXDECODE(gfxdecodeinfo) */
+/*  MDRV_GFXDECODE(gfxdecodeinfo) */
 
 	MDRV_VIDEO_START(ss23)
 	MDRV_VIDEO_UPDATE(ss23)
 MACHINE_DRIVER_END
 
+ROM_START( timecrs2 )
+	ROM_REGION( 0x080000, REGION_CPU1, 0 )	/* dummy region for R4650 */
+
+	ROM_REGION32_BE( 0x400000, REGION_USER1, 0 ) /* 4 megs for main R4650 code */
+        ROM_LOAD16_BYTE( "tss3verb.2",   0x000000, 0x200000, CRC(c7be691f) SHA1(5e2e7a0db3d8ce6dfeb6c0d99e9fe6a9f9cab467) )
+        ROM_LOAD16_BYTE( "tss3verb.1",   0x000001, 0x200000, CRC(6e3f232b) SHA1(8007d8f31a605a5df89938d7c9f9d3d209c934be) )
+
+	ROM_REGION( 0x80000, REGION_CPU2, 0 )	/* Hitachi H8/3002 MCU code */
+        ROM_LOAD16_WORD_SWAP( "tss3verb.3",   0x000000, 0x080000, CRC(41e41994) SHA1(eabc1a307c329070bfc6486cb68169c94ff8a162) )
+
+	ROM_REGION( 0x2000000, REGION_GFX1, 0 )	/* sprite? tilemap? tiles */
+        ROM_LOAD16_BYTE( "tss1mtal.2h",  0x0000000, 0x800000, CRC(bfc79190) SHA1(04bda00c4cc5660d27af4f3b0ee3550dea8d3805) )
+        ROM_LOAD16_BYTE( "tss1mtah.2j",  0x0000001, 0x800000, CRC(697c26ed) SHA1(72f6f69e89496ba0c6183b35c3bde71f5a3c721f) )
+        ROM_LOAD16_BYTE( "tss1mtbl.2f",  0x1000000, 0x800000, CRC(e648bea4) SHA1(3803d03e72b25fbcc124d5b25066d25629b76b94) )
+        ROM_LOAD16_BYTE( "tss1mtbh.2m",  0x1000001, 0x800000, CRC(82582776) SHA1(7c790d09bac660ea1c62da3ffb21ab43f2461594) )
+
+	ROM_REGION( 0x2000000, REGION_GFX2, 0 )	/* texture tiles */
+        ROM_LOAD( "tss1cguu.4f",  0x0000000, 0x800000, CRC(76924e04) SHA1(751065d6ce658cbbcd88f854f6937ebd2204ec68) )
+        ROM_LOAD( "tss1cgum.4j",  0x0800000, 0x800000, CRC(c22739e1) SHA1(8671ee047bb248033656c50befd1c35e5e478e1a) )
+        ROM_LOAD( "tss1cgll.4m",  0x1000000, 0x800000, CRC(18433aaa) SHA1(08539beb2e66ec4e41062621fc098b121c669546) )
+        ROM_LOAD( "tss1cglm.4k",  0x1800000, 0x800000, CRC(669974c2) SHA1(cfebe199631e38f547b38fcd35f1645b74e8dd0a) )
+
+	ROM_REGION( 0x600000, REGION_GFX3, 0 )	/* texture tilemap */
+        ROM_LOAD( "tss1ccrl.7f",  0x000000, 0x400000, CRC(3a325fe7) SHA1(882735dce7aeb36f9e88a983498360f5de901e9d) )
+        ROM_LOAD( "tss1ccrh.7e",  0x400000, 0x200000, CRC(f998de1a) SHA1(371f540f505608297c5ffcfb623b983ca8310afb) )
+
+	ROM_REGION32_LE( 0x2000000, REGION_GFX4, 0 )	/* 3D model data */
+        ROM_LOAD32_WORD( "tss1pt0l.7c",  0x0000000, 0x400000, CRC(896f0fb4) SHA1(bdfa99eb21ce4fc8021f9d95a5558a34f9942c57) )
+        ROM_LOAD32_WORD( "tss1pt0h.7a",  0x0000002, 0x400000, CRC(cdbe0ba8) SHA1(f8c6da31654c0a2a8024888ffb7fc1c783b2d629) )
+        ROM_LOAD32_WORD( "tss1pt1l.5c",  0x0800000, 0x400000, CRC(5a09921f) SHA1(c23885708c7adf0b81c2c9346e21b869634a5b35) )
+        ROM_LOAD32_WORD( "tss1pt1h.5a",  0x0800002, 0x400000, CRC(63647596) SHA1(833412be8f61686bd7e06c2738df740e0e585d0f) )
+        ROM_LOAD32_WORD( "tss1pt2l.4c",  0x1000000, 0x400000, CRC(4b230d79) SHA1(794cee0a19993e90913f58507c53224f361e9663) )
+        ROM_LOAD32_WORD( "tss1pt2h.4a",  0x1000002, 0x400000, CRC(9b06e22d) SHA1(cff5ed098112a4f0a2bc8937e226f50066e605b1) )
+
+	ROM_REGION( 0x1000000, REGION_SOUND1, 0 ) /* C352 PCM samples */
+        ROM_LOAD( "tss1wavel.2c", 0x000000, 0x800000, CRC(deaead26) SHA1(72dac0c3f41d4c3c290f9eb1b50236ae3040a472) )
+        ROM_LOAD( "tss1waveh.2a", 0x800000, 0x800000, CRC(5c8758b4) SHA1(b85c8f6869900224ef83a2340b17f5bbb2801af9) )
+ROM_END
+
 ROM_START( gp500 )
 	/* r4650-generic-xrom-generic: NMON 1.0.8-sys23-19990105 P for SYSTEM23 P1 */
 	ROM_REGION( 0x080000, REGION_CPU1, 0 )	/* dummy region for R4650 */
@@ -503,8 +708,8 @@ ROM_START( gp500 )
         ROM_LOAD16_BYTE( "5gp1mtah.2j",  0x0000001, 0x800000, CRC(246e4b7a) SHA1(75743294b8f48bffb84f062febfbc02230d49ce9) )
 
 		/* COMMON FUJII YASUI WAKAO KURE INOUE
-		 * 0x000000..0x57ffff: all 0xff
-		 */
+         * 0x000000..0x57ffff: all 0xff
+         */
         ROM_LOAD16_BYTE( "5gp1mtbl.2f",  0x1000000, 0x800000, CRC(66640606) SHA1(c69a0219748241c49315d7464f8156f8068e9cf5) )
         ROM_LOAD16_BYTE( "5gp1mtbh.2m",  0x1000001, 0x800000, CRC(352360e8) SHA1(d621dfac3385059c52d215f6623901589a8658a3) )
 
@@ -537,4 +742,5 @@ ROM_START( gp500 )
 ROM_END
 
 /* Games */
+GAMEX( 1997, timecrs2, 0,  s23, ss23, ss23, ROT0, "Namco", "Time Crisis 2", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_NO_SOUND )
 GAMEX( 1999, gp500, 0,    ss23, ss23, ss23, ROT0, "Namco", "GP500", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_NO_SOUND )
