@@ -12,7 +12,7 @@ David Graves
 Nicola Salmoria. Thanks to Richard Bush and the Raine team, whose open
 source was very helpful in many areas particularly the sprites.)
 
-				*****
+                *****
 
 The triple screen games operate on hardware with various similarities to
 the Taito F2 system, as they share some custom ics e.g. the TC0100SCN.
@@ -66,10 +66,10 @@ Ninja Warriors (JPN Ver.)
 
 Sound Board
 K1100313A
-CPU 	:Z80
-Sound	:YM2610
-OSC 	:16000.00KHz
-Other	:TC0140SYT,TC0060DCA x2
+CPU     :Z80
+Sound   :YM2610
+OSC     :16000.00KHz
+Other   :TC0140SYT,TC0060DCA x2
 -----------------------
 B31-08.19
 B31-09.18
@@ -80,10 +80,10 @@ B31_37.11
 CPU Board
 M4300086A
 K1100311A
-CPU 	:TS68000CP8 x2
-Sound	:YM2610
-OSC 	:26686.00KHz,16000.00KHz
-Other	:TC0040IOC,TC0070RGB x3,TC0110PCR x3,TC0100SCN x3
+CPU     :TS68000CP8 x2
+Sound   :YM2610
+OSC     :26686.00KHz,16000.00KHz
+Other   :TC0040IOC,TC0070RGB x3,TC0110PCR x3,TC0100SCN x3
 -----------------------
 B31-01.23
 B31-01.26
@@ -108,7 +108,7 @@ B31_41.5
 -----------------------
 OBJECT Board
 K1100312A
-Other	:TC0120SHT
+Other   :TC0120SHT
 -----------------------
 B31-04.173
 B31-05.174
@@ -150,6 +150,8 @@ rumbling on a subwoofer in the cabinet.)
 #include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
+#include "sound/2610intf.h"
+#include "sound/flt_vol.h"
 
 MACHINE_INIT( ninjaw );
 
@@ -176,7 +178,7 @@ static void parse_control(void)	/* assumes Z80 sandwiched between 68Ks */
 {
 	/* bit 0 enables cpu B */
 	/* however this fails when recovering from a save state
-	   if cpu B is disabled !! */
+       if cpu B is disabled !! */
 	cpunum_set_input_line(2, INPUT_LINE_RESET, (cpua_ctrl &0x1) ? CLEAR_LINE : ASSERT_LINE);
 
 }
@@ -194,7 +196,7 @@ static WRITE16_HANDLER( cpua_ctrl_w )
 
 
 /*****************************************
-			SOUND
+            SOUND
 *****************************************/
 
 static int banknum = -1;
@@ -238,17 +240,12 @@ WRITE8_HANDLER( ninjaw_pancontrol )
   offset = offset&3;
   ninjaw_pandata[offset] = (float)data * (100.f / 255.0f);
   /*usrintf_showmessage(" pan %02x %02x %02x %02x", ninjaw_pandata[0], ninjaw_pandata[1], ninjaw_pandata[2], ninjaw_pandata[3] ); */
-  if( offset < 2 ){
-    mixer_set_stereo_volume( 3, ninjaw_pandata[0], ninjaw_pandata[1] );
-  }
-  else{
-    mixer_set_stereo_volume( 4, ninjaw_pandata[2], ninjaw_pandata[3] );
-  }
+  flt_volume_set_volume(offset, ninjaw_pandata[offset] / 100.0);
 }
 
 
 /***********************************************************
-			 MEMORY STRUCTURES
+             MEMORY STRUCTURES
 ***********************************************************/
 
 static ADDRESS_MAP_START( ninjaw_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -411,7 +408,7 @@ ADDRESS_MAP_END
 
 
 /***********************************************************
-			 INPUT PORTS, DIPs
+             INPUT PORTS, DIPs
 ***********************************************************/
 
 #define NINJAW_DSWA \
@@ -582,9 +579,9 @@ INPUT_PORTS_END
 
 
 /***********************************************************
-				GFX DECODING
+                GFX DECODING
 
-	(Thanks to Raine for the obj decoding)
+    (Thanks to Raine for the obj decoding)
 ***********************************************************/
 
 static struct GfxLayout tilelayout =
@@ -622,7 +619,7 @@ static struct GfxDecodeInfo ninjaw_gfxdecodeinfo[] =
 
 
 /**************************************************************
-			     YM2610 (SOUND)
+                 YM2610 (SOUND)
 **************************************************************/
 
 /* handler called by the YM2610 emulator when the internal timers cause an IRQ */
@@ -633,24 +630,17 @@ static void irqhandler(int irq)
 
 static struct YM2610interface ym2610_interface =
 {
-	1,	/* 1 chip */
-	16000000/2,	/* 8 MHz ?? */
-	{ 25 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler },
-	{ REGION_SOUND2 },	/* Delta-T */
-	{ REGION_SOUND1 },	/* ADPCM */
-	{ YM3012_VOL(100,MIXER_PAN_CENTER,100,MIXER_PAN_CENTER) }
+	irqhandler,
+	REGION_SOUND2,	/* Delta-T */
+	REGION_SOUND1	/* ADPCM */
 };
 
 
 /**************************************************************
-			     SUBWOOFER (SOUND)
+                 SUBWOOFER (SOUND)
 **************************************************************/
 
+#if 0
 static int subwoofer_sh_start(const struct MachineSound *msound)
 {
 	/* Adjust the lowpass filter of the first three YM2610 channels */
@@ -671,10 +661,11 @@ static struct CustomSound_interface subwoofer_interface =
 	0, /* none */
 	0 /* none */
 };
+#endif
 
 
 /*************************************************************
-			     MACHINE DRIVERS
+                 MACHINE DRIVERS
 
 Ninjaw: high interleaving of 100, but doesn't stop enemies
 "sliding" when they should be standing still relative
@@ -691,7 +682,7 @@ static MACHINE_DRIVER_START( ninjaw )
 	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,16000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 16/4 MHz ? */
+	/* audio CPU */	/* 16/4 MHz ? */
 	MDRV_CPU_PROGRAM_MAP(z80_sound_readmem,z80_sound_writemem)
 
 	MDRV_CPU_ADD(M68000,16000000/2)	/* 8 MHz ? */
@@ -716,9 +707,27 @@ static MACHINE_DRIVER_START( ninjaw )
 	MDRV_VIDEO_UPDATE(ninjaw)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2610, ym2610_interface)
-	MDRV_SOUND_ADD(CUSTOM, subwoofer_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2610, 16000000/2)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.25)
+	MDRV_SOUND_ROUTE(0, "right", 0.25)
+	MDRV_SOUND_ROUTE(1, "2610.1.l", 1.0)
+	MDRV_SOUND_ROUTE(1, "2610.1.r", 1.0)
+	MDRV_SOUND_ROUTE(2, "2610.2.l", 1.0)
+	MDRV_SOUND_ROUTE(2, "2610.2.r", 1.0)
+
+	MDRV_SOUND_ADD_TAG("2610.1.l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("2610.1.r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("2610.2.l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("2610.2.r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+/*  MDRV_SOUND_ADD(CUSTOM, subwoofer_interface) */
 MACHINE_DRIVER_END
 
 
@@ -730,7 +739,7 @@ static MACHINE_DRIVER_START( darius2 )
 	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,16000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 4 MHz ? */
+	/* audio CPU */	/* 4 MHz ? */
 	MDRV_CPU_PROGRAM_MAP(z80_sound_readmem,z80_sound_writemem)
 
 	MDRV_CPU_ADD(M68000,16000000/2)	/* 8 MHz ? */
@@ -755,14 +764,32 @@ static MACHINE_DRIVER_START( darius2 )
 	MDRV_VIDEO_UPDATE(ninjaw)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2610, ym2610_interface)
-	MDRV_SOUND_ADD(CUSTOM, subwoofer_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2610, 16000000/2)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.25)
+	MDRV_SOUND_ROUTE(0, "right", 0.25)
+	MDRV_SOUND_ROUTE(1, "2610.1.l", 1.0)
+	MDRV_SOUND_ROUTE(1, "2610.1.r", 1.0)
+	MDRV_SOUND_ROUTE(2, "2610.2.l", 1.0)
+	MDRV_SOUND_ROUTE(2, "2610.2.r", 1.0)
+
+	MDRV_SOUND_ADD_TAG("2610.1.l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("2610.1.r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("2610.2.l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("2610.2.r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+/*  MDRV_SOUND_ADD(CUSTOM, subwoofer_interface) */
 MACHINE_DRIVER_END
 
 
 /***************************************************************************
-					DRIVERS
+                    DRIVERS
 ***************************************************************************/
 
 ROM_START( ninjaw )
@@ -803,10 +830,10 @@ ROM_START( ninjaw )
 	ROM_COPY( REGION_GFX1, 0x000000, 0x000000, 0x100000 )	/* SCR (screens 2+) */
 
 /* The actual board duplicates the SCR gfx roms for 2nd/3rd TC0100SCN */
-/*	ROM_LOAD( "b31-01.26", 0x00000, 0x80000, CRC(8e8237a7) SHA1(3e181a153d9b4b7f6a620614ea9022285583a5b5) )	   SCR (screen 2)    */
-/*	ROM_LOAD( "b31-02.27", 0x80000, 0x80000, CRC(4c3b4e33) SHA1(f99b379be1af085bf102d4d7cf35803e002fe80b) ) */
-/*	ROM_LOAD( "b31-01.28", 0x00000, 0x80000, CRC(8e8237a7) SHA1(3e181a153d9b4b7f6a620614ea9022285583a5b5) )	   SCR (screen 3)    */
-/*	ROM_LOAD( "b31-02.29", 0x80000, 0x80000, CRC(4c3b4e33) SHA1(f99b379be1af085bf102d4d7cf35803e002fe80b) ) */
+/*  ROM_LOAD( "b31-01.26", 0x00000, 0x80000, CRC(8e8237a7) SHA1(3e181a153d9b4b7f6a620614ea9022285583a5b5) )    SCR (screen 2)    */
+/*  ROM_LOAD( "b31-02.27", 0x80000, 0x80000, CRC(4c3b4e33) SHA1(f99b379be1af085bf102d4d7cf35803e002fe80b) ) */
+/*  ROM_LOAD( "b31-01.28", 0x00000, 0x80000, CRC(8e8237a7) SHA1(3e181a153d9b4b7f6a620614ea9022285583a5b5) )    SCR (screen 3)    */
+/*  ROM_LOAD( "b31-02.29", 0x80000, 0x80000, CRC(4c3b4e33) SHA1(f99b379be1af085bf102d4d7cf35803e002fe80b) ) */
 
 	ROM_REGION( 0x180000, REGION_SOUND1, 0 )	/* ADPCM samples */
 	ROM_LOAD( "b31-09.18", 0x000000, 0x80000, CRC(60a73382) SHA1(0ddeb86fcd4d19a58e62bf8564f996d17e36e5c5) )
@@ -859,10 +886,10 @@ ROM_START( ninjawj )
 	ROM_COPY( REGION_GFX1, 0x000000, 0x000000, 0x100000 )	/* SCR (screens 2+) */
 
 /* The actual board duplicates the SCR gfx roms for 2nd/3rd TC0100SCN */
-/*	ROM_LOAD( "b31-01.26", 0x00000, 0x80000, CRC(8e8237a7) SHA1(3e181a153d9b4b7f6a620614ea9022285583a5b5) )	   SCR (screen 2)    */
-/*	ROM_LOAD( "b31-02.27", 0x80000, 0x80000, CRC(4c3b4e33) SHA1(f99b379be1af085bf102d4d7cf35803e002fe80b) ) */
-/*	ROM_LOAD( "b31-01.28", 0x00000, 0x80000, CRC(8e8237a7) SHA1(3e181a153d9b4b7f6a620614ea9022285583a5b5) )	   SCR (screen 3)    */
-/*	ROM_LOAD( "b31-02.29", 0x80000, 0x80000, CRC(4c3b4e33) SHA1(f99b379be1af085bf102d4d7cf35803e002fe80b) ) */
+/*  ROM_LOAD( "b31-01.26", 0x00000, 0x80000, CRC(8e8237a7) SHA1(3e181a153d9b4b7f6a620614ea9022285583a5b5) )    SCR (screen 2)    */
+/*  ROM_LOAD( "b31-02.27", 0x80000, 0x80000, CRC(4c3b4e33) SHA1(f99b379be1af085bf102d4d7cf35803e002fe80b) ) */
+/*  ROM_LOAD( "b31-01.28", 0x00000, 0x80000, CRC(8e8237a7) SHA1(3e181a153d9b4b7f6a620614ea9022285583a5b5) )    SCR (screen 3)    */
+/*  ROM_LOAD( "b31-02.29", 0x80000, 0x80000, CRC(4c3b4e33) SHA1(f99b379be1af085bf102d4d7cf35803e002fe80b) ) */
 
 	ROM_REGION( 0x180000, REGION_SOUND1, 0 )	/* ADPCM samples */
 	ROM_LOAD( "b31-09.18", 0x000000, 0x80000, CRC(60a73382) SHA1(0ddeb86fcd4d19a58e62bf8564f996d17e36e5c5) )
@@ -934,7 +961,7 @@ static DRIVER_INIT( ninjaw )
 MACHINE_INIT( ninjaw )
 {
   /**** mixer control enable ****/
-  mixer_sound_enable_global_w( 1 );	/* mixer enabled */
+  sound_global_enable( 1 );	/* mixer enabled */
 }
 
 
