@@ -193,7 +193,7 @@ INPUT_PORTS_START( snes )
 INPUT_PORTS_END
 
 static struct CustomSound_interface snes_sound_interface =
-{ snes_sh_start, 0, 0 };
+{ snes_sh_start };
 
 static struct GfxDecodeInfo gfxdecodeinfo[] =
 {
@@ -224,7 +224,7 @@ static MACHINE_DRIVER_START( snes )
 	MDRV_CPU_VBLANK_INT(snes_scanline_interrupt, SNES_MAX_LINES_NTSC)
 
 	MDRV_CPU_ADD_TAG("sound", SPC700, 2048000)	/* 2.048 Mhz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(spc_readmem, spc_writemem)
 	MDRV_CPU_VBLANK_INT(NULL, 0)
 
@@ -247,8 +247,12 @@ static MACHINE_DRIVER_START( snes )
 	MDRV_PALETTE_INIT( snes )
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(CUSTOM, snes_sound_interface)
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_CONFIG(snes_sound_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(0, "right", 0.50)
 MACHINE_DRIVER_END
 
 /***************************************************************************
