@@ -34,16 +34,17 @@ NOTE :
 
 /*
 
-	TODO:
+    TODO:
 
-	- "XXX Intturupt Hold ???" msg at post screen
-	- coin counters/lockouts
-	- sprites are invisible in flipscreen mode
+    - "XXX Intturupt Hold ???" msg at post screen
+    - coin counters/lockouts
+    - sprites are invisible in flipscreen mode
 
 */
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2203intf.h"
 
 
 /**************************************************************************
@@ -495,17 +496,19 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x0000, 0x0000) AM_READ(YM2203_status_port_0_r)
-	AM_RANGE(0x0001, 0x0001) AM_READ(YM2203_read_port_0_r)
-	AM_RANGE(0x0080, 0x0080) AM_READ(YM2203_status_port_1_r)
-	AM_RANGE(0x0081, 0x0081) AM_READ(YM2203_read_port_1_r)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x00, 0x00) AM_READ(YM2203_status_port_0_r)
+	AM_RANGE(0x01, 0x01) AM_READ(YM2203_read_port_0_r)
+	AM_RANGE(0x80, 0x80) AM_READ(YM2203_status_port_1_r)
+	AM_RANGE(0x81, 0x81) AM_READ(YM2203_read_port_1_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x0000, 0x0000) AM_WRITE(YM2203_control_port_0_w)
-	AM_RANGE(0x0001, 0x0001) AM_WRITE(YM2203_write_port_0_w)
-	AM_RANGE(0x0080, 0x0080) AM_WRITE(YM2203_control_port_1_w)
-	AM_RANGE(0x0081, 0x0081) AM_WRITE(YM2203_write_port_1_w)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x00, 0x00) AM_WRITE(YM2203_control_port_0_w)
+	AM_RANGE(0x01, 0x01) AM_WRITE(YM2203_write_port_0_w)
+	AM_RANGE(0x80, 0x80) AM_WRITE(YM2203_control_port_1_w)
+	AM_RANGE(0x81, 0x81) AM_WRITE(YM2203_write_port_1_w)
 ADDRESS_MAP_END
 
 
@@ -550,7 +553,7 @@ static struct GfxLayout omegaf_bigspritelayout =
 	{ 32*0, 32*1, 32*2, 32*3, 32*4, 32*5, 32*6, 32*7,
 		32*8, 32*9, 32*10, 32*11, 32*12, 32*13, 32*14, 32*15,
 		64*16+32*0, 64*16+32*1, 64*16+32*2, 64*16+32*3, 64*16+32*4, 64*16+32*5, 64*16+32*6, 64*16+32*7,
-		64*16+32*8, 64*16+32*9, 64*16+32*10, 64*16+32*11, 64*16+32*12, 64*16+32*13, 64*16+32*14, 64*16+32*15, 64*16+32*16 },
+		64*16+32*8, 64*16+32*9, 64*16+32*10, 64*16+32*11, 64*16+32*12, 64*16+32*13, 64*16+32*14, 64*16+32*15 },
 	16*64*4
 };
 
@@ -593,7 +596,7 @@ static struct GfxLayout robokid_bigspritelayout =
 	{ 32*0, 32*1, 32*2, 32*3, 32*4, 32*5, 32*6, 32*7,
 		32*8, 32*9, 32*10, 32*11, 32*12, 32*13, 32*14, 32*15,
 		64*16+32*0, 64*16+32*1, 64*16+32*2, 64*16+32*3, 64*16+32*4, 64*16+32*5, 64*16+32*6, 64*16+32*7,
-		64*16+32*8, 64*16+32*9, 64*16+32*10, 64*16+32*11, 64*16+32*12, 64*16+32*13, 64*16+32*14, 64*16+32*15, 64*16+32*16 },
+		64*16+32*8, 64*16+32*9, 64*16+32*10, 64*16+32*11, 64*16+32*12, 64*16+32*13, 64*16+32*14, 64*16+32*15 },
 	16*64*4
 };
 
@@ -624,17 +627,6 @@ static struct GfxDecodeInfo robokid_gfxdecodeinfo[] =
   Machine drivers
 **************************************************************************/
 
-static struct YM2203interface ym2203_interface =
-{
-	2,	 /* 2 chips */
-	12000000/8,
-	{ YM2203_VOL(35, 35), YM2203_VOL(35, 35)},
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static MACHINE_DRIVER_START( omegaf )
 
 	/* basic machine hardware */
@@ -643,7 +635,7 @@ static MACHINE_DRIVER_START( omegaf )
 	MDRV_CPU_VBLANK_INT(omegaf_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 5000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		/* 5 mhz crystal ??? */
+	/* audio CPU */		/* 5 mhz crystal ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,2)
@@ -663,7 +655,13 @@ static MACHINE_DRIVER_START( omegaf )
 	MDRV_VIDEO_UPDATE(omegaf)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 12000000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.35)
+
+	MDRV_SOUND_ADD(YM2203, 12000000/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.35)
 MACHINE_DRIVER_END
 
 
