@@ -30,6 +30,10 @@ TO DO :
 */
 
 #include "driver.h"
+#include "sound/okim6295.h"
+#include "sound/3812intf.h"
+
+
 data16_t *oneshot_sprites;
 data16_t *oneshot_bg_videoram;
 data16_t *oneshot_mid_videoram;
@@ -157,7 +161,7 @@ static ADDRESS_MAP_START( snd_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 INPUT_PORTS_START( oneshot )
-	PORT_START	/* DSW 1	(0x19c020.l -> 0x08006c.l) */
+	PORT_START	/* DSW 1    (0x19c020.l -> 0x08006c.l) */
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Coinage ) )		/* 0x080084.l : credits (00-09) */
 	PORT_DIPSETTING(    0x03, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 2C_1C ) )
@@ -179,7 +183,7 @@ INPUT_PORTS_START( oneshot )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START	/* DSW 2	(0x19c024.l -> 0x08006e.l) */
+	PORT_START	/* DSW 2    (0x19c024.l -> 0x08006e.l) */
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ) )		/* 0x082500.l */
 	PORT_DIPSETTING(    0x01, "1" )
 	PORT_DIPSETTING(    0x02, "2" )
@@ -203,7 +207,7 @@ INPUT_PORTS_START( oneshot )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START	/* Credits	(0x19c02c.l -> 0x08007a.l) */
+	PORT_START	/* Credits  (0x19c02c.l -> 0x08007a.l) */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNKNOWN )
@@ -213,7 +217,7 @@ INPUT_PORTS_START( oneshot )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_START2 )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START	/* Player 1 Gun Trigger	(0x19c030.l) */
+	PORT_START	/* Player 1 Gun Trigger (0x19c030.l) */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNKNOWN )
@@ -223,7 +227,7 @@ INPUT_PORTS_START( oneshot )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START	/* Player 2 Gun Trigger	(0x19c034.l) */
+	PORT_START	/* Player 2 Gun Trigger (0x19c034.l) */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNKNOWN )
@@ -233,16 +237,16 @@ INPUT_PORTS_START( oneshot )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START	/* Player 1 Gun X		($190026.l) */
+	PORT_START	/* Player 1 Gun X       ($190026.l) */
 	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_MINMAX(0,0xff) PORT_SENSITIVITY(35) PORT_KEYDELTA(15) PORT_PLAYER(1)
 
-	PORT_START	/* Player 1 Gun Y		($190036.l) */
+	PORT_START	/* Player 1 Gun Y       ($190036.l) */
 	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_MINMAX(0,0xff) PORT_SENSITIVITY(35) PORT_KEYDELTA(15) PORT_PLAYER(1)
 
-	PORT_START	/* Player 2 Gun X		($19002e.l) */
+	PORT_START	/* Player 2 Gun X       ($19002e.l) */
 	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_MINMAX(0,0xff) PORT_SENSITIVITY(35) PORT_KEYDELTA(15) PORT_PLAYER(2)
 
-	PORT_START	/* Player 2 Gun Y		($19003e.l) */
+	PORT_START	/* Player 2 Gun Y       ($19003e.l) */
 	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_MINMAX(0,0xff) PORT_SENSITIVITY(35) PORT_KEYDELTA(15) PORT_PLAYER(2)
 
 INPUT_PORTS_END
@@ -281,7 +285,7 @@ INPUT_PORTS_START( maddonna )
 	PORT_DIPSETTING(    0x08, "80 Seconds" )
 	PORT_DIPSETTING(    0x04, "90 Seconds" )
 	PORT_DIPSETTING(    0x00, "100 Seconds" )
-/*	PORT_DIPSETTING(    0x0c, "?? Seconds" )		// Not Defined for On+On */
+/*  PORT_DIPSETTING(    0x0c, "?? Seconds" )        // Not Defined for On+On */
 	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x10, "3" )
 	PORT_DIPSETTING(    0x00, "5" )
@@ -365,18 +369,7 @@ static void irq_handler(int irq)
 
 static struct YM3812interface ym3812_interface =
 {
-	1,
-	3500000,	/* ??? music tempo in maddonna */
-	{ 100 },
-	{ irq_handler }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,
-	{ 8000 },	/* ? */
-	{ REGION_SOUND1 },
-	{ 100 }
+	irq_handler
 };
 
 static MACHINE_DRIVER_START( oneshot )
@@ -403,8 +396,15 @@ static MACHINE_DRIVER_START( oneshot )
 	MDRV_VIDEO_START(oneshot)
 	MDRV_VIDEO_UPDATE(oneshot)
 
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 3500000)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( maddonna )
