@@ -19,6 +19,7 @@ Atari Orbit Driver
 
 #include "driver.h"
 #include "orbit.h"
+#include "sound/discrete.h"
 
 
 extern VIDEO_START( orbit );
@@ -315,8 +316,12 @@ static MACHINE_DRIVER_START( orbit )
 	MDRV_VIDEO_UPDATE(orbit)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, orbit_discrete_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, 0)
+	MDRV_SOUND_CONFIG(orbit_discrete_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
