@@ -18,6 +18,8 @@ TODO:
 #include "cpu/z80/z80.h"
 #include "cpu/i8039/i8039.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
 
 static int irq_enable_a, irq_enable_b;
 static int firq_old_data_a, firq_old_data_b;
@@ -64,14 +66,14 @@ static WRITE8_HANDLER( pandoras_sharedram2_w ){
 }
 
 static WRITE8_HANDLER( pandoras_int_control_w ){
-	/*	byte 0:	irq enable (CPU A)
-		byte 2:	coin counter 1
-		byte 3: coin counter 2
-		byte 5: flip screen
-		byte 6:	irq enable (CPU B)
-		byte 7:	NMI to CPU B
+	/*  byte 0: irq enable (CPU A)
+        byte 2: coin counter 1
+        byte 3: coin counter 2
+        byte 5: flip screen
+        byte 6: irq enable (CPU B)
+        byte 7: NMI to CPU B
 
-		other bytes unknown */
+        other bytes unknown */
 
 	switch (offset){
 		case 0x00:	if (!data) cpunum_set_input_line(0, M6809_IRQ_LINE, CLEAR_LINE);
@@ -166,7 +168,7 @@ static ADDRESS_MAP_START( pandoras_readmem_b, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x1a02, 0x1a02) AM_READ(input_port_5_r)			/* 2P inputs */
 	AM_RANGE(0x1a03, 0x1a03) AM_READ(input_port_2_r)			/* DIPSW #3 */
 	AM_RANGE(0x1c00, 0x1c00) AM_READ(input_port_1_r)			/* DISPW #2 */
-/*	AM_RANGE(0x1e00, 0x1e00) AM_READ(MRA8_NOP)				   ??? seems to be important    */
+/*  AM_RANGE(0x1e00, 0x1e00) AM_READ(MRA8_NOP)                 ??? seems to be important    */
 	AM_RANGE(0xc000, 0xc7ff) AM_READ(pandoras_sharedram2_r)	/* Shared RAM with the CPU A */
 	AM_RANGE(0xe000, 0xffff) AM_READ(MRA8_ROM)				/* ROM */
 ADDRESS_MAP_END
@@ -218,7 +220,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************
 
-	Input Ports
+    Input Ports
 
 ***************************************************************************/
 
@@ -257,7 +259,7 @@ INPUT_PORTS_START( pandoras )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )
@@ -369,7 +371,7 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /***************************************************************************
 
-	Machine Driver
+    Machine Driver
 
 ***************************************************************************/
 
@@ -391,19 +393,8 @@ static READ8_HANDLER( pandoras_portB_r )
 
 static struct AY8910interface ay8910_interface =
 {
-	1,			/* 1 chip */
-	14318000/8,
-	{ 40 },
-	{ pandoras_portA_r },	/* not used */
-	{ pandoras_portB_r },
-	{ 0 },
-	{ 0 }
-};
-
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 25 }
+	pandoras_portA_r,	/* not used */
+	pandoras_portB_r
 };
 
 static MACHINE_DRIVER_START( pandoras )
@@ -418,11 +409,11 @@ static MACHINE_DRIVER_START( pandoras )
 	MDRV_CPU_VBLANK_INT(pandoras_interrupt_b,1)
 
 	MDRV_CPU_ADD(Z80,14318000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(pandoras_readmem_snd,pandoras_writemem_snd)
 
 	MDRV_CPU_ADD(I8039,(14318000/2)/I8039_CLOCK_DIVIDER)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(i8039_readmem,i8039_writemem)
 	MDRV_CPU_IO_MAP(i8039_readport,i8039_writeport)
 
@@ -445,8 +436,14 @@ static MACHINE_DRIVER_START( pandoras )
 	MDRV_VIDEO_UPDATE(pandoras)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 14318000/8)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
