@@ -1,20 +1,23 @@
 /***************************************************************************
 
-	Pocket Gal						(c) 1987 Data East Corporation
-	Pocket Gal (Bootleg)			(c) 1989 Yada East Corporation(!!!)
-	Super Pool III					(c) 1989 Data East Corporation
-	Pocket Gal 2					(c) 1989 Data East Corporation
-	Super Pool III (I-Vics Inc)		(c) 1990 Data East Corporation
+    Pocket Gal                      (c) 1987 Data East Corporation
+    Pocket Gal (Bootleg)            (c) 1989 Yada East Corporation(!!!)
+    Super Pool III                  (c) 1989 Data East Corporation
+    Pocket Gal 2                    (c) 1989 Data East Corporation
+    Super Pool III (I-Vics Inc)     (c) 1990 Data East Corporation
 
-	Pocket Gal (Bootleg) is often called 'Sexy Billiards'
+    Pocket Gal (Bootleg) is often called 'Sexy Billiards'
 
-	Emulation by Bryan McPhail, mish@tendril.co.uk
+    Emulation by Bryan McPhail, mish@tendril.co.uk
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/2203intf.h"
+#include "sound/3812intf.h"
+#include "sound/msm5205.h"
 
 extern WRITE8_HANDLER( pcktgal_videoram_w );
 extern WRITE8_HANDLER( pcktgal_flipscreen_w );
@@ -230,31 +233,10 @@ static struct GfxDecodeInfo bootleg_gfxdecodeinfo[] =
 
 /***************************************************************************/
 
-static struct YM2203interface ym2203_interface =
-{
-	1,	  /* 1 chip */
-	1500000,		/* 1.5 MHz */
-	{ YM2203_VOL(60,60) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-static struct YM3812interface ym3812_interface =
-{
-	1,			/* 1 chip (no more supported) */
-	3000000,	/* 3 MHz */
-	{ 100 }
-};
-
 static struct MSM5205interface msm5205_interface =
 {
-	1,					/* 1 chip			 */
-	384000,				/* 384KHz			 */
-	{ pcktgal_adpcm_int },/* interrupt function */
-	{ MSM5205_S48_4B},	/* 8KHz			   */
-	{ 70 }
+	pcktgal_adpcm_int,	/* interrupt function */
+	MSM5205_S48_4B		/* 8KHz            */
 };
 
 /***************************************************************************/
@@ -267,7 +249,7 @@ static MACHINE_DRIVER_START( pcktgal )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(M6502, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 							/* IRQs are caused by the ADPCM chip */
 							/* NMIs are caused by the main CPU */
@@ -286,9 +268,17 @@ static MACHINE_DRIVER_START( pcktgal )
 	MDRV_VIDEO_UPDATE(pcktgal)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
+
+	MDRV_SOUND_ADD(YM3812, 3000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.70)
 MACHINE_DRIVER_END
 
 
