@@ -5,7 +5,11 @@ Phoenix hardware games
 driver by Richard Davies
 
 Note:
-   pleiads is using another sound driver, sndhrdw\pleiads.c
+    The discrete sound part of Phoenix requires a sample rate of at least 44100.
+    This is because the frequencies are so high, that some sounds will be
+    missed at a lower sample rate.
+
+    pleiads is using another sound driver, sndhrdw\pleiads.c
  Andrew Scott (ascott@utkux.utcc.utk.edu)
 
 
@@ -34,7 +38,10 @@ Pleiads:
 ***************************************************************************/
 
 #include "driver.h"
-
+#include "sound/tms36xx.h"
+#include "sound/ay8910.h"
+#include "sound/custom.h"
+#include "phoenix.h"
 
 
 READ8_HANDLER( phoenix_videoram_r );
@@ -51,17 +58,11 @@ PALETTE_INIT( pleiads );
 VIDEO_START( phoenix );
 VIDEO_UPDATE( phoenix );
 
-WRITE8_HANDLER( phoenix_sound_control_a_w );
-WRITE8_HANDLER( phoenix_sound_control_b_w );
-int phoenix_sh_start(const struct MachineSound *msound);
-void phoenix_sh_stop(void);
-void phoenix_sh_update(void);
+void *phoenix_sh_start(int clock, const struct CustomSound_interface *config);
 
 WRITE8_HANDLER( pleiads_sound_control_a_w );
 WRITE8_HANDLER( pleiads_sound_control_b_w );
-int pleiads_sh_start(const struct MachineSound *msound);
-void pleiads_sh_stop(void);
-void pleiads_sh_update(void);
+void *pleiads_sh_start(int clock, const struct CustomSound_interface *config);
 
 
 static ADDRESS_MAP_START( phoenix_readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -429,7 +430,7 @@ INPUT_PORTS_START( pleiadce )
 	PORT_DIPSETTING(	0x00, "7K 70K" )
 	PORT_DIPSETTING(	0x04, "8K 80K" )
 	PORT_DIPSETTING(	0x08, "9K 90K" )
-  /*PORT_DIPSETTING(	0x0c, "INVALID" )   Sets bonus to A000 */
+  /*PORT_DIPSETTING(    0x0c, "INVALID" )   Sets bonus to A000 */
 	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(	0x10, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( 1C_1C ) )
@@ -570,52 +571,37 @@ static struct GfxDecodeInfo pleiads_gfxdecodeinfo[] =
 
 static struct TMS36XXinterface phoenix_tms36xx_interface =
 {
-	1,
-	{ 50 }, 		/* mixing levels */
-	{ MM6221AA },	/* TMS36xx subtype(s) */
-	{ 372  },		/* base frequency */
-	{ {0.50,0,0,1.05,0,0} }, /* decay times of voices */
-    { 0.21 },       /* tune speed (time between beats) */
+	MM6221AA,	/* TMS36xx subtype(s) */
+	{0.50,0,0,1.05,0,0}, /* decay times of voices */
+    0.21       /* tune speed (time between beats) */
 };
 
 static struct CustomSound_interface phoenix_custom_interface =
 {
-	phoenix_sh_start,
-	phoenix_sh_stop,
-	phoenix_sh_update
+	phoenix_sh_start
 };
 
 static struct TMS36XXinterface pleiads_tms36xx_interface =
 {
-	1,
-	{ 75		},	/* mixing levels */
-	{ TMS3615	},	/* TMS36xx subtype(s) */
-	{ 247		},	/* base frequencies (one octave below A) */
+	TMS3615,	/* TMS36xx subtype(s) */
 	/*
-	 * Decay times of the voices; NOTE: it's unknown if
-	 * the the TMS3615 mixes more than one voice internally.
-	 * A wav taken from Pop Flamer sounds like there
-	 * are at least no 'odd' harmonics (5 1/3' and 2 2/3')
+     * Decay times of the voices; NOTE: it's unknown if
+     * the the TMS3615 mixes more than one voice internally.
+     * A wav taken from Pop Flamer sounds like there
+     * are at least no 'odd' harmonics (5 1/3' and 2 2/3')
      */
-	{ {0.33,0.33,0,0.33,0,0.33} }
+	{0.33,0.33,0,0.33,0,0.33}
 };
 
 static struct CustomSound_interface pleiads_custom_interface =
 {
-	pleiads_sh_start,
-	pleiads_sh_stop,
-	pleiads_sh_update
+	pleiads_sh_start
 };
 
 static struct AY8910interface survival_ay8910_interface =
 {
-	1,	/* 1 chip */
-	11000000/4,
-	{ 50 },
-	{ 0 },
-	{ survival_protection_r },
-	{ 0 },
-	{ 0 }
+	0,
+	survival_protection_r
 };
 
 
@@ -642,8 +628,19 @@ static MACHINE_DRIVER_START( phoenix )
 	MDRV_VIDEO_UPDATE(phoenix)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("tms",  TMS36XX, phoenix_tms36xx_interface)
-	MDRV_SOUND_ADD_TAG("cust", CUSTOM, phoenix_custom_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD_TAG("tms",  TMS36XX, 372)
+	MDRV_SOUND_CONFIG(phoenix_tms36xx_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.5)
+
+	MDRV_SOUND_ADD_TAG("cust", CUSTOM, 0)
+	MDRV_SOUND_CONFIG(phoenix_custom_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.4)
+
+	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, 0)
+	MDRV_SOUND_CONFIG(phoenix_discrete_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.6)
 MACHINE_DRIVER_END
 
 
@@ -661,8 +658,15 @@ static MACHINE_DRIVER_START( pleiads )
 	MDRV_PALETTE_INIT(pleiads)
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("tms",  TMS36XX, pleiads_tms36xx_interface)
-	MDRV_SOUND_REPLACE("cust", CUSTOM, pleiads_custom_interface)
+	MDRV_SOUND_REPLACE("tms", TMS36XX, 247)
+	MDRV_SOUND_CONFIG(pleiads_tms36xx_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
+
+	MDRV_SOUND_REPLACE("cust", CUSTOM, 0)
+	MDRV_SOUND_CONFIG(pleiads_custom_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+
+	MDRV_SOUND_REMOVE("discrete")
 MACHINE_DRIVER_END
 
 
@@ -690,7 +694,11 @@ static MACHINE_DRIVER_START( survival )
 	MDRV_VIDEO_UPDATE(phoenix)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, survival_ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 11000000/4)
+	MDRV_SOUND_CONFIG(survival_ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -919,7 +927,7 @@ ROM_START( griffon )
 	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
 	ROM_LOAD( "griffon.d7",   0x0000, 0x0800, CRC(53c52eb0) SHA1(19624ca359996b77d3c65ef78a7af90eeb092377) )
 	ROM_LOAD( "griffon.d8",   0x0800, 0x0800, CRC(eba42f0f) SHA1(378282cb2c4e10c23179ae3c605ae7bf691150f6) )
-	
+
 	ROM_REGION( 0x0200, REGION_PROMS, 0 )
 	ROM_LOAD( "ic40_b.bin",   0x0000, 0x0100, CRC(79350b25) SHA1(57411be4c1d89677f7919ae295446da90612c8a8) )  /* palette low bits */
 	ROM_LOAD( "ic41_a.bin",   0x0100, 0x0100, CRC(e176b768) SHA1(e2184dd495ed579f10b6da0b78379e02d7a6229f) )  /* palette high bits */
@@ -1007,7 +1015,7 @@ ROM_START( capitol )
 	ROM_LOAD( "cp6.50",       0x2800, 0x0800, CRC(aaf798eb) SHA1(660774db4195aaa499569804a2304e969f168cdf) )
 	ROM_LOAD( "cp7.51",       0x3000, 0x0800, CRC(eaadf14c) SHA1(753a46317e98b1ae63f88f5c3e70ff1c7ec04286) )
 	ROM_LOAD( "cp8.52",       0x3800, 0x0800, CRC(d3fe2af4) SHA1(f0c9bfc17ba6f55fbe95136da40a3de775aa46d2) )
-	
+
 	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "cp11.23",      0x0000, 0x0800, CRC(9b0bbb8d) SHA1(cde7c0140e773fe28e97e36486d4e048710f6004) )
 	ROM_LOAD( "cp12.24",      0x0800, 0x0800, CRC(39949e66) SHA1(21a204f22f04c5808538b21d49ebc6b7cb7625e8) )
