@@ -1,45 +1,45 @@
 /***************************************************************************
 
-	Pipe Dream
+    Pipe Dream
 
     driver by Bryan McPhail & Aaron Giles
 
 ****************************************************************************
 
-	Memory map
+    Memory map
 
 ****************************************************************************
 
-	========================================================================
-	MAIN CPU
-	========================================================================
-	0000-7FFF   R     xxxxxxxx   Program ROM
-	8000-9FFF   R/W   xxxxxxxx   Program RAM
-	A000-BFFF   R     xxxxxxxx   Banked ROM
-	C000-CBFF   R/W   xxxxxxxx   Palette RAM (1536 entries x 2 bytes)
-	            R/W   ---xxxxx      (0: Blue)
-	            R/W   xxx-----      (0: Green, 3 LSB)
-	            R/W   ------xx      (1: Green, 2 MSB)
-	            R/W   -xxxxx--      (1: Red)
-	CC00-CFFF   R/W   xxxxxxxx   Sprite RAM (256 entries x 8 bytes)
-	            R/W   xxxxxxxx      (0: Y position, 8 LSB)
-	            R/W   -------x      (1: Y position, 1 MSB)
-	            R/W   xxxx----      (1: Y zoom factor)
-	            R/W   xxxxxxxx      (2: X position, 8 LSB)
-	            R/W   -------x      (3: X position, 1 MSB)
-	            R/W   xxxx----      (3: X zoom factor)
-	            R/W   ---x----      (4: Priority)
-	            R/W   ----xxxx      (4: Palette entry)
-	            R/W   x-------      (5: Y flip)
-	            R/W   -xxx----      (5: Number of Y tiles - 1)
-	            R/W   ----x---      (5: X flip)
-	            R/W   -----xxx      (5: Number of X tiles - 1)
-	            R/W   xxxxxxxx      (6: Starting tile index, 8 LSB)
-	            R/W   ----xxxx      (7: Starting tile index, 4 MSB)
-	D000-DFFF   R/W   --xxxxxx   Background tile color
-	E000-EFFF   R/W   xxxxxxxx   Background tile index, 8 MSB
-	F000-FFFF   R/W   xxxxxxxx   Background tile index, 8 LSB
-	========================================================================
+    ========================================================================
+    MAIN CPU
+    ========================================================================
+    0000-7FFF   R     xxxxxxxx   Program ROM
+    8000-9FFF   R/W   xxxxxxxx   Program RAM
+    A000-BFFF   R     xxxxxxxx   Banked ROM
+    C000-CBFF   R/W   xxxxxxxx   Palette RAM (1536 entries x 2 bytes)
+                R/W   ---xxxxx      (0: Blue)
+                R/W   xxx-----      (0: Green, 3 LSB)
+                R/W   ------xx      (1: Green, 2 MSB)
+                R/W   -xxxxx--      (1: Red)
+    CC00-CFFF   R/W   xxxxxxxx   Sprite RAM (256 entries x 8 bytes)
+                R/W   xxxxxxxx      (0: Y position, 8 LSB)
+                R/W   -------x      (1: Y position, 1 MSB)
+                R/W   xxxx----      (1: Y zoom factor)
+                R/W   xxxxxxxx      (2: X position, 8 LSB)
+                R/W   -------x      (3: X position, 1 MSB)
+                R/W   xxxx----      (3: X zoom factor)
+                R/W   ---x----      (4: Priority)
+                R/W   ----xxxx      (4: Palette entry)
+                R/W   x-------      (5: Y flip)
+                R/W   -xxx----      (5: Number of Y tiles - 1)
+                R/W   ----x---      (5: X flip)
+                R/W   -----xxx      (5: Number of X tiles - 1)
+                R/W   xxxxxxxx      (6: Starting tile index, 8 LSB)
+                R/W   ----xxxx      (7: Starting tile index, 4 MSB)
+    D000-DFFF   R/W   --xxxxxx   Background tile color
+    E000-EFFF   R/W   xxxxxxxx   Background tile index, 8 MSB
+    F000-FFFF   R/W   xxxxxxxx   Background tile index, 8 LSB
+    ========================================================================
     0020        R     xxxxxxxx   Player 1 controls
                 R     --x-----      (Fast button)
                 R     ---x----      (Place button)
@@ -76,29 +76,29 @@
     0024          W   xxxxxxxx   Background 2 X scroll, 8 LSB
     0025        R     -------x   Sound command pending
     0025          W   xxxxxxxx   Background 2 Y scroll
-	========================================================================
-	Interrupts:
-	   INT generated by CRTC VBLANK
-	========================================================================
+    ========================================================================
+    Interrupts:
+       INT generated by CRTC VBLANK
+    ========================================================================
 
 
-	========================================================================
-	SOUND CPU
-	========================================================================
-	0000-77FF   R     xxxxxxxx   Program ROM
-	7800-7FFF   R/W   xxxxxxxx   Program RAM
-	8000-FFFF   R     xxxxxxxx   Banked ROM
-	========================================================================
-	0004          W   -------x   Bank ROM select
-	0016        R     xxxxxxxx   Sound command read
-	0017          W   --------   Sound command acknowledge
-	0018-0019   R/W   xxxxxxxx   YM2610 port A
-	001A-001B   R/W   xxxxxxxx   YM2610 port B
-	========================================================================
-	Interrupts:
-	   INT generated by YM2610
-	   NMI generated by command from main CPU
-	========================================================================
+    ========================================================================
+    SOUND CPU
+    ========================================================================
+    0000-77FF   R     xxxxxxxx   Program ROM
+    7800-7FFF   R/W   xxxxxxxx   Program RAM
+    8000-FFFF   R     xxxxxxxx   Banked ROM
+    ========================================================================
+    0004          W   -------x   Bank ROM select
+    0016        R     xxxxxxxx   Sound command read
+    0017          W   --------   Sound command acknowledge
+    0018-0019   R/W   xxxxxxxx   YM2610 port A
+    001A-001B   R/W   xxxxxxxx   YM2610 port B
+    ========================================================================
+    Interrupts:
+       INT generated by YM2610
+       NMI generated by command from main CPU
+    ========================================================================
 
 ***************************************************************************/
 
@@ -107,6 +107,8 @@
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
 #include "fromance.h"
+#include "sound/2608intf.h"
+#include "sound/2610intf.h"
 #include <math.h>
 
 
@@ -117,7 +119,7 @@ static UINT8 sound_command;
 
 /*************************************
  *
- *	Initialization & bankswitching
+ *  Initialization & bankswitching
  *
  *************************************/
 
@@ -138,15 +140,15 @@ MACHINE_INIT( pipedrm )
 static WRITE8_HANDLER( pipedrm_bankswitch_w )
 {
 	/*
-		Bit layout:
+        Bit layout:
 
-		D7 = unknown
-		D6 = flip screen
-		D5 = background 2 X scroll MSB
-		D4 = background 1 X scroll MSB
-		D3 = background videoram select
-		D2-D0 = program ROM bank select
-	*/
+        D7 = unknown
+        D6 = flip screen
+        D5 = background 2 X scroll MSB
+        D4 = background 1 X scroll MSB
+        D3 = background videoram select
+        D2-D0 = program ROM bank select
+    */
 
 	/* set the memory bank on the Z80 using the low 3 bits */
 	UINT8 *ram = memory_region(REGION_CPU1);
@@ -168,7 +170,7 @@ static WRITE8_HANDLER( sound_bankswitch_w )
 
 /*************************************
  *
- *	Sound CPU I/O
+ *  Sound CPU I/O
  *
  *************************************/
 
@@ -219,7 +221,7 @@ static READ8_HANDLER( sound_command_r )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -242,6 +244,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x20, 0x20) AM_READ(input_port_0_r)
 	AM_RANGE(0x21, 0x21) AM_READ(input_port_1_r)
 	AM_RANGE(0x22, 0x22) AM_READ(input_port_2_r)
@@ -252,6 +255,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x20, 0x20) AM_WRITE(sound_command_w)
 	AM_RANGE(0x21, 0x21) AM_WRITE(pipedrm_bankswitch_w)
 	AM_RANGE(0x22, 0x25) AM_WRITE(fromance_scroll_w)
@@ -261,7 +265,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
@@ -280,6 +284,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x16, 0x16) AM_READ(sound_command_r)
 	AM_RANGE(0x18, 0x18) AM_READ(YM2610_status_port_0_A_r)
 	AM_RANGE(0x1a, 0x1a) AM_READ(YM2610_status_port_0_B_r)
@@ -287,6 +292,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x04, 0x04) AM_WRITE(sound_bankswitch_w)
 	AM_RANGE(0x17, 0x17) AM_WRITE(pending_command_clear_w)
 	AM_RANGE(0x18, 0x18) AM_WRITE(YM2610_control_port_0_A_w)
@@ -297,6 +303,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( hatris_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x04, 0x04) AM_READ(sound_command_r)
 	AM_RANGE(0x05, 0x05) AM_READ(pending_command_r)
 	AM_RANGE(0x08, 0x08) AM_READ(YM2608_status_port_0_A_r)
@@ -305,6 +312,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( hatris_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x02, 0x02) AM_WRITE(YM2608_control_port_0_B_w)
 	AM_RANGE(0x03, 0x03) AM_WRITE(YM2608_data_port_0_B_w)
 	AM_RANGE(0x05, 0x05) AM_WRITE(pending_command_clear_w)
@@ -318,7 +326,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -355,7 +363,7 @@ INPUT_PORTS_START( pipedrm )
 	PORT_DIPSETTING(    0x02, "5 Coins/6 Credits" )
 	PORT_DIPSETTING(    0x01, DEF_STR( 4C_5C ))
 	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ))
-/*	PORT_DIPSETTING(    0x05, DEF_STR( 2C_3C )) */
+/*  PORT_DIPSETTING(    0x05, DEF_STR( 2C_3C )) */
 	PORT_DIPSETTING(    0x0e, DEF_STR( 1C_2C ))
 	PORT_DIPSETTING(    0x0d, DEF_STR( 1C_3C ))
 	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_4C ))
@@ -372,7 +380,7 @@ INPUT_PORTS_START( pipedrm )
 	PORT_DIPSETTING(    0x20, "5 Coins/6 Credits" )
 	PORT_DIPSETTING(    0x10, DEF_STR( 4C_5C ))
 	PORT_DIPSETTING(    0x00, DEF_STR( 2C_3C ))
-/*	PORT_DIPSETTING(    0x50, DEF_STR( 2C_3C )) */
+/*  PORT_DIPSETTING(    0x50, DEF_STR( 2C_3C )) */
 	PORT_DIPSETTING(    0xe0, DEF_STR( 1C_2C ))
 	PORT_DIPSETTING(    0xd0, DEF_STR( 1C_3C ))
 	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ))
@@ -446,7 +454,7 @@ INPUT_PORTS_START( hatris )
 	PORT_DIPSETTING(    0x0d, "5 Coins/6 Credits" )
 	PORT_DIPSETTING(    0x0e, DEF_STR( 4C_5C ))
 	PORT_DIPSETTING(    0x0f, DEF_STR( 2C_3C ))
-/*	PORT_DIPSETTING(    0x0a, DEF_STR( 2C_3C )) */
+/*  PORT_DIPSETTING(    0x0a, DEF_STR( 2C_3C )) */
 	PORT_DIPSETTING(    0x01, DEF_STR( 1C_2C ))
 	PORT_DIPSETTING(    0x02, DEF_STR( 1C_3C ))
 	PORT_DIPSETTING(    0x03, DEF_STR( 1C_4C ))
@@ -463,7 +471,7 @@ INPUT_PORTS_START( hatris )
 	PORT_DIPSETTING(    0xd0, "5 Coins/6 Credits" )
 	PORT_DIPSETTING(    0xe0, DEF_STR( 4C_5C ))
 	PORT_DIPSETTING(    0xf0, DEF_STR( 2C_3C ))
-/*	PORT_DIPSETTING(    0xa0, DEF_STR( 2C_3C )) */
+/*  PORT_DIPSETTING(    0xa0, DEF_STR( 2C_3C )) */
 	PORT_DIPSETTING(    0x10, DEF_STR( 1C_2C ))
 	PORT_DIPSETTING(    0x20, DEF_STR( 1C_3C ))
 	PORT_DIPSETTING(    0x30, DEF_STR( 1C_4C ))
@@ -505,7 +513,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -554,7 +562,7 @@ static struct GfxDecodeInfo gfxdecodeinfo_hatris[] =
 
 /*************************************
  *
- *	Sound definitions
+ *  Sound definitions
  *
  *************************************/
 
@@ -566,39 +574,23 @@ static void irqhandler(int irq)
 
 static struct YM2608interface ym2608_interface =
 {
-	1,
-	8000000,	/* 8 MHz */
-	{ 50 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler },
-	{ REGION_SOUND1 },
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) }
+	0,0,0,0,irqhandler,
+	REGION_SOUND1
 };
 
 
 static struct YM2610interface ym2610_interface =
 {
-	1,
-	8000000,	/* 8 MHz */
-	{ 50 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler },
-	{ REGION_SOUND1 },
-	{ REGION_SOUND2 },
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) }
+	irqhandler,
+	REGION_SOUND1,
+	REGION_SOUND2
 };
 
 
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -611,7 +603,7 @@ static MACHINE_DRIVER_START( pipedrm )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,14318000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 
@@ -631,7 +623,13 @@ static MACHINE_DRIVER_START( pipedrm )
 	MDRV_VIDEO_UPDATE(pipedrm)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2610, ym2610_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.50)
+	MDRV_SOUND_ROUTE(1, "mono", 1.0)
+	MDRV_SOUND_ROUTE(2, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -644,7 +642,7 @@ static MACHINE_DRIVER_START( hatris )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,14318000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(hatris_sound_readport,hatris_sound_writeport)
 
@@ -664,14 +662,20 @@ static MACHINE_DRIVER_START( hatris )
 	MDRV_VIDEO_UPDATE(fromance)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2608, ym2608_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2608, 8000000)
+	MDRV_SOUND_CONFIG(ym2608_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.50)
+	MDRV_SOUND_ROUTE(1, "mono", 1.0)
+	MDRV_SOUND_ROUTE(2, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -758,7 +762,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver initialization
+ *  Driver initialization
  *
  *************************************/
 
@@ -781,7 +785,7 @@ static DRIVER_INIT( hatris )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
