@@ -1,17 +1,17 @@
 /***************************************************************************
 
-	  Poly-Play
-	  (c) 1985 by VEB Polytechnik Karl-Marx-Stadt
+      Poly-Play
+      (c) 1985 by VEB Polytechnik Karl-Marx-Stadt
 
-	  driver by Martin Buchholz (buchholz@mail.uni-greifswald.de)
+      driver by Martin Buchholz (buchholz@mail.uni-greifswald.de)
 
-	  Very special thanks to the following people, each one of them spent
-	  some of their spare time to make this driver working:
-	  - Juergen Oppermann and Volker Hann for electronical assistance,
-	    repair work and ROM dumping.
-	  - Jan-Ole Christian from the Videogamemuseum in Berlin, which houses
-	    one of the last existing Poly-Play arcade automatons. He also
-	    provided me with schematics and service manuals.
+      Very special thanks to the following people, each one of them spent
+      some of their spare time to make this driver working:
+      - Juergen Oppermann and Volker Hann for electronical assistance,
+        repair work and ROM dumping.
+      - Jan-Ole Christian from the Videogamemuseum in Berlin, which houses
+        one of the last existing Poly-Play arcade automatons. He also
+        provided me with schematics and service manuals.
 
 
 memory map:
@@ -61,7 +61,7 @@ read:
 87        PIO Control register
 
 write:
-80	      Sound Channel 1
+80        Sound Channel 1
 81        Sound Channel 2
 82        generates 40 Hz timer for timeout in game title screens
 83        generates main 75 Hz timer interrupt
@@ -82,6 +82,7 @@ emulated now. ;)
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "machine/random.h"
+#include "sound/samples.h"
 
 /* video hardware access */
 extern unsigned char *polyplay_characterram;
@@ -104,9 +105,7 @@ static int channel2_active;
 static int channel2_const;
 void play_channel1(int data);
 void play_channel2(int data);
-int  polyplay_sh_start(const struct MachineSound *msound);
-void polyplay_sh_stop(void);
-void polyplay_sh_update(void);
+void polyplay_sh_start(void);
 
 /* timer handling */
 static void timer_callback(int param);
@@ -116,11 +115,11 @@ static WRITE8_HANDLER( polyplay_sound_channel );
 
 
 /* Polyplay Sound Interface */
-static struct CustomSound_interface custom_interface =
+static struct Samplesinterface custom_interface =
 {
-	polyplay_sh_start,
-	polyplay_sh_stop,
-	polyplay_sh_update
+	2,
+	NULL,
+	polyplay_sh_start
 };
 
 
@@ -188,11 +187,13 @@ ADDRESS_MAP_END
 
 /* port mapping */
 static ADDRESS_MAP_START( readport_polyplay, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x84, 0x84) AM_READ(input_port_0_r)
 	AM_RANGE(0x83, 0x83) AM_READ(polyplay_random_read)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport_polyplay, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x80, 0x81) AM_WRITE(polyplay_sound_channel)
 	AM_RANGE(0x82, 0x82) AM_WRITE(polyplay_start_timer2)
 ADDRESS_MAP_END
@@ -330,7 +331,11 @@ static MACHINE_DRIVER_START( polyplay )
 	MDRV_VIDEO_UPDATE(polyplay)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(CUSTOM, custom_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(custom_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
