@@ -19,6 +19,7 @@ Notes:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/ay8910.h"
 
 
 extern UINT8 *popeye_background_pos;
@@ -147,6 +148,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)
 	AM_RANGE(0x01, 0x01) AM_READ(input_port_1_r)
 	AM_RANGE(0x02, 0x02) AM_READ(input_port_2_r)
@@ -154,6 +156,7 @@ static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
 ADDRESS_MAP_END
@@ -301,7 +304,7 @@ INPUT_PORTS_START( popeye )
 	PORT_DIPSETTING(    0x40, "Nintendo" )
 	PORT_DIPSETTING(    0x20, "Nintendo Co.,Ltd" )
 	PORT_DIPSETTING(    0x60, "Nintendo of America" )
-/*	PORT_DIPSETTING(    0x00, "Nintendo of America" ) */
+/*  PORT_DIPSETTING(    0x00, "Nintendo of America" ) */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* scans DSW1 one bit at a time */
 
 	PORT_START	/* DSW1 (FAKE - appears as bit 7 of DSW0, see code below) */
@@ -385,7 +388,7 @@ INPUT_PORTS_START( popeyef )
 	PORT_DIPSETTING(    0x40, "Nintendo" )
 	PORT_DIPSETTING(    0x20, "Nintendo Co.,Ltd" )
 	PORT_DIPSETTING(    0x60, "Nintendo of America" )
-/*	PORT_DIPSETTING(    0x00, "Nintendo of America" ) */
+/*  PORT_DIPSETTING(    0x00, "Nintendo of America" ) */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* scans DSW1 one bit at a time */
 
 	PORT_START	/* DSW1 (FAKE - appears as bit 7 of DSW0, see code below) */
@@ -471,13 +474,10 @@ static READ8_HANDLER( popeye_portA_r )
 
 static struct AY8910interface ay8910_interface =
 {
-	1,	/* 1 chip */
-	8000000/4,	/* 2 MHz */
-	{ 40 },
-	{ popeye_portA_r },
-	{ 0 },
-	{ 0 },
-	{ popeye_portB_w }
+	popeye_portA_r,
+	0,
+	0,
+	popeye_portB_w
 };
 
 
@@ -505,7 +505,11 @@ static MACHINE_DRIVER_START( skyskipr )
 	MDRV_VIDEO_UPDATE(popeye)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 8000000/4)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 MACHINE_DRIVER_END
 
 
