@@ -97,6 +97,8 @@ write:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/vlm5030.h"
+#include "sound/nes_apu.h"
 
 
 extern unsigned char *punchout_videoram2;
@@ -407,6 +409,7 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)
 	AM_RANGE(0x01, 0x01) AM_READ(input_port_1_r)
 	AM_RANGE(0x02, 0x02) AM_READ(input_port_2_r)
@@ -427,6 +430,7 @@ static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x01) AM_WRITE(MWA8_NOP)	/* the 2A03 #1 is not present */
 	AM_RANGE(0x02, 0x02) AM_WRITE(soundlatch_w)
 	AM_RANGE(0x03, 0x03) AM_WRITE(soundlatch2_w)
@@ -522,12 +526,12 @@ INPUT_PORTS_START( punchout )
 	PORT_DIPSETTING(    0x0c, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
-/*	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(    0x08, "1 Coin/2 Credits (2 Credits/1 Play)" )
 	PORT_DIPSETTING(    0x0d, "1 Coin/3 Credits (2 Credits/1 Play)" )
 	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
-/*	PORT_DIPSETTING(    0x04, DEF_STR( 1C_2C ) ) */
-/*	PORT_DIPSETTING(    0x09, DEF_STR( 1C_2C ) ) */
+/*  PORT_DIPSETTING(    0x04, DEF_STR( 1C_2C ) ) */
+/*  PORT_DIPSETTING(    0x09, DEF_STR( 1C_2C ) ) */
 	PORT_DIPSETTING(    0x05, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x06, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x0a, DEF_STR( 1C_5C ) )
@@ -591,11 +595,11 @@ INPUT_PORTS_START( spnchout )
 	PORT_DIPSETTING(    0x08, DEF_STR( 6C_1C ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 5C_1C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 4C_1C ) )
-/*	PORT_DIPSETTING(    0x09, DEF_STR( 4C_1C ) ) */
+/*  PORT_DIPSETTING(    0x09, DEF_STR( 4C_1C ) ) */
 	PORT_DIPSETTING(    0x0c, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
-/*	PORT_DIPSETTING(    0x0e, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0e, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(    0x0d, "1 Coin/3 Credits (2 Credits/1 Play)" )
 	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(    0x0b, "1 Coin/2 Credits (3 Credits/1 Play)" )
@@ -754,16 +758,12 @@ static struct GfxDecodeInfo armwrest_gfxdecodeinfo[] =
 
 static struct NESinterface nes_interface =
 {
-	1,
-	{ REGION_CPU2 },
-	{ 50 },
+	REGION_CPU2
 };
 
 
 static struct VLM5030interface vlm5030_interface =
 {
-	3580000,    /* master clock */
-	50,        /* volume       */
 	REGION_SOUND1,	/* memory region of speech rom */
 	0           /* memory size of speech rom */
 };
@@ -779,7 +779,7 @@ static MACHINE_DRIVER_START( punchout )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(N2A03, N2A03_DEFAULTCLOCK)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
@@ -802,8 +802,15 @@ static MACHINE_DRIVER_START( punchout )
 	MDRV_VIDEO_UPDATE(punchout)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(NES, nes_interface)
-	MDRV_SOUND_ADD(VLM5030, vlm5030_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(NES, 0)
+	MDRV_SOUND_CONFIG(nes_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(VLM5030, 3580000)
+	MDRV_SOUND_CONFIG(vlm5030_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
