@@ -1,7 +1,7 @@
 /***************************************************************************
 
-Quiz Do Re Mi Fa Grand Prix (Japan)		(GQ460) (c)1994 Konami
-Quiz Do Re Mi Fa Grand Prix 2 (Japan)	(GE557) (c)1995 Konami
+Quiz Do Re Mi Fa Grand Prix (Japan)     (GQ460) (c)1994 Konami
+Quiz Do Re Mi Fa Grand Prix 2 (Japan)   (GE557) (c)1995 Konami
 
 
 CPU  :MC68HC000FN16
@@ -15,8 +15,8 @@ driver by Eisuke Watanabe
 
 Note:
 GP1 HDD data contents:
-	0x000-0x52D intro quiz musics
-	0x52E-0x535 not used quiz (system music or invalid data)
+    0x000-0x52D intro quiz musics
+    0x52E-0x535 not used quiz (system music or invalid data)
 ***************************************************************************/
 
 #include "driver.h"
@@ -40,7 +40,7 @@ static int gp2_irq_control;
 
 /*************************************
  *
- *	68k CPU memory handlers
+ *  68k CPU memory handlers
  *
  *************************************/
 
@@ -54,7 +54,7 @@ static READ16_HANDLER( i_port1_r )
 
 static READ16_HANDLER( i_port2_r )
 {
-	/* bit 0-1	battery power sensor: 3=good, 2=low, other=bad */
+	/* bit 0-1  battery power sensor: 3=good, 2=low, other=bad */
 
 	return (input_port_2_word_r(0,0) & 0xfffc) | 0x0003;
 }
@@ -67,17 +67,17 @@ int qdrmfgp_get_palette(void)
 
 static WRITE16_HANDLER( gp_control_w )
 {
-	/* bit 0		enable irq 1 (sound) */
-	/* bit 1		enable irq 2 (not used) */
-	/* bit 2		enable irq 3 (vblank) */
-	/* bit 3		enable irq 4 (hdd) */
-	/* bit 4-6		palette (tilemap) */
-	/* bit 7		inputports bankswitch */
-	/* bit 8		enable volume control */
-	/* bit 9		volume: 1=up, 0=down (low5,mid90,high180) */
-	/* bit 10		enable headphone volume control */
-	/* bit 11		headphone volume: 1=up, 0=down */
-	/* bit 15		gfxrom bankswitch */
+	/* bit 0        enable irq 1 (sound) */
+	/* bit 1        enable irq 2 (not used) */
+	/* bit 2        enable irq 3 (vblank) */
+	/* bit 3        enable irq 4 (hdd) */
+	/* bit 4-6      palette (tilemap) */
+	/* bit 7        inputports bankswitch */
+	/* bit 8        enable volume control */
+	/* bit 9        volume: 1=up, 0=down (low5,mid90,high180) */
+	/* bit 10       enable headphone volume control */
+	/* bit 11       headphone volume: 1=up, 0=down */
+	/* bit 15       gfxrom bankswitch */
 
 	COMBINE_DATA(&control);
 	qdrmfgp_pal = control & 0x70;
@@ -98,15 +98,15 @@ static WRITE16_HANDLER( gp_control_w )
 
 static WRITE16_HANDLER( gp2_control_w )
 {
-	/* bit 2		enable irq 3 (sound) */
-	/* bit 3		enable irq 4 (vblank) */
-	/* bit 4		enable irq 5 (hdd) */
-	/* bit 7		inputports bankswitch */
-	/* bit 8		enable volume control */
-	/* bit 9		volume: 1=up, 0=down (low0,mid90,high255) */
-	/* bit 10		enable headphone volume control */
-	/* bit 11		headphone volume: 1=up, 0=down */
-	/* bit 15		gfxrom bankswitch */
+	/* bit 2        enable irq 3 (sound) */
+	/* bit 3        enable irq 4 (vblank) */
+	/* bit 4        enable irq 5 (hdd) */
+	/* bit 7        inputports bankswitch */
+	/* bit 8        enable volume control */
+	/* bit 9        volume: 1=up, 0=down (low0,mid90,high255) */
+	/* bit 10       enable headphone volume control */
+	/* bit 11       headphone volume: 1=up, 0=down */
+	/* bit 15       gfxrom bankswitch */
 
 	COMBINE_DATA(&control);
 	qdrmfgp_pal = 0;
@@ -270,7 +270,7 @@ static READ16_HANDLER( gp2_ide_std_r )
 
 /*************************************
  *
- *	Interrupt handlers
+ *  Interrupt handlers
  *
  *************************************/
 
@@ -336,7 +336,7 @@ static void gp2_ide_interrupt(int state)
 
 /*************************************
  *
- *	Memory definitions
+ *  Memory definitions
  *
  *************************************/
 
@@ -416,7 +416,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -583,14 +583,14 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics layouts
+ *  Graphics layouts
  *
  *************************************/
 
 
 /*************************************
  *
- *	IDE interfaces
+ *  IDE interfaces
  *
  *************************************/
 
@@ -607,7 +607,7 @@ static struct ide_interface gp2_ide_intf =
 
 /*************************************
  *
- *	Sound interfaces
+ *  Sound interfaces
  *
  *************************************/
 
@@ -619,26 +619,20 @@ static void sound_irq(void)
 
 static struct K054539interface k054539_interface =
 {
-	1,					/* 1 chip */
-	18432000/384,		/* 48000 Hz */
-	{ REGION_SOUND1 },
-	{ { 100, 100 } },
-	{ 0 },
-	{ sound_irq }
+	REGION_SOUND1,
+	NULL,
+	sound_irq
 };
 
 static struct K054539interface gp2_k054539_interface =
 {
-	1,					/* 1 chip (not used 2nd chip & interrupt) */
-	18432000/384,		/* 48000 Hz */
-	{ REGION_SOUND1 },
-	{ { 100, 100 } },
+	REGION_SOUND1
 };
 
 
 /*************************************
  *
- *	Machine-specific init
+ *  Machine-specific init
  *
  *************************************/
 
@@ -666,7 +660,7 @@ static MACHINE_INIT( qdrmfgp2 )
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -693,8 +687,12 @@ static MACHINE_DRIVER_START( qdrmfgp )
 	MDRV_VIDEO_UPDATE(qdrmfgp)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(K054539, k054539_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(K054539, 18432000/384)
+	MDRV_SOUND_CONFIG(k054539_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( qdrmfgp2 )
@@ -720,14 +718,18 @@ static MACHINE_DRIVER_START( qdrmfgp2 )
 	MDRV_VIDEO_UPDATE(qdrmfgp)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(K054539, gp2_k054539_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(K054539, 18432000/384)
+	MDRV_SOUND_CONFIG(gp2_k054539_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -768,7 +770,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver-specific init
+ *  Driver-specific init
  *
  *************************************/
 
@@ -797,7 +799,7 @@ static DRIVER_INIT( qdrmfgp2 )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
