@@ -14,7 +14,7 @@
 
   - Make Asto Wars to boot
   - Make Cat'n Mouse to boot
-	(it jumps to unpopulated rom, check jump at 0x2e62 and 0x4076)
+    (it jumps to unpopulated rom, check jump at 0x2e62 and 0x4076)
   - ...
 
 ************************************************************************
@@ -61,6 +61,7 @@ Sound Board 1b11107
 #include "cpu/s2650/s2650.h"
 #include "vidhrdw/generic.h"
 #include "cpu/i8039/i8039.h"
+#include "sound/dac.h"
 
 PALETTE_INIT( quasar );
 VIDEO_UPDATE( quasar );
@@ -248,7 +249,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound board memory handlers
+ *  Sound board memory handlers
  *
  *************************************/
 
@@ -424,12 +425,6 @@ static INTERRUPT_GEN( quasar_interrupt )
 	cpunum_set_input_line_and_vector(0,0,PULSE_LINE,0x03);
 }
 
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 100 }
-};
-
 /* ************************(*************** */
 /* Quasar S2650 Main CPU, I8035 sound board */
 /* **************************************** */
@@ -442,7 +437,7 @@ static MACHINE_DRIVER_START( quasar )
 	MDRV_CPU_VBLANK_INT(quasar_interrupt,1)
 
 	MDRV_CPU_ADD_TAG("sound",I8035,6000000/15)			/* 6MHz crystal divide by 15 in CPU */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 	MDRV_CPU_IO_MAP(readport_sound,writeport_sound)
 
@@ -464,7 +459,10 @@ static MACHINE_DRIVER_START( quasar )
 	MDRV_VIDEO_UPDATE(quasar)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 ROM_START( quasar )
