@@ -4,12 +4,14 @@ Quiz DNA no Hanran (c) 1992 Face
 Quiz Gakuen Paradise (c) 1991 NMK
 Quiz Gekiretsu Scramble (Gakuen Paradise 2) (c) 1993 Face
 
-	Driver by Uki
+    Driver by Uki
 
 *****************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2203intf.h"
+#include "sound/okim6295.h"
 
 #define MCLK 16000000
 
@@ -66,6 +68,7 @@ static ADDRESS_MAP_START( gekiretu_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( quizdna_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x80, 0x80) AM_READ(input_port_2_r)
 	AM_RANGE(0x81, 0x81) AM_READ(input_port_3_r)
 	AM_RANGE(0x90, 0x90) AM_READ(input_port_4_r)
@@ -77,6 +80,7 @@ static ADDRESS_MAP_START( quizdna_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( quizdna_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x02, 0x03) AM_WRITE(quizdna_bg_xscroll_w)
 	AM_RANGE(0x04, 0x04) AM_WRITE(quizdna_bg_yscroll_w)
 	AM_RANGE(0x05, 0x06) AM_WRITE(MWA8_NOP) /* unknown */
@@ -88,6 +92,7 @@ static ADDRESS_MAP_START( quizdna_writeport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( gakupara_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x01) AM_WRITE(quizdna_bg_xscroll_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(quizdna_bg_yscroll_w)
 	AM_RANGE(0x03, 0x04) AM_WRITE(MWA8_NOP) /* unknown */
@@ -99,6 +104,7 @@ static ADDRESS_MAP_START( gakupara_writeport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( gekiretu_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x02, 0x03) AM_WRITE(quizdna_bg_xscroll_w)
 	AM_RANGE(0x04, 0x04) AM_WRITE(quizdna_bg_yscroll_w)
 	AM_RANGE(0x05, 0x06) AM_WRITE(MWA8_NOP) /* unknown */
@@ -442,21 +448,8 @@ static struct GfxDecodeInfo quizdna_gfxdecodeinfo[] =
 
 static struct YM2203interface ym2203_interface =
 {
-	1,
-	MCLK/4,  /* 4.000 MHz */
-	{ YM2203_VOL(40,10) },
-	{ input_port_1_r },
-	{ input_port_0_r },
-	{ 0 },
-	{ 0 }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,
-	{ MCLK/1024 },	/* 15.625KHz */
-	{ REGION_SOUND1 },
-	{ 30 }
+	input_port_1_r,
+	input_port_0_r
 };
 
 
@@ -482,9 +475,18 @@ static MACHINE_DRIVER_START( quizdna )
 	MDRV_VIDEO_UPDATE(quizdna)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
 
+	MDRV_SOUND_ADD(YM2203, MCLK/4)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.10)
+	MDRV_SOUND_ROUTE(1, "mono", 0.10)
+	MDRV_SOUND_ROUTE(2, "mono", 0.10)
+	MDRV_SOUND_ROUTE(3, "mono", 0.40)
+
+	MDRV_SOUND_ADD(OKIM6295, MCLK/1024)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( gakupara )
