@@ -42,26 +42,26 @@ static void draw_sprites( struct mame_bitmap *bitmap, const struct rectangle *cl
 
 	const struct GfxElement *gfx = Machine->gfx[2];
 
-/*	static int ytlim = 1; */
-/*	static int xtlim = 1; */
+/*  static int ytlim = 1; */
+/*  static int xtlim = 1; */
 
-/*	if ( code_pressed_memory(KEYCODE_Q) ) ytlim--; */
-/*	if ( code_pressed_memory(KEYCODE_W) ) ytlim++; */
+/*  if ( code_pressed_memory(KEYCODE_Q) ) ytlim--; */
+/*  if ( code_pressed_memory(KEYCODE_W) ) ytlim++; */
 
-/*	if ( code_pressed_memory(KEYCODE_A) ) xtlim--; */
-/*	if ( code_pressed_memory(KEYCODE_S) ) xtlim++; */
+/*  if ( code_pressed_memory(KEYCODE_A) ) xtlim--; */
+/*  if ( code_pressed_memory(KEYCODE_S) ) xtlim++; */
 
 
 	/*00 ???? ????  (colour / priority?)
-	  01 fhhh Fwww   h = height f=flipy w = width F = flipx
-	  02 nnnn nnnn   n = tileno
-	  03 nnnn nnnn   n = tile no
-	  04 xxxx xxxx   x = xpos
-	  05 xxxx xxxx   x = xpos
-	  06 yyyy yyyy   y = ypos
-	  07 yyyy yyyy   y = ypos
+      01 fhhh Fwww   h = height f=flipy w = width F = flipx
+      02 nnnn nnnn   n = tileno
+      03 nnnn nnnn   n = tile no
+      04 xxxx xxxx   x = xpos
+      05 xxxx xxxx   x = xpos
+      06 yyyy yyyy   y = ypos
+      07 yyyy yyyy   y = ypos
 
-	 */
+     */
 
 
 	while( source>finish ){
@@ -187,7 +187,7 @@ static void get_fore_tile_info( int tile_index )
 	int tile=fore_data[offs]+(fore_data[offs+1]<<8);
 	int color=tile >> 12;
 
-	/*	tile=tile&0xfff; */
+	/*  tile=tile&0xfff; */
 	tile = (tile & 0xfff) | (3<<12);  /* 3000 intro (cliff) 1000 game (bg ) */
 
 	SET_TILE_INFO(1,tile,color,0)
@@ -272,7 +272,7 @@ VIDEO_UPDATE (raiden2)
 			tilemap_mark_all_tiles_dirty(foreground_layer);
 		}
 	}
-/*		fillbitmap(bitmap, get_black_pen(), cliprect); */
+/*      fillbitmap(bitmap, get_black_pen(), cliprect); */
 
 	tilemap_draw(bitmap,cliprect,background_layer,0,0);
 	tilemap_draw(bitmap,cliprect,foreground_layer,0,0);
@@ -317,22 +317,8 @@ static WRITE8_HANDLER(any_w)
 }
 
 enum {SZ=16};
-static UINT8 scroll[SZ];
+/*static UINT8 scroll[SZ]; */
 
-static WRITE8_HANDLER(scroll_w)
-{
-	int i;
-	scroll[offset] = data;
-	/*	if(offset == 1) */
-	/*		fprintf(stderr, "Tilebank_w %02x (%x)\n", data, activecpu_get_pc()); */
-
-	if(0) {
-		fprintf(stderr, "Scroll.%x :", offset);
-		for(i=0; i<SZ; i++)
-			fprintf(stderr, " %02x", scroll[i]);
-		fprintf(stderr, "\n");
-	}
-}
 
 /* MEMORY MAPS */
 
@@ -341,7 +327,7 @@ static ADDRESS_MAP_START( raiden2_mem, ADDRESS_SPACE_PROGRAM, 8 )
 
 	AM_RANGE(0x00430, 0x0043f) AM_WRITE(sound_w)
 	AM_RANGE(0x620, 0x62f) AM_RAM AM_BASE(&scrollregs)
-/*	 AM_RANGE(0x470, 0x47f) AM_WRITE(scroll_w) */
+/*   AM_RANGE(0x470, 0x47f) AM_WRITE(scroll_w) */
 
 	/* I have my doubts these are really mapped here, protection? */
 	AM_RANGE(0x00740, 0x00740) AM_READ(input_port_2_r) /* dip 1 */
@@ -1281,13 +1267,13 @@ ROM_START( zeroteam )
 
 	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE ) /* background gfx */
 	/* not dumped for this set */
-/*	ROM_LOAD( "back-1",   0x000000, 0x100000, CRC(8b7f9219) SHA1(3412b6f8a4fe245e521ddcf185a53f2f4520eb57) ) */
-/*	ROM_LOAD( "back-2",   0x100000, 0x080000, CRC(ce61c952) SHA1(52a843c8ba428b121fab933dd3b313b2894d80ac) ) */
+/*  ROM_LOAD( "back-1",   0x000000, 0x100000, CRC(8b7f9219) SHA1(3412b6f8a4fe245e521ddcf185a53f2f4520eb57) ) */
+/*  ROM_LOAD( "back-2",   0x100000, 0x080000, CRC(ce61c952) SHA1(52a843c8ba428b121fab933dd3b313b2894d80ac) ) */
 
 	ROM_REGION( 0x800000, REGION_GFX3, ROMREGION_DISPOSE ) /* sprite gfx (encrypted) (diff encrypt to raiden2? ) */
 	/* not dumped for this set */
-/*	ROM_LOAD32_WORD( "obj-1",  0x000000, 0x200000, CRC(45be8029) SHA1(adc164f9dede9a86b96a4d709e9cba7d2ad0e564) ) */
-/*	ROM_LOAD32_WORD( "obj-2",  0x000002, 0x200000, CRC(cb61c19d) SHA1(151a2ce9c32f3321a974819e9b165dddc31c8153) ) */
+/*  ROM_LOAD32_WORD( "obj-1",  0x000000, 0x200000, CRC(45be8029) SHA1(adc164f9dede9a86b96a4d709e9cba7d2ad0e564) ) */
+/*  ROM_LOAD32_WORD( "obj-2",  0x000002, 0x200000, CRC(cb61c19d) SHA1(151a2ce9c32f3321a974819e9b165dddc31c8153) ) */
 
 	ROM_REGION( 0x100000, REGION_SOUND1, 0 )	/* ADPCM samples */
 	ROM_LOAD( "pcm", 0x00000, 0x40000,  CRC(48be32b1) SHA1(969d2191a3c46871ee8bf93088b3cecce3eccf0c) ) /* 6.4a */
@@ -1311,18 +1297,49 @@ ROM_START( zeroteaa )
 
 	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE ) /* background gfx */
 	/* not dumped for this set */
-/*	ROM_LOAD( "back-1",   0x000000, 0x100000, CRC(8b7f9219) SHA1(3412b6f8a4fe245e521ddcf185a53f2f4520eb57) ) */
-/*	ROM_LOAD( "back-2",   0x100000, 0x080000, CRC(ce61c952) SHA1(52a843c8ba428b121fab933dd3b313b2894d80ac) ) */
+/*  ROM_LOAD( "back-1",   0x000000, 0x100000, CRC(8b7f9219) SHA1(3412b6f8a4fe245e521ddcf185a53f2f4520eb57) ) */
+/*  ROM_LOAD( "back-2",   0x100000, 0x080000, CRC(ce61c952) SHA1(52a843c8ba428b121fab933dd3b313b2894d80ac) ) */
 
 	ROM_REGION( 0x800000, REGION_GFX3, ROMREGION_DISPOSE ) /* sprite gfx (encrypted) (diff encrypt to raiden2? ) */
 	/* not dumped for this set */
-/*	ROM_LOAD32_WORD( "obj-1",  0x000000, 0x200000, CRC(45be8029) SHA1(adc164f9dede9a86b96a4d709e9cba7d2ad0e564) ) */
-/*	ROM_LOAD32_WORD( "obj-2",  0x000002, 0x200000, CRC(cb61c19d) SHA1(151a2ce9c32f3321a974819e9b165dddc31c8153) ) */
+/*  ROM_LOAD32_WORD( "obj-1",  0x000000, 0x200000, CRC(45be8029) SHA1(adc164f9dede9a86b96a4d709e9cba7d2ad0e564) ) */
+/*  ROM_LOAD32_WORD( "obj-2",  0x000002, 0x200000, CRC(cb61c19d) SHA1(151a2ce9c32f3321a974819e9b165dddc31c8153) ) */
 
 	ROM_REGION( 0x100000, REGION_SOUND1, 0 )	/* ADPCM samples */
 	ROM_LOAD( "pcm", 0x00000, 0x40000,  CRC(48be32b1) SHA1(969d2191a3c46871ee8bf93088b3cecce3eccf0c) ) /* 6.bin */
 ROM_END
 
+/* set contained only program roms, was marked as 'non-encrytped' but program isn't encrypted anyway?! */
+ROM_START( zeroteab )
+	ROM_REGION( 0x200000, REGION_CPU1, 0 ) /* dummy */
+
+	ROM_REGION( 0x200000, REGION_USER1, 0 ) /* v30 main cpu */
+	ROM_LOAD32_BYTE("z1",   0x000000, 0x40000, CRC(157743d0) SHA1(f9c84c9025319f76807ef0e79f1ee1599f915b45) )
+	ROM_LOAD32_BYTE("z3",   0x000002, 0x40000, CRC(fea7e4e8) SHA1(08c4bdff82362ae4bcf86fa56fcfc384bbf82b71) )
+	ROM_LOAD32_BYTE("z2",   0x000001, 0x40000, CRC(21d68f62) SHA1(8aa85b38e8f36057ef6c7dce5a2878958ce93ce8) )
+	ROM_LOAD32_BYTE("z4",   0x000003, 0x40000, CRC(ce8fe6c2) SHA1(69627867c7866e43e771ab85014553117044d18d) )
+
+	ROM_REGION( 0x20000, REGION_CPU2, 0 ) /* 64k code for sound Z80 */
+	ROM_LOAD( "sound",  0x000000, 0x10000, CRC(7ec1fbc3) SHA1(48299d6530f641b18764cc49e283c347d0918a47) ) /* 5.5c */
+
+	ROM_REGION( 0x020000, REGION_GFX1, ROMREGION_DISPOSE ) /* chars */
+	ROM_LOAD16_BYTE( "7.5s",	0x000000,	0x010000,	CRC(9f6aa0f0) SHA1(1caad7092c07723d12a07aa363ae2aa69cb6be0d) )
+	ROM_LOAD16_BYTE( "8.5r",	0x000001,	0x010000,	CRC(68f7dddc) SHA1(6938fa974c6ef028751982fdabd6a3820b0d30a8) )
+
+	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE ) /* background gfx */
+	/* not dumped for this set */
+/*  ROM_LOAD( "back-1",   0x000000, 0x100000, CRC(8b7f9219) SHA1(3412b6f8a4fe245e521ddcf185a53f2f4520eb57) ) */
+/*  ROM_LOAD( "back-2",   0x100000, 0x080000, CRC(ce61c952) SHA1(52a843c8ba428b121fab933dd3b313b2894d80ac) ) */
+
+	ROM_REGION( 0x800000, REGION_GFX3, ROMREGION_DISPOSE ) /* sprite gfx (encrypted) (diff encrypt to raiden2? ) */
+	/* not dumped for this set */
+/*  ROM_LOAD32_WORD( "obj-1",  0x000000, 0x200000, CRC(45be8029) SHA1(adc164f9dede9a86b96a4d709e9cba7d2ad0e564) ) */
+/*  ROM_LOAD32_WORD( "obj-2",  0x000002, 0x200000, CRC(cb61c19d) SHA1(151a2ce9c32f3321a974819e9b165dddc31c8153) ) */
+
+	ROM_REGION( 0x100000, REGION_SOUND1, 0 )	/* ADPCM samples */
+	ROM_LOAD( "pcm", 0x00000, 0x40000,  CRC(48be32b1) SHA1(969d2191a3c46871ee8bf93088b3cecce3eccf0c) ) /* 6.4a */
+ROM_END
+
 ROM_START( nzerotea )
 	ROM_REGION( 0x200000, REGION_CPU1, 0 ) /* dummy */
 
@@ -1454,11 +1471,12 @@ unsigned int zmap_5[32] = {
   0xc0c6e6c0, 0xfccaf047, 0xf89fb813, 0xe753d648, 0xba704519, 0x00548eca, 0x519799f6, 0x60604917,
 };
 
-
+#if 0
 static unsigned int xrot(unsigned int v, int r)
 {
   return (v >> r) | (v << (32-r));
 }
+#endif
 
 static unsigned int yrot(unsigned int v, int r)
 {
@@ -1661,5 +1679,6 @@ GAMEX( 1993, raidndxb, raidndx, raiden2,  raiden2n, r2nocpu,  ROT270, "Seibu Kai
 GAMEX( 1993, raidndxj, raidndx, raiden2,  raidendx, raiden2,  ROT270, "Seibu Kaihatsu", "Raiden DX (Japan)", GAME_NOT_WORKING|GAME_NO_SOUND)
 GAMEX( 1993, zeroteam, 0,       raiden2,  raiden2,  raiden2,  ROT0,   "Seibu Kaihatsu", "Zero Team (set 1)", GAME_NOT_WORKING|GAME_NO_SOUND)
 GAMEX( 1993, zeroteaa, zeroteam,raiden2,  raiden2,  raiden2,  ROT0,   "Seibu Kaihatsu", "Zero Team (set 2)", GAME_NOT_WORKING|GAME_NO_SOUND)
+GAMEX( 1993, zeroteab, zeroteam,raiden2,  raiden2,  raiden2,  ROT0,   "Seibu Kaihatsu", "Zero Team (set 3)", GAME_NOT_WORKING|GAME_NO_SOUND)
 GAMEX( 1993, nzerotea, zeroteam,raiden2,  raiden2,  raiden2,  ROT0,   "Seibu Kaihatsu", "New Zero Team", GAME_NOT_WORKING|GAME_NO_SOUND)
 
