@@ -182,7 +182,8 @@ TODO:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "sndhrdw/timeplt.h"
-
+#include "sound/namco.h"
+#include "sound/samples.h"
 
 
 extern data8_t *rallyx_videoram,*rallyx_radarattr;
@@ -230,7 +231,7 @@ static WRITE8_HANDLER( rallyx_latch_w )
 
 		case 0x02:	/* SOUND ON */
 			/* this doesn't work in New Rally X so I'm not supporting it */
-/*			pengo_sound_enable_w(0,bit); */
+/*          pacman_sound_enable_w(0,bit); */
 			break;
 
 		case 0x03:	/* FLIP */
@@ -271,7 +272,7 @@ static WRITE8_HANDLER( locomotn_latch_w )
 			break;
 
 		case 0x02:	/* MUT */
-/*			sound disable */
+/*          sound disable */
 			break;
 
 		case 0x03:	/* FLIP */
@@ -306,7 +307,7 @@ static ADDRESS_MAP_START( rallyx_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xa100, 0xa100) AM_READ(input_port_2_r)
 	AM_RANGE(0xa000, 0xa00f) AM_WRITE(MWA8_RAM) AM_BASE(&rallyx_radarattr)
 	AM_RANGE(0xa080, 0xa080) AM_WRITE(watchdog_reset_w)
-	AM_RANGE(0xa100, 0xa11f) AM_WRITE(pengo_sound_w) AM_BASE(&namco_soundregs)
+	AM_RANGE(0xa100, 0xa11f) AM_WRITE(pacman_sound_w) AM_BASE(&namco_soundregs)
 	AM_RANGE(0xa130, 0xa130) AM_WRITE(rallyx_scrollx_w)
 	AM_RANGE(0xa140, 0xa140) AM_WRITE(rallyx_scrolly_w)
 	AM_RANGE(0xa170, 0xa170) AM_WRITE(MWA8_NOP)			/* ? */
@@ -314,6 +315,7 @@ static ADDRESS_MAP_START( rallyx_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0, 0) AM_WRITE(interrupt_vector_w)
 ADDRESS_MAP_END
 
@@ -622,12 +624,12 @@ INPUT_PORTS_START( tactcian )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 1C_2C ) )
 	/*
-	PORT_DIPNAME( 0x06, 0x00, DEF_STR( Coinage ) )			// Mode 2
-	PORT_DIPSETTING(    0x02, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(    0x04, "A 2C/1C  B 1C/3C" )
-	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(    0x06, "A 1C/1C  B 1C/6C" )
-	*/
+    PORT_DIPNAME( 0x06, 0x00, DEF_STR( Coinage ) )          // Mode 2
+    PORT_DIPSETTING(    0x02, DEF_STR( 2C_1C ) )
+    PORT_DIPSETTING(    0x04, "A 2C/1C  B 1C/3C" )
+    PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
+    PORT_DIPSETTING(    0x06, "A 1C/1C  B 1C/6C" )
+    */
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Bonus_Life ) )
 	PORT_DIPSETTING(    0x00, "10k, 80k then every 100k" )
 	PORT_DIPSETTING(    0x01, "20k, 80k then every 100k" )
@@ -809,9 +811,7 @@ static struct GfxDecodeInfo jungler_gfxdecodeinfo[] =
 
 static struct namco_interface namco_interface =
 {
-	18432000/6/32,	/* 96 kHz sample rate */
 	3,				/* number of voices */
-	100,			/* playback volume */
 	REGION_SOUND1	/* memory region */
 };
 
@@ -825,7 +825,6 @@ static const char *rallyx_sample_names[] =
 static struct Samplesinterface samples_interface =
 {
 	1,	/* 1 channel */
-	80, /* volume */
 	rallyx_sample_names
 };
 
@@ -855,8 +854,15 @@ static MACHINE_DRIVER_START( rallyx )
 	MDRV_VIDEO_UPDATE(rallyx)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(NAMCO, namco_interface)
-	MDRV_SOUND_ADD(SAMPLES, samples_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(NAMCO, 18432000/6/32)
+	MDRV_SOUND_CONFIG(namco_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
 
@@ -868,7 +874,7 @@ static MACHINE_DRIVER_START( tactcian )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(Z80, 14318180/8)	/* 1.789772727 MHz */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(locomotn_sound_readmem,locomotn_sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -887,7 +893,32 @@ static MACHINE_DRIVER_START( tactcian )
 	MDRV_VIDEO_UPDATE(rallyx)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, timeplt_ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 14318180/8)
+	MDRV_SOUND_CONFIG(timeplt_ay8910_interface)
+	MDRV_SOUND_ROUTE(0, "filter.0.0", 0.60)
+	MDRV_SOUND_ROUTE(1, "filter.0.1", 0.60)
+	MDRV_SOUND_ROUTE(2, "filter.0.2", 0.60)
+
+	MDRV_SOUND_ADD(AY8910, 14318180/8)
+	MDRV_SOUND_ROUTE(0, "filter.1.0", 0.60)
+	MDRV_SOUND_ROUTE(1, "filter.1.1", 0.60)
+	MDRV_SOUND_ROUTE(2, "filter.1.2", 0.60)
+
+	MDRV_SOUND_ADD_TAG("filter.0.0", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.0.1", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.0.2", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD_TAG("filter.1.0", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.1.1", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ADD_TAG("filter.1.2", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1053,7 +1084,7 @@ ROM_START( tactcian )
 	ROM_LOAD( "tact6331.002", 0x0000, 0x0020, CRC(b7ef83b7) SHA1(5ffab25c2dc5be0856a43a93711d39c4aec6660b) ) /* palette */
 	ROM_LOAD( "tact6301.003", 0x0020, 0x0100, CRC(a92796f2) SHA1(0faab2dc0f868f4023a34ecfcf972d1c86a224a0) ) /* loookup table */	/* tac.b4 */
 	ROM_LOAD( "tact6331.001", 0x0120, 0x0020, CRC(8f574815) SHA1(4f84162db9d58b64742c67dc689eb665b9862fb3) ) /* video layout (not used) */
-/*	ROM_LOAD( "10a.bpr",      0x0140, 0x0020, CRC(b8861096) SHA1(26fad384ed7a1a1e0ba719b5578e2dbb09334a25) )    video timing (not used)    */
+/*  ROM_LOAD( "10a.bpr",      0x0140, 0x0020, CRC(b8861096) SHA1(26fad384ed7a1a1e0ba719b5578e2dbb09334a25) )    video timing (not used)    */
 ROM_END
 
 ROM_START( tactcan2 )
@@ -1081,7 +1112,7 @@ ROM_START( tactcan2 )
 	ROM_LOAD( "tact6331.002", 0x0000, 0x0020, CRC(b7ef83b7) SHA1(5ffab25c2dc5be0856a43a93711d39c4aec6660b) ) /* palette */
 	ROM_LOAD( "tact6301.003", 0x0020, 0x0100, CRC(a92796f2) SHA1(0faab2dc0f868f4023a34ecfcf972d1c86a224a0) ) /* loookup table */	/* tac.b4 */
 	ROM_LOAD( "tact6331.001", 0x0120, 0x0020, CRC(8f574815) SHA1(4f84162db9d58b64742c67dc689eb665b9862fb3) ) /* video layout (not used) */
-/*	ROM_LOAD( "10a.bpr",      0x0140, 0x0020, CRC(b8861096) SHA1(26fad384ed7a1a1e0ba719b5578e2dbb09334a25) )    video timing (not used)    */
+/*  ROM_LOAD( "10a.bpr",      0x0140, 0x0020, CRC(b8861096) SHA1(26fad384ed7a1a1e0ba719b5578e2dbb09334a25) )    video timing (not used)    */
 ROM_END
 
 ROM_START( locomotn )
