@@ -1,21 +1,21 @@
 /***************************************************************************
 
-	Atari Rampart hardware
+    Atari Rampart hardware
 
-	driver by Aaron Giles
+    driver by Aaron Giles
 
-	Games supported:
-		* Rampart (1990) [3 sets]
+    Games supported:
+        * Rampart (1990) [3 sets]
 
-	Known bugs:
-		* P3 trackball doesn't work, maybe it needs some kind of fake input port
+    Known bugs:
+        * P3 trackball doesn't work, maybe it needs some kind of fake input port
 
-	Note:
-		P3 buttons 1 and 2 are mapped twice. THIS IS NOT A BUG!
+    Note:
+        P3 buttons 1 and 2 are mapped twice. THIS IS NOT A BUG!
 
 ****************************************************************************
 
-	Memory map (TBA)
+    Memory map (TBA)
 
 ***************************************************************************/
 
@@ -23,12 +23,13 @@
 #include "driver.h"
 #include "machine/atarigen.h"
 #include "rampart.h"
-
+#include "sound/okim6295.h"
+#include "sound/2413intf.h"
 
 
 /*************************************
  *
- *	Interrupt handling
+ *  Interrupt handling
  *
  *************************************/
 
@@ -57,7 +58,7 @@ static void scanline_update(int scanline)
 
 /*************************************
  *
- *	Initialization
+ *  Initialization
  *
  *************************************/
 
@@ -73,7 +74,7 @@ static MACHINE_INIT( rampart )
 
 /*************************************
  *
- *	MSM5295 I/O
+ *  MSM5295 I/O
  *
  *************************************/
 
@@ -93,7 +94,7 @@ static WRITE16_HANDLER( adpcm_w )
 
 /*************************************
  *
- *	YM2413 I/O
+ *  YM2413 I/O
  *
  *************************************/
 
@@ -112,7 +113,7 @@ static WRITE16_HANDLER( ym2413_w )
 
 /*************************************
  *
- *	Latch write
+ *  Latch write
  *
  *************************************/
 
@@ -120,17 +121,17 @@ static WRITE16_HANDLER( latch_w )
 {
 	/* bit layout in this register:
 
-		0x8000 == VCR ???
-		0x2000 == LETAMODE1 (controls right trackball)
-		0x1000 == CBANK (color bank -- is it ever set to non-zero?)
-		0x0800 == LETAMODE0 (controls center and left trackballs)
-		0x0400 == LETARES (reset LETA analog control reader)
+        0x8000 == VCR ???
+        0x2000 == LETAMODE1 (controls right trackball)
+        0x1000 == CBANK (color bank -- is it ever set to non-zero?)
+        0x0800 == LETAMODE0 (controls center and left trackballs)
+        0x0400 == LETARES (reset LETA analog control reader)
 
-		0x0020 == PMIX0 (ADPCM mixer level)
-		0x0010 == /PCMRES (ADPCM reset)
-		0x000E == YMIX2-0 (YM2413 mixer level)
-		0x0001 == /YAMRES (YM2413 reset)
-	*/
+        0x0020 == PMIX0 (ADPCM mixer level)
+        0x0010 == /PCMRES (ADPCM reset)
+        0x000E == YMIX2-0 (YM2413 mixer level)
+        0x0001 == /YAMRES (YM2413 reset)
+    */
 
 	/* upper byte being modified? */
 	if (ACCESSING_MSB)
@@ -151,7 +152,7 @@ static WRITE16_HANDLER( latch_w )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -196,7 +197,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -347,7 +348,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -373,31 +374,7 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound definitions
- *
- *************************************/
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,
-	{ ATARI_CLOCK_14MHz/4/3/165 },
-	{ REGION_SOUND1 },
-	{ 60 }
-};
-
-
-static struct YM2413interface ym2413_interface =
-{
-	1,
-	ATARI_CLOCK_14MHz/4,
-	{ YM2413_VOL(100,MIXER_PAN_CENTER,100,MIXER_PAN_CENTER) }
-};
-
-
-
-/*************************************
- *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -425,15 +402,21 @@ static MACHINE_DRIVER_START( rampart )
 	MDRV_VIDEO_UPDATE(rampart)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
-	MDRV_SOUND_ADD(YM2413, ym2413_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, ATARI_CLOCK_14MHz/4/3/165)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
+
+	MDRV_SOUND_ADD(YM2413, ATARI_CLOCK_14MHz/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definition(s)
+ *  ROM definition(s)
  *
  *************************************/
 
@@ -492,7 +475,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver initialization
+ *  Driver initialization
  *
  *************************************/
 
@@ -532,7 +515,7 @@ static DRIVER_INIT( rampart )
 
 /*************************************
  *
- *	Game driver(s)
+ *  Game driver(s)
  *
  *************************************/
 
