@@ -1,18 +1,18 @@
 /***************************************************************************
 
-	Atari "Round" hardware
+    Atari "Round" hardware
 
-	driver by Aaron Giles
+    driver by Aaron Giles
 
-	Games supported:
-		* Relief Pitcher (1990) [2 sets]
+    Games supported:
+        * Relief Pitcher (1990) [2 sets]
 
-	Known bugs:
-		* none at this time
+    Known bugs:
+        * none at this time
 
 ****************************************************************************
 
-	Memory map (TBA)
+    Memory map (TBA)
 
 ***************************************************************************/
 
@@ -20,12 +20,13 @@
 #include "driver.h"
 #include "machine/atarigen.h"
 #include "relief.h"
-
+#include "sound/okim6295.h"
+#include "sound/2413intf.h"
 
 
 /*************************************
  *
- *	Statics
+ *  Statics
  *
  *************************************/
 
@@ -37,7 +38,7 @@ static UINT32 adpcm_bank_base;
 
 /*************************************
  *
- *	Interrupt handling
+ *  Interrupt handling
  *
  *************************************/
 
@@ -58,7 +59,7 @@ static void update_interrupts(void)
 
 /*************************************
  *
- *	Initialization
+ *  Initialization
  *
  *************************************/
 
@@ -78,7 +79,7 @@ static MACHINE_INIT( relief )
 
 /*************************************
  *
- *	I/O handling
+ *  I/O handling
  *
  *************************************/
 
@@ -94,7 +95,7 @@ static READ16_HANDLER( special_port2_r )
 
 /*************************************
  *
- *	Audio control I/O
+ *  Audio control I/O
  *
  *************************************/
 
@@ -127,7 +128,7 @@ static WRITE16_HANDLER( audio_volume_w )
 
 /*************************************
  *
- *	MSM5295 I/O
+ *  MSM5295 I/O
  *
  *************************************/
 
@@ -147,7 +148,7 @@ static WRITE16_HANDLER( adpcm_w )
 
 /*************************************
  *
- *	YM2413 I/O
+ *  YM2413 I/O
  *
  *************************************/
 
@@ -166,7 +167,7 @@ static WRITE16_HANDLER( ym2413_w )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -211,7 +212,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -287,7 +288,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -327,31 +328,7 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound definitions
- *
- *************************************/
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,
-	{ ATARI_CLOCK_14MHz/4/3/165 },
-	{ REGION_SOUND1 },
-	{ 50 }
-};
-
-
-static struct YM2413interface ym2413_interface =
-{
-	1,
-	ATARI_CLOCK_14MHz/4,
-	{ YM2413_VOL(100,MIXER_PAN_CENTER,100,MIXER_PAN_CENTER) }
-};
-
-
-
-/*************************************
- *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -379,15 +356,21 @@ static MACHINE_DRIVER_START( relief )
 	MDRV_VIDEO_UPDATE(relief)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
-	MDRV_SOUND_ADD(YM2413,   ym2413_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, ATARI_CLOCK_14MHz/4/3/165)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(YM2413, ATARI_CLOCK_14MHz/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definition(s)
+ *  ROM definition(s)
  *
  *************************************/
 
@@ -438,7 +421,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver initialization
+ *  Driver initialization
  *
  *************************************/
 
@@ -463,7 +446,6 @@ static void init_common(const data16_t *def_eeprom)
 	memcpy(&sound_base[0x060000], &sound_base[0x120000], 0x20000);
 	memcpy(&sound_base[0x0a0000], &sound_base[0x120000], 0x20000);
 	memcpy(&sound_base[0x0e0000], &sound_base[0x120000], 0x20000);
-	memcpy(&sound_base[0x120000], &sound_base[0x120000], 0x20000);
 	memcpy(&sound_base[0x160000], &sound_base[0x120000], 0x20000);
 	memcpy(&sound_base[0x1a0000], &sound_base[0x120000], 0x20000);
 	memcpy(&sound_base[0x1e0000], &sound_base[0x120000], 0x20000);
@@ -512,7 +494,7 @@ static DRIVER_INIT( relief2 )
 
 /*************************************
  *
- *	Game driver(s)
+ *  Game driver(s)
  *
  *************************************/
 
