@@ -20,7 +20,7 @@ Notes:
   them so we can't verify without schematics.
 
 - We don't have a dump of the original MCU. We have a dump from a bootleg MCU,
-  which however cannot be the same as the original. The gaame works fine with it,
+  which however cannot be the same as the original. The game works fine with it,
   but only when the flip screen dip switch is set to off. If it is set to on, it
   hangs when starting a game because the mcu doesn't answer a command.
   See MCU code at $206 and $435: when the dip switch is on, the lda #$00 should
@@ -29,6 +29,7 @@ Notes:
 ***************************************************************************/
 
 #include "driver.h"
+#include "sound/sn76496.h"
 
 /* in machine */
 READ8_HANDLER( retofinv_68705_portA_r );
@@ -154,7 +155,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc801, 0xc801) AM_WRITE(coinlockout_w)
 	AM_RANGE(0xc802, 0xc802) AM_WRITE(cpu2_reset_w)
 	AM_RANGE(0xc803, 0xc803) AM_WRITE(mcu_reset_w)
-/*	AM_RANGE(0xc804, 0xc804) AM_WRITE(irq1_ack_w)	// presumably (meaning memory map is shared with cpu 1) */
+/*  AM_RANGE(0xc804, 0xc804) AM_WRITE(irq1_ack_w)   // presumably (meaning memory map is shared with cpu 1) */
 	AM_RANGE(0xc805, 0xc805) AM_WRITE(cpu1_reset_w)
 	AM_RANGE(0xd000, 0xd000) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0xd800, 0xd800) AM_WRITE(soundcommand_w)
@@ -239,7 +240,7 @@ INPUT_PORTS_START( retofinv )
 	PORT_DIPSETTING(    0x18, "1" )
 	PORT_DIPSETTING(    0x10, "2" )
 	PORT_DIPSETTING(    0x08, "3" )
-	PORT_DIPSETTING(    0x00, "4" )
+	PORT_DIPSETTING(    0x00, "5" )
 	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unused ) )	/* according to manual */
 	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -313,6 +314,18 @@ INPUT_PORTS_START( retofinv )
 	PORT_DIPSETTING(    0x00, "A only" )
 INPUT_PORTS_END
 
+INPUT_PORTS_START( retofin2 )
+	PORT_INCLUDE( retofinv )
+
+	PORT_MODIFY( "DSW1" )
+	PORT_DIPNAME( 0x18, 0x08, DEF_STR( Lives ) )
+	PORT_DIPSETTING(    0x18, "1" )
+	PORT_DIPSETTING(    0x10, "2" )
+	PORT_DIPSETTING(    0x08, "3" )
+	PORT_DIPSETTING(    0x00, "4" )
+INPUT_PORTS_END
+
+
 
 static struct GfxLayout charlayout =
 {
@@ -359,15 +372,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct SN76496interface sn76496_interface =
-{
-	2,		/* 2 chips */
-	{ 18432000/6, 18432000/6 },
-	{ 80, 80 }
-};
-
-
-
 static MACHINE_DRIVER_START( retofinv )
 
 	/* basic machine hardware */
@@ -403,7 +407,13 @@ static MACHINE_DRIVER_START( retofinv )
 	MDRV_VIDEO_UPDATE(retofinv)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 18432000/6)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+
+	MDRV_SOUND_ADD(SN76496, 18432000/6)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
 
@@ -526,4 +536,4 @@ ROM_END
 
 GAME( 1985, retofinv, 0,        retofinv, retofinv, 0, ROT90, "Taito Corporation", "Return of the Invaders" )
 GAME( 1985, retofin1, retofinv, retofinb, retofinv, 0, ROT90, "bootleg", "Return of the Invaders (bootleg set 1)" )
-GAME( 1985, retofin2, retofinv, retofinb, retofinv, 0, ROT90, "bootleg", "Return of the Invaders (bootleg set 2)" )
+GAME( 1985, retofin2, retofinv, retofinb, retofin2, 0, ROT90, "bootleg", "Return of the Invaders (bootleg set 2)" )
