@@ -4,10 +4,10 @@ Real Mahjong Haihai                (c)1985 Alba
 Real Mahjong Haihai Jinji Idou Hen (c)1986 Alba
 Real Mahjong Haihai Seichouhen     (c)1986 Visco
 
-CPU:	Z80
-Sound:	AY-3-8910
+CPU:    Z80
+Sound:  AY-3-8910
         M5205
-OSC:	20.000MHz
+OSC:    20.000MHz
 
 driver by Nicola Salmoria
 
@@ -30,6 +30,8 @@ TODO:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/msm5205.h"
 
 static int gfxbank;
 static struct tilemap *bg_tilemap;
@@ -63,7 +65,7 @@ static void get_bg_tile_info(int tile_index)
 
 VIDEO_START( rmhaihai )
 {
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows, 
+	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows,
 		TILEMAP_OPAQUE, 8, 8, 64, 32);
 
 	if ( !bg_tilemap )
@@ -277,74 +279,75 @@ INPUT_PORTS_START( rmhaihai )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 	PORT_START	/* fake, handled by keyboard_r() */
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Small") PORT_CODE(KEYCODE_BACKSPACE)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Double") PORT_CODE(KEYCODE_RSHIFT)
-	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Big") PORT_CODE(KEYCODE_ENTER)
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Take") PORT_CODE(KEYCODE_RCONTROL)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Flip") PORT_CODE(KEYCODE_X)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Last") PORT_CODE(KEYCODE_RALT)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP )
+	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG )
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE )
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP )
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE )
 	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 K") PORT_CODE(KEYCODE_K)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Ron") PORT_CODE(KEYCODE_Z)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 G") PORT_CODE(KEYCODE_G)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Chi") PORT_CODE(KEYCODE_SPACE)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 C") PORT_CODE(KEYCODE_C)
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K )
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON )
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G )
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI )
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C )
 	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 L") PORT_CODE(KEYCODE_L)
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L )
 	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 H") PORT_CODE(KEYCODE_H)
+	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H )
 
 	PORT_START	/* fake, handled by keyboard_r() */
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Pon") PORT_CODE(KEYCODE_LALT)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 D") PORT_CODE(KEYCODE_D)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON )
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D )
 	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START1 )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 I") PORT_CODE(KEYCODE_I)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Kan") PORT_CODE(KEYCODE_LCONTROL)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 E") PORT_CODE(KEYCODE_E)
-	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 M") PORT_CODE(KEYCODE_M)
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 A") PORT_CODE(KEYCODE_A)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Bet") PORT_CODE(KEYCODE_RCONTROL)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 J") PORT_CODE(KEYCODE_J)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Reach") PORT_CODE(KEYCODE_LSHIFT)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 F") PORT_CODE(KEYCODE_F)
-	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 N") PORT_CODE(KEYCODE_N)
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 B") PORT_CODE(KEYCODE_B)
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I )
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN )
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E )
+	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M )
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A )
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET )
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J )
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH )
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F )
+	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N )
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B )
 	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
 
 	PORT_START	/* fake, handled by keyboard_r() */
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Small") PORT_CODE(KEYCODE_BACKSPACE)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Double") PORT_CODE(KEYCODE_RSHIFT)
-	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Big") PORT_CODE(KEYCODE_ENTER)
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Take") PORT_CODE(KEYCODE_RCONTROL)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Flip") PORT_CODE(KEYCODE_X)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Last") PORT_CODE(KEYCODE_RALT)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )PORT_PLAYER(2)
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP )PORT_PLAYER(2)
+	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG )PORT_PLAYER(2)
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE )PORT_PLAYER(2)
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP )PORT_PLAYER(2)
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE )PORT_PLAYER(2)
 	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 K") PORT_CODE(KEYCODE_K)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Ron") PORT_CODE(KEYCODE_Z)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 G") PORT_CODE(KEYCODE_G)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Chi") PORT_CODE(KEYCODE_SPACE)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 C") PORT_CODE(KEYCODE_C)
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K )PORT_PLAYER(2)
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON )PORT_PLAYER(2)
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G )PORT_PLAYER(2)
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI )PORT_PLAYER(2)
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C )PORT_PLAYER(2)
 	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 L") PORT_CODE(KEYCODE_L)
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L )PORT_PLAYER(2)
 	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 H") PORT_CODE(KEYCODE_H)
+	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H )PORT_PLAYER(2)
+
 
 	PORT_START	/* fake, handled by keyboard_r() */
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Pon") PORT_CODE(KEYCODE_LALT)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 D") PORT_CODE(KEYCODE_D)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON )PORT_PLAYER(2)
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D )PORT_PLAYER(2)
 	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START2 )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 I") PORT_CODE(KEYCODE_I)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Kan") PORT_CODE(KEYCODE_LCONTROL)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 E") PORT_CODE(KEYCODE_E)
-	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 M") PORT_CODE(KEYCODE_M)
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 A") PORT_CODE(KEYCODE_A)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Bet") PORT_CODE(KEYCODE_RCONTROL)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 J") PORT_CODE(KEYCODE_J)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Reach") PORT_CODE(KEYCODE_LSHIFT)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 F") PORT_CODE(KEYCODE_F)
-	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 N") PORT_CODE(KEYCODE_N)
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 B") PORT_CODE(KEYCODE_B)
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I )PORT_PLAYER(2)
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN )PORT_PLAYER(2)
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E )PORT_PLAYER(2)
+	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M )PORT_PLAYER(2)
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A )PORT_PLAYER(2)
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET )PORT_PLAYER(2)
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J )PORT_PLAYER(2)
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH )PORT_PLAYER(2)
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F )PORT_PLAYER(2)
+	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N )PORT_PLAYER(2)
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B )PORT_PLAYER(2)
 	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
 INPUT_PORTS_END
@@ -400,83 +403,83 @@ INPUT_PORTS_START( rmhaihib )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 	PORT_START	/* fake, handled by keyboard_r() */
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Small") PORT_CODE(KEYCODE_BACKSPACE)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Double") PORT_CODE(KEYCODE_RSHIFT)
-	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Big") PORT_CODE(KEYCODE_ENTER)
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Take") PORT_CODE(KEYCODE_RCONTROL)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Flip") PORT_CODE(KEYCODE_X)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Last") PORT_CODE(KEYCODE_RALT)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP )
+	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG )
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE )
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP )
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE )
 	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 K") PORT_CODE(KEYCODE_K)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Ron") PORT_CODE(KEYCODE_Z)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 G") PORT_CODE(KEYCODE_G)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Chi") PORT_CODE(KEYCODE_SPACE)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 C") PORT_CODE(KEYCODE_C)
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K )
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON )
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G )
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI )
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C )
 	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 L") PORT_CODE(KEYCODE_L)
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L )
 	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 H") PORT_CODE(KEYCODE_H)
+	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H )
 
 	PORT_START	/* fake, handled by keyboard_r() */
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Pon") PORT_CODE(KEYCODE_LALT)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 D") PORT_CODE(KEYCODE_D)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON )
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D )
 	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START1 )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 I") PORT_CODE(KEYCODE_I)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Kan") PORT_CODE(KEYCODE_LCONTROL)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 E") PORT_CODE(KEYCODE_E)
-	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 M") PORT_CODE(KEYCODE_M)
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 A") PORT_CODE(KEYCODE_A)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Bet") PORT_CODE(KEYCODE_RCONTROL)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 J") PORT_CODE(KEYCODE_J)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 Reach") PORT_CODE(KEYCODE_LSHIFT)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 F") PORT_CODE(KEYCODE_F)
-	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 N") PORT_CODE(KEYCODE_N)
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P1 B") PORT_CODE(KEYCODE_B)
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I )
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN )
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E )
+	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M )
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A )
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET )
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J )
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH )
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F )
+	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N )
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B )
 	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
 
 	PORT_START	/* fake, handled by keyboard_r() */
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Small") PORT_CODE(KEYCODE_BACKSPACE)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Double") PORT_CODE(KEYCODE_RSHIFT)
-	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Big") PORT_CODE(KEYCODE_ENTER)
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Take") PORT_CODE(KEYCODE_RCONTROL)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Flip") PORT_CODE(KEYCODE_X)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Last") PORT_CODE(KEYCODE_RALT)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )PORT_PLAYER(2)
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP )PORT_PLAYER(2)
+	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG )PORT_PLAYER(2)
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE )PORT_PLAYER(2)
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP )PORT_PLAYER(2)
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE )PORT_PLAYER(2)
 	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 K") PORT_CODE(KEYCODE_K)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Ron") PORT_CODE(KEYCODE_Z)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 G") PORT_CODE(KEYCODE_G)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Chi") PORT_CODE(KEYCODE_SPACE)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 C") PORT_CODE(KEYCODE_C)
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K )PORT_PLAYER(2)
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON )PORT_PLAYER(2)
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G )PORT_PLAYER(2)
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI )PORT_PLAYER(2)
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C )PORT_PLAYER(2)
 	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 L") PORT_CODE(KEYCODE_L)
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L )PORT_PLAYER(2)
 	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 H") PORT_CODE(KEYCODE_H)
+	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H )PORT_PLAYER(2)
 
 	PORT_START	/* fake, handled by keyboard_r() */
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Pon") PORT_CODE(KEYCODE_LALT)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 D") PORT_CODE(KEYCODE_D)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON )PORT_PLAYER(2)
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D )PORT_PLAYER(2)
 	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START2 )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 I") PORT_CODE(KEYCODE_I)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Kan") PORT_CODE(KEYCODE_LCONTROL)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 E") PORT_CODE(KEYCODE_E)
-	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 M") PORT_CODE(KEYCODE_M)
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 A") PORT_CODE(KEYCODE_A)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Bet") PORT_CODE(KEYCODE_RCONTROL)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 J") PORT_CODE(KEYCODE_J)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 Reach") PORT_CODE(KEYCODE_LSHIFT)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 F") PORT_CODE(KEYCODE_F)
-	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 N") PORT_CODE(KEYCODE_N)
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("P2 B") PORT_CODE(KEYCODE_B)
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I )PORT_PLAYER(2)
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN )PORT_PLAYER(2)
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E )PORT_PLAYER(2)
+	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M )PORT_PLAYER(2)
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A )PORT_PLAYER(2)
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET )PORT_PLAYER(2)
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J )PORT_PLAYER(2)
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH )PORT_PLAYER(2)
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F )PORT_PLAYER(2)
+	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N )PORT_PLAYER(2)
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B )PORT_PLAYER(2)
 	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
 
-/*	PORT_START // 11 */
-/*	PORT_BIT(    0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Pay Out") PORT_CODE(KEYCODE_3) */
-/*	PORT_BIT(     0x02, IP_ACTIVE_LOW, IPT_SERVICE4 )    RAM clear    */
-/*	PORT_SERVICE( 0x04, IP_ACTIVE_LOW ) */
-/*	PORT_BIT(     0x08, IP_ACTIVE_LOW, IPT_SERVICE2 )    Analyzer    */
-/*	PORT_BIT(     0xF0, IP_ACTIVE_LOW, IPT_UNKNOWN ) */
+/*  PORT_START // 11 */
+/*  PORT_BIT(    0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Pay Out") PORT_CODE(KEYCODE_3) */
+/*  PORT_BIT(     0x02, IP_ACTIVE_LOW, IPT_SERVICE4 )    RAM clear    */
+/*  PORT_SERVICE( 0x04, IP_ACTIVE_LOW ) */
+/*  PORT_BIT(     0x08, IP_ACTIVE_LOW, IPT_SERVICE2 )    Analyzer    */
+/*  PORT_BIT(     0xF0, IP_ACTIVE_LOW, IPT_UNKNOWN ) */
 INPUT_PORTS_END
 
 
@@ -508,22 +511,14 @@ static struct GfxDecodeInfo gfxdecodeinfo2[] =
 
 static struct AY8910interface ay8910_interface =
 {
-	1,	/* 1 chip */
-	20000000/16,	/* 1.25 MHz ??? */
-	{ 30 },
-	{ input_port_0_r },
-	{ input_port_1_r },
-	{ 0 },
-	{ 0 }
+	input_port_0_r,
+	input_port_1_r
 };
 
 static struct MSM5205interface msm5205_interface =
 {
-	1,					/* 1 chip             */
-	500000,				/* 500KHz ?? (I don't know what I'm doing, really) */
-	{ 0 },				/* interrupt function */
-	{ MSM5205_SEX_4B },	/* vclk input mode    */
-	{ MIXERG(100,MIXER_GAIN_2x,MIXER_PAN_CENTER) }
+	0,				/* interrupt function */
+	MSM5205_SEX_4B	/* vclk input mode    */
 };
 
 
@@ -532,7 +527,6 @@ static MACHINE_DRIVER_START( rmhaihai )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main",Z80,20000000/4)	/* 5 MHz ??? */
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
 	MDRV_CPU_IO_MAP(readport,writeport)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
@@ -552,8 +546,15 @@ static MACHINE_DRIVER_START( rmhaihai )
 	MDRV_VIDEO_UPDATE(rmhaihai)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 20000000/16)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(MSM5205, 500000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( rmhaisei )
