@@ -1,105 +1,105 @@
 /***************************************************************************
 
-	Rabbit Punch / Rabio Lepus
+    Rabbit Punch / Rabio Lepus
 
     driver by Aaron Giles
 
 ****************************************************************************
 
-	Memory map
+    Memory map
 
 ****************************************************************************
 
-	========================================================================
-	MAIN CPU
-	========================================================================
-	000000-03FFFF   R     xxxxxxxx xxxxxxxx   Program ROM
-	040000-04FFFF   R/W   xxxxxxxx xxxxxxxx   Bitmap RAM (512x256 pixels)
-	                R/W   xxxx---- --------      (leftmost pixel)
-	                R/W   ----xxxx --------      (2nd pixel)
-	                R/W   -------- xxxx----      (3rd pixel)
-	                R/W   -------- ----xxxx      (rightmost pixel)
-	060000-060FFF   R/W   xxxxxxxx xxxxxxxx   Sprite RAM (512 entries x 4 words)
-	                R/W   -------x xxxxxxxx      (0: horizontal position)
-	                R/W   xxx----- --------      (1: color index)
-	                R/W   ---x---- --------      (1: horizontal flip)
-	                R/W   -----xxx xxxxxxxx      (1: image number)
-	                R/W   -------x xxxxxxxx      (2: Y position)
-	                R/W   -------- --------      (3: not used)
-	080000-081FFF   R/W   xxxxxxxx xxxxxxxx   Background 1 RAM (64x64 tiles)
-	                R/W   xxx----- --------      (color index)
-	                R/W   ---xxxxx xxxxxxxx      (image number)
-	082000-083FFF   R/W   xxxxxxxx xxxxxxxx   Background 2 RAM (64x64 tiles)
-	                R/W   xxx----- --------      (color index)
-	                R/W   ---xxxxx xxxxxxxx      (image number)
-	0A0000-0A01FF   R/W   -xxxxxxx xxxxxxxx   Background 1 palette RAM (256 entries)
-	                R/W   -xxxxx-- --------      (red component)
-	                R/W   ------xx xxx-----      (green component)
-	                R/W   -------- ---xxxxx      (blue component)
-	0A0200-0A03FF   R/W   -xxxxxxx xxxxxxxx   Background 2 palette RAM (256 entries)
-	0A0400-0A05FF   R/W   -xxxxxxx xxxxxxxx   Bitmap palette RAM (256 entries)
-	0A0600-0A07FF   R/W   -xxxxxxx xxxxxxxx   Sprite palette RAM (256 entries)
-	0C0000            W   -------x xxxxxxxx   Background 1 vertical scroll
-	0C0002            W   -------x xxxxxxxx   Background 1 horizontal scroll
-	0C0004            W   -------x xxxxxxxx   Background 2 vertical scroll
-	0C0006            W   -------x xxxxxxxx   Background 2 horizontal scroll
-	0C0008            W   -------- ????????   Video controller data (CRTC)
-	0C000C            W   ---xxx-- -xxxxxxx   Video flags
-	                  W   ---x---- --------      (flip screen)
-	                  W   ----x--- --------      (background 2 image bank)
-	                  W   -----x-- --------      (background 1 image bank)
-	                  W   -------- -x------      (sprite palette bank)
-	                  W   -------- --x-----      (background 2 palette bank)
-	                  W   -------- ---x----      (background 1 palette bank)
-	                  W   -------- ----xxxx      (bitmap palette bank)
-	0C000E            W   -------- xxxxxxxx   Sound communications
-	0C0010            W   -------- --xxxxxx   Sprite bias (???)
-	0C0012            W   -------- --xxxxxx   Bitmap bias (???)
-	0C0018          R     -xxxx-xx --xxxxxx   Player 1 input port
-	                R     -x------ --------      (2 player start)
-	                R     --x----- --------      (1 player start)
-	                R     ---x---- --------      (coin 1)
-	                R     ----x--- --------      (coin 2)
-	                R     ------x- --------      (test switch)
-	                R     -------x --------      (service coin)
-	                R     -------- --x-----      (punch button)
-	                R     -------- ---x----      (missile button)
-	                R     -------- ----xxxx      (joystick right/left/down/up)
-	0C001A          R     -xxxx-xx --xxxxxx   Player 2 input port
-	0C001C          R     xxxxxxxx xxxxxxxx   DIP switches
-	                R     x------- --------      (flip screen)
-	                R     -x------ --------      (continues allowed)
-	                R     --x----- --------      (demo sounds)
-	                R     ---x---- --------      (extended play)
-	                R     ----x--- --------      (laser control)
-	                R     -----x-- --------      (number of lives)
-	                R     ------xx --------      (difficulty)
-	                R     -------- xxxx----      (coinage 2)
-	                R     -------- ----xxxx      (coinage 1)
-	0C001E          R     -------- -------x   Sound busy flag
-	0C0028            W   -------- ????????   Video controller register select (CRTC)
-	0FC000-0FFFFF   R/W   xxxxxxxx xxxxxxxx   Program RAM
-	========================================================================
-	Interrupts:
-		IRQ1 = VBLANK
-	========================================================================
+    ========================================================================
+    MAIN CPU
+    ========================================================================
+    000000-03FFFF   R     xxxxxxxx xxxxxxxx   Program ROM
+    040000-04FFFF   R/W   xxxxxxxx xxxxxxxx   Bitmap RAM (512x256 pixels)
+                    R/W   xxxx---- --------      (leftmost pixel)
+                    R/W   ----xxxx --------      (2nd pixel)
+                    R/W   -------- xxxx----      (3rd pixel)
+                    R/W   -------- ----xxxx      (rightmost pixel)
+    060000-060FFF   R/W   xxxxxxxx xxxxxxxx   Sprite RAM (512 entries x 4 words)
+                    R/W   -------x xxxxxxxx      (0: horizontal position)
+                    R/W   xxx----- --------      (1: color index)
+                    R/W   ---x---- --------      (1: horizontal flip)
+                    R/W   -----xxx xxxxxxxx      (1: image number)
+                    R/W   -------x xxxxxxxx      (2: Y position)
+                    R/W   -------- --------      (3: not used)
+    080000-081FFF   R/W   xxxxxxxx xxxxxxxx   Background 1 RAM (64x64 tiles)
+                    R/W   xxx----- --------      (color index)
+                    R/W   ---xxxxx xxxxxxxx      (image number)
+    082000-083FFF   R/W   xxxxxxxx xxxxxxxx   Background 2 RAM (64x64 tiles)
+                    R/W   xxx----- --------      (color index)
+                    R/W   ---xxxxx xxxxxxxx      (image number)
+    0A0000-0A01FF   R/W   -xxxxxxx xxxxxxxx   Background 1 palette RAM (256 entries)
+                    R/W   -xxxxx-- --------      (red component)
+                    R/W   ------xx xxx-----      (green component)
+                    R/W   -------- ---xxxxx      (blue component)
+    0A0200-0A03FF   R/W   -xxxxxxx xxxxxxxx   Background 2 palette RAM (256 entries)
+    0A0400-0A05FF   R/W   -xxxxxxx xxxxxxxx   Bitmap palette RAM (256 entries)
+    0A0600-0A07FF   R/W   -xxxxxxx xxxxxxxx   Sprite palette RAM (256 entries)
+    0C0000            W   -------x xxxxxxxx   Background 1 vertical scroll
+    0C0002            W   -------x xxxxxxxx   Background 1 horizontal scroll
+    0C0004            W   -------x xxxxxxxx   Background 2 vertical scroll
+    0C0006            W   -------x xxxxxxxx   Background 2 horizontal scroll
+    0C0008            W   -------- ????????   Video controller data (CRTC)
+    0C000C            W   ---xxx-- -xxxxxxx   Video flags
+                      W   ---x---- --------      (flip screen)
+                      W   ----x--- --------      (background 2 image bank)
+                      W   -----x-- --------      (background 1 image bank)
+                      W   -------- -x------      (sprite palette bank)
+                      W   -------- --x-----      (background 2 palette bank)
+                      W   -------- ---x----      (background 1 palette bank)
+                      W   -------- ----xxxx      (bitmap palette bank)
+    0C000E            W   -------- xxxxxxxx   Sound communications
+    0C0010            W   -------- --xxxxxx   Sprite bias (???)
+    0C0012            W   -------- --xxxxxx   Bitmap bias (???)
+    0C0018          R     -xxxx-xx --xxxxxx   Player 1 input port
+                    R     -x------ --------      (2 player start)
+                    R     --x----- --------      (1 player start)
+                    R     ---x---- --------      (coin 1)
+                    R     ----x--- --------      (coin 2)
+                    R     ------x- --------      (test switch)
+                    R     -------x --------      (service coin)
+                    R     -------- --x-----      (punch button)
+                    R     -------- ---x----      (missile button)
+                    R     -------- ----xxxx      (joystick right/left/down/up)
+    0C001A          R     -xxxx-xx --xxxxxx   Player 2 input port
+    0C001C          R     xxxxxxxx xxxxxxxx   DIP switches
+                    R     x------- --------      (flip screen)
+                    R     -x------ --------      (continues allowed)
+                    R     --x----- --------      (demo sounds)
+                    R     ---x---- --------      (extended play)
+                    R     ----x--- --------      (laser control)
+                    R     -----x-- --------      (number of lives)
+                    R     ------xx --------      (difficulty)
+                    R     -------- xxxx----      (coinage 2)
+                    R     -------- ----xxxx      (coinage 1)
+    0C001E          R     -------- -------x   Sound busy flag
+    0C0028            W   -------- ????????   Video controller register select (CRTC)
+    0FC000-0FFFFF   R/W   xxxxxxxx xxxxxxxx   Program RAM
+    ========================================================================
+    Interrupts:
+        IRQ1 = VBLANK
+    ========================================================================
 
 
-	========================================================================
-	SOUND CPU
-	========================================================================
-	0000-EFFF   R     xxxxxxxx   Program ROM
-	F000-F001   R/W   xxxxxxxx   YM2151 communications
-	F200        R     xxxxxxxx   Sound command input
-	F400          W   x------x   UPD7759 control
-	              W   x-------      (/RESET line)
-	              W   -------x      (ROM bank select)
-	F600          W   xxxxxxxx   UPD7759 data/trigger
-	F800-FFFF   R/W   xxxxxxxx   Program RAM
-	========================================================================
-	Interrupts:
-		IRQ = YM2151 IRQ or'ed with the sound command latch flag
-	========================================================================
+    ========================================================================
+    SOUND CPU
+    ========================================================================
+    0000-EFFF   R     xxxxxxxx   Program ROM
+    F000-F001   R/W   xxxxxxxx   YM2151 communications
+    F200        R     xxxxxxxx   Sound command input
+    F400          W   x------x   UPD7759 control
+                  W   x-------      (/RESET line)
+                  W   -------x      (ROM bank select)
+    F600          W   xxxxxxxx   UPD7759 data/trigger
+    F800-FFFF   R/W   xxxxxxxx   Program RAM
+    ========================================================================
+    Interrupts:
+        IRQ = YM2151 IRQ or'ed with the sound command latch flag
+    ========================================================================
 
 ***************************************************************************/
 
@@ -107,6 +107,8 @@
 #include "driver.h"
 #include "cpu/m6809/m6809.h"
 #include "vidhrdw/generic.h"
+#include "sound/2151intf.h"
+#include "sound/upd7759.h"
 #include <math.h>
 
 
@@ -127,7 +129,6 @@ static UINT8 sound_busy;
 static UINT8 ym2151_irq;
 static UINT8 upd_rom_bank;
 
-WRITE16_HANDLER( rpunch_bitmap_w );
 WRITE16_HANDLER( rpunch_videoram_w );
 WRITE16_HANDLER( rpunch_videoreg_w );
 WRITE16_HANDLER( rpunch_scrollreg_w );
@@ -139,7 +140,7 @@ WRITE16_HANDLER( rpunch_crtc_register_w );
 
 /*************************************
  *
- *	Interrupt handling
+ *  Interrupt handling
  *
  *************************************/
 
@@ -159,7 +160,7 @@ MACHINE_INIT( rpunch )
 
 /*************************************
  *
- *	Input ports
+ *  Input ports
  *
  *************************************/
 
@@ -172,7 +173,7 @@ READ16_HANDLER( common_port_r )
 
 /*************************************
  *
- *	Sound I/O
+ *  Sound I/O
  *
  *************************************/
 
@@ -208,7 +209,7 @@ static READ16_HANDLER( sound_busy_r )
 
 /*************************************
  *
- *	UPD7759 controller
+ *  UPD7759 controller
  *
  *************************************/
 
@@ -219,22 +220,22 @@ WRITE8_HANDLER( upd_control_w )
 		upd_rom_bank = data & 1;
 		memcpy(memory_region(REGION_SOUND1), memory_region(REGION_SOUND1) + 0x20000 * (upd_rom_bank + 1), 0x20000);
 	}
-	UPD7759_reset_w(0, data >> 7);
+	upd7759_reset_w(0, data >> 7);
 }
 
 
 WRITE8_HANDLER( upd_data_w )
 {
-	UPD7759_port_w(0, data);
-	UPD7759_start_w(0, 0);
-	UPD7759_start_w(0, 1);
+	upd7759_port_w(0, data);
+	upd7759_start_w(0, 0);
+	upd7759_start_w(0, 1);
 }
 
 
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -255,7 +256,7 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(20) )
 	AM_RANGE(0x000000, 0x03ffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x040000, 0x04ffff) AM_WRITE(rpunch_bitmap_w) AM_BASE(&rpunch_bitmapram) AM_SIZE(&rpunch_bitmapram_size)
+	AM_RANGE(0x040000, 0x04ffff) AM_WRITE(MWA16_RAM) AM_BASE(&rpunch_bitmapram) AM_SIZE(&rpunch_bitmapram_size)
 	AM_RANGE(0x060000, 0x060fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16)
 	AM_RANGE(0x080000, 0x083fff) AM_WRITE(rpunch_videoram_w) AM_BASE(&videoram16) AM_SIZE(&videoram_size)
 	AM_RANGE(0x0a0000, 0x0a07ff) AM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
@@ -272,7 +273,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
@@ -297,7 +298,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -549,7 +550,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -592,33 +593,26 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound definitions
+ *  Sound definitions
  *
  *************************************/
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	MASTER_CLOCK/4,
-	{ YM3012_VOL(50,MIXER_PAN_CENTER,50,MIXER_PAN_CENTER) },
-	{ ym2151_irq_gen }
+	ym2151_irq_gen
 };
 
 
-static struct UPD7759_interface upd7759_interface =
+static struct upd7759_interface upd7759_interface =
 {
-	1,			/* 1 chip */
-	{ 50 },
-	{ REGION_SOUND1 },
-	UPD7759_STANDALONE_MODE,
-	{ 0 }
+	REGION_SOUND1
 };
 
 
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -647,15 +641,23 @@ static MACHINE_DRIVER_START( rpunch )
 	MDRV_VIDEO_UPDATE(rpunch)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(UPD7759, upd7759_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, MASTER_CLOCK/4)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.50)
+	MDRV_SOUND_ROUTE(1, "mono", 0.50)
+
+	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
+	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -669,19 +671,18 @@ ROM_START( rpunch )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )
 	ROM_LOAD( "rpunch.92", 0x00000, 0x10000, CRC(5e1870e3) SHA1(0ab33f39144ed72d805341d869f61764610d3df6) )
 
-	ROM_REGION( 0x60000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_ERASEFF )
 	ROM_LOAD( "rl_c13.bin", 0x00000, 0x40000, CRC(7c8403b0) SHA1(2fb92860a41f3331076c73b2b010e175cb4929ca) )
 	ROM_LOAD( "rl_c10.bin", 0x40000, 0x08000, CRC(312eb260) SHA1(31faa90fde54fbc6c110bee7b4690a30beaec469) )
 	ROM_LOAD( "rl_c12.bin", 0x48000, 0x08000, CRC(bea85219) SHA1(4036bdad921dd3555a2dc6bb12e9ffa615de70ca) )
 	ROM_FILL(               0x50000, 0x10000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX2, 0 )
+	ROM_REGION( 0x80000, REGION_GFX2, ROMREGION_ERASEFF )
 	ROM_LOAD( "rl_a10.bin", 0x00000, 0x40000, CRC(c2a77619) SHA1(9b1e85fb18833c3b96a6c58b8714984f60a90afc) )
 	ROM_LOAD( "rl_a13.bin", 0x40000, 0x08000, CRC(a39c2c16) SHA1(d8d55eb58d3fc79f982f535ec85f69593fe9d883) )
 	ROM_LOAD( "rpunch.54",  0x48000, 0x08000, CRC(e2969747) SHA1(8da996fc2e2e3d281f293d0ccaf35ebdb9379d48) )
-	ROM_FILL(               0x50000, 0x10000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX3, 0 )
+	ROM_REGION( 0x80000, REGION_GFX3, ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "rl_4g.bin", 0x00000, 0x20000, CRC(c5cb4b7a) SHA1(2b6be85800ab62b000a0b01cff8af689b25c4c65) )
 	ROM_LOAD16_BYTE( "rl_4h.bin", 0x00001, 0x20000, CRC(8a4d3c99) SHA1(29fca0ea60ac040fc0b0f65b9d2069fcffe039bd) )
 	ROM_LOAD16_BYTE( "rl_1g.bin", 0x40000, 0x08000, CRC(74d41b2e) SHA1(cd690df46242dd54061bf5f6464203e1f29ce6d8) )
@@ -691,7 +692,7 @@ ROM_START( rpunch )
 
 	ROM_REGION( 0x60000, REGION_SOUND1, 0 )
 	ROM_LOAD( "rl_f18.bin", 0x20000, 0x20000, CRC(47840673) SHA1(ffe20f8772a987f5dd06a3f348a1e3cfed26e19e) )
-/*	ROM_LOAD( "rpunch.91", 0x00000, 0x0f000, CRC(7512cc59) ) */
+/*  ROM_LOAD( "rpunch.91", 0x00000, 0x0f000, CRC(7512cc59) ) */
 ROM_END
 
 ROM_START( rabiolep )
@@ -704,19 +705,18 @@ ROM_START( rabiolep )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )
 	ROM_LOAD( "rl_f20.bin", 0x00000, 0x10000, CRC(a6f50351) SHA1(3152d4ed100b0dfaf0da4ee79cd9e0f1692335e0) )
 
-	ROM_REGION( 0x60000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_ERASEFF )
 	ROM_LOAD( "rl_c13.bin", 0x00000, 0x40000, CRC(7c8403b0) SHA1(2fb92860a41f3331076c73b2b010e175cb4929ca) )
 	ROM_LOAD( "rl_c10.bin", 0x40000, 0x08000, CRC(312eb260) SHA1(31faa90fde54fbc6c110bee7b4690a30beaec469) )
 	ROM_LOAD( "rl_c12.bin", 0x48000, 0x08000, CRC(bea85219) SHA1(4036bdad921dd3555a2dc6bb12e9ffa615de70ca) )
 	ROM_FILL(               0x50000, 0x10000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX2, 0 )
+	ROM_REGION( 0x80000, REGION_GFX2, ROMREGION_ERASEFF )
 	ROM_LOAD( "rl_a10.bin", 0x00000, 0x40000, CRC(c2a77619) SHA1(9b1e85fb18833c3b96a6c58b8714984f60a90afc) )
 	ROM_LOAD( "rl_a13.bin", 0x40000, 0x08000, CRC(a39c2c16) SHA1(d8d55eb58d3fc79f982f535ec85f69593fe9d883) )
 	ROM_LOAD( "rl_a12.bin", 0x48000, 0x08000, CRC(970b0e32) SHA1(a1d4025ee4470a41aa047c6f06ca7aa98a1f7ffd) )
-	ROM_FILL(               0x50000, 0x10000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX3, 0 )
+	ROM_REGION( 0x80000, REGION_GFX3, ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "rl_4g.bin", 0x00000, 0x20000, CRC(c5cb4b7a) SHA1(2b6be85800ab62b000a0b01cff8af689b25c4c65) )
 	ROM_LOAD16_BYTE( "rl_4h.bin", 0x00001, 0x20000, CRC(8a4d3c99) SHA1(29fca0ea60ac040fc0b0f65b9d2069fcffe039bd) )
 	ROM_LOAD16_BYTE( "rl_1g.bin", 0x40000, 0x08000, CRC(74d41b2e) SHA1(cd690df46242dd54061bf5f6464203e1f29ce6d8) )
@@ -739,24 +739,21 @@ ROM_START( svolley )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )
 	ROM_LOAD( "sps_17.bin", 0x00000, 0x10000, CRC(48b89688) SHA1(1f39d979a852f5237a7d95231e86a28cdc1f4d65) )
 
-	ROM_REGION( 0x60000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_ERASEFF )
 	ROM_LOAD( "sps_02.bin", 0x00000, 0x10000, CRC(1a0abe75) SHA1(49251c5e377f9317471f7df26ac2c6b8cfa51007) )
 	ROM_LOAD( "sps_03.bin", 0x10000, 0x10000, CRC(36279075) SHA1(6c4cf3fab9eb764cb8bc10ab4f8aa54d0afb65d9) )
 	ROM_LOAD( "sps_04.bin", 0x20000, 0x10000, CRC(7cede7d9) SHA1(9c7e3a9b7dd8d390b327d52ced35b03b8c1fd5ee) )
 	ROM_LOAD( "sps_01.bin", 0x30000, 0x08000, CRC(6425e6d7) SHA1(b6c81155c22072d1de88ca23d58bd9621139dc6c) )
-	ROM_FILL(               0x38000, 0x08000, 0xff )
 	ROM_LOAD( "sps_10.bin", 0x40000, 0x08000, CRC(a12b1589) SHA1(ecaa941f29c028ca94fcd1d86edfd69884e61d2c) )
-	ROM_FILL(               0x48000, 0x18000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX2, 0 )
+	ROM_REGION( 0x80000, REGION_GFX2, ROMREGION_ERASEFF )
 	ROM_LOAD( "sps_05.bin", 0x00000, 0x10000, CRC(b0671d12) SHA1(defc71b6d7c31c74a58789a1620a506f36b85837) )
 	ROM_LOAD( "sps_06.bin", 0x10000, 0x10000, CRC(c231957e) SHA1(b56afd41969bd865ad3ca16fb51e39030aeb1943) )
 	ROM_LOAD( "sps_07.bin", 0x20000, 0x10000, CRC(904b7709) SHA1(9b66a565cd599928b666baad9f97c50f35ffcc37) )
 	ROM_LOAD( "sps_08.bin", 0x30000, 0x10000, CRC(5430ffac) SHA1(163311d96f2f7e1ecb0901d0be73ac357b01bf6a) )
 	ROM_LOAD( "sps_09.bin", 0x40000, 0x10000, CRC(414a6278) SHA1(baa9dc9ab0dd3c5f27c128de23053edcddf45ad0) )
-	ROM_FILL(               0x50000, 0x10000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX3, 0 )
+	ROM_REGION( 0x80000, REGION_GFX3, ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "sps_20.bin", 0x00000, 0x10000, CRC(c9e7206d) SHA1(af5b2f49387a3b46c6693f4782aa0e587f17ab25) )
 	ROM_LOAD16_BYTE( "sps_23.bin", 0x00001, 0x10000, CRC(7b15c805) SHA1(b55d67956ca10c172f244edce4dc0a8bd155b3ce) )
 	ROM_LOAD16_BYTE( "sps_19.bin", 0x20000, 0x08000, CRC(8ac2f232) SHA1(6ccd003d7e6fb933241e58964e682bd0fcc37b35) )
@@ -779,25 +776,22 @@ ROM_START( svolleyk )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )
 	ROM_LOAD( "sps_17.bin", 0x00000, 0x10000, CRC(48b89688) SHA1(1f39d979a852f5237a7d95231e86a28cdc1f4d65) )
 
-	ROM_REGION( 0x60000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_ERASEFF )
 	ROM_LOAD( "sps_02.bin", 0x00000, 0x10000, CRC(1a0abe75) SHA1(49251c5e377f9317471f7df26ac2c6b8cfa51007) )
 	ROM_LOAD( "sps_03.bin", 0x10000, 0x10000, CRC(36279075) SHA1(6c4cf3fab9eb764cb8bc10ab4f8aa54d0afb65d9) )
 	ROM_LOAD( "sps_04.bin", 0x20000, 0x10000, CRC(7cede7d9) SHA1(9c7e3a9b7dd8d390b327d52ced35b03b8c1fd5ee) )
 	ROM_LOAD( "sps_01.bin", 0x30000, 0x08000, CRC(6425e6d7) SHA1(b6c81155c22072d1de88ca23d58bd9621139dc6c) )
-	ROM_FILL(               0x38000, 0x08000, 0xff )
 	ROM_LOAD( "sps_10.bin", 0x40000, 0x08000, CRC(a12b1589) SHA1(ecaa941f29c028ca94fcd1d86edfd69884e61d2c) )
-	ROM_FILL(               0x48000, 0x18000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX2, 0 )
+	ROM_REGION( 0x80000, REGION_GFX2, ROMREGION_ERASEFF )
 	ROM_LOAD( "sps_05.bin", 0x00000, 0x10000, CRC(b0671d12) SHA1(defc71b6d7c31c74a58789a1620a506f36b85837) )
 	ROM_LOAD( "sps_06.bin", 0x10000, 0x10000, CRC(c231957e) SHA1(b56afd41969bd865ad3ca16fb51e39030aeb1943) )
 	ROM_LOAD( "sps_07.bin", 0x20000, 0x10000, CRC(904b7709) SHA1(9b66a565cd599928b666baad9f97c50f35ffcc37) )
 	ROM_LOAD( "sps_08.bin", 0x30000, 0x10000, CRC(5430ffac) SHA1(163311d96f2f7e1ecb0901d0be73ac357b01bf6a) )
 	ROM_LOAD( "sps_09.bin", 0x40000, 0x10000, CRC(414a6278) SHA1(baa9dc9ab0dd3c5f27c128de23053edcddf45ad0) )
 	ROM_LOAD( "a09.bin",    0x50000, 0x08000, CRC(dd92dfe1) SHA1(08c956e11d567a215ec3cdaf6ef75fa9a886513a) )
-	ROM_FILL(               0x58000, 0x08000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX3, 0 )
+	ROM_REGION( 0x80000, REGION_GFX3, ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "sps_20.bin", 0x00000, 0x10000, CRC(c9e7206d) SHA1(af5b2f49387a3b46c6693f4782aa0e587f17ab25) )
 	ROM_LOAD16_BYTE( "sps_23.bin", 0x00001, 0x10000, CRC(7b15c805) SHA1(b55d67956ca10c172f244edce4dc0a8bd155b3ce) )
 	ROM_LOAD16_BYTE( "sps_19.bin", 0x20000, 0x08000, CRC(8ac2f232) SHA1(6ccd003d7e6fb933241e58964e682bd0fcc37b35) )
@@ -820,25 +814,22 @@ ROM_START( svolleyu )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 )
 	ROM_LOAD( "sps_17.bin", 0x00000, 0x10000, CRC(48b89688) SHA1(1f39d979a852f5237a7d95231e86a28cdc1f4d65) )
 
-	ROM_REGION( 0x60000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_ERASEFF )
 	ROM_LOAD( "sps_02.bin", 0x00000, 0x10000, CRC(1a0abe75) SHA1(49251c5e377f9317471f7df26ac2c6b8cfa51007) )
 	ROM_LOAD( "sps_03.bin", 0x10000, 0x10000, CRC(36279075) SHA1(6c4cf3fab9eb764cb8bc10ab4f8aa54d0afb65d9) )
 	ROM_LOAD( "sps_04.bin", 0x20000, 0x10000, CRC(7cede7d9) SHA1(9c7e3a9b7dd8d390b327d52ced35b03b8c1fd5ee) )
 	ROM_LOAD( "sps_01.bin", 0x30000, 0x08000, CRC(6425e6d7) SHA1(b6c81155c22072d1de88ca23d58bd9621139dc6c) )
-	ROM_FILL(               0x38000, 0x08000, 0xff )
 	ROM_LOAD( "sps_10.bin", 0x40000, 0x08000, CRC(a12b1589) SHA1(ecaa941f29c028ca94fcd1d86edfd69884e61d2c) )
-	ROM_FILL(               0x48000, 0x18000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX2, 0 )
+	ROM_REGION( 0x80000, REGION_GFX2, ROMREGION_ERASEFF )
 	ROM_LOAD( "sps_05.bin", 0x00000, 0x10000, CRC(b0671d12) SHA1(defc71b6d7c31c74a58789a1620a506f36b85837) )
 	ROM_LOAD( "sps_06.bin", 0x10000, 0x10000, CRC(c231957e) SHA1(b56afd41969bd865ad3ca16fb51e39030aeb1943) )
 	ROM_LOAD( "sps_07.bin", 0x20000, 0x10000, CRC(904b7709) SHA1(9b66a565cd599928b666baad9f97c50f35ffcc37) )
 	ROM_LOAD( "sps_08.bin", 0x30000, 0x10000, CRC(5430ffac) SHA1(163311d96f2f7e1ecb0901d0be73ac357b01bf6a) )
 	ROM_LOAD( "sps_09.bin", 0x40000, 0x10000, CRC(414a6278) SHA1(baa9dc9ab0dd3c5f27c128de23053edcddf45ad0) )
 	ROM_LOAD( "a09.bin",    0x50000, 0x08000, CRC(dd92dfe1) SHA1(08c956e11d567a215ec3cdaf6ef75fa9a886513a) )
-	ROM_FILL(               0x58000, 0x08000, 0xff )
 
-	ROM_REGION( 0x60000, REGION_GFX3, 0 )
+	ROM_REGION( 0x80000, REGION_GFX3, ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "sps_20.bin", 0x00000, 0x10000, CRC(c9e7206d) SHA1(af5b2f49387a3b46c6693f4782aa0e587f17ab25) )
 	ROM_LOAD16_BYTE( "sps_23.bin", 0x00001, 0x10000, CRC(7b15c805) SHA1(b55d67956ca10c172f244edce4dc0a8bd155b3ce) )
 	ROM_LOAD16_BYTE( "sps_19.bin", 0x20000, 0x08000, CRC(8ac2f232) SHA1(6ccd003d7e6fb933241e58964e682bd0fcc37b35) )
@@ -855,7 +846,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver initialization
+ *  Driver initialization
  *
  *************************************/
 
@@ -877,7 +868,7 @@ static DRIVER_INIT( svolley )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
