@@ -10,30 +10,30 @@ Main CPU
 
 Memory mapped:
 
-0000-dfff	ROM
-e000-e7ff	RAM
-e800-ebff	Sprite RAM
-f000-fbff	Background Video RAM
-f400-ffff	Background Color RAM
-f800-fbff	Foreground Video RAM
-fc00-ffff	Foreground Color RAM
+0000-dfff   ROM
+e000-e7ff   RAM
+e800-ebff   Sprite RAM
+f000-fbff   Background Video RAM
+f400-ffff   Background Color RAM
+f800-fbff   Foreground Video RAM
+fc00-ffff   Foreground Color RAM
 
 Ports:
 
-00		R	DSW #1
-20		R	DSW #2
-40		R	Input Ports Player 1
-60		R   Input Ports Player 2
-80		 W  Sound Commnand
-c0		 W  Flip Screen
-c1		 W  ???
-c2-c4	 W  ???
-c6-c7	 W  ??? (Loads the sound latch?)
-c8		 W	???
-c9		 W	???
-ca-cd	 W  ???
-ce		 W  ???
-e0		 W	Watchdog
+00      R   DSW #1
+20      R   DSW #2
+40      R   Input Ports Player 1
+60      R   Input Ports Player 2
+80       W  Sound Commnand
+c0       W  Flip Screen
+c1       W  ???
+c2-c4    W  ???
+c6-c7    W  ??? (Loads the sound latch?)
+c8       W  ???
+c9       W  ???
+ca-cd    W  ???
+ce       W  ???
+e0       W  Watchdog
 
 
 Sound CPU
@@ -41,13 +41,13 @@ Sound CPU
 
 Memory mapped:
 
-0000-7fff		ROM
-8000-87ff		RAM
-a000	     W  ADPCM trigger
-c000-c001	 W	YM3812
-e000		R   Sound latch
-e000-e006	 W  ???
-e00e-e00f	 W  ???
+0000-7fff       ROM
+8000-87ff       RAM
+a000         W  ADPCM trigger
+c000-c001    W  YM3812
+e000        R   Sound latch
+e000-e006    W  ???
+e00e-e00f    W  ???
 
 
 TODO
@@ -76,6 +76,7 @@ Addition by Reip
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/3812intf.h"
 
 extern UINT8 *tecfri_videoram;
 extern UINT8 *tecfri_colorram;
@@ -140,6 +141,7 @@ static ADDRESS_MAP_START( sauro_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sauro_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_2_r)
 	AM_RANGE(0x20, 0x20) AM_READ(input_port_3_r)
 	AM_RANGE(0x40, 0x40) AM_READ(input_port_0_r)
@@ -147,6 +149,7 @@ static ADDRESS_MAP_START( sauro_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sauro_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xa0, 0xa0) AM_WRITE(tecfri_scroll_bg_w)
 	AM_RANGE(0xa1, 0xa1) AM_WRITE(sauro_scroll_fg_w)
 	AM_RANGE(0x80, 0x80) AM_WRITE(sauro_sound_command_w)
@@ -169,7 +172,7 @@ static ADDRESS_MAP_START( sauro_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0x87ff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0xc000, 0xc000) AM_WRITE(YM3812_control_port_0_w)
 	AM_RANGE(0xc001, 0xc001) AM_WRITE(YM3812_write_port_0_w)
-/*	AM_RANGE(0xa000, 0xa000) AM_WRITE(ADPCM_trigger) */
+/*  AM_RANGE(0xa000, 0xa000) AM_WRITE(ADPCM_trigger) */
 	AM_RANGE(0xe000, 0xe006) AM_WRITE(MWA8_NOP)
 	AM_RANGE(0xe00e, 0xe00f) AM_WRITE(MWA8_NOP)
 ADDRESS_MAP_END
@@ -331,13 +334,6 @@ static INTERRUPT_GEN( sauro_interrupt )
 	cpunum_set_input_line(1, 0, HOLD_LINE);
 }
 
-static struct YM3526interface ym3812_interface =
-{
-	1,			/* 1 chip (no more supported) */
-	3600000,	/* 3.600000 MHz ? */
-	{ 100 } 	/* volume */
-};
-
 static MACHINE_DRIVER_START( tecfri )
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("main", Z80, 4000000)        /* 4 MHz??? */
@@ -354,7 +350,10 @@ static MACHINE_DRIVER_START( tecfri )
 	MDRV_PALETTE_INIT(RRRR_GGGG_BBBB)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 3600000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( trckydoc )
@@ -377,7 +376,7 @@ static MACHINE_DRIVER_START( sauro )
 	MDRV_CPU_IO_MAP(sauro_readport, sauro_writeport)
 
 	MDRV_CPU_ADD(Z80, 4000000)	/* 4 MHz? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sauro_sound_readmem, sauro_sound_writemem)
 	MDRV_CPU_VBLANK_INT(sauro_interrupt, 8) /* ? */
 
@@ -448,7 +447,7 @@ ROM_END
 static DRIVER_INIT( tecfri )
 {
 	/* This game doesn't like all memory to be initialized to zero, it won't
-	   initialize the high scores */
+       initialize the high scores */
 
 	UINT8 *RAM = memory_region(REGION_CPU1);
 
