@@ -18,6 +18,8 @@ MAIN BOARD:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
+#include "sound/vlm5030.h"
+#include "sound/dac.h"
 
 
 extern void konami1_decode(void);
@@ -35,10 +37,6 @@ extern PALETTE_INIT( sbasketb );
 extern VIDEO_START( sbasketb );
 extern VIDEO_UPDATE( sbasketb );
 
-extern struct VLM5030interface konami_vlm5030_interface;
-extern struct SN76496interface konami_sn76496_interface;
-extern struct DACinterface konami_dac_interface;
-
 extern WRITE8_HANDLER( konami_SN76496_latch_w );
 extern WRITE8_HANDLER( konami_SN76496_0_w );
 extern WRITE8_HANDLER( hyperspt_sound_w );
@@ -234,8 +232,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 struct VLM5030interface sbasketb_vlm5030_interface =
 {
-	3580000,    /* master clock  */
-	100,        /* volume        */
 	REGION_SOUND1,	/* memory region  */
 	0           /* memory size    */
 };
@@ -249,7 +245,7 @@ static MACHINE_DRIVER_START( sbasketb )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,14318000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 3.5795 MHz */
+	/* audio CPU */	/* 3.5795 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -268,9 +264,17 @@ static MACHINE_DRIVER_START( sbasketb )
 	MDRV_VIDEO_UPDATE(sbasketb)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, konami_dac_interface)
-	MDRV_SOUND_ADD(SN76496, konami_sn76496_interface)
-	MDRV_SOUND_ADD(VLM5030, sbasketb_vlm5030_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+
+	MDRV_SOUND_ADD(SN76496, 14318180/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(VLM5030, 3580000)
+	MDRV_SOUND_CONFIG(sbasketb_vlm5030_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
