@@ -1,134 +1,134 @@
 /***************************************************************************
 
-	Sega vector hardware
+    Sega vector hardware
 
-	Games supported:
-		* Space Fury
-		* Zektor
-		* Tac/Scan
-		* Eliminator
-		* Star Trek
+    Games supported:
+        * Space Fury
+        * Zektor
+        * Tac/Scan
+        * Eliminator
+        * Star Trek
 
-	Known bugs:
-		* none at this time
+    Known bugs:
+        * none at this time
 
 ****************************************************************************
 
-	4/25/99 - Tac-Scan sound call for coins now works. (Jim Hernandez)
-	2/5/98 - Added input ports support for Tac Scan. Bonus Ships now work.
-			 Zektor now uses it's own input port section. (Jim Hernandez)
+    4/25/99 - Tac-Scan sound call for coins now works. (Jim Hernandez)
+    2/5/98 - Added input ports support for Tac Scan. Bonus Ships now work.
+             Zektor now uses it's own input port section. (Jim Hernandez)
 
-	Sega Vector memory map (preliminary)
+    Sega Vector memory map (preliminary)
 
-	Most of the info here comes from the wiretap archive at:
-	http://www.spies.com/arcade/simulation/gameHardware/
+    Most of the info here comes from the wiretap archive at:
+    http://www.spies.com/arcade/simulation/gameHardware/
 
-	 * Sega G80 Vector Simulation
+     * Sega G80 Vector Simulation
 
-	ROM Address Map
-	---------------
-		   Eliminator Elim4Player Space Fury  Zektor  TAC/SCAN	Star Trk
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	0000 | 969		 | 1390 	 | 969		 | 1611  | 1711    | 1873	 | CPU u25
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	0800 | 1333 	 | 1347 	 | 960		 | 1586  | 1670    | 1848	 | ROM u1
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	1000 | 1334 	 | 1348 	 | 961		 | 1587  | 1671    | 1849	 | ROM u2
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	1800 | 1335 	 | 1349 	 | 962		 | 1588  | 1672    | 1850	 | ROM u3
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	2000 | 1336 	 | 1350 	 | 963		 | 1589  | 1673    | 1851	 | ROM u4
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	2800 | 1337 	 | 1351 	 | 964		 | 1590  | 1674    | 1852	 | ROM u5
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	3000 | 1338 	 | 1352 	 | 965		 | 1591  | 1675    | 1853	 | ROM u6
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	3800 | 1339 	 | 1353 	 | 966		 | 1592  | 1676    | 1854	 | ROM u7
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	4000 | 1340 	 | 1354 	 | 967		 | 1593  | 1677    | 1855	 | ROM u8
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	4800 | 1341 	 | 1355 	 | 968		 | 1594  | 1678    | 1856	 | ROM u9
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	5000 | 1342 	 | 1356 	 |			 | 1595  | 1679    | 1857	 | ROM u10
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	5800 | 1343 	 | 1357 	 |			 | 1596  | 1680    | 1858	 | ROM u11
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	6000 | 1344 	 | 1358 	 |			 | 1597  | 1681    | 1859	 | ROM u12
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	6800 | 1345 	 | 1359 	 |			 | 1598  | 1682    | 1860	 | ROM u13
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	7000 |			 | 1360 	 |			 | 1599  | 1683    | 1861	 | ROM u14
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	7800 |									 | 1600  | 1684    | 1862	 | ROM u15
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	8000 |									 | 1601  | 1685    | 1863	 | ROM u16
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	8800 |									 | 1602  | 1686    | 1864	 | ROM u17
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	9000 |									 | 1603  | 1687    | 1865	 | ROM u18
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	9800 |									 | 1604  | 1688    | 1866	 | ROM u19
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	A000 |									 | 1605  | 1709    | 1867	 | ROM u20
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	A800 |									 | 1606  | 1710    | 1868	 | ROM u21
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	B000 |													   | 1869	 | ROM u22
-	-----+-----------+-----------+-----------+-------+---------+---------+
-	B800 |													   | 1870	 | ROM u23
-	-----+-----------+-----------+-----------+-------+---------+---------+
+    ROM Address Map
+    ---------------
+           Eliminator Elim4Player Space Fury  Zektor  TAC/SCAN  Star Trk
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    0000 | 969       | 1390      | 969       | 1611  | 1711    | 1873    | CPU u25
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    0800 | 1333      | 1347      | 960       | 1586  | 1670    | 1848    | ROM u1
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    1000 | 1334      | 1348      | 961       | 1587  | 1671    | 1849    | ROM u2
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    1800 | 1335      | 1349      | 962       | 1588  | 1672    | 1850    | ROM u3
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    2000 | 1336      | 1350      | 963       | 1589  | 1673    | 1851    | ROM u4
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    2800 | 1337      | 1351      | 964       | 1590  | 1674    | 1852    | ROM u5
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    3000 | 1338      | 1352      | 965       | 1591  | 1675    | 1853    | ROM u6
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    3800 | 1339      | 1353      | 966       | 1592  | 1676    | 1854    | ROM u7
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    4000 | 1340      | 1354      | 967       | 1593  | 1677    | 1855    | ROM u8
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    4800 | 1341      | 1355      | 968       | 1594  | 1678    | 1856    | ROM u9
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    5000 | 1342      | 1356      |           | 1595  | 1679    | 1857    | ROM u10
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    5800 | 1343      | 1357      |           | 1596  | 1680    | 1858    | ROM u11
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    6000 | 1344      | 1358      |           | 1597  | 1681    | 1859    | ROM u12
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    6800 | 1345      | 1359      |           | 1598  | 1682    | 1860    | ROM u13
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    7000 |           | 1360      |           | 1599  | 1683    | 1861    | ROM u14
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    7800 |                                   | 1600  | 1684    | 1862    | ROM u15
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    8000 |                                   | 1601  | 1685    | 1863    | ROM u16
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    8800 |                                   | 1602  | 1686    | 1864    | ROM u17
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    9000 |                                   | 1603  | 1687    | 1865    | ROM u18
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    9800 |                                   | 1604  | 1688    | 1866    | ROM u19
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    A000 |                                   | 1605  | 1709    | 1867    | ROM u20
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    A800 |                                   | 1606  | 1710    | 1868    | ROM u21
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    B000 |                                                     | 1869    | ROM u22
+    -----+-----------+-----------+-----------+-------+---------+---------+
+    B800 |                                                     | 1870    | ROM u23
+    -----+-----------+-----------+-----------+-------+---------+---------+
 
-	I/O ports:
-	read:
+    I/O ports:
+    read:
 
-	write:
+    write:
 
-	These games all have dipswitches, but they are mapped in such a way as to make
-	using them with MAME extremely difficult. I might try to implement them in the
-	future.
+    These games all have dipswitches, but they are mapped in such a way as to make
+    using them with MAME extremely difficult. I might try to implement them in the
+    future.
 
-	SWITCH MAPPINGS
-	---------------
+    SWITCH MAPPINGS
+    ---------------
 
-	+------+------+------+------+------+------+------+------+
-	|SW1-8 |SW1-7 |SW1-6 |SW1-5 |SW1-4 |SW1-3 |SW1-2 |SW1-1 |
-	+------+------+------+------+------+------+------+------+
-	 F8:08 |F9:08 |FA:08 |FB:08 |F8:04 |F9:04  FA:04  FB:04    Zektor &
-		   |	  | 	 |		|	   |	  | 			   Space Fury
-		   |	  | 	 |		|	   |	  |
-	   1  -|------|------|------|------|------|--------------- upright
-	   0  -|------|------|------|------|------|--------------- cocktail
-		   |	  | 	 |		|	   |	  |
-		   |  1  -|------|------|------|------|--------------- voice
-		   |  0  -|------|------|------|------|--------------- no voice
-				  | 	 |		|	   |	  |
-				  |  1	 |	1  -|------|------|--------------- 5 ships
-				  |  0	 |	1  -|------|------|--------------- 4 ships
-				  |  1	 |	0  -|------|------|--------------- 3 ships
-				  |  0	 |	0  -|------|------|--------------- 2 ships
-								|	   |	  |
-								|  1   |  1  -|--------------- hardest
-								|  0   |  1  -|--------------- hard
-	1 = Open					|  1   |  0  -|--------------- medium
-	0 = Closed					|  0   |  0  -|--------------- easy
+    +------+------+------+------+------+------+------+------+
+    |SW1-8 |SW1-7 |SW1-6 |SW1-5 |SW1-4 |SW1-3 |SW1-2 |SW1-1 |
+    +------+------+------+------+------+------+------+------+
+     F8:08 |F9:08 |FA:08 |FB:08 |F8:04 |F9:04  FA:04  FB:04    Zektor &
+           |      |      |      |      |      |                Space Fury
+           |      |      |      |      |      |
+       1  -|------|------|------|------|------|--------------- upright
+       0  -|------|------|------|------|------|--------------- cocktail
+           |      |      |      |      |      |
+           |  1  -|------|------|------|------|--------------- voice
+           |  0  -|------|------|------|------|--------------- no voice
+                  |      |      |      |      |
+                  |  1   |  1  -|------|------|--------------- 5 ships
+                  |  0   |  1  -|------|------|--------------- 4 ships
+                  |  1   |  0  -|------|------|--------------- 3 ships
+                  |  0   |  0  -|------|------|--------------- 2 ships
+                                |      |      |
+                                |  1   |  1  -|--------------- hardest
+                                |  0   |  1  -|--------------- hard
+    1 = Open                    |  1   |  0  -|--------------- medium
+    0 = Closed                  |  0   |  0  -|--------------- easy
 
-	+------+------+------+------+------+------+------+------+
-	|SW2-8 |SW2-7 |SW2-6 |SW2-5 |SW2-4 |SW2-3 |SW2-2 |SW2-1 |
-	+------+------+------+------+------+------+------+------+
-	|F8:02 |F9:02 |FA:02 |FB:02 |F8:01 |F9:01 |FA:01 |FB:01 |
-	|	   |	  | 	 |		|	   |	  | 	 |		|
-	|  1   |  1   |  0	 |	0	|  1   | 1	  | 0	 |	0	| 1 coin/ 1 play
-	+------+------+------+------+------+------+------+------+
+    +------+------+------+------+------+------+------+------+
+    |SW2-8 |SW2-7 |SW2-6 |SW2-5 |SW2-4 |SW2-3 |SW2-2 |SW2-1 |
+    +------+------+------+------+------+------+------+------+
+    |F8:02 |F9:02 |FA:02 |FB:02 |F8:01 |F9:01 |FA:01 |FB:01 |
+    |      |      |      |      |      |      |      |      |
+    |  1   |  1   |  0   |  0   |  1   | 1    | 0    |  0   | 1 coin/ 1 play
+    +------+------+------+------+------+------+------+------+
 
-	Known problems:
+    Known problems:
 
-	1 The games seem to run too fast. This is most noticable
-	  with the speech samples in Zektor - they don't match the mouth.
-	  Slowing down the Z80 doesn't help and in fact hurts performance.
+    1 The games seem to run too fast. This is most noticable
+      with the speech samples in Zektor - they don't match the mouth.
+      Slowing down the Z80 doesn't help and in fact hurts performance.
 
-	2 Cocktail mode isn't implemented.
+    2 Cocktail mode isn't implemented.
 
-	Is 1) still valid?
+    Is 1) still valid?
 
 ***************************************************************************/
 
@@ -136,12 +136,13 @@
 #include "vidhrdw/vector.h"
 #include "sndhrdw/segasnd.h"
 #include "sega.h"
+#include "sound/samples.h"
 
 
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -168,6 +169,7 @@ static READ8_HANDLER( sega_sh_r )
 }
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x3f, 0x3f) AM_READ(sega_sh_r)
 	AM_RANGE(0xbe, 0xbe) AM_READ(sega_mult_r)
 	AM_RANGE(0xf8, 0xfb) AM_READ(sega_ports_r)
@@ -175,6 +177,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xbd, 0xbd) AM_WRITE(sega_mult1_w)
 	AM_RANGE(0xbe, 0xbe) AM_WRITE(sega_mult2_w)
 	AM_RANGE(0xf8, 0xf8) AM_WRITE(sega_switch_w)
@@ -184,19 +187,12 @@ ADDRESS_MAP_END
 
 
 
-static ADDRESS_MAP_START( speech_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_READ(MRA8_ROM)
-ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( speech_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_WRITE(MWA8_ROM)
-ADDRESS_MAP_END
-
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -616,7 +612,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Space Fury sound interfaces
+ *  Space Fury sound interfaces
  *
  *************************************/
 
@@ -641,14 +637,13 @@ static const char *spacfury_sample_names[] =
 static struct Samplesinterface spacfury_samples_interface =
 {
 	8,	/* 8 channels */
-	10, /* volume */
 	spacfury_sample_names
 };
 
 
 /*************************************
  *
- *	Zektor sound interfaces
+ *  Zektor sound interfaces
  *
  *************************************/
 
@@ -678,7 +673,6 @@ static const char *zektor_sample_names[] =
 static struct Samplesinterface zektor_samples_interface =
 {
 	8,
-	10, /* volume */
 	zektor_sample_names
 };
 
@@ -686,7 +680,7 @@ static struct Samplesinterface zektor_samples_interface =
 
 /*************************************
  *
- *	Tac/Scan sound interfaces
+ *  Tac/Scan sound interfaces
  *
  *************************************/
 
@@ -724,23 +718,20 @@ static const char *tacscan_sample_names[] =
 static struct Samplesinterface tacscan_samples_interface =
 {
 	12, /* 12 channels */
-	100, /* volume */
 	tacscan_sample_names
 };
 
 
 static struct CustomSound_interface tacscan_custom_interface =
 {
-	tacscan_sh_start,
-	0,
-	tacscan_sh_update
+	tacscan_sh_start
 };
 
 
 
 /*************************************
  *
- *	Eliminator sound interfaces
+ *  Eliminator sound interfaces
  *
  *************************************/
 
@@ -765,7 +756,6 @@ static const char *elim_sample_names[] =
 static struct Samplesinterface elim2_samples_interface =
 {
 	8,	/* 8 channels */
-	100, /* volume */
 	elim_sample_names
 };
 
@@ -773,7 +763,7 @@ static struct Samplesinterface elim2_samples_interface =
 
 /*************************************
  *
- *	Star Trek sound interfaces
+ *  Star Trek sound interfaces
  *
  *************************************/
 
@@ -816,7 +806,6 @@ static const char *startrek_sample_names[] =
 static struct Samplesinterface startrek_samples_interface =
 {
 	5, /* 5 channels */
-	10, /* volume */
 	startrek_sample_names
 };
 
@@ -824,7 +813,7 @@ static struct Samplesinterface startrek_samples_interface =
 
 /*************************************
  *
- *	Machine drivers
+ *  Machine drivers
  *
  *************************************/
 
@@ -848,7 +837,11 @@ static MACHINE_DRIVER_START( elim2 )
 	MDRV_VIDEO_UPDATE(sega)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("samples", SAMPLES, elim2_samples_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD_TAG("samples", SAMPLES, 0)
+	MDRV_SOUND_CONFIG(elim2_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -858,16 +851,21 @@ static MACHINE_DRIVER_START( zektor )
 	MDRV_IMPORT_FROM(elim2)
 
 	MDRV_CPU_ADD(I8035, 3120000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sega_speechboard_readmem, sega_speechboard_writemem)
 	MDRV_CPU_IO_MAP (sega_speechboard_readport,sega_speechboard_writeport)
-	MDRV_SOUND_ADD(SP0250, sega_sp0250_interface)
 
 	/* video hardware */
 	MDRV_VISIBLE_AREA(512, 1536, 624, 1432)
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("samples", SAMPLES, zektor_samples_interface)
+	MDRV_SOUND_REPLACE("samples", SAMPLES, 0)
+	MDRV_SOUND_CONFIG(zektor_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+
+	MDRV_SOUND_ADD(SP0250, 0)
+	MDRV_SOUND_CONFIG(sega_sp0250_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -880,8 +878,12 @@ static MACHINE_DRIVER_START( tacscan )
 	MDRV_VISIBLE_AREA(496, 1552, 592, 1456)
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("samples", SAMPLES, tacscan_samples_interface)
-	MDRV_SOUND_ADD_TAG("custom",  CUSTOM,  tacscan_custom_interface)
+	MDRV_SOUND_REPLACE("samples", SAMPLES, 0)
+	MDRV_SOUND_CONFIG(tacscan_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD_TAG("custom",  CUSTOM, 0)
+	MDRV_SOUND_CONFIG(tacscan_custom_interface)
 MACHINE_DRIVER_END
 
 
@@ -891,16 +893,21 @@ static MACHINE_DRIVER_START( spacfury )
 	MDRV_IMPORT_FROM(elim2)
 
 	MDRV_CPU_ADD(I8035, 3120000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sega_speechboard_readmem, sega_speechboard_writemem)
 	MDRV_CPU_IO_MAP (sega_speechboard_readport,sega_speechboard_writeport)
-	MDRV_SOUND_ADD(SP0250, sega_sp0250_interface)
 
 	/* video hardware */
 	MDRV_VISIBLE_AREA(512, 1536, 552, 1464)
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("samples", SAMPLES, spacfury_samples_interface)
+	MDRV_SOUND_REPLACE("samples", SAMPLES, 0)
+	MDRV_SOUND_CONFIG(spacfury_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+
+	MDRV_SOUND_ADD(SP0250, 0)
+	MDRV_SOUND_CONFIG(sega_sp0250_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -910,23 +917,28 @@ static MACHINE_DRIVER_START( startrek )
 	MDRV_IMPORT_FROM(elim2)
 
 	MDRV_CPU_ADD(I8035, 3120000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sega_speechboard_readmem, sega_speechboard_writemem)
 	MDRV_CPU_IO_MAP (sega_speechboard_readport,sega_speechboard_writeport)
-	MDRV_SOUND_ADD(SP0250, sega_sp0250_interface)
 
 	/* video hardware */
 	MDRV_VISIBLE_AREA(512, 1536, 616, 1464)
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("samples", SAMPLES, startrek_samples_interface)
+	MDRV_SOUND_REPLACE("samples", SAMPLES, 0)
+	MDRV_SOUND_CONFIG(startrek_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(SP0250, 0)
+	MDRV_SOUND_CONFIG(sega_sp0250_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -1139,7 +1151,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver initialization
+ *  Driver initialization
  *
  *************************************/
 
@@ -1220,7 +1232,7 @@ DRIVER_INIT( tacscan )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
