@@ -1,48 +1,48 @@
 /***************************************************************************
 
-	Sega G-80 raster hardware
+    Sega G-80 raster hardware
 
-	Games supported:
-		* Astro Blaster
-		* Monster Bash
-		* 005
-		* Space Odyssey
-		* Pig Newton
-		* Sindbad Mystery
+    Games supported:
+        * Astro Blaster
+        * Monster Bash
+        * 005
+        * Space Odyssey
+        * Pig Newton
+        * Sindbad Mystery
 
-	Known bugs:
-		* none at this time
+    Known bugs:
+        * none at this time
 
 ****************************************************************************
 
-	See also sega.c for the Sega G-80 Vector games.
+    See also sega.c for the Sega G-80 Vector games.
 
-	Many thanks go to Dave Fish for the fine detective work he did into the
-	G-80 security chips (315-0064, 315-0070, 315-0076, 315-0082) which provided
-	me with enough information to emulate those chips at runtime along with
-	the 315-0062 Astro Blaster chip and the 315-0063 Space Odyssey chip.
+    Many thanks go to Dave Fish for the fine detective work he did into the
+    G-80 security chips (315-0064, 315-0070, 315-0076, 315-0082) which provided
+    me with enough information to emulate those chips at runtime along with
+    the 315-0062 Astro Blaster chip and the 315-0063 Space Odyssey chip.
 
-	Special note (24-MAR-1999) - Sindbad Mystery does *not* use the standard
-	G-80 security chip; rather, it uses the Sega System 1 encryption.
+    Special note (24-MAR-1999) - Sindbad Mystery does *not* use the standard
+    G-80 security chip; rather, it uses the Sega System 1 encryption.
 
-	Thanks also go to Paul Tonizzo, Clay Cowgill, John Bowes, and Kevin Klopp
-	for all the helpful information, samples, and schematics!
+    Thanks also go to Paul Tonizzo, Clay Cowgill, John Bowes, and Kevin Klopp
+    for all the helpful information, samples, and schematics!
 
-	TODO:
-	- locate Pig Newton cocktail mode?
-	- verify Pig Newton and Sindbad Mystery DIPs
-	- attempt Pig Newton, 005 sound
-	- fix transparency issues (Pig Newton, Sindbad Mystery)
-	- fix Space Odyssey background
-	- figure out why Astro Blaster version 1 ends the game right away
+    TODO:
+    - locate Pig Newton cocktail mode?
+    - verify Pig Newton and Sindbad Mystery DIPs
+    - attempt Pig Newton, 005 sound
+    - fix transparency issues (Pig Newton, Sindbad Mystery)
+    - fix Space Odyssey background
+    - figure out why Astro Blaster version 1 ends the game right away
 
-	- Mike Balfour (mab22@po.cwru.edu)
+    - Mike Balfour (mab22@po.cwru.edu)
 
 ***************************************************************************
 
-	26/3/2000:	** Darren Hatton (UKVAC) / Adrian Purser (UKVAC) **
-				Added a 3rd Astro Blaster ROM set (ASTROB2).
-				Updated Dip Switches to be correct for the Astro Blaster sets.
+    26/3/2000:  ** Darren Hatton (UKVAC) / Adrian Purser (UKVAC) **
+                Added a 3rd Astro Blaster ROM set (ASTROB2).
+                Updated Dip Switches to be correct for the Astro Blaster sets.
 
 ***************************************************************************/
 
@@ -53,12 +53,16 @@
 #include "machine/segacrpt.h"
 #include "sndhrdw/segasnd.h"
 #include "segar.h"
-
+#include "sound/dac.h"
+#include "sound/sn76496.h"
+#include "sound/samples.h"
+#include "sound/tms36xx.h"
+#include "sound/sp0250.h"
 
 
 /*************************************
  *
- *	Interrupt handling
+ *  Interrupt handling
  *
  *************************************/
 
@@ -74,7 +78,7 @@ static INTERRUPT_GEN( segar_interrupt )
 
 /*************************************
  *
- *	Input ports
+ *  Input ports
  *
  *************************************/
 
@@ -125,7 +129,7 @@ static READ8_HANDLER( segar_ports_r )
 
 /***************************************************************************
 
-  The Sega game spaceod stores the INP and DIP switches in a very mangled 
+  The Sega game spaceod stores the INP and DIP switches in a very mangled
   format that's not directly useable by MAME.  This function mangles them
   into a format that can be used.
 
@@ -137,20 +141,20 @@ static READ8_HANDLER( segar_ports_r )
   Port 4 -  INP4-8  INP4-7  INP4-6  INP4-5  INP2-4  INP2-3  INP2-2  INP2-1
   Port 6 -  DIP1-8  DIP1-7  DIP1-6  DIP1-5  DIP1-4  DIP1-3  DIP1-2  DIP1-1
   Port 7 -  DIP2-8  DIP2-7  DIP2-6  DIP2-5  DIP2-4  DIP2-3  DIP2-2  DIP2-1
-  
+
   Original format (cocktail):
   Port 0 -  INP0-8  INP0-7  INP0-6  INP0-5  DIP1-8  DIP1-4  DIP2-8  DIP2-4
   Port 1 -  INP1-8  INP1-7  INP1-6  INP1-5  DIP1-7  DIP1-3  DIP2-7  DIP2-3
   Port 2 -  INP2-8  INP2-7  INP2-6  INP2-5  DIP1-6  DIP1-2  DIP2-6  DIP2-2
   Port 3 -  INP3-8  INP3-7  INP3-6  INP3-5  DIP1-5  DIP1-1  DIP2-5  DIP2-1
-  Port 4 -  INP4-8  INP4-7  INP4-6  INP4-5  INP4-4  INP4-3  INP4-2  INP4-1 
+  Port 4 -  INP4-8  INP4-7  INP4-6  INP4-5  INP4-4  INP4-3  INP4-2  INP4-1
 
   Original format (upright):
   Port 0 -  INP0-8  INP0-7  INP0-6 (INP4-4) DIP1-8  DIP1-4  DIP2-8  DIP2-4
   Port 1 -  INP1-8  INP1-7  INP1-6  INP1-5  DIP1-7  DIP1-3  DIP2-7  DIP2-3
   Port 2 -  INP2-8  INP2-7 (INP4-6) INP2-5  DIP1-6  DIP1-2  DIP2-6  DIP2-2
   Port 3 -  INP3-8  INP3-7 (INP4-5) INP3-5  DIP1-5  DIP1-1  DIP2-5  DIP2-1
-  Port 4 -  INP4-8  INP4-7  INP4-6  INP4-5  INP4-4  INP4-3  INP4-1  INP4-2 
+  Port 4 -  INP4-8  INP4-7  INP4-6  INP4-5  INP4-4  INP4-3  INP4-1  INP4-2
 
 ***************************************************************************/
 
@@ -204,7 +208,7 @@ static READ8_HANDLER( spaceod_ports_r )
 
 /*************************************
  *
- *	sindbad Mystery sound handling
+ *  sindbad Mystery sound handling
  *
  *************************************/
 
@@ -237,7 +241,7 @@ static WRITE8_HANDLER( sindbadm_SN76496_1_w )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -280,11 +284,12 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Main CPU port handlers
+ *  Main CPU port handlers
  *
  *************************************/
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 /*AM_RANGE(0x3f, 0x3f) AM_READ(MRA8_NOP)    Pig Newton - read from 1D87    */
 	AM_RANGE(0x0e, 0x0e) AM_READ(monsterb_audio_8255_r)
 	AM_RANGE(0x81, 0x81) AM_READ(input_port_8_r)     /* only used by Sindbad Mystery */
@@ -293,16 +298,19 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( spaceod_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xf8, 0xfc) AM_READ(spaceod_ports_r)
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xbf, 0xbf) AM_WRITE(segar_video_port_w)
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( sindbadm_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 /*      AM_RANGE(0x00, 0x00) AM_WRITE(???_w)    toggles on and off immediately (0x01, 0x00)    */
 	AM_RANGE(0x41, 0x41) AM_WRITE(sindbadm_back_port_w)
 	AM_RANGE(0x43, 0x43) AM_WRITE(segar_video_port_w) /* bit0=cocktail flip, bit1=write to color RAM, bit2=always on? */
@@ -313,19 +321,12 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
-static ADDRESS_MAP_START( speech_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_READ(MRA8_ROM)
-ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( speech_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_WRITE(MWA8_ROM)
-ADDRESS_MAP_END
-
 
 static ADDRESS_MAP_START( monsterb_7751_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x03ff) AM_READ(MRA8_ROM)
@@ -372,7 +373,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -668,7 +669,7 @@ SEGAR_COMMON2A
 INPUT_PORTS_END
 
 
-/* The port mapping in spaceod is different for upright vs. cocktail.  Use  */
+/* The port mapping in spaceod is different for upright vs. cocktail.  Use */
 /* the cocktail mapping by default to gain access to all inputs, and remap */
 /* the inputs for upright in spaceod_ports_r() */
 
@@ -678,7 +679,7 @@ INPUT_PORTS_START( spaceod )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(3)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(3)
-	
+
 	PORT_START_TAG("IN1")
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
@@ -930,7 +931,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics layouts
+ *  Graphics layouts
  *
  *************************************/
 
@@ -1000,21 +1001,19 @@ static struct GfxDecodeInfo spaceod_gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound interfaces
+ *  Sound interfaces
  *
  *************************************/
 
 static struct Samplesinterface astrob_samples_interface =
 {
 	11,    /* 11 channels */
-	25,    /* volume */
 	astrob_sample_names
 };
 
 static struct Samplesinterface spaceod_samples_interface =
 {
 	12,    /* 12 channels */
-	25,    /* volume */
 	spaceod_sample_names
 };
 
@@ -1022,7 +1021,6 @@ static struct Samplesinterface spaceod_samples_interface =
 static struct Samplesinterface samples_interface_005 =
 {
 	12,    /* 12 channels */
-	25,    /* volume */
 	s005_sample_names
 };
 
@@ -1030,40 +1028,21 @@ static struct Samplesinterface samples_interface_005 =
 static struct Samplesinterface monsterb_samples_interface =
 {
 	2,    /* 2 channels */
-	25,    /* volume */
 	monsterb_sample_names
 };
 
 
-static struct DACinterface monsterb_dac_interface =
-{
-	1,
-	{ 100 }
-};
-
-
 static struct TMS36XXinterface monsterb_tms3617_interface =
 {
-	1,
-    { 50 },         /* mixing levels */
-	{ TMS3617 },	/* TMS36xx subtype(s) */
-	{ 247 },		/* base clock (one octave below A) */
-	{ {0.5,0.5,0.5,0.5,0.5,0.5} }  /* decay times of voices */
-};
-
-
-static struct SN76496interface sn76496_interface =
-{
-	2,          			/* 2 chips */
-	{ 4000000, 2000000 },    /* I'm assuming that the sound board is the same as System 1 */
-	{ 100, 100 }
+	TMS3617,	/* TMS36xx subtype(s) */
+	{0.5,0.5,0.5,0.5,0.5,0.5}  /* decay times of voices */
 };
 
 
 
 /*************************************
  *
- *	Machine drivers
+ *  Machine drivers
  *
  *************************************/
 
@@ -1089,6 +1068,8 @@ static MACHINE_DRIVER_START( segar )
 	MDRV_PALETTE_INIT(segar)
 	MDRV_VIDEO_START(segar)
 	MDRV_VIDEO_UPDATE(segar)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
 MACHINE_DRIVER_END
 
 
@@ -1098,13 +1079,18 @@ static MACHINE_DRIVER_START( astrob )
 	MDRV_IMPORT_FROM(segar)
 
 	MDRV_CPU_ADD(I8035, 3120000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sega_speechboard_readmem, sega_speechboard_writemem)
 	MDRV_CPU_IO_MAP (sega_speechboard_readport,sega_speechboard_writeport)
-	MDRV_SOUND_ADD(SP0250, sega_sp0250_interface)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SAMPLES, astrob_samples_interface)
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(astrob_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(SP0250, 0)
+	MDRV_SOUND_CONFIG(sega_sp0250_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1124,7 +1110,9 @@ static MACHINE_DRIVER_START( spaceod )
 	MDRV_VIDEO_UPDATE(spaceod)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SAMPLES, spaceod_samples_interface)
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(spaceod_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -1134,7 +1122,9 @@ static MACHINE_DRIVER_START( 005 )
 	MDRV_IMPORT_FROM(segar)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SAMPLES, samples_interface_005)
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(samples_interface_005)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -1144,7 +1134,7 @@ static MACHINE_DRIVER_START( monsterb )
 	MDRV_IMPORT_FROM(segar)
 
 	MDRV_CPU_ADD(N7751, 6000000/15)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(monsterb_7751_readmem,monsterb_7751_writemem)
 	MDRV_CPU_IO_MAP(monsterb_7751_readport,monsterb_7751_writeport)
 
@@ -1157,9 +1147,16 @@ static MACHINE_DRIVER_START( monsterb )
 	MDRV_VIDEO_UPDATE(monsterb)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SAMPLES, monsterb_samples_interface)
-	MDRV_SOUND_ADD(TMS36XX, monsterb_tms3617_interface)
-	MDRV_SOUND_ADD(DAC,     monsterb_dac_interface)
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(monsterb_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(TMS36XX, 247)
+	MDRV_SOUND_CONFIG(monsterb_tms3617_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1187,7 +1184,7 @@ static MACHINE_DRIVER_START( sindbadm )
 	MDRV_CPU_VBLANK_INT(segar_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)	/* 4 MHz ? - see system1.c */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sindbadm_sound_readmem,sindbadm_sound_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
 
@@ -1207,14 +1204,20 @@ static MACHINE_DRIVER_START( sindbadm )
 	MDRV_VIDEO_UPDATE(sindbadm)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 4000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(SN76496, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -1496,7 +1499,7 @@ ROM_END
 
 ROM_START( pignewt )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for code */
-/*	ROM_LOAD( "cpu.u25",    0x0000, 0x0800, NO_DUMP )    U25    why was it NO_DUMP not BAD_DUMP? */
+/*  ROM_LOAD( "cpu.u25",    0x0000, 0x0800, NO_DUMP )    U25    why was it NO_DUMP not BAD_DUMP? */
 	ROM_LOAD( "cpu.u25",    0x0000, 0x0800, BAD_DUMP CRC(eccc814d) SHA1(d999d7d433bde5d7773cd7afaf3e673089ba2544)) /* U25 */
 	ROM_LOAD( "1888c",      0x0800, 0x0800, CRC(fd18ed09) SHA1(8bba49d93ae72dbc0497a5a24991c5da26d169d3) ) /* U1 */
 	ROM_LOAD( "1889c",      0x1000, 0x0800, CRC(f633f5ff) SHA1(b647bebfd8a2093b0b0b7587f7c816aade796b26) ) /* U2 */
@@ -1535,7 +1538,7 @@ ROM_END
 
 ROM_START( pignewta )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for code */
-/*	ROM_LOAD( "cpu.u25",    0x0000, 0x0800, NO_DUMP )    U25    why was it NO_DUMP not BAD_DUMP? */
+/*  ROM_LOAD( "cpu.u25",    0x0000, 0x0800, NO_DUMP )    U25    why was it NO_DUMP not BAD_DUMP? */
 	ROM_LOAD( "cpu.u25",    0x0000, 0x0800, BAD_DUMP CRC(eccc814d) SHA1(d999d7d433bde5d7773cd7afaf3e673089ba2544)) /* U25 */
 	ROM_LOAD( "1888a",      0x0800, 0x0800, CRC(491c0835) SHA1(65c917ebcfa8e5199e9923c04626c067fda3c637) ) /* U1 */
 	ROM_LOAD( "1889a",      0x1000, 0x0800, CRC(0dcf0af2) SHA1(788c24c87f44f9206c994286c7ba093d365f056f) ) /* U2 */
@@ -1563,8 +1566,8 @@ ROM_START( pignewta )
 
 	ROM_REGION( 0x4000, REGION_USER1, 0 )		      /* background charmaps */
 	/* NOTE: No background ROMs for set A have been dumped, so the
-	ROMs from set C have been copied and renamed. This is to
-	provide a reminder that these ROMs still need to be dumped. */
+    ROMs from set C have been copied and renamed. This is to
+    provide a reminder that these ROMs still need to be dumped. */
 	ROM_LOAD( "1906a.bg",  0x0000, 0x1000, BAD_DUMP CRC(c79d33ce) SHA1(8a5332a801d0db6e5f33c0d39d165819f9914e65)  ) /* ??? */
 	ROM_LOAD( "1907a.bg",  0x1000, 0x1000, BAD_DUMP CRC(bc839d3c) SHA1(80b1c96cac7c51e49ca40a1c5fbc156b12529d2f)  ) /* ??? */
 	ROM_LOAD( "1908a.bg",  0x2000, 0x1000, BAD_DUMP CRC(92cb14da) SHA1(257db7bb2758d579bcf171cda410acff1877122c)  ) /* ??? */
@@ -1600,7 +1603,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver initialization
+ *  Driver initialization
  *
  *************************************/
 
@@ -1634,7 +1637,7 @@ static DRIVER_INIT( monster2 )
 {
 
 	/* This game uses an encrypted CPU */
-/*	monster2_decode(); */
+/*  monster2_decode(); */
 	spatter_decode();
 
 	/* This game uses the 315-0082 security chip */
@@ -1680,7 +1683,7 @@ static DRIVER_INIT( sindbadm )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
