@@ -44,6 +44,8 @@ This info came from http://www.ne.jp/asahi/cc-sakura/akkun/old/fryski.html
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
 
 extern UINT8 *seicross_row_scroll;
 
@@ -150,11 +152,13 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x04, 0x04) AM_READ(AY8910_read_port_0_r)
 	AM_RANGE(0x0c, 0x0c) AM_READ(AY8910_read_port_0_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x08, 0x08) AM_WRITE(AY8910_control_port_0_w)
@@ -426,19 +430,10 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 static struct AY8910interface ay8910_interface =
 {
-	1,	/* 1 chip */
-	1536000,	/* 1.536 MHz ?? */
-	{ 25 },
-	{ 0 },
-	{ friskyt_portB_r },
-	{ 0 },
-	{ friskyt_portB_w }
-};
-
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 25 }
+	0,
+	friskyt_portB_r,
+	0,
+	friskyt_portB_w
 };
 
 
@@ -472,8 +467,14 @@ static MACHINE_DRIVER_START( nvram )
 	MDRV_VIDEO_UPDATE(seicross)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1536000)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
