@@ -1,33 +1,33 @@
 /***************************************************************************
 
-						  -= Newer Seta Hardware =-
+                          -= Newer Seta Hardware =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
-CPU    :	TMP68301*
+CPU    :    TMP68301*
 
-Custom :	X1-010				Sound: 8 Bit PCM
-			DX-101				Sprites
-			DX-102 x3
+Custom :    X1-010              Sound: 8 Bit PCM
+            DX-101              Sprites
+            DX-102 x3
 
-OSC:	50.0000MHz
+OSC:    50.0000MHz
         32.5304MHz
 
-*	The Toshiba TMP68301 is a 68HC000 + serial I/O, parallel I/O,
-	3 timers, address decoder, wait generator, interrupt controller,
-	all integrated in a single chip.
+*   The Toshiba TMP68301 is a 68HC000 + serial I/O, parallel I/O,
+    3 timers, address decoder, wait generator, interrupt controller,
+    all integrated in a single chip.
 
 -------------------------------------------------------------------------------------------
-Ordered by Board		Year	Game									By
+Ordered by Board        Year    Game                                    By
 -------------------------------------------------------------------------------------------
-P-FG01-1				1995	Guardians / Denjin Makai II				Banpresto
-PO-113A					1994	Mobile Suit Gundam EX Revue				Banpresto
-P0-123A					1996	Wakakusamonogatari Mahjong Yonshimai	Maboroshi Ware
-P0-125A ; KE (Namco)	1996	Kosodate Quiz My Angel					Namco
-P0-136A ; KL (Namco)	1997	Kosodate Quiz My Angel 2				Namco
-P0-142A					1999	Puzzle De Bowling						Nihon System / Moss
-P0-142A + extra parts	2000	Penguin Brothers						Subsino
+P-FG01-1                1995    Guardians / Denjin Makai II             Banpresto
+PO-113A                 1994    Mobile Suit Gundam EX Revue             Banpresto
+P0-123A                 1996    Wakakusamonogatari Mahjong Yonshimai    Maboroshi Ware
+P0-125A ; KE (Namco)    1996    Kosodate Quiz My Angel                  Namco
+P0-136A ; KL (Namco)    1997    Kosodate Quiz My Angel 2                Namco
+P0-142A                 1999    Puzzle De Bowling                       Nihon System / Moss
+P0-142A + extra parts   2000    Penguin Brothers                        Subsino
 -------------------------------------------------------------------------------------------
 
 TODO:
@@ -144,21 +144,21 @@ Notes:
 
 /***************************************************************************
 
-							Penguin Brothers (Japan)
+                            Penguin Brothers (Japan)
 
 (c)2000 Subsino
-Board:	P0-142A
-CPU:	TMP68301 (68000 core)
+Board:  P0-142A
+CPU:    TMP68301 (68000 core)
 
-OSC:	50.0000MHz
+OSC:    50.0000MHz
         32.5304MHz
         28.0000MHz
 
-Chips.:	DX-101
+Chips.: DX-101
         DX-102 x3
-Sound:	X1-010
+Sound:  X1-010
 
-Notes:	pzlbowl PCB with extra parts:
+Notes:  pzlbowl PCB with extra parts:
         28MHz OSC
         2x 62256 SRAM
         74HC00
@@ -169,12 +169,13 @@ Notes:	pzlbowl PCB with extra parts:
 #include "vidhrdw/generic.h"
 #include "machine/tmp68301.h"
 #include "machine/eeprom.h"
+#include "sound/x1_010.h"
 #include "seta.h"
 
 /***************************************************************************
 
 
-							Memory Maps - Main CPU
+                            Memory Maps - Main CPU
 
 
 ***************************************************************************/
@@ -196,7 +197,7 @@ WRITE16_HANDLER( seta2_sound_bank_w )
 
 
 /***************************************************************************
-								Guardians
+                                Guardians
 ***************************************************************************/
 
 static WRITE16_HANDLER( grdians_lockout_w )
@@ -207,7 +208,7 @@ static WRITE16_HANDLER( grdians_lockout_w )
 		coin_counter_w(0,data & 0x01);	/* or 0x04 */
 		coin_counter_w(1,data & 0x02);	/* or 0x08 */
 	}
-/*	usrintf_showmessage("%04X", data & 0xffff); */
+/*  usrintf_showmessage("%04X", data & 0xffff); */
 }
 
 static ADDRESS_MAP_START( grdians_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -241,7 +242,7 @@ static ADDRESS_MAP_START( grdians_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 /***************************************************************************
-						Mobile Suit Gundam EX Revue
+                        Mobile Suit Gundam EX Revue
 ***************************************************************************/
 
 static NVRAM_HANDLER(93C46_gundamex)
@@ -367,7 +368,7 @@ ADDRESS_MAP_END
 
 
 /***************************************************************************
-							Kosodate Quiz My Angel
+                            Kosodate Quiz My Angel
 ***************************************************************************/
 
 static ADDRESS_MAP_START( myangel_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -399,7 +400,7 @@ ADDRESS_MAP_END
 
 
 /***************************************************************************
-							Kosodate Quiz My Angel 2
+                            Kosodate Quiz My Angel 2
 ***************************************************************************/
 
 static ADDRESS_MAP_START( myangel2_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -431,11 +432,11 @@ ADDRESS_MAP_END
 
 
 /***************************************************************************
-								Puzzle De Bowling
+                                Puzzle De Bowling
 ***************************************************************************/
 
-/*	The game checks for a specific value read from the ROM region.
-	The offset to use is stored in RAM at address 0x20BA16 */
+/*  The game checks for a specific value read from the ROM region.
+    The offset to use is stored in RAM at address 0x20BA16 */
 READ16_HANDLER( pzlbowl_protection_r )
 {
 	UINT32 address = (program_read_word(0x20ba16) << 16) | program_read_word(0x20ba18);
@@ -486,7 +487,7 @@ ADDRESS_MAP_END
 
 
 /***************************************************************************
-							Penguin Bros
+                            Penguin Bros
 ***************************************************************************/
 
 static ADDRESS_MAP_START( penbros_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -500,7 +501,7 @@ static ADDRESS_MAP_START( penbros_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x600002, 0x600003) AM_READ(input_port_3_word_r		)	/* P2 */
 	AM_RANGE(0x600004, 0x600005) AM_READ(input_port_4_word_r		)	/* Coins */
 	AM_RANGE(0x600006, 0x600007) AM_READ(watchdog_reset16_r		)	/* Watchdog */
-/*	AM_RANGE(0x700000, 0x700001) AM_READ(pzlbowl_protection_r		)	// Protection */
+/*  AM_RANGE(0x700000, 0x700001) AM_READ(pzlbowl_protection_r       )   // Protection */
 	AM_RANGE(0xb00000, 0xb3ffff) AM_READ(MRA16_RAM					)	/* Sprites */
 	AM_RANGE(0xb40000, 0xb4ffff) AM_READ(MRA16_RAM					)	/* Palette */
 	AM_RANGE(0xa00000, 0xa03fff) AM_READ(seta_sound_word_r 		)	/* Sound */
@@ -525,12 +526,12 @@ ADDRESS_MAP_END
 
 /***************************************************************************
 
-								Input Ports
+                                Input Ports
 
 ***************************************************************************/
 
 /***************************************************************************
-						Mobile Suit Gundam EX Revue
+                        Mobile Suit Gundam EX Revue
 ***************************************************************************/
 
 INPUT_PORTS_START( gundamex )
@@ -645,7 +646,7 @@ INPUT_PORTS_START( gundamex )
 INPUT_PORTS_END
 
 /***************************************************************************
-								Guardians
+                                Guardians
 ***************************************************************************/
 
 INPUT_PORTS_START( grdians )
@@ -820,45 +821,45 @@ INPUT_PORTS_START( mj4simai )
 	PORT_BIT(  0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START_TAG("IN3")	/* $600000(0) */
-	PORT_BIT(0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("A") PORT_CODE(KEYCODE_A)
-	PORT_BIT(0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("E") PORT_CODE(KEYCODE_E)
-	PORT_BIT(0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("I") PORT_CODE(KEYCODE_I)
-	PORT_BIT(0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("M") PORT_CODE(KEYCODE_M)
-	PORT_BIT(0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Kan") PORT_CODE(KEYCODE_LCONTROL)
+	PORT_BIT(0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_A )
+	PORT_BIT(0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_E )
+	PORT_BIT(0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_I )
+	PORT_BIT(0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_M )
+	PORT_BIT(0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_KAN )
 	PORT_BIT(0x0020, IP_ACTIVE_LOW, IPT_START1  )
 	PORT_BIT(0xffc0, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START_TAG("IN4")	/* $600000(1) */
-	PORT_BIT(0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("B") PORT_CODE(KEYCODE_B)
-	PORT_BIT(0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("F") PORT_CODE(KEYCODE_F)
-	PORT_BIT(0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("J") PORT_CODE(KEYCODE_J)
-	PORT_BIT(0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("N") PORT_CODE(KEYCODE_N)
-	PORT_BIT(0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Reach") PORT_CODE(KEYCODE_LSHIFT)
-	PORT_BIT(0x0020, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Bet") PORT_CODE(KEYCODE_2)
+	PORT_BIT(0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_B )
+	PORT_BIT(0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_F )
+	PORT_BIT(0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_J )
+	PORT_BIT(0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_N )
+	PORT_BIT(0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_REACH )
+	PORT_BIT(0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_BET )
 	PORT_BIT(0xffc0, IP_ACTIVE_LOW, IPT_UNKNOWN)
 
 	PORT_START_TAG("IN5")	/* $600000(2) */
-	PORT_BIT(0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("C") PORT_CODE(KEYCODE_C)
-	PORT_BIT(0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("G") PORT_CODE(KEYCODE_G)
-	PORT_BIT(0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("K") PORT_CODE(KEYCODE_K)
-	PORT_BIT(0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Chi") PORT_CODE(KEYCODE_SPACE)
-	PORT_BIT(0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Ron") PORT_CODE(KEYCODE_Z)
+	PORT_BIT(0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_C )
+	PORT_BIT(0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_G )
+	PORT_BIT(0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_K )
+	PORT_BIT(0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_CHI )
+	PORT_BIT(0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_RON )
 	PORT_BIT( 0xffe0, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START_TAG("IN6")	/* $600000(3) */
-	PORT_BIT(0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("D") PORT_CODE(KEYCODE_D)
-	PORT_BIT(0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("H") PORT_CODE(KEYCODE_H)
-	PORT_BIT(0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("L") PORT_CODE(KEYCODE_L)
-	PORT_BIT(0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Pon") PORT_CODE(KEYCODE_LALT)
+	PORT_BIT(0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_D )
+	PORT_BIT(0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_H )
+	PORT_BIT(0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_K )
+	PORT_BIT(0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_PON )
 	PORT_BIT( 0xfff0, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START_TAG("IN7")	/* $600000(4) */
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Last") PORT_CODE(KEYCODE_RALT)
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Take") PORT_CODE(KEYCODE_RCONTROL)
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Double") PORT_CODE(KEYCODE_RSHIFT)
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Flip") PORT_CODE(KEYCODE_X)
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Big") PORT_CODE(KEYCODE_ENTER)
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Small") PORT_CODE(KEYCODE_BACKSPACE)
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_LAST_CHANCE )
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_SCORE )
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_DOUBLE_UP )
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_FLIP_FLOP )
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_BIG )
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_SMALL )
 	PORT_BIT(  0x00c0, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_BIT(  0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -866,7 +867,7 @@ INPUT_PORTS_END
 
 
 /***************************************************************************
-							Kosodate Quiz My Angel
+                            Kosodate Quiz My Angel
 ***************************************************************************/
 
 INPUT_PORTS_START( myangel )
@@ -967,7 +968,7 @@ INPUT_PORTS_END
 
 
 /***************************************************************************
-							Kosodate Quiz My Angel 2
+                            Kosodate Quiz My Angel 2
 ***************************************************************************/
 
 INPUT_PORTS_START( myangel2 )
@@ -1068,7 +1069,7 @@ INPUT_PORTS_END
 
 
 /***************************************************************************
-								Puzzle De Bowling
+                                Puzzle De Bowling
 ***************************************************************************/
 
 INPUT_PORTS_START( pzlbowl )
@@ -1083,16 +1084,16 @@ INPUT_PORTS_START( pzlbowl )
 	PORT_DIPNAME( 0x0038, 0x0038, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(      0x0030, DEF_STR( Easy ) )
 	PORT_DIPSETTING(      0x0038, DEF_STR( Normal ) )
-/*	PORT_DIPSETTING(      0x0028, DEF_STR( Normal ) ) */
-/*	PORT_DIPSETTING(      0x0020, DEF_STR( Normal ) ) */
-/*	PORT_DIPSETTING(      0x0018, DEF_STR( Normal ) ) */
-/*	PORT_DIPSETTING(      0x0010, DEF_STR( Normal ) ) */
-/*	PORT_DIPSETTING(      0x0008, DEF_STR( Normal ) ) */
+/*  PORT_DIPSETTING(      0x0028, DEF_STR( Normal ) ) */
+/*  PORT_DIPSETTING(      0x0020, DEF_STR( Normal ) ) */
+/*  PORT_DIPSETTING(      0x0018, DEF_STR( Normal ) ) */
+/*  PORT_DIPSETTING(      0x0010, DEF_STR( Normal ) ) */
+/*  PORT_DIPSETTING(      0x0008, DEF_STR( Normal ) ) */
 	PORT_DIPSETTING(      0x0000, DEF_STR( Hard ) )
 	PORT_DIPNAME( 0x00c0, 0x00c0, "Winning Rounds (Player VS Player)" )
 	PORT_DIPSETTING(      0x0040, "1" )
 	PORT_DIPSETTING(      0x00c0, "2" )
-/*	PORT_DIPSETTING(      0x0000, "2" ) */
+/*  PORT_DIPSETTING(      0x0000, "2" ) */
 	PORT_DIPSETTING(      0x0080, "3" )
 
 	PORT_BIT(     0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -1102,13 +1103,13 @@ INPUT_PORTS_START( pzlbowl )
 	PORT_DIPSETTING(      0x0005, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(      0x0008, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(      0x0004, DEF_STR( 3C_2C ) )
-/*	PORT_DIPSETTING(      0x0002, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(      0x0002, DEF_STR( 1C_1C ) ) */
 	PORT_DIPSETTING(      0x000f, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(      0x0003, DEF_STR( 3C_4C ) )
 	PORT_DIPSETTING(      0x0007, DEF_STR( 2C_3C ) )
 	PORT_DIPSETTING(      0x000e, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(      0x0006, DEF_STR( 2C_5C ) )
-/*	PORT_DIPSETTING(      0x000d, DEF_STR( 1C_3C ) ) */
+/*  PORT_DIPSETTING(      0x000d, DEF_STR( 1C_3C ) ) */
 	PORT_DIPSETTING(      0x0001, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(      0x000c, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(      0x000b, DEF_STR( 1C_5C ) )
@@ -1169,7 +1170,7 @@ INPUT_PORTS_END
 
 
 /***************************************************************************
-							Penguin Bros
+                            Penguin Bros
 ***************************************************************************/
 
 INPUT_PORTS_START( penbros )
@@ -1262,7 +1263,7 @@ INPUT_PORTS_END
 /***************************************************************************
 
 
-							Graphics Layouts
+                            Graphics Layouts
 
 
 ***************************************************************************/
@@ -1342,8 +1343,8 @@ static struct GfxLayout layout_2bpp_hi =
 	8*8*2
 };
 
-/*	Tiles are 8bpp, but the hardware is additionally able to discard
-	some bitplanes and use the low 4 bits only, or the high 4 bits only	*/
+/*  Tiles are 8bpp, but the hardware is additionally able to discard
+    some bitplanes and use the low 4 bits only, or the high 4 bits only */
 static struct GfxDecodeInfo gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_4bpp_lo, 0, 0x8000/16 },
@@ -1358,7 +1359,7 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /***************************************************************************
 
-								Machine Drivers
+                                Machine Drivers
 
 ***************************************************************************/
 
@@ -1373,10 +1374,8 @@ static INTERRUPT_GEN( seta2_interrupt )
 	}
 }
 
-static struct x1_010_interface x1_010_sound_intf_16MHz =
+static struct x1_010_interface x1_010_sound_intf =
 {
-	50000000/3,	/* clock */
-	YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT),	/* volume */
 	0x0000,		/* address */
 };
 
@@ -1405,8 +1404,12 @@ static MACHINE_DRIVER_START( mj4simai )
 	MDRV_VIDEO_EOF(seta2)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(X1_010, x1_010_sound_intf_16MHz)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(X1_010, 50000000/3)
+	MDRV_SOUND_CONFIG(x1_010_sound_intf)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( gundamex )
@@ -1488,7 +1491,7 @@ MACHINE_DRIVER_END
 
 /***************************************************************************
 
-								ROMs Loading
+                                ROMs Loading
 
 ***************************************************************************/
 
