@@ -78,6 +78,8 @@ lev 7 : 0x7c : 0000 11d0 - just rte
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 data16_t *shadfrce_fgvideoram, *shadfrce_bg0videoram,  *shadfrce_bg1videoram,   *shadfrce_spvideoram;
 /* data16_t *shadfrce_videoregs; */
@@ -104,79 +106,79 @@ WRITE16_HANDLER( shadfrce_flip_screen )
 
 /* Ports mapping :
 
-	$1d0020.w : 0123456789ABCDEF
-	            x---------------	right     (player 1)
-	            -x--------------	left      (player 1)
-	            --x-------------	up        (player 1)
-	            ---x------------	down      (player 1)
-	            ----x-----------	button 1  (player 1)
-	            -----x----------	button 2  (player 1)
-	            ------x---------	button 3  (player 1)
-	            -------x--------	start     (player 1)
-	            --------x-------	coin 1
-	            ---------x------	coin 2                       *
-	            ----------x-----	service 1                    *
-	            -----------x----	unused
-	            ------------x---	DIP2-7
-	            -------------x--	DIP2-8
-	            --------------x-	unused
-	            ---------------x	unused
+    $1d0020.w : 0123456789ABCDEF
+                x---------------    right     (player 1)
+                -x--------------    left      (player 1)
+                --x-------------    up        (player 1)
+                ---x------------    down      (player 1)
+                ----x-----------    button 1  (player 1)
+                -----x----------    button 2  (player 1)
+                ------x---------    button 3  (player 1)
+                -------x--------    start     (player 1)
+                --------x-------    coin 1
+                ---------x------    coin 2                       *
+                ----------x-----    service 1                    *
+                -----------x----    unused
+                ------------x---    DIP2-7
+                -------------x--    DIP2-8
+                --------------x-    unused
+                ---------------x    unused
 
-	$1d0022.w : 0123456789ABCDEF
-	            x---------------	right     (player 2)
-	            -x--------------	left      (player 2)
-	            --x-------------	up        (player 2)
-	            ---x------------	down      (player 2)
-	            ----x-----------	button 1  (player 2)
-	            -----x----------	button 2  (player 2)
-	            ------x---------	button 3  (player 2)
-	            -------x--------	start     (player 2)
-	            --------x-------	DIP2-1    ("Difficulty")
-	            ---------x------	DIP2-2    ("Difficulty")
-	            ----------x-----	DIP2-3    ("Stage Clear Energy Regain")
-	            -----------x----	DIP2-4    ("Stage Clear Energy Regain")
-	            ------------x---	DIP2-5
-	            -------------x--	DIP2-6
-	            --------------x-	unused
-	            ---------------x	unused
+    $1d0022.w : 0123456789ABCDEF
+                x---------------    right     (player 2)
+                -x--------------    left      (player 2)
+                --x-------------    up        (player 2)
+                ---x------------    down      (player 2)
+                ----x-----------    button 1  (player 2)
+                -----x----------    button 2  (player 2)
+                ------x---------    button 3  (player 2)
+                -------x--------    start     (player 2)
+                --------x-------    DIP2-1    ("Difficulty")
+                ---------x------    DIP2-2    ("Difficulty")
+                ----------x-----    DIP2-3    ("Stage Clear Energy Regain")
+                -----------x----    DIP2-4    ("Stage Clear Energy Regain")
+                ------------x---    DIP2-5
+                -------------x--    DIP2-6
+                --------------x-    unused
+                ---------------x    unused
 
-	$1d0024.w : 0123456789ABCDEF
-	            x---------------	button 4  (player 1)
-	            -x--------------	button 5  (player 1)
-	            --x-------------	button 6  (player 1)
-	            ---x------------	button 4  (player 2)
-	            ----x-----------	button 5  (player 2)
-	            -----x----------	button 6  (player 2)
-	            ------x---------	unused
-	            -------x--------	unused
-	            --------x-------	DIP1-1
-	            ---------x------	DIP1-2    ("Coin(s) for Credit(s)")
-	            ----------x-----	DIP1-3    ("Coin(s) for Credit(s)")
-	            -----------x----	DIP1-4    (DEF_STR( Continue_Price ))
-	            ------------x---	DIP1-5    ("Free Play")
-	            -------------x--	DIP1-6    ("Flip Screen")
-	            --------------x-	unused
-	            ---------------x	unused
+    $1d0024.w : 0123456789ABCDEF
+                x---------------    button 4  (player 1)
+                -x--------------    button 5  (player 1)
+                --x-------------    button 6  (player 1)
+                ---x------------    button 4  (player 2)
+                ----x-----------    button 5  (player 2)
+                -----x----------    button 6  (player 2)
+                ------x---------    unused
+                -------x--------    unused
+                --------x-------    DIP1-1
+                ---------x------    DIP1-2    ("Coin(s) for Credit(s)")
+                ----------x-----    DIP1-3    ("Coin(s) for Credit(s)")
+                -----------x----    DIP1-4    (DEF_STR( Continue_Price ))
+                ------------x---    DIP1-5    ("Free Play")
+                -------------x--    DIP1-6    ("Flip Screen")
+                --------------x-    unused
+                ---------------x    unused
 
-	$1d0026.w : 0123456789ABCDEF
-	            x---------------	unused
-	            -x--------------	unused
-	            --x-------------	unused
-	            ---x------------	unused
-	            ----x-----------	unused
-	            -----x----------	unused
-	            ------x---------	unused
-	            -------x--------	unused
-	            --------x-------	DIP 1-7   ("Demo Sound")
-	            ---------x------	DIP 1-8   ("Test Mode")
-	            ----------x-----	vblank?
-	            -----------x----	unused
-	            ------------x---	unused
-	            -------------x--	unused
-	            --------------x-	unused
-	            ---------------x	unused
+    $1d0026.w : 0123456789ABCDEF
+                x---------------    unused
+                -x--------------    unused
+                --x-------------    unused
+                ---x------------    unused
+                ----x-----------    unused
+                -----x----------    unused
+                ------x---------    unused
+                -------x--------    unused
+                --------x-------    DIP 1-7   ("Demo Sound")
+                ---------x------    DIP 1-8   ("Test Mode")
+                ----------x-----    vblank?
+                -----------x----    unused
+                ------------x---    unused
+                -------------x--    unused
+                --------------x-    unused
+                ---------------x    unused
 
-	* only available when you are in "test mode"
+    * only available when you are in "test mode"
 
 */
 
@@ -259,7 +261,7 @@ static ADDRESS_MAP_START( shadfrce_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x142000, 0x143fff) AM_WRITE(MWA16_RAM) AM_BASE(&shadfrce_spvideoram) AM_SIZE(&spriteram_size) /* sprites */
 	AM_RANGE(0x180000, 0x187fff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16) /* ?? */
 	/* probably video registers etc. */
-/*	AM_RANGE(0x1c0000, 0x1d000d) AM_WRITE(MWA16_RAM) AM_BASE(&shadfrce_videoregs) */
+/*  AM_RANGE(0x1c0000, 0x1d000d) AM_WRITE(MWA16_RAM) AM_BASE(&shadfrce_videoregs) */
 	AM_RANGE(0x1c0000, 0x1c0001) AM_WRITE(shadfrce_bg0scrollx_w) /* SCROLL X */
 	AM_RANGE(0x1c0002, 0x1c0003) AM_WRITE(shadfrce_bg0scrolly_w) /* SCROLL Y */
 	AM_RANGE(0x1c0004, 0x1c0005) AM_WRITE(shadfrce_bg1scrollx_w) /* SCROLL X */
@@ -539,18 +541,7 @@ static void irq_handler(int irq)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	3579545,	/* Guess */
-	{ YM3012_VOL(50,MIXER_PAN_LEFT,50,MIXER_PAN_RIGHT) },
-	{ irq_handler }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,				/* 1 chip */
-	{ 12000 },			/* fixed */
-	{ REGION_SOUND1 },	/* memory region */
-	{ 50 }
+	irq_handler
 };
 
 static INTERRUPT_GEN( shadfrce_interrupt ) {
@@ -567,7 +558,7 @@ static MACHINE_DRIVER_START( shadfrce )
 	MDRV_CPU_VBLANK_INT(shadfrce_interrupt,2)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 
 
@@ -586,9 +577,17 @@ static MACHINE_DRIVER_START( shadfrce )
 	MDRV_VIDEO_UPDATE(shadfrce)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(1, "right", 0.50)
+
+	MDRV_SOUND_ADD(OKIM6295, 12000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
 MACHINE_DRIVER_END
 
 /* Rom Defs. */
