@@ -1,18 +1,18 @@
 /***************************************************************************
 
-	Atari Shuuz hardware
+    Atari Shuuz hardware
 
-	driver by Aaron Giles
+    driver by Aaron Giles
 
-	Games supported:
-		* Shuuz (1990) [2 sets]
+    Games supported:
+        * Shuuz (1990) [2 sets]
 
-	Known bugs:
-		* none at this time
+    Known bugs:
+        * none at this time
 
 ****************************************************************************
 
-	Memory map (TBA)
+    Memory map (TBA)
 
 ***************************************************************************/
 
@@ -20,12 +20,13 @@
 #include "driver.h"
 #include "machine/atarigen.h"
 #include "shuuz.h"
+#include "sound/okim6295.h"
 
 
 
 /*************************************
  *
- *	Interrupt handling
+ *  Interrupt handling
  *
  *************************************/
 
@@ -46,7 +47,7 @@ static void update_interrupts(void)
 
 /*************************************
  *
- *	Initialization
+ *  Initialization
  *
  *************************************/
 
@@ -66,7 +67,7 @@ static WRITE16_HANDLER( latch_w )
 
 /*************************************
  *
- *	LETA I/O
+ *  LETA I/O
  *
  *************************************/
 
@@ -94,7 +95,7 @@ static READ16_HANDLER( leta_r )
 
 /*************************************
  *
- *	MSM5295 I/O
+ *  MSM5295 I/O
  *
  *************************************/
 
@@ -114,7 +115,7 @@ static WRITE16_HANDLER( adpcm_w )
 
 /*************************************
  *
- *	Additional I/O
+ *  Additional I/O
  *
  *************************************/
 
@@ -132,7 +133,7 @@ static READ16_HANDLER( special_port0_r )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -173,7 +174,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -240,7 +241,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -267,23 +268,7 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Sound definitions
- *
- *************************************/
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,
-	{ ATARI_CLOCK_14MHz/16/132 },
-	{ REGION_SOUND1 },
-	{ 100 }
-};
-
-
-
-/*************************************
- *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -295,7 +280,7 @@ static MACHINE_DRIVER_START( shuuz )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	
+
 	MDRV_MACHINE_INIT(shuuz)
 	MDRV_NVRAM_HANDLER(atarigen)
 
@@ -310,14 +295,18 @@ static MACHINE_DRIVER_START( shuuz )
 	MDRV_VIDEO_UPDATE(shuuz)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, ATARI_CLOCK_14MHz/16/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definition(s)
+ *  ROM definition(s)
  *
  *************************************/
 
@@ -378,7 +367,7 @@ ROM_END
 
 /*************************************
  *
- *	Driver init
+ *  Driver init
  *
  *************************************/
 
@@ -391,7 +380,7 @@ static DRIVER_INIT( shuuz )
 
 /*************************************
  *
- *	Game driver(s)
+ *  Game driver(s)
  *
  *************************************/
 
