@@ -17,6 +17,8 @@ i8751 protection simluation and other fixes by Bryan McPhail, 15/10/00.
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/2203intf.h"
+#include "sound/3812intf.h"
 
 /* from vidhrdw */
 PALETTE_INIT( sidepckt );
@@ -283,23 +285,9 @@ static void irqhandler(int linestate)
 	cpunum_set_input_line(1,0,linestate);
 }
 
-static struct YM2203interface ym2203_interface =
-{
-    1,      /* 1 chip */
-    1500000,        /* 1.5 MHz */
-    { YM2203_VOL(25,25) },
-    { 0 },
-    { 0 },
-    { 0 },
-    { 0 }
-};
-
 static struct YM3526interface ym3526_interface =
 {
-	1,			/* 1 chip */
-	3000000,	/* 3 MHz */
-	{ 100 },		/* volume */
-	{ irqhandler},
+	irqhandler
 };
 
 
@@ -312,7 +300,7 @@ static MACHINE_DRIVER_START( sidepckt )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(M6502, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)        /* 1.5 MHz */
+	/* audio CPU */        /* 1.5 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 								/* NMIs are triggered by the main cpu */
 	MDRV_FRAMES_PER_SECOND(58)
@@ -330,8 +318,14 @@ static MACHINE_DRIVER_START( sidepckt )
 	MDRV_VIDEO_UPDATE(sidepckt)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM3526, ym3526_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(YM3526, 3000000)
+	MDRV_SOUND_CONFIG(ym3526_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -343,7 +337,7 @@ static MACHINE_DRIVER_START( sidepctj )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(M6502, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)        /* 1.5 MHz */
+	/* audio CPU */        /* 1.5 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 								/* NMIs are triggered by the main cpu */
 	MDRV_FRAMES_PER_SECOND(58)
@@ -361,8 +355,14 @@ static MACHINE_DRIVER_START( sidepctj )
 	MDRV_VIDEO_UPDATE(sidepckt)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM3526, ym3526_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(YM3526, 3000000)
+	MDRV_SOUND_CONFIG(ym3526_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /***************************************************************************
