@@ -1,4 +1,6 @@
 #include "driver.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 /* The Legend of Silk Road - Unico 1999 */
 
@@ -42,59 +44,59 @@ DIPs   : 8 position (x2)
 Typed from sheet supplied with PCB (* = Default)
 
 DIP SWA
-			1	2	3	4	5	6	7	8
+            1   2   3   4   5   6   7   8
 --------------------------------------------------------------------------------------
-Lives		1	OFF
-		2*	ON
+Lives       1   OFF
+        2*  ON
 
-Special		OFF		OFF
-Effect		ON*		ON
+Special     OFF     OFF
+Effect      ON*     ON
 
-Position 3-5	Not used		OFF	OFF	OFF
+Position 3-5    Not used        OFF OFF OFF
 
-Difficulty	1						OFF	OFF	ON
-		2						ON	OFF	ON
-		3						OFF	ON	ON
-		4*						ON	ON	ON
-		5						OFF	OFF	OFF
-		6						ON	OFF	OFF
-		7						OFF	ON	OFF
-		8						ON	ON	OFF
+Difficulty  1                       OFF OFF ON
+        2                       ON  OFF ON
+        3                       OFF ON  ON
+        4*                      ON  ON  ON
+        5                       OFF OFF OFF
+        6                       ON  OFF OFF
+        7                       OFF ON  OFF
+        8                       ON  ON  OFF
 --------------------------------------------------------------------------------------
 
 
 DIP SWB
-			1	2	3	4	5	6	7	8
+            1   2   3   4   5   6   7   8
 --------------------------------------------------------------------------------------
 Position 1    Not Used  OFF
 
-Freeplay	No*		OFF
-		Yes		ON
+Freeplay    No*     OFF
+        Yes     ON
 
-Position 3	Not Used		OFF
+Position 3  Not Used        OFF
 
-Demo Sound	No				OFF
-		Yes*				ON
+Demo Sound  No              OFF
+        Yes*                ON
 
-Chute Type	Single*					OFF
-		Multi					ON
+Chute Type  Single*                 OFF
+        Multi                   ON
 
-Coin/Credit	1 Coin 1 Credit*				OFF	OFF	OFF
-		1 Coin 2 Credit					ON	OFF	OFF
-		1 Coin 3 Credit					OFF	ON	OFF
-		1 Coin 4 Credit					ON	ON	OFF
-		2 Coin 1 Credit					OFF	OFF	ON
-		3 Coin 1 Credit					ON	OFF	ON
-		4 Coin 1 Credit					OFF	ON	ON
-		5 Coin 1 Credit					ON	ON	ON
+Coin/Credit 1 Coin 1 Credit*                OFF OFF OFF
+        1 Coin 2 Credit                 ON  OFF OFF
+        1 Coin 3 Credit                 OFF ON  OFF
+        1 Coin 4 Credit                 ON  ON  OFF
+        2 Coin 1 Credit                 OFF OFF ON
+        3 Coin 1 Credit                 ON  OFF ON
+        4 Coin 1 Credit                 OFF ON  ON
+        5 Coin 1 Credit                 ON  ON  ON
 --------------------------------------------------------------------------------------
 
 ROMs:
-ROM00.BIN	32 pin 4M Mask, read as 27C4001			OKI Samples
-ROM01.BIN	MX27C2000					Sound Program
+ROM00.BIN   32 pin 4M Mask, read as 27C4001         OKI Samples
+ROM01.BIN   MX27C2000                   Sound Program
 
-ROM02.BIN	42 pin 8M Mask, read as uPD27C8000        \
-ROM03.BIN	42 pin 8M Mask, read as uPD27C8000        /	Main Program
+ROM02.BIN   42 pin 8M Mask, read as uPD27C8000        \
+ROM03.BIN   42 pin 8M Mask, read as uPD27C8000        / Main Program
 
 ROM04.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM \
 ROM05.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |
@@ -102,7 +104,7 @@ ROM06.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |
 ROM07.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |
 ROM08.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |
 ROM09.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |
-ROM10.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |	GFX
+ROM10.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |    GFX
 ROM11.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |
 ROM12.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |
 ROM13.BIN       MX29F1610, SOP44 Surface Mounted Mask ROM  |
@@ -250,17 +252,17 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 32 )
 
 	/* C00038 appears to be the coin counter, bit 0 is pulsed when a coin is inserted */
 /*
-	AM_RANGE(0xC00034, 0xC00037) AM_WRITE(MWA32_NOP)
+    AM_RANGE(0xC00034, 0xC00037) AM_WRITE(MWA32_NOP)
 */
 
 	AM_RANGE(0xC0010c, 0xC00123) AM_WRITE(MWA32_RAM) AM_BASE(&silkroad_regs)
 /*
-	AM_RANGE(0xC0010C, 0xC0010f) AM_WRITE(MWA32_NOP) // 0
-	AM_RANGE(0xC00110, 0xC00113) AM_WRITE(MWA32_NOP) // 1
-	AM_RANGE(0xC00114, 0xC00117) AM_WRITE(MWA32_NOP) // 2
+    AM_RANGE(0xC0010C, 0xC0010f) AM_WRITE(MWA32_NOP) // 0
+    AM_RANGE(0xC00110, 0xC00113) AM_WRITE(MWA32_NOP) // 1
+    AM_RANGE(0xC00114, 0xC00117) AM_WRITE(MWA32_NOP) // 2
 
-	AM_RANGE(0xC0011c, 0xC0011f) AM_WRITE(MWA32_NOP) // 4
-	AM_RANGE(0xC00120, 0xC00123) AM_WRITE(MWA32_NOP) // 5
+    AM_RANGE(0xC0011c, 0xC0011f) AM_WRITE(MWA32_NOP) // 4
+    AM_RANGE(0xC00120, 0xC00123) AM_WRITE(MWA32_NOP) // 5
 */
 	AM_RANGE(0xfe0000, 0xffffff) AM_WRITE(MWA32_RAM)
 ADDRESS_MAP_END
@@ -320,14 +322,14 @@ INPUT_PORTS_START( silkroad )
 	PORT_DIPSETTING(      0x0010, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x00e0, 0x0000, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(      0x0060, "Easiest" )				/* "1" */
-	PORT_DIPSETTING(      0x0040, "Easier" )				/* "2" */
+	PORT_DIPSETTING(      0x0060, DEF_STR( Easiest ) )			/* "1" */
+	PORT_DIPSETTING(      0x0040, DEF_STR( Easier ) )			/* "2" */
 	PORT_DIPSETTING(      0x0020, DEF_STR( Easy ) )				/* "3" */
-	PORT_DIPSETTING(      0x0000, DEF_STR( Normal ) )				/* "4" */
-	PORT_DIPSETTING(      0x00e0, DEF_STR( Medium ) )				/* "5" */
+	PORT_DIPSETTING(      0x0000, DEF_STR( Normal ) )			/* "4" */
+	PORT_DIPSETTING(      0x00e0, DEF_STR( Medium ) )			/* "5" */
 	PORT_DIPSETTING(      0x00c0, DEF_STR( Hard ) )				/* "6" */
-	PORT_DIPSETTING(      0x00a0, DEF_STR( Harder ) )				/* "7" */
-	PORT_DIPSETTING(      0x0080, DEF_STR( Hardest ) )				/* "8" */
+	PORT_DIPSETTING(      0x00a0, DEF_STR( Harder ) )			/* "7" */
+	PORT_DIPSETTING(      0x0080, DEF_STR( Hardest ) )			/* "8" */
 	PORT_DIPNAME( 0x0100, 0x0100, "Unused DIP B-0" )
 	PORT_DIPSETTING(      0x0100, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -340,9 +342,9 @@ INPUT_PORTS_START( silkroad )
 	PORT_DIPNAME( 0x0800, 0x0000, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(      0x0800, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x1000, 0x1000, "Chute Type" )			/* "Coin Box" */
-	PORT_DIPSETTING(      0x1000, DEF_STR( Single ) )				/* "1" */
-	PORT_DIPSETTING(      0x0000, "Multi" )			/* "2" */
+	PORT_DIPNAME( 0x1000, 0x1000, "Chute Type" )		    	/* "Coin Box" */
+	PORT_DIPSETTING(      0x1000, DEF_STR( Single ) )			/* "1" */
+	PORT_DIPSETTING(      0x0000, "Multi" )			            /* "2" */
 	PORT_DIPNAME( 0xe000, 0xe000, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING( 0x0000, DEF_STR(5C_1C))
 	PORT_DIPSETTING( 0x2000, DEF_STR(4C_1C))
@@ -353,9 +355,9 @@ INPUT_PORTS_START( silkroad )
 	PORT_DIPSETTING( 0xa000, DEF_STR(1C_3C))
 	PORT_DIPSETTING( 0x8000, DEF_STR(1C_4C))
 
-/*	PORT_START	   Misc inputs    */
-/*	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_SPECIAL )	   VBLANK ?    */
-/*	PORT_BIT( 0xff7f, IP_ACTIVE_LOW, IPT_UNUSED )    unknown / unused    */
+/*  PORT_START     Misc inputs    */
+/*  PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_SPECIAL )    VBLANK ?    */
+/*  PORT_BIT( 0xff7f, IP_ACTIVE_LOW, IPT_UNUSED )    unknown / unused    */
 INPUT_PORTS_END
 
 
@@ -377,21 +379,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static struct YM2151interface ym2151_interface =
-{
-	1,
-	3579545,/* unknown, fixme */
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },
-};
-
-static struct OKIM6295interface m6295_interface =
-{
-	2,  /* 2 chips */
-	{ 8000, 16000 }, /* unknown, but sounds good */
-	{ REGION_SOUND1, REGION_SOUND2 },
-	{ 45,45 }
-};
-
 static MACHINE_DRIVER_START( silkroad )
 
 	/* basic machine hardware */
@@ -413,9 +400,21 @@ static MACHINE_DRIVER_START( silkroad )
 	MDRV_VIDEO_UPDATE(silkroad)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, m6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.45)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 16000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.45)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.45)
 MACHINE_DRIVER_END
 
 
@@ -428,8 +427,8 @@ DRIVER_INIT( silkroad )
 {
 
 	/* why? rom04.bin looks like a bad dump, but it seems not since it was
-	   verified as correct... problem with the original which the gfx
-	   hardware didn't care about? */
+       verified as correct... problem with the original which the gfx
+       hardware didn't care about? */
 
 	data8_t *src = memory_region(REGION_GFX1)+0x1000000;
 	int len = 0x0200000;
