@@ -9,7 +9,7 @@ David Graves
 (this is based on the F2 driver by Bryan McPhail, Brad Oliver, Andrew Prime,
 Nicola Salmoria.)
 
-				*****
+                *****
 
 Slapshot uses one or two newer Taito custom ics, but the hardware is
 very similar to the Taito F2 system, especially F2 games using the same
@@ -37,13 +37,13 @@ Commands are written to it by the 68000 (as in the Taito F2 games).
 Slapshot custom ics
 -------------------
 
-TC0480SCP (IC61)	- known tilemap chip
-TC0640FIO (IC83)	- new version of TC0510NIO io chip?
-TC0650FDA (IC84)	- (palette?)
-TC0360PRI (IC56)	- (common in pri/color combo on F2 boards)
-TC0530SYC (IC58)	- known sound comm chip
-TC0520TBC (IC36)	- known object chip
-TC0540OBN (IC54)	- known object chip
+TC0480SCP (IC61)    - known tilemap chip
+TC0640FIO (IC83)    - new version of TC0510NIO io chip?
+TC0650FDA (IC84)    - (palette?)
+TC0360PRI (IC56)    - (common in pri/color combo on F2 boards)
+TC0530SYC (IC58)    - known sound comm chip
+TC0520TBC (IC36)    - known object chip
+TC0540OBN (IC54)    - known object chip
 
 
 TODO
@@ -124,11 +124,11 @@ ADC0809CNN - 8-bit Microprocessor Compatible A/D Converter
  DataSheet:  http://www.national.com/ds/AD/ADC0808.pdf
 
 Region byte at offset 0x031:
-	d74_21.1  0x02	World Version
-	d74_20.1  0x01	US Version
-	d74_??.1  0x00	Will Produce a Japanese Version, but it's unknown if the
-					actual sound CPU code is the same as the World version,
-					US versions or different then both.
+    d74_21.1  0x02  World Version
+    d74_20.1  0x01  US Version
+    d74_??.1  0x00  Will Produce a Japanese Version, but it's unknown if the
+                    actual sound CPU code is the same as the World version,
+                    US versions or different then both.
 ***************************************************************************/
 
 #include "driver.h"
@@ -137,6 +137,8 @@ Region byte at offset 0x031:
 #include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
+#include "sound/2610intf.h"
+#include "machine/timekpr.h"
 
 
 VIDEO_EOF( opwolf3_full_buffer_delayed );
@@ -151,7 +153,7 @@ extern size_t taito_spriteext_size;
 
 
 /******************************************************
-				COLOR
+                COLOR
 ******************************************************/
 
 static READ16_HANDLER( color_ram_word_r )
@@ -176,7 +178,7 @@ static WRITE16_HANDLER( color_ram_word_w )
 
 
 /***********************************************************
-				INTERRUPTS
+                INTERRUPTS
 ***********************************************************/
 
 void slapshot_interrupt6(int x)
@@ -193,7 +195,7 @@ static INTERRUPT_GEN( slapshot_interrupt )
 
 
 /**********************************************************
-				GAME INPUTS
+                GAME INPUTS
 **********************************************************/
 
 static READ16_HANDLER( slapshot_service_input_r )
@@ -209,19 +211,6 @@ static READ16_HANDLER( slapshot_service_input_r )
 	}
 }
 
-static READ16_HANDLER( opwolf3_service_input_r )
-{
-	switch (offset)
-	{
-		case 0x03:
-			return ((input_port_3_word_r(0,0) & 0xef) |
-				  (input_port_5_word_r(0,0) & 0x10))  << 8;	/* IN3 + service switch */
-
-		default:
-			return TC0640FIO_r(offset) << 8;
-	}
-}
-
 static READ16_HANDLER( opwolf3_adc_r )
 {
 	return readinputport(6 + offset)<<8;
@@ -234,7 +223,7 @@ static WRITE16_HANDLER( opwolf3_adc_req_w )
 }
 
 /*****************************************************
-				SOUND
+                SOUND
 *****************************************************/
 
 static int banknum = -1;
@@ -272,7 +261,7 @@ static READ16_HANDLER( slapshot_msb_sound_r )
 
 
 /***********************************************************
-			 MEMORY STRUCTURES
+             MEMORY STRUCTURES
 ***********************************************************/
 
 static ADDRESS_MAP_START( slapshot_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -283,7 +272,7 @@ static ADDRESS_MAP_START( slapshot_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x800000, 0x80ffff) AM_READ(TC0480SCP_word_r)	/* tilemaps */
 	AM_RANGE(0x830000, 0x83002f) AM_READ(TC0480SCP_ctrl_word_r)
 	AM_RANGE(0x900000, 0x907fff) AM_READ(color_ram_word_r)	/* 8bpg palette */
-	AM_RANGE(0xa00000, 0xa03fff) AM_READ(MRA16_RAM)	/* nvram (only low bytes used) */
+	AM_RANGE(0xa00000, 0xa03fff) AM_READ(timekeeper_0_msb16_r)	/* nvram (only low bytes used) */
 	AM_RANGE(0xc00000, 0xc0000f) AM_READ(TC0640FIO_halfword_byteswap_r)
 	AM_RANGE(0xc00020, 0xc0002f) AM_READ(slapshot_service_input_r)	/* service mirror */
 	AM_RANGE(0xd00000, 0xd00003) AM_READ(slapshot_msb_sound_r)
@@ -297,7 +286,7 @@ static ADDRESS_MAP_START( slapshot_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x800000, 0x80ffff) AM_WRITE(TC0480SCP_word_w)	  /* tilemaps */
 	AM_RANGE(0x830000, 0x83002f) AM_WRITE(TC0480SCP_ctrl_word_w)
 	AM_RANGE(0x900000, 0x907fff) AM_WRITE(color_ram_word_w) AM_BASE(&color_ram)
-	AM_RANGE(0xa00000, 0xa03fff) AM_WRITE(MWA16_RAM) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0xa00000, 0xa03fff) AM_WRITE(timekeeper_0_msb16_w)
 	AM_RANGE(0xb00000, 0xb0001f) AM_WRITE(TC0360PRI_halfword_swap_w)	/* priority chip */
 	AM_RANGE(0xc00000, 0xc0000f) AM_WRITE(TC0640FIO_halfword_byteswap_w)
 	AM_RANGE(0xd00000, 0xd00003) AM_WRITE(slapshot_msb_sound_w)
@@ -311,7 +300,7 @@ static ADDRESS_MAP_START( opwolf3_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x800000, 0x80ffff) AM_READ(TC0480SCP_word_r)	/* tilemaps */
 	AM_RANGE(0x830000, 0x83002f) AM_READ(TC0480SCP_ctrl_word_r)
 	AM_RANGE(0x900000, 0x907fff) AM_READ(color_ram_word_r)	/* 8bpg palette */
-	AM_RANGE(0xa00000, 0xa03fff) AM_READ(MRA16_RAM)	/* nvram (only low bytes used) */
+	AM_RANGE(0xa00000, 0xa03fff) AM_READ(timekeeper_0_msb16_r)	/* nvram (only low bytes used) */
 	AM_RANGE(0xc00000, 0xc0000f) AM_READ(TC0640FIO_halfword_byteswap_r)
 	AM_RANGE(0xc00020, 0xc0002f) AM_READ(slapshot_service_input_r)	/* service mirror */
 	AM_RANGE(0xd00000, 0xd00003) AM_READ(slapshot_msb_sound_r)
@@ -326,7 +315,7 @@ static ADDRESS_MAP_START( opwolf3_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x800000, 0x80ffff) AM_WRITE(TC0480SCP_word_w)	  /* tilemaps */
 	AM_RANGE(0x830000, 0x83002f) AM_WRITE(TC0480SCP_ctrl_word_w)
 	AM_RANGE(0x900000, 0x907fff) AM_WRITE(color_ram_word_w) AM_BASE(&color_ram)
-	AM_RANGE(0xa00000, 0xa03fff) AM_WRITE(MWA16_RAM) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0xa00000, 0xa03fff) AM_WRITE(timekeeper_0_msb16_w)
 	AM_RANGE(0xb00000, 0xb0001f) AM_WRITE(TC0360PRI_halfword_swap_w)	/* priority chip */
 	AM_RANGE(0xc00000, 0xc0000f) AM_WRITE(TC0640FIO_halfword_byteswap_w)
 	AM_RANGE(0xd00000, 0xd00003) AM_WRITE(slapshot_msb_sound_w)
@@ -364,7 +353,7 @@ ADDRESS_MAP_END
 
 
 /***********************************************************
-			 INPUT PORTS (DIPs in nvram)
+             INPUT PORTS (DIPs in nvram)
 ***********************************************************/
 
 INPUT_PORTS_START( slapshot )
@@ -490,7 +479,7 @@ INPUT_PORTS_START( opwolf3 )
 INPUT_PORTS_END
 
 /***********************************************************
-				GFX DECODING
+                GFX DECODING
 
 ***********************************************************/
 
@@ -531,7 +520,7 @@ static struct GfxDecodeInfo slapshot_gfxdecodeinfo[] =
 
 
 /**************************************************************
-			     YM2610B (SOUND)
+                 YM2610B (SOUND)
 **************************************************************/
 
 /* handler called by the YM2610 emulator when the internal timers cause an IRQ */
@@ -542,22 +531,14 @@ static void irqhandler(int irq)
 
 static struct YM2610interface ym2610_interface =
 {
-	1,	/* 1 chip */
-	16000000/2,	/* 8 MHz ?? */
-	{ 25 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler },
-	{ REGION_SOUND2 },	/* Delta-T */
-	{ REGION_SOUND1 },	/* ADPCM */
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) }
+	irqhandler,
+	REGION_SOUND2,	/* Delta-T */
+	REGION_SOUND1	/* ADPCM */
 };
 
 
 /***********************************************************
-			     MACHINE DRIVERS
+                 MACHINE DRIVERS
 ***********************************************************/
 
 static MACHINE_DRIVER_START( slapshot )
@@ -568,14 +549,14 @@ static MACHINE_DRIVER_START( slapshot )
 	MDRV_CPU_VBLANK_INT(slapshot_interrupt,1)
 
 	MDRV_CPU_ADD(Z80,32000000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 4 MHz */
+	/* audio CPU */	/* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(z80_sound_readmem,z80_sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10)
 
-	MDRV_NVRAM_HANDLER(generic_1fill)
+	MDRV_NVRAM_HANDLER(timekeeper_0)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN)
@@ -589,8 +570,14 @@ static MACHINE_DRIVER_START( slapshot )
 	MDRV_VIDEO_UPDATE(slapshot)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2610B, ym2610_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2610B, 16000000/2)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.25)
+	MDRV_SOUND_ROUTE(0, "right", 0.25)
+	MDRV_SOUND_ROUTE(1, "left",  1.0)
+	MDRV_SOUND_ROUTE(2, "right", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( opwolf3 )
@@ -601,14 +588,14 @@ static MACHINE_DRIVER_START( opwolf3 )
 	MDRV_CPU_VBLANK_INT(slapshot_interrupt,1)
 
 	MDRV_CPU_ADD(Z80,32000000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 4 MHz */
+	/* audio CPU */	/* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(z80_sound_readmem,z80_sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10)
 
-	MDRV_NVRAM_HANDLER(generic_1fill)
+	MDRV_NVRAM_HANDLER(timekeeper_0)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN)
@@ -622,12 +609,18 @@ static MACHINE_DRIVER_START( opwolf3 )
 	MDRV_VIDEO_UPDATE(slapshot)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2610B, ym2610_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2610B, 16000000/2)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.25)
+	MDRV_SOUND_ROUTE(0, "right", 0.25)
+	MDRV_SOUND_ROUTE(1, "left",  1.0)
+	MDRV_SOUND_ROUTE(2, "right", 1.0)
 MACHINE_DRIVER_END
 
 /***************************************************************************
-					DRIVERS
+                    DRIVERS
 ***************************************************************************/
 
 ROM_START( slapshot )
@@ -654,13 +647,13 @@ ROM_START( slapshot )
 
 	/* no Delta-T samples */
 
-/*	Pals (not dumped) */
-/*	ROM_LOAD( "d71-08.40",  0x00000, 0x00???, NO_DUMP ) */
-/*	ROM_LOAD( "d71-09.57",  0x00000, 0x00???, NO_DUMP ) */
-/*	ROM_LOAD( "d71-10.60",  0x00000, 0x00???, NO_DUMP ) */
-/*	ROM_LOAD( "d71-11.42",  0x00000, 0x00???, NO_DUMP ) */
-/*	ROM_LOAD( "d71-12.59",  0x00000, 0x00???, NO_DUMP ) */
-/*	ROM_LOAD( "d71-13.8",   0x00000, 0x00???, NO_DUMP ) */
+/*  Pals (not dumped) */
+/*  ROM_LOAD( "d71-08.40",  0x00000, 0x00???, NO_DUMP ) */
+/*  ROM_LOAD( "d71-09.57",  0x00000, 0x00???, NO_DUMP ) */
+/*  ROM_LOAD( "d71-10.60",  0x00000, 0x00???, NO_DUMP ) */
+/*  ROM_LOAD( "d71-11.42",  0x00000, 0x00???, NO_DUMP ) */
+/*  ROM_LOAD( "d71-12.59",  0x00000, 0x00???, NO_DUMP ) */
+/*  ROM_LOAD( "d71-13.8",   0x00000, 0x00???, NO_DUMP ) */
 ROM_END
 
 ROM_START( opwolf3 )
@@ -725,6 +718,8 @@ static DRIVER_INIT( slapshot )
 	int size=memory_region_length(REGION_GFX2);
 	int data;
 
+	timekeeper_init( 0, TIMEKEEPER_MK48T08, NULL );
+
 	offset = size/2;
 	for (i = size/2+size/4; i<size; i++)
 	{
