@@ -1,18 +1,18 @@
 /***************************************************************************
 
-	POW - Prisoners Of War (US) 		A7008	SNK 1988
-	POW - Prisoners Of War (Japan)		A7008	SNK 1988
-	SAR - Search And Rescue (World) 	A8007	SNK 1989
-	SAR - Search And Rescue (US)		A8007	SNK 1989
-	Street Smart (US version 1) 		A8007	SNK 1989
-	Street Smart (US version 2) 		A7008	SNK 1989
-	Street Smart (World version 1) 		A8007	SNK 1989
-	Street Smart (Japan version 1)		A8007	SNK 1989
-	Ikari III - The Rescue (US) 		A7007	SNK 1989
+    POW - Prisoners Of War (US)         A7008   SNK 1988
+    POW - Prisoners Of War (Japan)      A7008   SNK 1988
+    SAR - Search And Rescue (World)     A8007   SNK 1989
+    SAR - Search And Rescue (US)        A8007   SNK 1989
+    Street Smart (US version 1)         A8007   SNK 1989
+    Street Smart (US version 2)         A7008   SNK 1989
+    Street Smart (World version 1)      A8007   SNK 1989
+    Street Smart (Japan version 1)      A8007   SNK 1989
+    Ikari III - The Rescue (US)         A7007   SNK 1989
 
-	For some strange reason version 2 of Street Smart runs on Pow hardware!
+    For some strange reason version 2 of Street Smart runs on Pow hardware!
 
-	Emulation by Bryan McPhail, mish@tendril.co.uk
+    Emulation by Bryan McPhail, mish@tendril.co.uk
 
 
 Change Log:
@@ -35,6 +35,8 @@ Notes:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/3812intf.h"
+#include "sound/upd7759.h"
 
 VIDEO_START( pow );
 VIDEO_START( searchar );
@@ -202,20 +204,22 @@ ADDRESS_MAP_END
 
 static WRITE8_HANDLER( D7759_write_port_0_w )
 {
-	UPD7759_port_w(offset,data);
-	UPD7759_start_w (0,0);
-	UPD7759_start_w (0,1);
+	upd7759_port_w(offset,data);
+	upd7759_start_w (0,0);
+	upd7759_start_w (0,1);
 }
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(YM3812_status_port_0_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM3812_control_port_0_w)
 	AM_RANGE(0x20, 0x20) AM_WRITE(YM3812_write_port_0_w)
 	AM_RANGE(0x40, 0x40) AM_WRITE(D7759_write_port_0_w)
-	AM_RANGE(0x80, 0x80) AM_WRITE(UPD7759_0_reset_w)
+	AM_RANGE(0x80, 0x80) AM_WRITE(upd7759_0_reset_w)
 ADDRESS_MAP_END
 
 /******************************************************************************/
@@ -686,19 +690,12 @@ static void irqhandler(int irq)
 
 static struct YM3812interface ym3812_interface =
 {
-	1,			/* 1 chip */
-	4000000,	/* 4 MHz - accurate for POW, should be accurate for others */
-	{ 100 },
-	{ irqhandler },
+	irqhandler
 };
 
-static struct UPD7759_interface upd7759_interface =
+static struct upd7759_interface upd7759_interface =
 {
-	1,		/* number of chips */
-	{ 50 }, /* volume */
-	{ REGION_SOUND1 },		/* memory region */
-	UPD7759_STANDALONE_MODE,		/* chip mode */
-	{0}
+	REGION_SOUND1		/* memory region */
 };
 
 /******************************************************************************/
@@ -711,7 +708,7 @@ static MACHINE_DRIVER_START( ikari3 )
 	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Accurate */
+	/* audio CPU */	/* Accurate */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 
@@ -729,8 +726,15 @@ static MACHINE_DRIVER_START( ikari3 )
 	MDRV_VIDEO_UPDATE(searchar)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(UPD7759, upd7759_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 4000000)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
+	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -742,7 +746,7 @@ static MACHINE_DRIVER_START( pow )
 	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Accurate */
+	/* audio CPU */	/* Accurate */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 
@@ -760,8 +764,15 @@ static MACHINE_DRIVER_START( pow )
 	MDRV_VIDEO_UPDATE(pow)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(UPD7759, upd7759_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 4000000)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
+	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -773,7 +784,7 @@ static MACHINE_DRIVER_START( searchar )
 	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 
@@ -791,8 +802,15 @@ static MACHINE_DRIVER_START( searchar )
 	MDRV_VIDEO_UPDATE(searchar)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(UPD7759, upd7759_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 4000000)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
+	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -804,7 +822,7 @@ static MACHINE_DRIVER_START( streetsm )
 	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Accurate */
+	/* audio CPU */	/* Accurate */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 
@@ -822,8 +840,15 @@ static MACHINE_DRIVER_START( streetsm )
 	MDRV_VIDEO_UPDATE(searchar)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(UPD7759, upd7759_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 4000000)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
+	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 /******************************************************************************/
