@@ -6,32 +6,32 @@
 Snow Bros Nick & Tom
 Toaplan, 1990
 
-	PCB Layout
-	----------
-	MIN16-02
+    PCB Layout
+    ----------
+    MIN16-02
 
-	|------------------------------------------|
-	| VOL     YM3812  6116  4464  4464         |
-	| LA4460  YM3014        4464  4464         |
-	|       458   SBROS-4.29         SBROS1.40 |
-	|   2003       Z80B     PANDORA            |
-	|J                    D41101C-1 LS07  LS32 |
-	|A SBROS-3A.5 SBROS-2A.6        LS139 LS174|
-	|M                  LS245 LS74  LS04  16MHz|
-	|M   6264     6264  F32   LS74  LS74       |
-	|A      68000       LS20  F138  LS04  12MHz|
-	|                   LS04  LS148 LS251 LS00 |
-	| LS273 LS245 LS245 LS158 LS257 LS257 LS32 |
-	|                                          |
-	| LS273  6116  6116 LS157   DSW2  DSW1     |
-	|------------------------------------------|
+    |------------------------------------------|
+    | VOL     YM3812  6116  4464  4464         |
+    | LA4460  YM3014        4464  4464         |
+    |       458   SBROS-4.29         SBROS1.40 |
+    |   2003       Z80B     PANDORA            |
+    |J                    D41101C-1 LS07  LS32 |
+    |A SBROS-3A.5 SBROS-2A.6        LS139 LS174|
+    |M                  LS245 LS74  LS04  16MHz|
+    |M   6264     6264  F32   LS74  LS74       |
+    |A      68000       LS20  F138  LS04  12MHz|
+    |                   LS04  LS148 LS251 LS00 |
+    | LS273 LS245 LS245 LS158 LS257 LS257 LS32 |
+    |                                          |
+    | LS273  6116  6116 LS157   DSW2  DSW1     |
+    |------------------------------------------|
 
-	Notes:
-	       68k clock: 8.000MHz
-	      Z80B clock: 6.000MHz
-	    YM3812 clock: 3.000MHz
-	           VSync: 57.5Hz
-	           HSync: 15.68kHz
+    Notes:
+           68k clock: 8.000MHz
+          Z80B clock: 6.000MHz
+        YM3812 clock: 3.000MHz
+               VSync: 57.5Hz
+               HSync: 15.68kHz
 
   driver by Mike Coates
 
@@ -61,19 +61,50 @@ example, the protection data for that game was extracted from the bootleg.
 #include "vidhrdw/generic.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
+#include "sound/2151intf.h"
+#include "sound/3812intf.h"
+#include "sound/okim6295.h"
 
 
 WRITE16_HANDLER( snowbros_flipscreen_w );
 VIDEO_UPDATE( snowbros );
 VIDEO_UPDATE( wintbob );
+VIDEO_UPDATE( snowbro3 );
 
 static data16_t *hyperpac_ram;
+int sb3_music_is_playing;
+int sb3_music;
 
 static INTERRUPT_GEN( snowbros_interrupt )
 {
 	cpunum_set_input_line(0, cpu_getiloops() + 2, HOLD_LINE);	/* IRQs 4, 3, and 2 */
 }
 
+static INTERRUPT_GEN( snowbro3_interrupt )
+{
+	int status = OKIM6295_status_0_r(0);
+
+	cpunum_set_input_line(0, cpu_getiloops() + 2, HOLD_LINE);	/* IRQs 4, 3, and 2 */
+
+	if (sb3_music_is_playing)
+	{
+		if ((status&0x08)==0x00)
+		{
+			OKIM6295_data_0_w(0,0x80|sb3_music);
+			OKIM6295_data_0_w(0,0x00|0x82);
+		}
+
+	}
+	else
+	{
+		if ((status&0x08)==0x08)
+		{
+			OKIM6295_data_0_w(0,0x40);		/* Stop playing music */
+		}
+	}
+
+}
+
 
 /* Sound Routines */
 
@@ -82,7 +113,7 @@ READ16_HANDLER( snowbros_68000_sound_r )
 	int ret;
 
 	/* If the sound CPU is running, read the YM3812 status, otherwise
-	   just make it pass the test */
+       just make it pass the test */
 	if (Machine->sample_rate != 0)
 	{
 		ret = soundlatch_r(offset);
@@ -148,11 +179,13 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x02, 0x02) AM_READ(YM3812_status_port_0_r)
 	AM_RANGE(0x04, 0x04) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x02, 0x02) AM_WRITE(YM3812_control_port_0_w)
 	AM_RANGE(0x03, 0x03) AM_WRITE(YM3812_write_port_0_w)
 	AM_RANGE(0x04, 0x04) AM_WRITE(soundlatch_w)	/* goes back to the main CPU, checked during boot */
@@ -181,7 +214,7 @@ static ADDRESS_MAP_START( hyperpac_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_ROM)
 	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(MWA16_RAM) AM_BASE(&hyperpac_ram)
 	AM_RANGE(0x300000, 0x300001) AM_WRITE(semicom_soundcmd_w)
-/*	AM_RANGE(0x400000, 0x400001) ??? */
+/*  AM_RANGE(0x400000, 0x400001) ??? */
 	AM_RANGE(0x600000, 0x6001ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x700000, 0x701fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size)
 
@@ -203,9 +236,144 @@ static ADDRESS_MAP_START( hyperpac_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf000, 0xf000) AM_WRITE(YM2151_register_port_0_w)
 	AM_RANGE(0xf001, 0xf001) AM_WRITE(YM2151_data_port_0_w)
 	AM_RANGE(0xf002, 0xf002) AM_WRITE(OKIM6295_data_0_w)
-/*	AM_RANGE(0xf006, 0xf006) ??? */
+/*  AM_RANGE(0xf006, 0xf006) ??? */
 ADDRESS_MAP_END
 
+/* Same volume used for all samples at the Moment, could be right, we have no
+   way of knowing .. */
+READ16_HANDLER( sb3_sound_r )
+{
+	return 0x0003;
+}
+
+void sb3_play_music(int data)
+{
+	/* sample is actually played in interrupt function so it loops */
+	sb3_music = data;
+
+	switch (data)
+	{
+		case 0x23:
+		memcpy(memory_region(REGION_SOUND1)+0x20000, memory_region(REGION_SOUND1)+0x80000, 0x20000);
+		sb3_music_is_playing = 1;
+		break;
+
+		case 0x24:
+		memcpy(memory_region(REGION_SOUND1)+0x20000, memory_region(REGION_SOUND1)+0x80000+0x20000, 0x20000);
+		sb3_music_is_playing = 1;
+		break;
+
+		case 0x25:
+		memcpy(memory_region(REGION_SOUND1)+0x20000, memory_region(REGION_SOUND1)+0x80000+0x40000, 0x20000);
+		sb3_music_is_playing = 1;
+		break;
+
+		case 0x26:
+		memcpy(memory_region(REGION_SOUND1)+0x20000, memory_region(REGION_SOUND1)+0x80000, 0x20000);
+		sb3_music_is_playing = 1;
+		break;
+
+		case 0x27:
+		case 0x28:
+		case 0x29:
+		case 0x2a:
+		case 0x2b:
+		case 0x2c:
+		case 0x2d:
+		memcpy(memory_region(REGION_SOUND1)+0x20000, memory_region(REGION_SOUND1)+0x80000+0x40000, 0x20000);
+		sb3_music_is_playing = 1;
+		break;
+
+		case 0x2e:
+		sb3_music_is_playing = 0;
+		break;
+	}
+}
+
+void sb3_play_sound (int data)
+{
+	int status = OKIM6295_status_0_r(0);
+
+	if ((status&0x01)==0x00)
+	{
+		OKIM6295_data_0_w(0,0x80|data);
+		OKIM6295_data_0_w(0,0x00|0x12);
+	}
+	else if ((status&0x02)==0x00)
+	{
+		OKIM6295_data_0_w(0,0x80|data);
+		OKIM6295_data_0_w(0,0x00|0x22);
+	}
+	else if ((status&0x04)==0x00)
+	{
+		OKIM6295_data_0_w(0,0x80|data);
+		OKIM6295_data_0_w(0,0x00|0x42);
+	}
+
+
+}
+
+WRITE16_HANDLER( sb3_sound_w )
+{
+	if (data == 0x00fe)
+	{
+		sb3_music_is_playing = 0;
+		OKIM6295_data_0_w(0,0x78);		/* Stop sounds */
+	}
+	else /* the alternating 0x00-0x2f or 0x30-0x5f might be something to do with the channels */
+	{
+		data = data>>8;
+
+		if (data <= 0x21)
+		{
+			sb3_play_sound(data);
+		}
+
+		if (data>=0x22 && data<=0x31)
+		{
+			sb3_play_music(data);
+		}
+
+		if ((data>=0x30) && (data<=0x51))
+		{
+			sb3_play_sound(data-0x30);
+		}
+
+		if (data>=0x52 && data<=0x5f)
+		{
+			sb3_play_music(data-0x30);
+		}
+
+	}
+}
+
+
+
+static ADDRESS_MAP_START( readmem3, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE( 0x000000, 0x03ffff) AM_READ(MRA16_ROM)
+	AM_RANGE( 0x100000, 0x103fff) AM_READ(MRA16_RAM)
+	AM_RANGE( 0x300000, 0x300001) AM_READ(sb3_sound_r) /* ? */
+	AM_RANGE( 0x500000, 0x500001) AM_READ(input_port_0_word_r)
+	AM_RANGE( 0x500002, 0x500003) AM_READ(input_port_1_word_r)
+	AM_RANGE( 0x500004, 0x500005) AM_READ(input_port_2_word_r)
+	AM_RANGE( 0x600000, 0x6003ff) AM_READ(MRA16_RAM)
+	AM_RANGE( 0x700000, 0x7021ff) AM_READ(MRA16_RAM)
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( writemem3, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE( 0x000000, 0x03ffff) AM_WRITE(MWA16_ROM)
+	AM_RANGE( 0x100000, 0x103fff) AM_WRITE(MWA16_RAM)
+	AM_RANGE( 0x200000, 0x200001) AM_WRITE(watchdog_reset16_w)
+	AM_RANGE( 0x300000, 0x300001) AM_WRITE(sb3_sound_w)  /* ? */
+	AM_RANGE( 0x400000, 0x400001) AM_WRITE(snowbros_flipscreen_w)
+	AM_RANGE( 0x600000, 0x6003ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE (&paletteram16)
+	AM_RANGE( 0x700000, 0x7021ff) AM_WRITE(MWA16_RAM) AM_BASE( &spriteram16) AM_SIZE( &spriteram_size )
+	AM_RANGE( 0x800000, 0x800001) AM_WRITE(MWA16_NOP) 	/* IRQ 4 acknowledge? */
+	AM_RANGE( 0x900000, 0x900001) AM_WRITE(MWA16_NOP) 	/* IRQ 3 acknowledge? */
+	AM_RANGE( 0xa00000, 0xa00001) AM_WRITE(MWA16_NOP) 	/* IRQ 2 acknowledge? */
+ADDRESS_MAP_END
+
+
 INPUT_PORTS_START( snowbros )
 	PORT_START	/* 500001 */
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Region ) )
@@ -361,6 +529,88 @@ INPUT_PORTS_START( snowbroj )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
 
+INPUT_PORTS_START( 4in1boot )
+	PORT_START	/* 500001 */
+	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x06, 0x06, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x06, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Hard ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Hardest ) )
+	PORT_DIPNAME( 0x78, 0x78, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(    0x18, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(    0x38, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( 4C_2C ) )
+	PORT_DIPSETTING(    0x58, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x30, DEF_STR( 3C_2C ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( 4C_3C ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( 4C_4C ) )
+	PORT_DIPSETTING(    0x28, DEF_STR( 3C_3C ) )
+	PORT_DIPSETTING(    0x50, DEF_STR( 2C_2C ) )
+	PORT_DIPSETTING(    0x78, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( 3C_4C ) )
+	PORT_DIPSETTING(    0x48, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( 2C_4C ) )
+	PORT_DIPSETTING(    0x70, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(    0x68, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(    0x60, DEF_STR( 1C_4C ) )
+	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Free_Play ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_BUTTON1 )
+	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_BUTTON2 )
+	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 )
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_UNKNOWN )	/* Must be low or game stops! */
+													/* probably VBlank */
+
+	PORT_START	/* 500003 */
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )
+	PORT_DIPSETTING(    0x02, "1" )
+	PORT_DIPSETTING(    0x00, "2" )
+	PORT_DIPSETTING(    0x03, "3" )
+	PORT_DIPSETTING(    0x01, "4" )
+	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Unused ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unused ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unused ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unused ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unused ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+
+	PORT_START	/* 500005 */
+	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_COIN3 )
+	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
+
 INPUT_PORTS_START( hyperpac )
 	PORT_START	/* 500000.w */
 	PORT_DIPNAME( 0x0001, 0x0000, DEF_STR( Demo_Sounds ) )
@@ -443,9 +693,9 @@ INPUT_PORTS_START( cookbib2 )
 	PORT_DIPNAME( 0x0001, 0x0000, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0002, 0x0002, DEF_STR( Lives ) )	/* "Language" in the "test mode" */
-	PORT_DIPSETTING(      0x0002, "3" )					/* "Korean" */
-	PORT_DIPSETTING(      0x0000, "5" )					/* "English" */
+	PORT_DIPNAME( 0x0002, 0x0002, "Max Vs Round" )	/* "Language" in the "test mode" */
+	PORT_DIPSETTING(      0x0002, "3" )
+	PORT_DIPSETTING(      0x0000, "1" )
 	PORT_DIPNAME( 0x001c, 0x001c, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( 5C_1C ) )
 	PORT_DIPSETTING(      0x0004, DEF_STR( 4C_1C ) )
@@ -515,6 +765,84 @@ INPUT_PORTS_START( cookbib2 )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 INPUT_PORTS_END
 
+INPUT_PORTS_START( moremore )
+	PORT_START	/* 500000.w */
+	PORT_DIPNAME( 0x0001, 0x0000, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x000e, 0x000e, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( 5C_1C ) )
+	PORT_DIPSETTING(      0x0002, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(      0x0004, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(      0x0006, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0x000e, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x000a, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(      0x000c, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(      0x0008, DEF_STR( 1C_3C ) )
+	PORT_DIPNAME( 0x0070, 0x0070, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(      0x0020, "Level 1" )
+	PORT_DIPSETTING(      0x0010, "Level 2" )
+	PORT_DIPSETTING(      0x0000, "Level 3" )
+	PORT_DIPSETTING(      0x0070, "Level 4" )
+	PORT_DIPSETTING(      0x0060, "Level 5" )
+	PORT_DIPSETTING(      0x0050, "Level 6" )
+	PORT_DIPSETTING(      0x0040, "Level 7" )
+	PORT_DIPSETTING(      0x0030, "Level 8" )
+	PORT_SERVICE( 0x0080, IP_ACTIVE_LOW )
+	PORT_BIT( 0x0100, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x0200, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x0400, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x0800, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(1)	/* jump */
+	PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(1)	/* fire */
+	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_PLAYER(1)	/* test mode only? */
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+
+	PORT_START	/* 500002.w */
+	PORT_DIPNAME( 0x0001, 0x0001, DEF_STR( Unused ) )
+	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0002, 0x0002, DEF_STR( Unused ) )
+	PORT_DIPSETTING(      0x0002, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0004, 0x0004, DEF_STR( Unused ) )
+	PORT_DIPSETTING(      0x0004, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0008, 0x0008, DEF_STR( Unused ) )
+	PORT_DIPSETTING(      0x0008, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0010, 0x0010, DEF_STR( Unused ) )
+	PORT_DIPSETTING(      0x0010, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0020, 0x0020, DEF_STR( Unused ) )
+	PORT_DIPSETTING(      0x0020, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Unused ) )
+	PORT_DIPSETTING(      0x0040, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0080, 0x0080, DEF_STR( Free_Play ) )
+	PORT_DIPSETTING(      0x0080, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_BIT( 0x0100, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x0200, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x0400, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x0800, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)	/* jump */
+	PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(2)	/* fire */
+	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_PLAYER(2)	/* test mode only? */
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+
+	PORT_START	/* 500004.w */
+	PORT_BIT( 0x0100, IP_ACTIVE_HIGH, IPT_START1 )
+	PORT_BIT( 0x0200, IP_ACTIVE_HIGH, IPT_START2 )
+	PORT_BIT( 0x0400, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x0800, IP_ACTIVE_HIGH, IPT_COIN2 )
+	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
+
 /* SnowBros */
 
 static struct GfxLayout tilelayout =
@@ -568,6 +896,28 @@ static struct GfxLayout hyperpac_tilelayout =
 	32*32
 };
 
+
+static struct GfxLayout sb3_tilebglayout =
+{
+ 	16,16,
+ 	RGN_FRAC(1,1),
+ 	8,
+ 	{8, 9,10, 11, 0, 1, 2, 3  },
+ 	{ 0, 4, 16, 20, 32, 36, 48, 52,
+ 	512+0,512+4,512+16,512+20,512+32,512+36,512+48,512+52},
+ 	{ 0*64, 1*64, 2*64, 3*64, 4*64, 5*64, 6*64, 7*64,
+ 	1024+0*16,1024+1*64,1024+2*64,1024+3*64,1024+4*64,1024+5*64,1024+6*64,1024+7*64},
+ 	32*64
+};
+
+
+static struct GfxDecodeInfo sb3_gfxdecodeinfo[] =
+{
+	{ REGION_GFX1, 0, &tilelayout,  0, 16 },
+	{ REGION_GFX2, 0, &sb3_tilebglayout,  0, 2 },
+	{ -1 } /* end of array */
+};
+
 static struct GfxDecodeInfo hyperpac_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &hyperpac_tilelayout,  0, 16 },
@@ -584,28 +934,14 @@ static void irqhandler(int irq)
 
 static struct YM3812interface ym3812_interface =
 {
-	1,			/* 1 chip */
-	3000000,	/* 3 MHz - confirmed */
-	{ 100 },	/* volume */
-	{ irqhandler },
+	irqhandler
 };
 
 /* SemiCom Sound */
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	4000000,	/* 4 MHz??? */
-	{ YM3012_VOL(10,MIXER_PAN_LEFT,10,MIXER_PAN_RIGHT) },
-	{ irqhandler }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,			/* 1 chip */
-	{ 7575 },		/* 7575Hz playback? */
-	{ REGION_SOUND1 },
-	{ 100 }
+	irqhandler
 };
 
 
@@ -626,7 +962,7 @@ static MACHINE_DRIVER_START( snowbros )
 	MDRV_CPU_VBLANK_INT(snowbros_interrupt,3)
 
 	MDRV_CPU_ADD_TAG("sound", Z80, 6000000) /* 6 MHz - confirmed */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 
@@ -643,7 +979,11 @@ static MACHINE_DRIVER_START( snowbros )
 	MDRV_VIDEO_UPDATE(snowbros)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("3812", YM3812, ym3812_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD_TAG("3812", YM3812, 3000000)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -666,14 +1006,20 @@ static MACHINE_DRIVER_START( semicom )
 	MDRV_CPU_PROGRAM_MAP(hyperpac_readmem,hyperpac_writemem)
 
 	MDRV_CPU_REPLACE("sound", Z80, 4000000) /* 4.0 MHz ??? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(hyperpac_sound_readmem,hyperpac_sound_writemem)
 
 	MDRV_GFXDECODE(hyperpac_gfxdecodeinfo)
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("3812",YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SOUND_REPLACE("3812", YM2151, 4000000)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.10)
+	MDRV_SOUND_ROUTE(1, "mono", 0.10)
+
+	MDRV_SOUND_ADD(OKIM6295, 7575)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( semiprot )
@@ -681,6 +1027,38 @@ static MACHINE_DRIVER_START( semiprot )
 	MDRV_MACHINE_INIT ( semiprot )
 MACHINE_DRIVER_END
 
+static MACHINE_DRIVER_START( _4in1 )
+	/* basic machine hardware */
+	MDRV_IMPORT_FROM(semicom)
+	MDRV_GFXDECODE(gfxdecodeinfo)
+MACHINE_DRIVER_END
+
+static MACHINE_DRIVER_START( snowbro3 )
+
+	/* basic machine hardware */
+	MDRV_CPU_ADD(M68000, 16000000) /* 16mhz or 12mhz ? */
+	MDRV_CPU_PROGRAM_MAP(readmem3,writemem3)
+	MDRV_CPU_VBLANK_INT(snowbro3_interrupt,3)
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+
+	/* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(32*8, 32*8)
+	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MDRV_GFXDECODE(sb3_gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(512)
+
+	MDRV_VIDEO_UPDATE(snowbro3)
+
+	/* sound hardware */
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, 8500)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_DRIVER_END
 
 /***************************************************************************
 
@@ -699,10 +1077,10 @@ ROM_START( snowbros )
 	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "sbros-1.41",   0x00000, 0x80000, CRC(16f06b3a) SHA1(c64d3b2d32f0f0fcf1d8c5f02f8589d59ddfd428) )
 	/* where were these from, a bootleg? */
-/*	ROM_LOAD( "ch0",          0x00000, 0x20000, CRC(36d84dfe) SHA1(5d45a750220930bc409de30f19282bb143fbf94f) ) */
-/*	ROM_LOAD( "ch1",          0x20000, 0x20000, CRC(76347256) SHA1(48ec03965905adaba5e50eb3e42a2813f7883bb4) ) */
-/*	ROM_LOAD( "ch2",          0x40000, 0x20000, CRC(fdaa634c) SHA1(1271c74df7da7596caf67caae3c51b4c163a49f4) ) */
-/*	ROM_LOAD( "ch3",          0x60000, 0x20000, CRC(34024aef) SHA1(003a9b9ee3aaab3d787894d3d4126d372b19d2a8) ) */
+/*  ROM_LOAD( "ch0",          0x00000, 0x20000, CRC(36d84dfe) SHA1(5d45a750220930bc409de30f19282bb143fbf94f) ) */
+/*  ROM_LOAD( "ch1",          0x20000, 0x20000, CRC(76347256) SHA1(48ec03965905adaba5e50eb3e42a2813f7883bb4) ) */
+/*  ROM_LOAD( "ch2",          0x40000, 0x20000, CRC(fdaa634c) SHA1(1271c74df7da7596caf67caae3c51b4c163a49f4) ) */
+/*  ROM_LOAD( "ch3",          0x60000, 0x20000, CRC(34024aef) SHA1(003a9b9ee3aaab3d787894d3d4126d372b19d2a8) ) */
 ROM_END
 
 ROM_START( snowbroa )
@@ -786,6 +1164,9 @@ ROM_START( hyperpac )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* Z80 Code */
 	ROM_LOAD( "hyperpac.u1", 0x00000, 0x10000 , CRC(03faf88e) SHA1(a8da883d4b765b809452bbffca37ff224edbe86d) )
 
+	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* Intel 87C52 MCU Code */
+	ROM_LOAD( "87c52.mcu", 0x00000, 0x10000 , NO_DUMP ) /* can't be dumped */
+
 	ROM_REGION( 0x040000, REGION_SOUND1, 0 ) /* Samples */
 	ROM_LOAD( "hyperpac.j15", 0x00000, 0x40000, CRC(fb9f468d) SHA1(52857b1a04c64ac853340ebb8e92d98eabea8bc1) )
 
@@ -812,6 +1193,55 @@ ROM_START( hyperpcb )
 	ROM_LOAD( "hyperpac.a6", 0x080000, 0x40000, CRC(61d86e63) SHA1(974c634607993924fa098eff106b1b288bec1e26) )
 ROM_END
 
+ROM_START( twinkle )
+	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_LOAD16_BYTE( "uh12.bin", 0x00001, 0x20000, CRC(a99626fe) SHA1(489098a2ceb36df97b6b1d59b7b696300deee3ab) )
+	ROM_LOAD16_BYTE( "ui12.bin", 0x00000, 0x20000, CRC(5af73684) SHA1(9be43e5c71152d515366e422eb077a41dbb3fe62) )
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* Z80 Code */
+	ROM_LOAD( "u1.bin", 0x00000, 0x10000 , CRC(e40481da) SHA1(1c1fabcb67693235eaa6ff59ae12a35854b5564a) )
+
+	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* Intel 87C52 MCU Code */
+	ROM_LOAD( "87c52.mcu", 0x00000, 0x10000 , NO_DUMP ) /* can't be dumped */
+
+	ROM_REGION( 0x200, REGION_USER1, 0 ) /* Data from Shared RAM */
+	/* this is not a real rom but instead the data extracted from
+       shared ram, the MCU puts it there */
+	ROM_LOAD16_WORD_SWAP( "protdata.bin", 0x00000, 0x200, CRC(00d3e4b4) SHA1(afa359a8b48605ff034133bad2a0a182429dec71) )
+
+	ROM_REGION( 0x040000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_LOAD( "uj15.bin", 0x00000, 0x40000, CRC(0a534b37) SHA1(b7d780eb4668f1f757a60884c022f5bbc424dc97) )
+
+	ROM_REGION( 0x080000, REGION_GFX1, 0 ) /* Sprites */
+	ROM_LOAD( "ua4.bin", 0x000000, 0x80000, CRC(6b64bb09) SHA1(547eac1ad931a6b937dff0b922d06af92cc7ab73) )
+ROM_END
+
+ROM_START( moremore )
+	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_LOAD16_BYTE( "u52.bin",  0x00001, 0x40000, CRC(cea4b246) SHA1(5febcb5dda6581caccfe9079b28c2366dfc1db2b) )
+	ROM_LOAD16_BYTE( "u74.bin",  0x00000, 0x40000, CRC(2acdcb88) SHA1(74d661d07752bbccab7eab151209a414e9bf7675) )
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* Z80 Code */
+	ROM_LOAD( "u35.bin", 0x00000, 0x10000 , CRC(92dc95fc) SHA1(f04e63cc680835458246989532faf5657e28db13) )
+
+	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* Intel 87C52 MCU Code */
+	ROM_LOAD( "87c52.mcu", 0x00000, 0x10000 , NO_DUMP ) /* can't be dumped */
+
+	ROM_REGION( 0x200, REGION_USER1, 0 ) /* Data from Shared RAM */
+	/* this is not a real rom but instead the data extracted from
+       shared ram, the MCU puts it there */
+	ROM_LOAD16_WORD_SWAP( "protdata.bin", 0x00000, 0x200 , CRC(782dd2aa) SHA1(2587734271e0c85cb76bcdee171366c4e6fc9f81) )
+
+	ROM_REGION( 0x040000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_LOAD( "u14.bin", 0x00000, 0x40000, CRC(90580088) SHA1(c64de2c0db95ab4ce06fc0a29c0cc8b7f3deeb28) )
+
+	ROM_REGION( 0x200000, REGION_GFX1, 0 ) /* Sprites */
+	ROM_LOAD( "u75.bin", 0x000000, 0x80000, CRC(d671815c) SHA1(a7e8d3bf688ce51b5d9a2b306cc557974328c322) )
+	ROM_LOAD( "u76.bin", 0x080000, 0x80000, CRC(e0d479e8) SHA1(454b53949664aca07a86229d3b6c9ce4e9449ea6) )
+	ROM_LOAD( "u77.bin", 0x100000, 0x80000, CRC(60a281da) SHA1(3f268f8b1cd8efd3e32d0fcdba5483c93122800e) )
+	ROM_LOAD( "u78.bin", 0x180000, 0x80000, CRC(e2723b4e) SHA1(6b4ba1e2e937b3231d76526af3f5a4a67144e4d5) )
+ROM_END
+
 ROM_START( moremorp )
 	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "mmp_u52.bin",  0x00001, 0x40000, CRC(66baf9b2) SHA1(f1d383a94ef4313cb02c59ace17b9562eddcfb3c) )
@@ -825,7 +1255,7 @@ ROM_START( moremorp )
 
 	ROM_REGION( 0x200, REGION_USER1, 0 ) /* Data from Shared RAM */
 	/* this is not a real rom but instead the data extracted from
-	   shared ram, the MCU puts it there */
+       shared ram, the MCU puts it there */
 	ROM_LOAD16_WORD_SWAP( "protdata.bin", 0x00000, 0x200 , CRC(782dd2aa) SHA1(2587734271e0c85cb76bcdee171366c4e6fc9f81) )
 
 	ROM_REGION( 0x040000, REGION_SOUND1, 0 ) /* Samples */
@@ -846,6 +1276,14 @@ ROM_START( 3in1semi )
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* Z80 Code */
 	ROM_LOAD( "u35", 0x00000, 0x10000 , CRC(e40481da) SHA1(1c1fabcb67693235eaa6ff59ae12a35854b5564a) )
 
+	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* Intel 87C52 MCU Code */
+	ROM_LOAD( "87c52.mcu", 0x00000, 0x10000 , NO_DUMP ) /* can't be dumped */
+
+	ROM_REGION( 0x200, REGION_USER1, 0 ) /* Data from Shared RAM */
+	/* this is not a real rom but instead the data extracted from
+       shared ram, the MCU puts it there */
+	ROM_LOAD16_WORD_SWAP( "protdata.bin", 0x00000, 0x200 , CRC(85deba7c) SHA1(44c6d9306b4f8e47182f4740a18971c49a8df8db) )
+
 	ROM_REGION( 0x040000, REGION_SOUND1, 0 ) /* Samples */
 	ROM_LOAD( "u14", 0x00000, 0x40000, CRC(c83c11be) SHA1(c05d96d61e5b8245232c85cbbcb7cc1e4e066492) )
 
@@ -869,7 +1307,7 @@ ROM_START( cookbib2 )
 
 	ROM_REGION( 0x200, REGION_USER1, 0 ) /* Data from Shared RAM */
 	/* this is not a real rom but instead the data extracted from
-	   shared ram, the MCU puts it there */
+       shared ram, the MCU puts it there */
 	ROM_LOAD16_WORD_SWAP( "protdata.bin", 0x00000, 0x200 , CRC(ae6d8ed5) SHA1(410cdacb9b90ea345c0e4be85e60a138f45a51f1) )
 
 	ROM_REGION( 0x020000, REGION_SOUND1, 0 ) /* Samples */
@@ -881,6 +1319,40 @@ ROM_START( cookbib2 )
 	ROM_LOAD( "cookbib2.03", 0x100000, 0x40000, CRC(e1604821) SHA1(bede6bdd8331128b9f2b229d718133470bf407c9) )
 ROM_END
 
+ROM_START( 4in1boot ) /* snow bros, tetris, hyperman 1, pacman 2 */
+	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_LOAD16_BYTE( "u52",  0x00001, 0x80000, CRC(71815878) SHA1(e3868f5687c1d8ec817671c50ade6c56ee83bfa1) )
+	ROM_LOAD16_BYTE( "u74",  0x00000, 0x80000, CRC(e22d3fa2) SHA1(020ab92d8cbf37a9f8186a81934abb97088c16f9) )
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* Z80 Code */
+	ROM_LOAD( "u35", 0x00000, 0x10000 , CRC(c894ac80) SHA1(ee896675b5205ab2dbd0cbb13db16aa145391d06) )
+
+	ROM_REGION( 0x040000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_LOAD( "u14", 0x00000, 0x40000, CRC(94b09b0e) SHA1(414de3e36eff85126038e8ff74145b35076e0a43) )
+
+	ROM_REGION( 0x200000, REGION_GFX1, 0 ) /* Sprites */
+	ROM_LOAD( "u78", 0x000000, 0x200000, CRC(6c1fbc9c) SHA1(067f32cae89fd4d57b90be659d2d648e557c11df) )
+ROM_END
+
+ROM_START( snowbro3 )
+	ROM_REGION( 0x40000, REGION_CPU1, 0 )	/* 68000 code */
+	ROM_LOAD16_BYTE( "ur4",  0x00000, 0x20000, CRC(19c13ffd) SHA1(4f9db70354bd410b7bcafa96be4591de8dc33d90) )
+	ROM_LOAD16_BYTE( "ur3",  0x00001, 0x20000, CRC(3f32fa15) SHA1(1402c173c1df142ff9dd7b859689c075813a50e5) )
+
+	/* is sound cpu code missing or is it driven by the main cpu? */
+
+	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "ua5",		0x000000, 0x80000, CRC(0604e385) SHA1(96acbc65a8db89a7be100f852dc07ba9a0313167) )	/* 16x16 tiles */
+
+	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE ) /* 16x16 BG Tiles */
+	ROM_LOAD( "un7",		0x000000, 0x200000, CRC(4a79da4c) SHA1(59207d116d39b9ee25c51affe520f5fdff34e536) )
+	ROM_LOAD( "un8",		0x200000, 0x200000, CRC(7a4561a4) SHA1(1dd823369c09368d1f0ec8e1cb85d700f10ff448) )
+
+	ROM_REGION( 0x100000, REGION_SOUND1, 0 )	/* OKIM6295 samples */
+	ROM_LOAD( "us5",     0x00000, 0x20000, CRC(7c6368ef) SHA1(53393c570c605f7582b61c630980041e2ed32e2d) )
+	ROM_CONTINUE(0x80000,0x60000)
+ROM_END
+
 READ16_HANDLER ( moremorp_0a_read )
 {
 	return 0x000a;
@@ -888,11 +1360,11 @@ READ16_HANDLER ( moremorp_0a_read )
 
 static DRIVER_INIT( moremorp )
 {
-/*	data16_t *PROTDATA = (data16_t*)memory_region(REGION_USER1); */
-/*	int i; */
+/*  data16_t *PROTDATA = (data16_t*)memory_region(REGION_USER1); */
+/*  int i; */
 
-/*	for (i = 0;i < 0x200/2;i++) */
-/*		hyperpac_ram[0xf000/2 + i] = PROTDATA[i]; */
+/*  for (i = 0;i < 0x200/2;i++) */
+/*      hyperpac_ram[0xf000/2 + i] = PROTDATA[i]; */
 
 	/* explicit check in the code */
 	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x200000, 0x200001, 0, 0, moremorp_0a_read );
@@ -901,35 +1373,35 @@ static DRIVER_INIT( moremorp )
 
 static DRIVER_INIT( cookbib2 )
 {
-/*	data16_t *HCROM = (data16_t*)memory_region(REGION_CPU1); */
-/*	data16_t *PROTDATA = (data16_t*)memory_region(REGION_USER1); */
-/*	int i; */
-/*	hyperpac_ram[0xf000/2] = 0x46fc; */
-/*	hyperpac_ram[0xf002/2] = 0x2700; */
+/*  data16_t *HCROM = (data16_t*)memory_region(REGION_CPU1); */
+/*  data16_t *PROTDATA = (data16_t*)memory_region(REGION_USER1); */
+/*  int i; */
+/*  hyperpac_ram[0xf000/2] = 0x46fc; */
+/*  hyperpac_ram[0xf002/2] = 0x2700; */
 
 /* verified on real hardware, need to move this to a file really */
 
-/*	static data16_t cookbib2_mcu68k[] = */
-/*	{ */
-/*		// moved to protdata.bin */
-/*	}; */
+/*  static data16_t cookbib2_mcu68k[] = */
+/*  { */
+/*      // moved to protdata.bin */
+/*  }; */
 
 
 
 
 /*for (i = 0;i < sizeof(cookbib2_mcu68k)/sizeof(cookbib2_mcu68k[0]);i++) */
-/*		hyperpac_ram[0xf000/2 + i] = cookbib2_mcu68k[i]; */
+/*      hyperpac_ram[0xf000/2 + i] = cookbib2_mcu68k[i]; */
 
-/*	for (i = 0;i < 0x200/2;i++) */
-/*		hyperpac_ram[0xf000/2 + i] = PROTDATA[i]; */
+/*  for (i = 0;i < 0x200/2;i++) */
+/*      hyperpac_ram[0xf000/2 + i] = PROTDATA[i]; */
 
 
 	/* trojan is actually buggy and gfx flicker like crazy */
 	/* but we can pause the system after bootup with HALT line of 68k to get the table before */
 	/* it goes nuts */
 
-	/*	hyperpac_ram[0xf07a/2] = 0x4e73; */
-	/*	hyperpac_ram[0xf000/2] = 0x4e73; */
+	/*  hyperpac_ram[0xf07a/2] = 0x4e73; */
+	/*  hyperpac_ram[0xf000/2] = 0x4e73; */
 
 #if 0
 
@@ -1025,8 +1497,8 @@ static DRIVER_INIT( cookbib2 )
 	/* put the address we want to read protection data  in A2 */
 	HCROM[0x048324/2] = 0x45f9;
 	HCROM[0x048326/2] = 0x0010;
-/*	HCROM[0x048328/2] = 0xf000; */
-/*	HCROM[0x048328/2] = 0xf000+0xb4; */
+/*  HCROM[0x048328/2] = 0xf000; */
+/*  HCROM[0x048328/2] = 0xf000+0xb4; */
 	HCROM[0x048328/2] = 0xf000+0xb4+0xb4;
 
 	/* put the address of spriteram  in A0 */
@@ -1139,10 +1611,10 @@ static DRIVER_INIT( cookbib2 )
 
 	/* Draw a character! */
 	/* D6 = y-coordinate
-	   D5 = x-coordinate
-	   D4 = value to draw
+       D5 = x-coordinate
+       D4 = value to draw
 
-	   A0 = spriteram base */
+       A0 = spriteram base */
 
 	/* 0002 0002 0002 0010 00xx 00yy 00nn 000n */
 
@@ -1256,6 +1728,71 @@ static DRIVER_INIT( hyperpac )
 	hyperpac_ram[0xe086/2] = 0x3210;
 }
 
+READ16_HANDLER ( _4in1_02_read )
+{
+	return 0x0202;
+}
+
+static DRIVER_INIT(4in1boot)
+{
+	unsigned char *buffer;
+	data8_t *src = memory_region(REGION_CPU1);
+	int len = memory_region_length(REGION_CPU1);
+
+	/* strange order */
+	if ((buffer = malloc(len)))
+	{
+		int i;
+		for (i = 0;i < len; i++)
+			if (i&1) buffer[i] = BITSWAP8(src[i],6,7,5,4,3,2,1,0);
+			else buffer[i] = src[i];
+
+		memcpy(src,buffer,len);
+		free(buffer);
+	}
+
+	src = memory_region(REGION_CPU2);
+	len = memory_region_length(REGION_CPU2);
+
+	/* strange order */
+	if ((buffer = malloc(len)))
+	{
+		int i;
+		for (i = 0;i < len; i++)
+			buffer[i] = src[i^0x4000];
+		memcpy(src,buffer,len);
+		free(buffer);
+	}
+	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x200000, 0x200001, 0, 0, _4in1_02_read );
+}
+
+static DRIVER_INIT(snowbro3)
+{
+	unsigned char *buffer;
+	data8_t *src = memory_region(REGION_CPU1);
+	int len = memory_region_length(REGION_CPU1);
+
+	/* strange order */
+	if ((buffer = malloc(len)))
+	{
+		int i;
+		for (i = 0;i < len; i++)
+			buffer[i] = src[BITSWAP24(i,23,22,21,20,19,18,17,16,15,14,13,12,11,10,9,8,7,6,5,3,4,1,2,0)];
+		memcpy(src,buffer,len);
+		free(buffer);
+	}
+}
+
+static READ16_HANDLER( _3in1_read )
+{
+	return 0x0a0a;
+}
+
+static DRIVER_INIT( 3in1semi )
+{
+	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x200000, 0x200001, 0, 0, _3in1_read );
+}
+
 GAME( 1990, snowbros, 0,        snowbros, snowbros, 0, ROT0, "Toaplan", "Snow Bros. - Nick & Tom (set 1)" )
 GAME( 1990, snowbroa, snowbros, snowbros, snowbros, 0, ROT0, "Toaplan", "Snow Bros. - Nick & Tom (set 2)" )
 GAME( 1990, snowbrob, snowbros, snowbros, snowbros, 0, ROT0, "Toaplan", "Snow Bros. - Nick & Tom (set 3)" )
@@ -1266,8 +1803,9 @@ GAME( 1990, wintbob,  snowbros, wintbob,  snowbros, 0, ROT0, "bootleg", "The Win
 GAME( 1995, hyperpac, 0,        semicom, hyperpac, hyperpac, ROT0, "SemiCom", "Hyper Pacman" )
 GAME( 1995, hyperpcb, hyperpac, semicom, hyperpac, 0,        ROT0, "bootleg", "Hyper Pacman (bootleg)" )
 GAME( 1996, cookbib2, 0,        semiprot, cookbib2, cookbib2, ROT0, "SemiCom", "Cookie and Bibi 2" )
-GAME( 1999, moremorp, 0,        semiprot, hyperpac, moremorp, ROT0, "SemiCom / Exit", "More More Plus" )
-
-/* the following don't work, they either point the interrupts at an area of ram probably shared by
-   some kind of mcu which puts 68k code there, or jump to the area in the interrupts */
-GAMEX(1997, 3in1semi, 0,        semicom, hyperpac, 0,        ROT0, "SemiCom", "3-in-1 (SemiCom)", GAME_UNEMULATED_PROTECTION | GAME_NOT_WORKING )
+GAME( 1997, 3in1semi, 0,        semiprot, moremore, 3in1semi, ROT0, "SemiCom", "XESS - The New Revolution (SemiCom 3-in-1)" )
+GAME( 1997, twinkle,  0,        semiprot, moremore, 0,        ROT0, "SemiCom", "Twinkle" )
+GAME( 1999, moremore, 0,        semiprot, moremore, moremorp, ROT0, "SemiCom / Exit", "More More" )
+GAME( 1999, moremorp, 0,        semiprot, moremore, moremorp, ROT0, "SemiCom / Exit", "More More Plus" )
+GAME( 1999, 4in1boot, 0,        _4in1,    4in1boot, 4in1boot, ROT0, "bootleg", "Puzzle King (bootleg)" ) /* original is 1999, bootleg 2002? */
+GAMEX(2002, snowbro3, snowbros, snowbro3, snowbroj, snowbro3, ROT0, "bootleg", "Snow Brothers 3 - Magical Adventure", GAME_IMPERFECT_SOUND ) /* its basically snowbros code?... */
