@@ -126,6 +126,8 @@ cpu #0 (PC=00001A1A): unmapped memory word write to 00090030 = 00F7 & 00FF
 *******************************************************************************/
 
 #include "driver.h"
+#include "sound/okim6295.h"
+#include "sound/3812intf.h"
 
 data16_t *spbactn_bgvideoram, *spbactn_fgvideoram, *spbactn_spvideoram;
 
@@ -166,7 +168,7 @@ static ADDRESS_MAP_START( spbactn_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	/* this is an awful lot of unknowns */
 	AM_RANGE(0x90000, 0x90001) AM_WRITE(MWA16_NOP)
 	AM_RANGE(0x90010, 0x90011) AM_WRITE(soundcommand_w)
-/*	AM_RANGE(0x90020, 0x90021) AM_WRITE(soundcommand_w) */
+/*  AM_RANGE(0x90020, 0x90021) AM_WRITE(soundcommand_w) */
 	AM_RANGE(0x90030, 0x90031) AM_WRITE(MWA16_NOP)
 
 	AM_RANGE(0x90080, 0x90081) AM_WRITE(MWA16_NOP)
@@ -348,18 +350,7 @@ static void irqhandler(int linestate)
 
 static struct YM3812interface ym3812_interface =
 {
-	1,			/* 1 chip */
-	3579545,	/* 3.579545 MHz ? */
-	{ 100 },	/* volume */
-	{ irqhandler },
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,					/* 1 chip */
-	{ 8000 },			/* 8000Hz frequency? */
-	{ REGION_SOUND1 },	/* memory region */
-	{ 50 }
+	irqhandler
 };
 
 static MACHINE_DRIVER_START( spbactn )
@@ -369,7 +360,7 @@ static MACHINE_DRIVER_START( spbactn )
 	MDRV_CPU_VBLANK_INT(irq3_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 4 MHz ??? */
+	/* audio CPU */	/* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -386,8 +377,15 @@ static MACHINE_DRIVER_START( spbactn )
 	MDRV_VIDEO_UPDATE(spbactn)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 3579545)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 ROM_START( spbactn )
