@@ -20,7 +20,8 @@ Notes:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
-
+#include "sound/3812intf.h"
+#include "sound/msm5205.h"
 
 extern unsigned char *spdodgeb_videoram;
 
@@ -227,7 +228,7 @@ static void mcu63705_update_inputs(void)
 
 static READ8_HANDLER( mcu63701_r )
 {
-/*	logerror("CPU #0 PC %04x: read from port %02x of 63701 data address 3801\n",activecpu_get_pc(),offset); */
+/*  logerror("CPU #0 PC %04x: read from port %02x of 63701 data address 3801\n",activecpu_get_pc(),offset); */
 
 	if (mcu63701_command == 0) return 0x6a;
 	else switch (offset)
@@ -243,7 +244,7 @@ static READ8_HANDLER( mcu63701_r )
 
 static WRITE8_HANDLER( mcu63701_w )
 {
-/*	logerror("CPU #0 PC %04x: write %02x to 63701 control address 3800\n",activecpu_get_pc(),data); */
+/*  logerror("CPU #0 PC %04x: write %02x to 63701 control address 3800\n",activecpu_get_pc(),data); */
 	mcu63701_command = data;
 	mcu63705_update_inputs();
 }
@@ -274,12 +275,12 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0x1000, 0x10ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x2000, 0x2fff) AM_WRITE(spdodgeb_videoram_w) AM_BASE(&spdodgeb_videoram)
-/*	AM_RANGE(0x3000, 0x3000) AM_WRITE(MWA8_RAM) */
-/*	AM_RANGE(0x3001, 0x3001) AM_WRITE(MWA8_RAM) */
+/*  AM_RANGE(0x3000, 0x3000) AM_WRITE(MWA8_RAM) */
+/*  AM_RANGE(0x3001, 0x3001) AM_WRITE(MWA8_RAM) */
 	AM_RANGE(0x3002, 0x3002) AM_WRITE(sound_command_w)
-/*	AM_RANGE(0x3003, 0x3003) AM_WRITE(MWA8_RAM) */
+/*  AM_RANGE(0x3003, 0x3003) AM_WRITE(MWA8_RAM) */
 	AM_RANGE(0x3004, 0x3004) AM_WRITE(spdodgeb_scrollx_lo_w)
-/*	AM_RANGE(0x3005, 0x3005) AM_WRITE(MWA8_RAM)    mcu63701_output_w    */
+/*  AM_RANGE(0x3005, 0x3005) AM_WRITE(MWA8_RAM)    mcu63701_output_w    */
 	AM_RANGE(0x3006, 0x3006) AM_WRITE(spdodgeb_ctrl_w)	/* scroll hi, flip screen, bank switch, palette select */
 	AM_RANGE(0x3800, 0x3800) AM_WRITE(mcu63701_w)
 	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)
@@ -416,19 +417,13 @@ static void irq_handler(int irq)
 
 static struct YM3812interface ym3812_interface =
 {
-	1,			/* 1 chip */
-	3000000, 	/* 3MHz ? */
-	{ 100 },		/* volume */
-	{ irq_handler }
+	irq_handler
 };
 
 static struct MSM5205interface msm5205_interface =
 {
-	2,			/* 2 chips */
-	384000,		/* 384KHz */
-	{ spd_adpcm_int, spd_adpcm_int },	/* interrupt function */
-	{ MSM5205_S48_4B, MSM5205_S48_4B },	/* 8kHz? */
-	{ 50, 50 }	/* volume */
+	spd_adpcm_int,	/* interrupt function */
+	MSM5205_S48_4B	/* 8kHz? */
 };
 
 
@@ -441,7 +436,7 @@ static MACHINE_DRIVER_START( spdodgeb )
 	MDRV_CPU_VBLANK_INT(spdodgeb_interrupt,33)	/* 1 IRQ every 8 visible scanlines, plus NMI for vblank */
 
 	MDRV_CPU_ADD(M6809,12000000/6)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 2MHz ? */
+	/* audio CPU */	/* 2MHz ? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -460,9 +455,22 @@ static MACHINE_DRIVER_START( spdodgeb )
 	MDRV_VIDEO_UPDATE(spdodgeb)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM3812, 3000000)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
 MACHINE_DRIVER_END
 
 
