@@ -34,6 +34,9 @@ Sound not working on Return of Lady Frog
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m68000/m68000.h"
+#include "sound/2203intf.h"
+#include "sound/3812intf.h"
+#include "sound/msm5205.h"
 
 
 extern data16_t *splash_vregs;
@@ -49,7 +52,7 @@ READ16_HANDLER( splash_vram_r );
 WRITE16_HANDLER( splash_vram_w );
 VIDEO_START( splash );
 VIDEO_UPDATE( splash );
-
+VIDEO_UPDATE( funystrp );
 
 static WRITE16_HANDLER( splash_sh_irqtrigger_w )
 {
@@ -138,7 +141,7 @@ static void splash_msm5205_int(int data)
 static ADDRESS_MAP_START( splash_writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xd7ff) AM_WRITE(MWA8_ROM)					/* ROM */
 	AM_RANGE(0xd800, 0xd800) AM_WRITE(splash_adpcm_data_w)		/* ADPCM data for the MSM5205 chip */
-/*	AM_RANGE(0xe000, 0xe000) AM_WRITE(MWA8_NOP)					   ???    */
+/*  AM_RANGE(0xe000, 0xe000) AM_WRITE(MWA8_NOP)                    ???    */
 	AM_RANGE(0xf000, 0xf000) AM_WRITE(YM3812_control_port_0_w)	/* YM3812 */
 	AM_RANGE(0xf001, 0xf001) AM_WRITE(YM3812_write_port_0_w)		/* YM3812 */
 	AM_RANGE(0xf800, 0xffff) AM_WRITE(MWA8_RAM)					/* RAM */
@@ -199,6 +202,7 @@ static ADDRESS_MAP_START( roldf_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( roldf_sound_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x12, 0x12) AM_WRITE(YM2203_control_port_0_w)
 	AM_RANGE(0x13, 0x13) AM_WRITE(YM2203_write_port_0_w)
 	AM_RANGE(0x40, 0x40) AM_NOP	/* NMI ack */
@@ -225,7 +229,7 @@ static ADDRESS_MAP_START( funystrp_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x01ffff) AM_WRITE(MWA16_ROM)										/* ROM */
 	AM_RANGE(0x100000, 0x100fff) AM_WRITE(MWA16_RAM)										/* protection? RAM */
 	AM_RANGE(0x800000, 0x83ffff) AM_WRITE(MWA16_RAM) AM_BASE(&splash_pixelram)			/* Pixel Layer */
-/*	AM_RANGE(0x84000e, 0x84000f) AM_WRITE(splash_sh_irqtrigger_w)							   Sound command    */
+/*  AM_RANGE(0x84000e, 0x84000f) AM_WRITE(splash_sh_irqtrigger_w)                              Sound command    */
 	AM_RANGE(0x84000a, 0x84003b) AM_WRITE(splash_coin_w)									/* Coin Counters + Coin Lockout */
 	AM_RANGE(0x880000, 0x8817ff) AM_WRITE(splash_vram_w) AM_BASE(&splash_videoram)				/* Video RAM */
 	AM_RANGE(0x881800, 0x881803) AM_WRITE(MWA16_RAM) AM_BASE(&splash_vregs)						/* Scroll registers */
@@ -274,7 +278,7 @@ INPUT_PORTS_START( splash )
 	PORT_DIPSETTING(    0x08, "1" )
 	PORT_DIPSETTING(    0x04, "2" )
 	PORT_DIPSETTING(    0x0c, "3" )
-	/* 	according to the manual, Lives = 0x00 is NOT used */
+	/*  according to the manual, Lives = 0x00 is NOT used */
 	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
@@ -307,6 +311,79 @@ INPUT_PORTS_START( splash )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 INPUT_PORTS_END
 
+INPUT_PORTS_START( funystrp )
+	PORT_START	/* DSW #1 */
+	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(    0x06, DEF_STR( 5C_1C ) )
+	PORT_DIPSETTING(    0x07, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(    0x09, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x0f, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x05, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x0e, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(    0x0d, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_5C ) )
+	PORT_DIPSETTING(    0x0a, DEF_STR( 1C_6C ) )
+	PORT_DIPSETTING(    0x00, "1C/1C or Free Play (if Coin B too)" )
+	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(    0x60, DEF_STR( 5C_1C ) )
+	PORT_DIPSETTING(    0x70, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(    0x90, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0xf0, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x50, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0xe0, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(    0xd0, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
+	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
+	PORT_DIPSETTING(    0x00, "1C/1C or Free Play (if Coin A too)" )
+
+	PORT_START	/* DSW #2 */
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x03, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Hardest ) )
+	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Lives ) )
+	PORT_DIPSETTING(    0x04, "1" )
+	PORT_DIPSETTING(    0x08, "2" )
+	PORT_DIPSETTING(    0x0c, "3" )
+	PORT_DIPSETTING(    0x00, "5" )
+	PORT_DIPNAME( 0x30, 0x30, "Bonus" )
+	PORT_DIPSETTING(    0x30, "Bonus Chance HI/LO Cards" )
+	PORT_DIPSETTING(    0x10, "Life at Stage 10" )
+	PORT_DIPSETTING(    0x00, "Life at Stage 20" )
+	PORT_DIPSETTING(    0x20, DEF_STR( None ) )
+	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( Normal ) )
+	PORT_DIPNAME( 0x80, 0x80, "Strip Mode" )
+	PORT_DIPSETTING(    0x80, "Soft" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Hard ) )
+
+	PORT_START	/* 1P INPUTS & COINSW */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
+
+	PORT_START	/* 2P INPUTS & STARTSW */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
+INPUT_PORTS_END
 
 static struct GfxLayout tilelayout8 =
 {
@@ -337,21 +414,10 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static struct YM3812interface splash_ym3812_interface =
-{
-	1,						/* 1 chip */
-	3000000,				/* 3.75 MHz (30/8) */
-	{ 80 },					/* volume */
-	{ 0 }					/* IRQ handler */
-};
-
 static struct MSM5205interface splash_msm5205_interface =
 {
-	1,						/* 1 chip */
-	384000,					/* 384KHz (384000/48) */
-	{ splash_msm5205_int },	/* IRQ handler */
-	{ MSM5205_S48_4B },		/* 8KHz */
-	{ 80 }					/* volume */
+	splash_msm5205_int,	/* IRQ handler */
+	MSM5205_S48_4B		/* 8KHz */
 };
 
 
@@ -363,7 +429,7 @@ static MACHINE_DRIVER_START( splash )
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,30000000/8)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)			/* 3.75 MHz (30/8) */
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(splash_readmem_sound,splash_writemem_sound)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,64)	/* needed for the msm5205 to play the samples */
 
@@ -381,8 +447,14 @@ static MACHINE_DRIVER_START( splash )
 	MDRV_VIDEO_UPDATE(splash)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM3812, splash_ym3812_interface)
-	MDRV_SOUND_ADD(MSM5205, splash_msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 3000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(splash_msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
 static void ym_irq(int state)
@@ -392,14 +464,7 @@ static void ym_irq(int state)
 
 static struct YM2203interface ym2203_interface =
 {
-	1,		/* 1 chip */
-	3000000,	/* 3 MHz - verified */
-	{ YM2203_VOL(40,60) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ ym_irq }
+	0,0,0,0,ym_irq
 };
 
 static MACHINE_DRIVER_START( roldfrog )
@@ -410,10 +475,10 @@ static MACHINE_DRIVER_START( roldfrog )
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,30000000)			/* 3 MHz - verified */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(roldf_sound_map,0)
 	MDRV_CPU_IO_MAP(roldf_sound_io_map,0)
-/*	MDRV_CPU_VBLANK_INT(nmi_line_pulse,64)	   needed for the msm5205 to play the samples    */
+/*  MDRV_CPU_VBLANK_INT(nmi_line_pulse,64)     needed for the msm5205 to play the samples    */
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
@@ -422,14 +487,21 @@ static MACHINE_DRIVER_START( roldfrog )
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(64*8, 64*8)
 	MDRV_VISIBLE_AREA(2*8, 49*8-1, 2*8, 32*8-1)
-/*	MDRV_VISIBLE_AREA(0*8, 64*8-1, 0*8, 64*8-1) */
+/*  MDRV_VISIBLE_AREA(0*8, 64*8-1, 0*8, 64*8-1) */
 	MDRV_GFXDECODE(gfxdecodeinfo)
 	MDRV_PALETTE_LENGTH(2048)
 
 	MDRV_VIDEO_START(splash)
 	MDRV_VIDEO_UPDATE(splash)
 
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.60)
+	MDRV_SOUND_ROUTE(1, "mono", 0.60)
+	MDRV_SOUND_ROUTE(2, "mono", 0.60)
+	MDRV_SOUND_ROUTE(3, "mono", 0.40)
 MACHINE_DRIVER_END
 
 
@@ -440,10 +512,10 @@ static MACHINE_DRIVER_START( funystrp )
 	MDRV_CPU_PROGRAM_MAP(funystrp_readmem,funystrp_writemem)
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
-/*	MDRV_CPU_ADD(Z80,30000000/8) */
-/*	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)			   3.75 MHz (30/8)    */
-/*	MDRV_CPU_PROGRAM_MAP(splash_readmem_sound,splash_writemem_sound) */
-/*	MDRV_CPU_VBLANK_INT(nmi_line_pulse,64)	   needed for the msm5205 to play the samples    */
+/*  MDRV_CPU_ADD(Z80,30000000/8) */
+/*     audio CPU    */
+/*  MDRV_CPU_PROGRAM_MAP(splash_readmem_sound,splash_writemem_sound) */
+/*  MDRV_CPU_VBLANK_INT(nmi_line_pulse,64)     needed for the msm5205 to play the samples    */
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
@@ -456,11 +528,17 @@ static MACHINE_DRIVER_START( funystrp )
 	MDRV_PALETTE_LENGTH(2048)
 
 	MDRV_VIDEO_START(splash)
-	MDRV_VIDEO_UPDATE(splash)
+	MDRV_VIDEO_UPDATE(funystrp)
 
 	/* sound hardware */
-/*	MDRV_SOUND_ADD(YM3812, splash_ym3812_interface) */
-/*	MDRV_SOUND_ADD(MSM5205, splash_msm5205_interface) */
+/*  MDRV_SPEAKER_STANDARD_MONO("mono") */
+
+/*  MDRV_SOUND_ADD(YM3812, 3000000) */
+/*  MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80) */
+
+/*  MDRV_SOUND_ADD(MSM5205, 384000) */
+/*  MDRV_SOUND_CONFIG(msm5205_interface) */
+/*  MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80) */
 MACHINE_DRIVER_END
 
 
@@ -734,4 +812,4 @@ GAME( 1992, paintlad, splash,   splash, splash, splash, ROT0, "Gaelco",    "Pain
 GAMEX(1993, roldfrog, 0,        roldfrog, splash, roldfrog, ROT0, "Microhard", "The Return of Lady Frog", GAME_NO_SOUND )
 GAMEX(1993, roldfrga, roldfrog, roldfrog, splash, roldfrog, ROT0, "Microhard", "The Return of Lady Frog (set 2)", GAME_NO_SOUND )
 
-GAMEX(199?, funystrp, 0,        funystrp, splash, funystrp, ROT0, "Microhard / MagicGames",    "Funny Strip",GAME_NOT_WORKING|GAME_UNEMULATED_PROTECTION|GAME_NO_SOUND )
+GAMEX(199?, funystrp, 0,        funystrp, funystrp, funystrp, ROT0, "Microhard / MagicGames",    "Funny Strip",GAME_NOT_WORKING|GAME_UNEMULATED_PROTECTION|GAME_NO_SOUND )
