@@ -1,24 +1,25 @@
 /***************************************************************************
 
-	Atari Sprint 2 hardware
+    Atari Sprint 2 hardware
 
-	driver by Mike Balfour
+    driver by Mike Balfour
 
-	Games supported:
-		* Sprint 1
-		* Sprint 2
-		* Dominos
+    Games supported:
+        * Sprint 1
+        * Sprint 2
+        * Dominos
 
-	All three games run on the same PCB but with minor modifications (some
-	chips removed, some wire-wrap connections added).
+    All three games run on the same PCB but with minor modifications (some
+    chips removed, some wire-wrap connections added).
 
-	If you have any questions about how this driver works, don't hesitate to
-	ask.  - Mike Balfour (mab22@po.cwru.edu)
+    If you have any questions about how this driver works, don't hesitate to
+    ask.  - Mike Balfour (mab22@po.cwru.edu)
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "sprint2.h"
+#include "sound/discrete.h"
 
 #define GAME_IS_SPRINT1   (game == 1)
 #define GAME_IS_SPRINT2   (game == 2)
@@ -388,10 +389,10 @@ INPUT_PORTS_START( sprint2 )
 	PORT_BIT( 0xff, 0x00, IPT_DIAL ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(2)
 
 	PORT_START
-	PORT_ADJUSTER( 20, "Motor 1 RPM" )
+	PORT_ADJUSTER( 30, "Motor 1 RPM" )
 
 	PORT_START
-	PORT_ADJUSTER( 30, "Motor 2 RPM" )
+	PORT_ADJUSTER( 40, "Motor 2 RPM" )
 INPUT_PORTS_END
 
 
@@ -448,7 +449,7 @@ INPUT_PORTS_START( sprint1 )
 	PORT_START
 
 	PORT_START
-	PORT_ADJUSTER( 20, "Motor RPM" )
+	PORT_ADJUSTER( 30, "Motor RPM" )
 INPUT_PORTS_END
 
 
@@ -496,7 +497,7 @@ INPUT_PORTS_START( dominos )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
 
 	PORT_START
-	PORT_ADJUSTER( 20, "Tone Freq" )
+	PORT_ADJUSTER( 50, "R23 - Tone Freq" )
 INPUT_PORTS_END
 
 
@@ -566,8 +567,12 @@ static MACHINE_DRIVER_START( sprint2 )
 	MDRV_VIDEO_EOF(sprint2)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, sprint2_discrete_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, 0)
+	MDRV_SOUND_CONFIG(sprint2_discrete_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -576,8 +581,13 @@ static MACHINE_DRIVER_START( sprint1 )
 	MDRV_IMPORT_FROM(sprint2)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(0)
-	MDRV_SOUND_REPLACE("discrete", DISCRETE, sprint1_discrete_interface)
+	MDRV_SPEAKER_REMOVE("left")
+	MDRV_SPEAKER_REMOVE("right")
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_REPLACE("discrete", DISCRETE, 0)
+	MDRV_SOUND_CONFIG(sprint1_discrete_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -586,8 +596,13 @@ static MACHINE_DRIVER_START( dominos )
 	MDRV_IMPORT_FROM(sprint2)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(0)
-	MDRV_SOUND_REPLACE("discrete", DISCRETE, dominos_discrete_interface)
+	MDRV_SPEAKER_REMOVE("left")
+	MDRV_SPEAKER_REMOVE("right")
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_REPLACE("discrete", DISCRETE, 0)
+	MDRV_SOUND_CONFIG(dominos_discrete_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
