@@ -57,6 +57,8 @@ Note:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/msm5205.h"
 
 
 /***************************************************************************
@@ -151,10 +153,10 @@ static MACHINE_INIT( srmp3 )
 static WRITE16_HANDLER( srmp2_flags_w )
 {
 /*
-	---- ---x : Coin Counter
-	---x ---- : Coin Lock Out
-	--x- ---- : ADPCM Bank
-	x--- ---- : Palette Bank
+    ---- ---x : Coin Counter
+    ---x ---- : Coin Lock Out
+    --x- ---- : ADPCM Bank
+    x--- ---- : Palette Bank
 */
 
 	coin_counter_w( 0, ((data & 0x01) >> 0) );
@@ -167,8 +169,8 @@ static WRITE16_HANDLER( srmp2_flags_w )
 static WRITE16_HANDLER( mjyuugi_flags_w )
 {
 /*
-	---- ---x : Coin Counter
-	---x ---- : Coin Lock Out
+    ---- ---x : Coin Counter
+    ---x ---- : Coin Lock Out
 */
 
 	coin_counter_w( 0, ((data & 0x01) >> 0) );
@@ -179,8 +181,8 @@ static WRITE16_HANDLER( mjyuugi_flags_w )
 static WRITE16_HANDLER( mjyuugi_adpcm_bank_w )
 {
 /*
-	---- xxxx : ADPCM Bank
-	--xx ---- : GFX Bank
+    ---- xxxx : ADPCM Bank
+    --xx ---- : GFX Bank
 */
 	srmp2_adpcm_bank = (data & 0x0f);
 	mjyuugi_gfx_bank = ((data >> 4) & 0x03);
@@ -190,10 +192,10 @@ static WRITE16_HANDLER( mjyuugi_adpcm_bank_w )
 static WRITE16_HANDLER( srmp2_adpcm_code_w )
 {
 /*
-	- Received data may be playing ADPCM number.
-	- 0x000000 - 0x0000ff and 0x010000 - 0x0100ff are offset table.
-	- When the hardware receives the ADPCM number, it refers the offset
-	  table and plays the ADPCM for itself.
+    - Received data may be playing ADPCM number.
+    - 0x000000 - 0x0000ff and 0x010000 - 0x0100ff are offset table.
+    - When the hardware receives the ADPCM number, it refers the offset
+      table and plays the ADPCM for itself.
 */
 
 	unsigned char *ROM = memory_region(REGION_SOUND1);
@@ -213,10 +215,10 @@ static WRITE16_HANDLER( srmp2_adpcm_code_w )
 static WRITE8_HANDLER( srmp3_adpcm_code_w )
 {
 /*
-	- Received data may be playing ADPCM number.
-	- 0x000000 - 0x0000ff and 0x010000 - 0x0100ff are offset table.
-	- When the hardware receives the ADPCM number, it refers the offset
-	  table and plays the ADPCM for itself.
+    - Received data may be playing ADPCM number.
+    - 0x000000 - 0x0000ff and 0x010000 - 0x0100ff are offset table.
+    - When the hardware receives the ADPCM number, it refers the offset
+      table and plays the ADPCM for itself.
 */
 
 	unsigned char *ROM = memory_region(REGION_SOUND1);
@@ -283,8 +285,8 @@ static READ16_HANDLER( srmp2_cchip_status_1_r )
 static READ16_HANDLER( srmp2_input_1_r )
 {
 /*
-	---x xxxx : Key code
-	--x- ---- : Player 1 and 2 side flag
+    ---x xxxx : Key code
+    --x- ---- : Player 1 and 2 side flag
 */
 
 	if (!ACCESSING_LSB)
@@ -359,8 +361,8 @@ static WRITE16_HANDLER( srmp2_input_2_w )
 static WRITE8_HANDLER( srmp3_rombank_w )
 {
 /*
-	---x xxxx : MAIN ROM bank
-	xxx- ---- : ADPCM ROM bank
+    ---x xxxx : MAIN ROM bank
+    xxx- ---- : ADPCM ROM bank
 */
 
 	unsigned char *ROM = memory_region(REGION_CPU1);
@@ -465,8 +467,8 @@ static READ8_HANDLER( srmp3_cchip_status_1_r )
 static WRITE8_HANDLER( srmp3_input_1_w )
 {
 /*
-	---- --x- : Player 1 side flag ?
-	---- -x-- : Player 2 side flag ?
+    ---- --x- : Player 1 side flag ?
+    ---- -x-- : Player 2 side flag ?
 */
 
 	logerror("PC:%04X DATA:%02X  srmp3_input_1_w\n", activecpu_get_pc(), data);
@@ -484,7 +486,7 @@ static WRITE8_HANDLER( srmp3_input_1_w )
 		else if (data == 0x49) qqq49++;
 		else qqqzz++;
 
-/*		usrintf_showmessage("%04X %04X %04X %04X", qqq01, qqq02, qqq49, qqqzz); */
+/*      usrintf_showmessage("%04X %04X %04X %04X", qqq01, qqq02, qqq49, qqqzz); */
 	}
 }
 
@@ -502,8 +504,8 @@ static WRITE8_HANDLER( srmp3_input_2_w )
 static READ8_HANDLER( srmp3_input_r )
 {
 /*
-	---x xxxx : Key code
-	--x- ---- : Player 1 and 2 side flag
+    ---x xxxx : Key code
+    --x- ---- : Player 1 and 2 side flag
 */
 
 	/* Currently I/O port of srmp3 is fully understood. */
@@ -512,8 +514,8 @@ static READ8_HANDLER( srmp3_input_r )
 
 	logerror("PC:%04X          srmp3_input_r\n", activecpu_get_pc());
 
-	/* PC:0x8903	ROM:0xC903 */
-	/* PC:0x7805	ROM:0x7805 */
+	/* PC:0x8903    ROM:0xC903 */
+	/* PC:0x7805    ROM:0x7805 */
 
 	if ((activecpu_get_pc() == 0x8903) || (activecpu_get_pc() == 0x7805))	/* Panel keys */
 	{
@@ -533,8 +535,8 @@ static READ8_HANDLER( srmp3_input_r )
 		}
 	}
 
-	/* PC:0x8926	ROM:0xC926 */
-	/* PC:0x7822	ROM:0x7822 */
+	/* PC:0x8926    ROM:0xC926 */
+	/* PC:0x7822    ROM:0x7822 */
 
 	if ((activecpu_get_pc() == 0x8926) || (activecpu_get_pc() == 0x7822))	/* Analizer and memory reset keys */
 	{
@@ -547,9 +549,9 @@ static READ8_HANDLER( srmp3_input_r )
 static WRITE8_HANDLER( srmp3_flags_w )
 {
 /*
-	---- ---x : Coin Counter
-	---x ---- : Coin Lock Out
-	xx-- ---- : GFX Bank
+    ---- ---x : Coin Counter
+    ---x ---- : Coin Lock Out
+    xx-- ---- : GFX Bank
 */
 
 	coin_counter_w( 0, ((data & 0x01) >> 0) );
@@ -579,6 +581,7 @@ static ADDRESS_MAP_START( srmp3_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( srmp3_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x40, 0x40) AM_READ(input_port_0_r)						/* coin, service */
 	AM_RANGE(0xa1, 0xa1) AM_READ(srmp3_cchip_status_0_r)				/* custom chip status ??? */
 	AM_RANGE(0xc0, 0xc0) AM_READ(srmp3_input_r)						/* key matrix */
@@ -587,6 +590,7 @@ static ADDRESS_MAP_START( srmp3_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( srmp3_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x20, 0x20) AM_WRITE(MWA8_NOP)							/* elapsed interrupt signal */
 	AM_RANGE(0x40, 0x40) AM_WRITE(srmp3_flags_w)						/* GFX bank, counter, lockout */
 	AM_RANGE(0x60, 0x60) AM_WRITE(srmp3_rombank_w)					/* ROM bank select */
@@ -607,48 +611,48 @@ ADDRESS_MAP_END
 #define SETAMJCTRL_PORT3 \
 	PORT_START_TAG("KMI3")	/* KEY MATRIX INPUT (3) */ \
 	PORT_BIT ( 0x0001, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Small") PORT_CODE(KEYCODE_BACKSPACE) \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Double Up") PORT_CODE(KEYCODE_RSHIFT) \
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Big") PORT_CODE(KEYCODE_ENTER) \
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Take Score") PORT_CODE(KEYCODE_RCONTROL) \
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Flip") PORT_CODE(KEYCODE_X) \
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Last Chance") PORT_CODE(KEYCODE_RALT) \
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_SMALL ) \
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_DOUBLE_UP ) \
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_BIG ) \
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_SCORE ) \
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_FLIP_FLOP ) \
+	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_MAHJONG_LAST_CHANCE ) \
 	PORT_BIT ( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 #define SETAMJCTRL_PORT4 \
 	PORT_START_TAG("KMI4")	/* KEY MATRIX INPUT (4) */ \
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 K") PORT_CODE(KEYCODE_K) \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Ron") PORT_CODE(KEYCODE_Z) \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 G") PORT_CODE(KEYCODE_G) \
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Chi") PORT_CODE(KEYCODE_SPACE) \
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 C") PORT_CODE(KEYCODE_C) \
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_K ) \
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_RON ) \
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_G ) \
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_CHI ) \
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_C ) \
 	PORT_BIT ( 0x0020, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 L") PORT_CODE(KEYCODE_L) \
+	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_MAHJONG_L ) \
 	PORT_BIT ( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 #define SETAMJCTRL_PORT5 \
 	PORT_START_TAG("KMI5")	/* KEY MATRIX INPUT (5) */ \
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 H") PORT_CODE(KEYCODE_H) \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Pon") PORT_CODE(KEYCODE_LALT) \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 D") PORT_CODE(KEYCODE_D) \
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Start") PORT_CODE(KEYCODE_1) \
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 I") PORT_CODE(KEYCODE_I) \
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Kan") PORT_CODE(KEYCODE_LCONTROL) \
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 E") PORT_CODE(KEYCODE_E) \
-	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 M") PORT_CODE(KEYCODE_M) \
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_H ) \
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_PON ) \
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_D ) \
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_START1 ) \
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_I ) \
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_KAN ) \
+	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_MAHJONG_E ) \
+	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_MAHJONG_M ) \
 	PORT_BIT ( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 #define SETAMJCTRL_PORT6 \
 	PORT_START_TAG("KMI6")	/* KEY MATRIX INPUT (6) */ \
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 A") PORT_CODE(KEYCODE_A) \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet") PORT_CODE(KEYCODE_2) \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 J") PORT_CODE(KEYCODE_J) \
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Reach") PORT_CODE(KEYCODE_LSHIFT) \
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 F") PORT_CODE(KEYCODE_F) \
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 N") PORT_CODE(KEYCODE_N) \
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 B") PORT_CODE(KEYCODE_B) \
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_MAHJONG_A ) \
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_BET ) \
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_J ) \
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_REACH ) \
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_F ) \
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_N ) \
+	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_MAHJONG_B ) \
 	PORT_BIT ( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT ( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
@@ -946,7 +950,7 @@ INPUT_PORTS_START( ponchin )
 	PORT_DIPNAME( 0x30, 0x30, "Player Score" )
 	PORT_DIPSETTING(    0x30, "1000" )
 	PORT_DIPSETTING(    0x20, "2000" )
-/*	PORT_DIPSETTING(    0x10, "1000" ) */
+/*  PORT_DIPSETTING(    0x10, "1000" ) */
 	PORT_DIPSETTING(    0x00, "3000" )
 	PORT_DIPNAME( 0x40, 0x40, "Debug Mode (Cheat)")
 	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
@@ -1034,62 +1038,15 @@ INPUT_PORTS_END
 
 static struct AY8910interface srmp2_ay8910_interface =
 {
-	1,
-	20000000/16,					/* 1.25 MHz */
-	{ 40 },
-	{ input_port_2_r },				/* Input A: DSW 2 */
-	{ input_port_1_r },				/* Input B: DSW 1 */
-	{ 0 },
-	{ 0 }
-};
-
-static struct AY8910interface srmp3_ay8910_interface =
-{
-	1,
-	16000000/16,					/* 1.00 MHz */
-	{ 20 },
-	{ input_port_2_r },				/* Input A: DSW 2 */
-	{ input_port_1_r },				/* Input B: DSW 1 */
-	{ 0 },
-	{ 0 }
-};
-
-static struct AY8910interface mjyuugi_ay8910_interface =
-{
-	1,
-	16000000/16,					/* 1.00 MHz */
-	{ 20 },
-	{ input_port_2_r },				/* Input A: DSW 2 */
-	{ input_port_1_r },				/* Input B: DSW 1 */
-	{ 0 },
-	{ 0 }
+	input_port_2_r,				/* Input A: DSW 2 */
+	input_port_1_r,				/* Input B: DSW 1 */
 };
 
 
-struct MSM5205interface srmp2_msm5205_interface =
+static struct MSM5205interface msm5205_interface =
 {
-	1,
-	384000,
-	{ srmp2_adpcm_int },			/* IRQ handler */
-	{ MSM5205_S48_4B },				/* 8 KHz, 4 Bits  */
-	{ 45 }
-};
-
-struct MSM5205interface srmp3_msm5205_interface =
-{
-#if 1
-	1,
-	384000,							/* 384 KHz */
-	{ srmp2_adpcm_int },			/* IRQ handler */
-	{ MSM5205_S48_4B },				/* 8 KHz, 4 Bits  */
-	{ 45 }
-#else
-	1,
-	455000,							/* 455 KHz */
-	{ srmp2_adpcm_int },			/* IRQ handler */
-	{ MSM5205_S64_4B },				/* 8 KHz, 4 Bits  */
-	{ 45 }
-#endif
+	srmp2_adpcm_int,			/* IRQ handler */
+	MSM5205_S48_4B				/* 8 KHz, 4 Bits  */
 };
 
 
@@ -1143,8 +1100,15 @@ static MACHINE_DRIVER_START( srmp2 )
 	MDRV_VIDEO_UPDATE(srmp2)		/* just draw the sprites */
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, srmp2_ay8910_interface)
-	MDRV_SOUND_ADD(MSM5205, srmp2_msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 20000000/16)
+	MDRV_SOUND_CONFIG(srmp2_ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.45)
 MACHINE_DRIVER_END
 
 
@@ -1153,7 +1117,7 @@ static MACHINE_DRIVER_START( srmp3 )
 	/* basic machine hardware */
 
 	MDRV_CPU_ADD(Z80, 3500000)		/* 3.50 MHz ? */
-	/*		4000000,				   4.00 MHz ?    */
+	/*      4000000,                   4.00 MHz ?    */
 	MDRV_CPU_PROGRAM_MAP(srmp3_readmem,srmp3_writemem)
 	MDRV_CPU_IO_MAP(srmp3_readport,srmp3_writeport)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
@@ -1175,8 +1139,15 @@ static MACHINE_DRIVER_START( srmp3 )
 	MDRV_VIDEO_UPDATE(srmp3)	/* just draw the sprites */
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, srmp3_ay8910_interface)
-	MDRV_SOUND_ADD(MSM5205, srmp3_msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 16000000/16)
+	MDRV_SOUND_CONFIG(srmp2_ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.45)
 MACHINE_DRIVER_END
 
 
@@ -1203,8 +1174,15 @@ static MACHINE_DRIVER_START( mjyuugi )
 	MDRV_VIDEO_UPDATE(mjyuugi)			/* just draw the sprites */
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, mjyuugi_ay8910_interface)
-	MDRV_SOUND_ADD(MSM5205, srmp2_msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 16000000/16)
+	MDRV_SOUND_CONFIG(srmp2_ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.45)
 MACHINE_DRIVER_END
 
 
