@@ -11,6 +11,7 @@
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
+#include "sound/2203intf.h"
 
 extern unsigned char *srumbler_backgroundram,*srumbler_foregroundram;
 
@@ -28,13 +29,13 @@ VIDEO_EOF( srumbler );
 static WRITE8_HANDLER( srumbler_bankswitch_w )
 {
 	/*
-	  banking is controlled by two PROMs. 0000-4fff is mapped to the same
-	  address (RAM and I/O) for all banks, so we don't handle it here.
-	  e000-ffff is all mapped to the same ROMs, however we do handle it
-	  here anyway.
-	  Note that 5000-8fff can be either ROM or RAM, so we should handle
-	  that as well to be 100% accurate.
-	 */
+      banking is controlled by two PROMs. 0000-4fff is mapped to the same
+      address (RAM and I/O) for all banks, so we don't handle it here.
+      e000-ffff is all mapped to the same ROMs, however we do handle it
+      here anyway.
+      Note that 5000-8fff can be either ROM or RAM, so we should handle
+      that as well to be 100% accurate.
+     */
 	int i;
 	unsigned char *ROM = memory_region(REGION_USER1);
 	unsigned char *prom1 = memory_region(REGION_PROMS) + (data & 0xf0);
@@ -241,7 +242,7 @@ static struct GfxLayout spritelayout =
 	4,
 	{ RGN_FRAC(3,4), RGN_FRAC(2,4), RGN_FRAC(1,4), RGN_FRAC(0,4) },
 	{ 0, 1, 2, 3, 4, 5, 6, 7,
-			2*64+0, 2*64+1, 2*64+2, 2*64+3, 2*64+4, 2*64+5, 2*64+6, 2*64+7, 2*64+8 },
+			2*64+0, 2*64+1, 2*64+2, 2*64+3, 2*64+4, 2*64+5, 2*64+6, 2*64+7 },
 	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8,
 			8*8, 9*8, 10*8, 11*8, 12*8, 13*8, 14*8, 15*8 },
 	32*8
@@ -257,18 +258,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct YM2203interface ym2203_interface =
-{
-	2,                      /* 2 chips */
-	4000000,        /* 4.0 MHz (? hand tuned to match the real board) */
-	{ YM2203_VOL(60,20), YM2203_VOL(60,20) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
 
 static MACHINE_DRIVER_START( srumbler )
 
@@ -278,7 +267,7 @@ static MACHINE_DRIVER_START( srumbler )
 	MDRV_CPU_VBLANK_INT(srumbler_interrupt,2)
 
 	MDRV_CPU_ADD(Z80, 3000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)        /* 3 MHz ??? */
+	/* audio CPU */        /* 3 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
 
@@ -299,7 +288,19 @@ static MACHINE_DRIVER_START( srumbler )
 	MDRV_VIDEO_UPDATE(srumbler)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+	MDRV_SOUND_ROUTE(2, "mono", 0.20)
+	MDRV_SOUND_ROUTE(3, "mono", 0.60)
+
+	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.20)
+	MDRV_SOUND_ROUTE(1, "mono", 0.20)
+	MDRV_SOUND_ROUTE(2, "mono", 0.20)
+	MDRV_SOUND_ROUTE(3, "mono", 0.60)
 MACHINE_DRIVER_END
 
 
