@@ -53,6 +53,8 @@ Stephh's notes (based on the games M68000 code and some tests) :
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/2203intf.h"
+#include "sound/okim6295.h"
 
 #define SSHANGHA_HACK	0
 
@@ -135,11 +137,11 @@ static READ16_HANDLER( deco_71_r )
 static MACHINE_INIT( sshangha )
 {
 	/* Such thing is needed as there is no code to turn the screen
-	   to normal orientation when the game is reset.
-	   I'm using the value that forces the screen to be in normal
+       to normal orientation when the game is reset.
+       I'm using the value that forces the screen to be in normal
          orientation when entering the "test mode"
          (check the game code from 0x0006b8 to 0x0006f0).
-	   I can't tell however if this is accurate or not. */
+       I can't tell however if this is accurate or not. */
 	sshangha_control_0_w(0, 0x10, 0xff00);
 }
 
@@ -188,7 +190,7 @@ static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
 	AM_RANGE(0xc000, 0xc000) AM_READ(YM2203_status_port_0_r)
 	AM_RANGE(0xf800, 0xffff) AM_READ(MRA8_RAM)
-/*	AM_RANGE(0xf800, 0xf800) AM_READ(soundlatch_r) */
+/*  AM_RANGE(0xf800, 0xf800) AM_READ(soundlatch_r) */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -329,14 +331,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /******************************************************************************/
 
-static struct OKIM6295interface okim6295_interface =
-{
-	1,          /* 1 chip */
-	{ 7757 },	/* Frequency */
-	{ REGION_SOUND1 },      /* memory region */
-	{ 50 }
-};
-
 static void irqhandler(int state)
 {
 	cpunum_set_input_line(1,0,state);
@@ -344,14 +338,7 @@ static void irqhandler(int state)
 
 static struct YM2203interface ym2203_interface =
 {
-	1,
-	16000000/4,
-	{ YM2203_VOL(60,60) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
+	0,0,0,0,irqhandler
 };
 
 static MACHINE_DRIVER_START( sshangha )
@@ -362,7 +349,7 @@ static MACHINE_DRIVER_START( sshangha )
 	MDRV_CPU_VBLANK_INT(irq6_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 16000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -380,9 +367,17 @@ static MACHINE_DRIVER_START( sshangha )
 	MDRV_VIDEO_UPDATE(sshangha)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2203, 16000000/4)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.60)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.60)
+
+	MDRV_SOUND_ADD(OKIM6295, 7757)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
 MACHINE_DRIVER_END
 
 /******************************************************************************/
