@@ -3,13 +3,18 @@
 /*
 
 Still some unknown reads / writes (it writes all over the place ...)
-Odd problem with sprites, and wrong text on tournament screen.
 Inputs / DSW's need finishing / verifying.
-Game crashes after you win your first match.
 
 The 87C751 MCU for sound has not had its internal program ROM dumped.
 So the sound MCU is simulated here - and therefore not 100% correct.
 
+Update 12/03/2005 - Pierpaolo Prazzoli
+- Fixed sprites
+- Fixed text tilemap colors
+- Fixed text tilemap scrolls
+- Fixed VSync
+- Fixed middle tilemap removing wraparound in the title screen (24/03/2005)
+
 */
 
 /*
@@ -36,6 +41,7 @@ a small kid and even with a dog! And remember, Winners don't use Drugs ;)
 */
 
 #include "driver.h"
+#include "sound/okim6295.h"
 
 
 #define oki_time_base 0x08
@@ -55,9 +61,15 @@ data16_t *sslam_spriteram, *sslam_regs;
    All commentry and most sound effects are correct, however the music
    tracks may be playing at the wrong times.
    Accordingly, the commands for playing the below samples is just a guess:
-   1A, 1B, 1C, 1D, 1E, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 6A, 6B, 6C
+   1A, 1B, 1C, 1D, 1E, 60, 61, 62, 65, 66, 67, 68, 69, 6B, 6C.
+   Samples 63, 64 and 6A are currently not fitted anywhere :-(
    Note: that samples 60, 61 and 62 combine to form a music track.
    Ditto for samples 65, 66, 67 and 68.
+   Command 29 is fired when the game is completed successfully. It requires
+   a melody from bank one to be playing, but we're already using the bank
+   one melody during game play.
+   The sound CPU simulation can only be perfected once it can be compared
+   against a real game board.
 */
 
 static const data8_t sslam_cmd_snd[128] =
@@ -67,7 +79,7 @@ static const data8_t sslam_cmd_snd[128] =
 /*10*/	0x72, 0x0e, 0x0f, 0x10, 0x11, 0x12, 0x13, 0x14,
 /*18*/	0x15, 0x16, 0x17, 0x18, 0x19, 0x73, 0x74, 0x75,
 /*20*/	0x76, 0x1a, 0x1b, 0x1c, 0x1d, 0x00, 0x1f, 0x6c,
-/*28*/	0x1e, 0x00, 0x00, 0x00, 0x60, 0x20, 0x69, 0x65,
+/*28*/	0x1e, 0x65, 0x00, 0x00, 0x60, 0x20, 0x69, 0x65,
 /*30*/	0x00, 0x00, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28,
 /*38*/	0x29, 0x2a, 0x2b, 0x00, 0x6b, 0x00, 0x00, 0x00
 };
@@ -199,7 +211,7 @@ static void sslam_play(int melody, int data)
 	int status = OKIM6295_status_0_r(0);
 
 	logerror("Playing sample %01x:%02x from command %02x\n",sslam_snd_bank,sslam_sound,data);
-	if (sslam_sound == 0 ) usrintf_showmessage("Unknown sound command %02x",sslam_sound);
+	if (sslam_sound == 0) usrintf_showmessage("Unknown sound command %02x",sslam_sound);
 
 	if (melody) {
 		if (sslam_melody != sslam_sound) {
@@ -252,7 +264,7 @@ WRITE16_HANDLER( sslam_snd_w )
 				if (sslam_snd_bank != 1)
 					OKIM6295_set_bank_base(0, (1 * 0x40000));
 				sslam_snd_bank = 1;
-				sslam_play(4, data);
+				sslam_play(0, data);
 			}
 			else if (sslam_sound >= 0x69) {
 				if (sslam_snd_bank != 2)
@@ -310,7 +322,7 @@ static INTERRUPT_GEN( sslam_interrupt )
 
 		if (sslam_melody_loop)
 		{
-/*			logerror("Changing to sample %02x\n",sslam_melody_loop); */
+/*          logerror("Changing to sample %02x\n",sslam_melody_loop); */
 			OKIM6295_data_0_w(0,((0x80 | sslam_melody_loop) & 0xff));
 			OKIM6295_data_0_w(0,0x81);
 		}
@@ -324,52 +336,27 @@ static INTERRUPT_GEN( sslam_interrupt )
 /* these will need verifying .. the game writes all over the place ... */
 
 static ADDRESS_MAP_START( sslam_program_map, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000400, 0x0fffff) AM_RAM
-
-/*	AM_RANGE(0x020000, 0x07ffff) AM_RAM */
-
+	AM_RANGE(0x000400, 0x07ffff) AM_RAM
 	AM_RANGE(0x100000, 0x103fff) AM_READWRITE(MRA16_RAM, sslam_bg_tileram_w) AM_BASE(&sslam_bg_tileram)
 	AM_RANGE(0x104000, 0x107fff) AM_READWRITE(MRA16_RAM, sslam_md_tileram_w) AM_BASE(&sslam_md_tileram)
 	AM_RANGE(0x108000, 0x10ffff) AM_READWRITE(MRA16_RAM, sslam_tx_tileram_w) AM_BASE(&sslam_tx_tileram)
-
-	AM_RANGE(0x110000, 0x11000f) AM_WRITE(MWA16_RAM) AM_BASE(&sslam_regs)
-
+	AM_RANGE(0x110000, 0x11000b) AM_RAM AM_BASE(&sslam_regs)
+	AM_RANGE(0x11000c, 0x11000d) AM_WRITENOP
+	AM_RANGE(0x200000, 0x200001) AM_WRITENOP
 	AM_RANGE(0x280000, 0x280fff) AM_READWRITE(MRA16_RAM, bigtwin_paletteram_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x201000, 0x220fff) AM_RAM AM_BASE(&sslam_spriteram) /* probably not all of it .. */
-
+	AM_RANGE(0x304000, 0x304001) AM_WRITENOP
 	AM_RANGE(0x300010, 0x300011) AM_READ(input_port_0_word_r)
 	AM_RANGE(0x300012, 0x300013) AM_READ(input_port_1_word_r)
 	AM_RANGE(0x300014, 0x300015) AM_READ(input_port_2_word_r)
 	AM_RANGE(0x300016, 0x300017) AM_READ(input_port_3_word_r)
 	AM_RANGE(0x300018, 0x300019) AM_READ(input_port_4_word_r)
-
 	AM_RANGE(0x30001a, 0x30001b) AM_READ(input_port_5_word_r)
 	AM_RANGE(0x30001c, 0x30001d) AM_READ(input_port_6_word_r)
 	AM_RANGE(0x30001e, 0x30001f) AM_WRITE(sslam_snd_w)
-
-	AM_RANGE(0x400000, 0x4fffff) AM_ROM
-	AM_RANGE(0x500000, 0x5fffff) AM_ROM
-	AM_RANGE(0x600000, 0x6fffff) AM_ROM
-	AM_RANGE(0x700000, 0x7fffff) AM_ROM
-	AM_RANGE(0x800000, 0x8fffff) AM_ROM
-	AM_RANGE(0x900000, 0x9fffff) AM_ROM
-	AM_RANGE(0xc00000, 0xcfffff) AM_ROM
-	AM_RANGE(0xa00000, 0xafffff) AM_ROM
-	AM_RANGE(0xb00000, 0xbfffff) AM_ROM
-	AM_RANGE(0xc00000, 0xcfffff) AM_ROM
-	AM_RANGE(0xd00000, 0xdfffff) AM_ROM
-	AM_RANGE(0xe00000, 0xefffff) AM_ROM
-	AM_RANGE(0xf00000, 0xffffff) AM_RAM		/* Main RAM */
-
+	AM_RANGE(0xf00000, 0xffffff) AM_RAM	  /* Main RAM */
 
 	AM_RANGE(0x000000, 0xffffff) AM_ROM   /* I don't honestly know where the rom is mirrored .. so all unmapped reads / writes go to rom */
-
-
-#if 0	/* Remove the log file noise */
-	AM_RANGE(0x300020, 0xbfffff) AM_RAM
-	AM_RANGE(0xd00000, 0xfdffff) AM_RAM
-	AM_RANGE(0xff0000, 0xffffff) AM_RAM
-#endif
 ADDRESS_MAP_END
 
 
@@ -443,9 +430,9 @@ INPUT_PORTS_START( sslam )
 	PORT_DIPSETTING(    0x20, "3-4" )
 	PORT_DIPSETTING(    0x10, "3-3" )
 	PORT_DIPSETTING(    0x00, "0-0" )
-	PORT_DIPNAME( 0x40, 0x40, "Max Players" )
-	PORT_DIPSETTING(    0x00, "2" )
-	PORT_DIPSETTING(    0x40, "4" )
+	PORT_DIPNAME( 0x40, 0x40, "Play Mode" )
+	PORT_DIPSETTING(    0x00, "2 Players" )
+	PORT_DIPSETTING(    0x40, "4 Players" )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -512,14 +499,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static struct OKIM6295interface okim6295_interface =
-{
-	1,							/* 1 chip */
-	{ (26000000/16)/165 },		/* frequency 9849Hz ??? */
-	{ REGION_SOUND1 },			/* memory region */
-	{ 80 }
-};
-
 
 /* Machine Driver */
 
@@ -531,7 +510,7 @@ static MACHINE_DRIVER_START( sslam )
 	MDRV_CPU_VBLANK_INT(irq2_line_hold,1)
 	MDRV_CPU_PERIODIC_INT(sslam_interrupt, 240)
 
-	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_FRAMES_PER_SECOND(58)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
 	/* video hardware */
@@ -545,15 +524,18 @@ static MACHINE_DRIVER_START( sslam )
 	MDRV_VIDEO_UPDATE(sslam)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, 26000000/16/165)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
-/* maybe one dump is bad .. which? */
-/* should use guru's (sslama) filenames, they're better */
+/* maybe one dump is bad .. which? -> 2nd set was verified good from 2 pcbs */
 
 ROM_START( sslam )
 	ROM_REGION( 0x1000000, REGION_CPU1, 0 ) /* 68000 Code */
-	ROM_LOAD16_BYTE( "it_21.bin", 0x00000, 0x80000, CRC(1ce52917) SHA1(b9b1d14ea44c248ce6e615c5c553c0d485c1302b) )
+	ROM_LOAD16_BYTE( "2.u67", 0x00000, 0x80000, CRC(1ce52917) SHA1(b9b1d14ea44c248ce6e615c5c553c0d485c1302b) )
 	ROM_RELOAD ( 0x100000, 0x80000 )
 	ROM_RELOAD ( 0x200000, 0x80000 )
 	ROM_RELOAD ( 0x300000, 0x80000 )
@@ -587,21 +569,21 @@ ROM_START( sslam )
 	ROM_RELOAD ( 0xf00001, 0x80000 )
 
 	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_DISPOSE  ) /* Bg */
-	ROM_LOAD( "it_23.bin", 0x180000, 0x80000, CRC(8e15fb9d) SHA1(47917d8aac1bce2e15f36904f5c2534e5b80236b) )
-	ROM_LOAD( "it_24.bin", 0x100000, 0x80000, CRC(8d18bdc6) SHA1(cacc4f475f85438a00ead4911730202e995983a7) )
-	ROM_LOAD( "it_25.bin", 0x080000, 0x80000, CRC(6928065c) SHA1(ad5b1889bebf0358df0295d6041b798ac53ac625) )
-	ROM_LOAD( "it_26.bin", 0x000000, 0x80000, CRC(64ecdde9) SHA1(576ba1169d90970622249e532baa4209bf12de5a) )
+	ROM_LOAD( "7.u45",     0x000000, 0x80000, CRC(64ecdde9) SHA1(576ba1169d90970622249e532baa4209bf12de5a) )
+	ROM_LOAD( "6.u39",     0x080000, 0x80000, CRC(6928065c) SHA1(ad5b1889bebf0358df0295d6041b798ac53ac625) )
+	ROM_LOAD( "5.u42",     0x100000, 0x80000, CRC(8d18bdc6) SHA1(cacc4f475f85438a00ead4911730202e995983a7) )
+	ROM_LOAD( "4.u36",     0x180000, 0x80000, CRC(8e15fb9d) SHA1(47917d8aac1bce2e15f36904f5c2534e5b80236b) )
 
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE  ) /* Sprites */
-	ROM_LOAD( "it_27.bin", 0x000000, 0x80000, CRC(19bb89dd) SHA1(c2a0c32d350a193d366b5086502998281fd0bec4) )
-	ROM_LOAD( "it_28.bin", 0x080000, 0x80000, CRC(d50d86c7) SHA1(7ecbcc03851a8174610f7f5ad889e40543da928e) )
-	ROM_LOAD( "it_29.bin", 0x100000, 0x80000, CRC(681b8ac8) SHA1(ebfeffc091f53af246311574b9c5d83d2716a7be) )
-	ROM_LOAD( "it_30.bin", 0x180000, 0x80000, CRC(e41f89e3) SHA1(e4b39411a4cea6aa6c01564f74bb8e432d382a73) )
+	ROM_LOAD( "8.u83",     0x000000, 0x80000, CRC(19bb89dd) SHA1(c2a0c32d350a193d366b5086502998281fd0bec4) )
+	ROM_LOAD( "9.u84",     0x080000, 0x80000, CRC(d50d86c7) SHA1(7ecbcc03851a8174610f7f5ad889e40543da928e) )
+	ROM_LOAD( "10.u85",    0x100000, 0x80000, CRC(681b8ac8) SHA1(ebfeffc091f53af246311574b9c5d83d2716a7be) )
+	ROM_LOAD( "11.u86",    0x180000, 0x80000, CRC(e41f89e3) SHA1(e4b39411a4cea6aa6c01564f74bb8e432d382a73) )
 
 	/* $00000-$20000 stays the same in all sound banks, */
 	/* the second half of the bank is the area that gets switched */
 	ROM_REGION( 0xc0000, REGION_SOUND1, 0 ) /* OKI Samples */
-	ROM_LOAD( "it_20.bin",   0x00000, 0x40000, CRC(d0a9245f) SHA1(2e840cdd7bdfe7c6f986daf88576de0559597499) )
+	ROM_LOAD( "3.u13",       0x00000, 0x40000, CRC(d0a9245f) SHA1(2e840cdd7bdfe7c6f986daf88576de0559597499) )
 	ROM_CONTINUE(            0x60000, 0x20000 )
 	ROM_CONTINUE(            0xa0000, 0x20000 )
 	ROM_COPY( REGION_SOUND1, 0x00000, 0x40000, 0x20000)
@@ -610,7 +592,7 @@ ROM_END
 
 ROM_START( sslama )
 	ROM_REGION( 0x1000000, REGION_CPU1, 0 ) /* 68000 Code */
-	ROM_LOAD16_BYTE( "it_21.bin", 0x00000, 0x80000, CRC(1ce52917) SHA1(b9b1d14ea44c248ce6e615c5c553c0d485c1302b) )
+	ROM_LOAD16_BYTE( "2.u67", 0x00000, 0x80000, CRC(1ce52917) SHA1(b9b1d14ea44c248ce6e615c5c553c0d485c1302b) )
 	ROM_RELOAD ( 0x100000, 0x80000 )
 	ROM_RELOAD ( 0x200000, 0x80000 )
 	ROM_RELOAD ( 0x300000, 0x80000 )
@@ -644,27 +626,26 @@ ROM_START( sslama )
 	ROM_RELOAD ( 0xf00001, 0x80000 )
 
 	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_DISPOSE  ) /* Bg */
-	ROM_LOAD( "it_23.bin", 0x180000, 0x80000, CRC(8e15fb9d) SHA1(47917d8aac1bce2e15f36904f5c2534e5b80236b) )
-	ROM_LOAD( "it_24.bin", 0x100000, 0x80000, CRC(8d18bdc6) SHA1(cacc4f475f85438a00ead4911730202e995983a7) )
-	ROM_LOAD( "it_25.bin", 0x080000, 0x80000, CRC(6928065c) SHA1(ad5b1889bebf0358df0295d6041b798ac53ac625) )
-	ROM_LOAD( "it_26.bin", 0x000000, 0x80000, CRC(64ecdde9) SHA1(576ba1169d90970622249e532baa4209bf12de5a) )
+	ROM_LOAD( "7.u45",     0x000000, 0x80000, CRC(64ecdde9) SHA1(576ba1169d90970622249e532baa4209bf12de5a) )
+	ROM_LOAD( "6.u39",     0x080000, 0x80000, CRC(6928065c) SHA1(ad5b1889bebf0358df0295d6041b798ac53ac625) )
+	ROM_LOAD( "5.u42",     0x100000, 0x80000, CRC(8d18bdc6) SHA1(cacc4f475f85438a00ead4911730202e995983a7) )
+	ROM_LOAD( "4.u36",     0x180000, 0x80000, CRC(8e15fb9d) SHA1(47917d8aac1bce2e15f36904f5c2534e5b80236b) )
 
 	ROM_REGION( 0x200000, REGION_GFX2, ROMREGION_DISPOSE  ) /* Sprites */
-	ROM_LOAD( "it_27.bin", 0x000000, 0x80000, CRC(19bb89dd) SHA1(c2a0c32d350a193d366b5086502998281fd0bec4) )
-	ROM_LOAD( "it_28.bin", 0x080000, 0x80000, CRC(d50d86c7) SHA1(7ecbcc03851a8174610f7f5ad889e40543da928e) )
-	ROM_LOAD( "it_29.bin", 0x100000, 0x80000, CRC(681b8ac8) SHA1(ebfeffc091f53af246311574b9c5d83d2716a7be) )
-	ROM_LOAD( "it_30.bin", 0x180000, 0x80000, CRC(e41f89e3) SHA1(e4b39411a4cea6aa6c01564f74bb8e432d382a73) )
+	ROM_LOAD( "8.u83",     0x000000, 0x80000, CRC(19bb89dd) SHA1(c2a0c32d350a193d366b5086502998281fd0bec4) )
+	ROM_LOAD( "9.u84",     0x080000, 0x80000, CRC(d50d86c7) SHA1(7ecbcc03851a8174610f7f5ad889e40543da928e) )
+	ROM_LOAD( "10.u85",    0x100000, 0x80000, CRC(681b8ac8) SHA1(ebfeffc091f53af246311574b9c5d83d2716a7be) )
+	ROM_LOAD( "11.u86",    0x180000, 0x80000, CRC(e41f89e3) SHA1(e4b39411a4cea6aa6c01564f74bb8e432d382a73) )
 
 	/* $00000-$20000 stays the same in all sound banks, */
 	/* the second half of the bank is the area that gets switched */
 	ROM_REGION( 0xc0000, REGION_SOUND1, 0 ) /* OKI Samples */
-	ROM_LOAD( "it_20.bin",   0x00000, 0x40000, CRC(d0a9245f) SHA1(2e840cdd7bdfe7c6f986daf88576de0559597499) )
+	ROM_LOAD( "3.u13",       0x00000, 0x40000, CRC(d0a9245f) SHA1(2e840cdd7bdfe7c6f986daf88576de0559597499) )
 	ROM_CONTINUE(            0x60000, 0x20000 )
 	ROM_CONTINUE(            0xa0000, 0x20000 )
 	ROM_COPY( REGION_SOUND1, 0x00000, 0x40000, 0x20000)
 	ROM_COPY( REGION_SOUND1, 0x00000, 0x80000, 0x20000)
 ROM_END
 
-
-GAMEX(1993, sslam, 0, sslam, sslam, 0, ROT0, "Playmark", "Super Slam", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
-GAMEX(1993, sslama, sslam, sslam, sslam, 0, ROT0, "Playmark", "Super Slam (alt)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
+GAMEX(1993, sslam, 0,      sslam, sslam, 0, ROT0, "Playmark", "Super Slam (set 1)", GAME_IMPERFECT_SOUND )
+GAMEX(1993, sslama, sslam, sslam, sslam, 0, ROT0, "Playmark", "Super Slam (set 2)", GAME_IMPERFECT_SOUND )
