@@ -1,14 +1,17 @@
 /***************************************************************************
 
-	Stadium Hero (Japan)			(c) 1988 Data East Corporation
+    Stadium Hero (Japan)            (c) 1988 Data East Corporation
 
-	Emulation by Bryan McPhail, mish@tendril.co.uk
+    Emulation by Bryan McPhail, mish@tendril.co.uk
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/2203intf.h"
+#include "sound/3812intf.h"
+#include "sound/okim6295.h"
 
 /* Video emulation definitions */
 VIDEO_START( stadhero );
@@ -269,31 +272,9 @@ static void irqhandler(int linestate)
 	cpunum_set_input_line(1,0,linestate);
 }
 
-static struct YM2203interface ym2203_interface =
-{
-	1,
-	1500000,	/* 12MHz clock divided by 8 = 1.50 MHz */
-	{ YM2203_VOL(40,95) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static struct YM3812interface ym3812_interface =
 {
-	1,			/* 1 chip */
-	3000000,	/* 3 MHz (12MHz/4) */
-	{ 80 },
-	{ irqhandler },
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,              /* 1 chip */
-	{ 7757 },           /* 8000Hz frequency */
-	{ REGION_SOUND1 },	/* memory region 3 */
-	{ 80 }
+	irqhandler
 };
 
 /******************************************************************************/
@@ -306,7 +287,7 @@ static MACHINE_DRIVER_START( stadhero )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)/* VBL */
 
 	MDRV_CPU_ADD(M6502, 1500000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(stadhero_s_readmem,stadhero_s_writemem)
 
 	MDRV_FRAMES_PER_SECOND(58)
@@ -323,9 +304,21 @@ static MACHINE_DRIVER_START( stadhero )
 	MDRV_VIDEO_UPDATE(stadhero)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(YM3812, ym3812_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ROUTE(0, "mono", 0.95)
+	MDRV_SOUND_ROUTE(1, "mono", 0.95)
+	MDRV_SOUND_ROUTE(2, "mono", 0.95)
+	MDRV_SOUND_ROUTE(3, "mono", 0.40)
+
+	MDRV_SOUND_ADD(YM3812, 3000000)
+	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+
+	MDRV_SOUND_ADD(OKIM6295, 7757)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
 /******************************************************************************/
