@@ -1,39 +1,39 @@
 /***************************************************************************
 
-	Star Fire/Fire One system
+    Star Fire/Fire One system
 
     driver by Daniel Boris, Olivier Galibert, Aaron Giles
 
 ****************************************************************************
 
-	Memory map
+    Memory map
 
 ****************************************************************************
 
-	========================================================================
-	MAIN CPU
-	========================================================================
-	0000-7FFF   R     xxxxxxxx   Program ROM
-	8000-9FFF   R/W   xxxxxxxx   Scratch RAM, actually mapped into low VRAM
-	9000          W   xxxxxxxx   VRAM write control register
-	              W   xxx-----      (VRAM shift amount 1)
-	              W   ---x----      (VRAM write mirror 1)
-	              W   ----xxx-      (VRAM shift amount 2)
-	              W   -------x      (VRAM write mirror 2)
-	9001          W   xxxxxxxx   Video control register
-	              W   x-------      (Color RAM source select)
-	              W   -x------      (Palette RAM write enable)
-	              W   --x-----      (Video RAM write enable)
-	              W   ---x----      (Right side mask select)
-	              W   ----xxxx      (Video RAM ALU operation)
-	9800-9807   R     xxxxxxxx   Input ports
-	A000-BFFF   R/W   xxxxxxxx   Color RAM
-	C000-DFFF   R/W   xxxxxxxx   Video RAM, using shift/mirror 1 and color
-	E000-FFFF   R/W   xxxxxxxx   Video RAM, using shift/mirror 2
-	========================================================================
-	Interrupts:
-	   NMI generated once/frame
-	========================================================================
+    ========================================================================
+    MAIN CPU
+    ========================================================================
+    0000-7FFF   R     xxxxxxxx   Program ROM
+    8000-9FFF   R/W   xxxxxxxx   Scratch RAM, actually mapped into low VRAM
+    9000          W   xxxxxxxx   VRAM write control register
+                  W   xxx-----      (VRAM shift amount 1)
+                  W   ---x----      (VRAM write mirror 1)
+                  W   ----xxx-      (VRAM shift amount 2)
+                  W   -------x      (VRAM write mirror 2)
+    9001          W   xxxxxxxx   Video control register
+                  W   x-------      (Color RAM source select)
+                  W   -x------      (Palette RAM write enable)
+                  W   --x-----      (Video RAM write enable)
+                  W   ---x----      (Right side mask select)
+                  W   ----xxxx      (Video RAM ALU operation)
+    9800-9807   R     xxxxxxxx   Input ports
+    A000-BFFF   R/W   xxxxxxxx   Color RAM
+    C000-DFFF   R/W   xxxxxxxx   Video RAM, using shift/mirror 1 and color
+    E000-FFFF   R/W   xxxxxxxx   Video RAM, using shift/mirror 2
+    ========================================================================
+    Interrupts:
+       NMI generated once/frame
+    ========================================================================
 
 ***************************************************************************
 
@@ -72,7 +72,7 @@ static read8_handler input_read;
 
 /*************************************
  *
- *	Video updates
+ *  Video updates
  *
  *************************************/
 
@@ -98,7 +98,7 @@ MACHINE_INIT( starfire )
 
 /*************************************
  *
- *	Scratch RAM, mapped into video RAM
+ *  Scratch RAM, mapped into video RAM
  *
  *************************************/
 
@@ -139,7 +139,7 @@ static READ8_HANDLER( starfire_scratch_r )
 
 /*************************************
  *
- *	Game-specific input handlers
+ *  Game-specific input handlers
  *
  *************************************/
 
@@ -188,7 +188,7 @@ static READ8_HANDLER( fireone_input_r )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -210,7 +210,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -305,7 +305,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -337,7 +337,7 @@ MACHINE_DRIVER_END
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -388,11 +388,25 @@ ROM_START( fireone )
 	ROM_LOAD( "fo-ic18.1c",     0x6800, 0x0800, CRC(771ee5ba) SHA1(6577e219386de594dbde8a54d5f5f9657419061a) )
 ROM_END
 
-
+ROM_START( starfir2 )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for code */
+	ROM_LOAD( "sfire2.01",     0x0000, 0x0800, CRC(f75be2f4) SHA1(b15511c345363f45eee0c019aa336a9aa16e63ea) )
+	ROM_LOAD( "sfire2.02",     0x0800, 0x0800, CRC(ccf98c6a) SHA1(3e7792aa47750ee19baf1e74016038fe80c92381) )
+	ROM_LOAD( "sfire2.03",     0x1000, 0x0800, CRC(604b2d50) SHA1(39d402135aaaa44c1ad05e1665eb6668280fae28) )
+	ROM_LOAD( "sfire2.04",     0x1800, 0x0800, CRC(f8a9658f) SHA1(aea97387001183a797375971c7325b4a838ea1d5) )
+	ROM_LOAD( "sfire2.05",     0x2000, 0x0800, CRC(acbaf827) SHA1(a546340f8533557a86b589f5011e5af0439e0d4d) )
+	ROM_LOAD( "sfire2.06",     0x2800, 0x0800, CRC(3525bb22) SHA1(1a1ca8b5ef1a5584d28644bdc751635aac3fad02) )
+	ROM_LOAD( "sfire2.07",     0x3000, 0x0800, CRC(7fce0e54) SHA1(17355fe98cf1511c32e90434960ced7b3f3ecac7) )
+	ROM_LOAD( "sfire2.08",     0x3800, 0x0800, CRC(98054c14) SHA1(4a561a9d87be9c5d4283ee78c4cf05c10c979a2f) )
+	ROM_LOAD( "sfire2.09",     0x4000, 0x0800, CRC(abaa4144) SHA1(045ebcd38d6a3f75c6d819a42aa1fb92ac84755c) )
+	ROM_LOAD( "sfire2.10",     0x4800, 0x0800, CRC(a0b3dadb) SHA1(d86683b528b5fbafad0cdd054940bc04b056b850) )
+	ROM_LOAD( "sfire2.11",     0x5000, 0x0800, CRC(a61ebbd2) SHA1(9fdf6558306aebbf5e9e106e4f4f6f7a3e703696) )
+	ROM_LOAD( "sfire2.12",     0x5800, 0x0800, CRC(a35ba06d) SHA1(122f1dbc235977367fdd06b7517c356a3147dfd1) )
+ROM_END
 
 /*************************************
  *
- *	Driver init
+ *  Driver init
  *
  *************************************/
 
@@ -410,10 +424,11 @@ static DRIVER_INIT( fireone )
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
 GAMEX( 1979, starfire, 0,        starfire, starfire, starfire, ROT0, "Exidy", "Star Fire (set 1)", GAME_NO_SOUND )
 GAMEX( 1979, starfira, starfire, starfire, starfire, starfire, ROT0, "Exidy", "Star Fire (set 2)", GAME_NO_SOUND )
 GAMEX( 1979, fireone,  0,        starfire, fireone,  fireone,  ROT0, "Exidy", "Fire One", GAME_NO_SOUND )
+GAMEX( 1979, starfir2, 0,        starfire, starfire, starfire, ROT0, "Exidy", "Star Fire 2", GAME_NO_SOUND )
