@@ -49,6 +49,7 @@
 
 #include "driver.h"
 #include "cpu/i8085/i8085.h"
+#include "sound/ay8910.h"
 
 /* Default NVram, we seem to need one or statriv2 crashes during attract
    attempting to display an unterminated message */
@@ -408,7 +409,7 @@ static ADDRESS_MAP_START( hangman_readport, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x21, 0x21) AM_READ(input_port_1_r)
 	AM_RANGE(0x28, 0x28) AM_READ(hangman_questions_read)                /* question data */
 	AM_RANGE(0xb1, 0xb1) AM_READ(AY8910_read_port_0_r)		/* ??? */
-	AM_RANGE(0xce, 0xce) AM_READ(MRA8_NOP)			/* ???	 */
+	AM_RANGE(0xce, 0xce) AM_READ(MRA8_NOP)			/* ??? */
 ADDRESS_MAP_END
 
 INPUT_PORTS_START( statriv2 )
@@ -529,7 +530,7 @@ INPUT_PORTS_START( hangman )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_IMPULSE(8) PORT_NAME("Spinner")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	
+
  	PORT_START
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_IMPULSE(8) PORT_NAME("Left")
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 ) PORT_IMPULSE(8)
@@ -568,17 +569,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct AY8910interface ay8910_interface =
-{
-	1,	/* 1 chip */
-	1500000,	/* 1.5 MHz ???? */
-	{ 100 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 static INTERRUPT_GEN( statriv2_interrupt )
 {
 	cpunum_set_input_line(0, I8085_RST75_LINE, HOLD_LINE);
@@ -609,7 +599,10 @@ static MACHINE_DRIVER_START( statriv2 )
 	MDRV_VIDEO_UPDATE(statriv2)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( statriv4 )
@@ -803,7 +796,7 @@ ROM_START( hangman )
 	ROM_LOAD( "main_hang_1b_2732.u7", 0x0000, 0x1000, CRC(0d71b2ad) SHA1(636e5e0e356c9c7de174a0b6a5663fedcb1e697f) )
 	ROM_LOAD( "main_hang_2b_2732.u8", 0x1000, 0x1000, CRC(77533554) SHA1(fe97a412135b770ce7e85442507eac0c25b7256a) )
 	ROM_LOAD( "main_hang_3b_2732.u9", 0x2000, 0x1000, CRC(daab4853) SHA1(b3b8ef051f4b04195cf7b25232f1af561c3ff7ba) )
-	
+
 	ROM_REGION( 0x1000,  REGION_GFX1, ROMREGION_INVERT )
 	ROM_LOAD( "main_hang_0b_2732.u36", 0x0000, 0x1000, CRC(e031dbf8) SHA1(ae6d34ad02b2d7deb1665d2420f8399a3ca88585) )
 
