@@ -2,14 +2,15 @@
 
 Strength & Skill (c) 1984 Sun Electronics
 
-	Driver by Uki
+    Driver by Uki
 
-	19/Jun/2001 -
+    19/Jun/2001 -
 
 *****************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/sn76496.h"
 
 static UINT8 *strnskil_sharedram;
 
@@ -98,7 +99,7 @@ static ADDRESS_MAP_START( strnskil_writemem1, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xd809, 0xd809) AM_WRITE(MWA8_NOP) /* coin counter? */
 	AM_RANGE(0xd80a, 0xd80b) AM_WRITE(strnskil_scroll_x_w)
 
-/*	AM_RANGE(0xd80c, 0xd80c) AM_WRITE(MWA8_NOP)		   protection reset?    */
+/*  AM_RANGE(0xd80c, 0xd80c) AM_WRITE(MWA8_NOP)        protection reset?    */
 	AM_RANGE(0xd80d, 0xd80d) AM_WRITE(protection_w)	/* protection data write (pettanp) */
 ADDRESS_MAP_END
 
@@ -331,14 +332,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct SN76496interface sn76496_interface =
-{
-	2,	/* 2 chips */
-	{ 8000000/4, 8000000/2 },
-	{ 75, 75 }
-};
-
-
 static MACHINE_DRIVER_START( strnskil )
 
 	/* basic machine hardware */
@@ -367,7 +360,13 @@ static MACHINE_DRIVER_START( strnskil )
 	MDRV_VIDEO_UPDATE(strnskil)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 8000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
+
+	MDRV_SOUND_ADD(SN76496, 8000000/2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
 MACHINE_DRIVER_END
 
 /****************************************************************************/
@@ -467,7 +466,7 @@ ROM_START( pettanp )
 	ROM_LOAD( "16-2.97",  0x0500,  0x0200, CRC(7f95d4b2) SHA1(68dc311739a4d5d72f4cfbace27f3a82f05316ff) ) /* bg */
 
 	ROM_REGION( 0x0100, REGION_USER1, 0 ) /* scroll control PROM */
-/*	ROM_LOAD( "16-6",     0x0000,  0x0100, NO_DUMP ) */
+/*  ROM_LOAD( "16-6",     0x0000,  0x0100, NO_DUMP ) */
 
 	ROM_REGION( 0x1000, REGION_USER2, 0 ) /* protection? */
 	ROM_LOAD( "tvg12-16.2", 0x0000,  0x1000, CRC(3abc6ba8) SHA1(15e0b0f9d068f6094e2be4f4f1dea0ff6e85686b) )
