@@ -1,35 +1,35 @@
 /****************************************************************************
 
-	Super Chase  						(c) 1992 Taito
+    Super Chase                         (c) 1992 Taito
 
-	Driver by Bryan McPhail & David Graves.
+    Driver by Bryan McPhail & David Graves.
 
-	Board Info:
+    Board Info:
 
-		CPU board:
-		68000
-		68020
-		TC0570SPC (Taito custom)
-		TC0470LIN (Taito custom)
-		TC0510NIO (Taito custom)
-		TC0480SCP (Taito custom)
-		TC0650FDA (Taito custom)
-		ADC0809CCN
+        CPU board:
+        68000
+        68020
+        TC0570SPC (Taito custom)
+        TC0470LIN (Taito custom)
+        TC0510NIO (Taito custom)
+        TC0480SCP (Taito custom)
+        TC0650FDA (Taito custom)
+        ADC0809CCN
 
-		X2=26.686MHz
-		X1=40MHz
-		X3=32MHz
+        X2=26.686MHz
+        X1=40MHz
+        X3=32MHz
 
-		Sound board:
-		68000
-		68681
-		MB8421 (x2)
-		MB87078
-		Ensoniq 5510
-		Ensoniq 5505
+        Sound board:
+        68000
+        68681
+        MB8421 (x2)
+        MB87078
+        Ensoniq 5510
+        Ensoniq 5505
 
-	(Acknowledgments and thanks to Richard Bush and the Raine team
-	for their preliminary Super Chase driver.)
+    (Acknowledgments and thanks to Richard Bush and the Raine team
+    for their preliminary Super Chase driver.)
 
 ***************************************************************************/
 
@@ -39,6 +39,7 @@
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
 #include "machine/eeprom.h"
+#include "sound/es5506.h"
 
 VIDEO_START( superchs );
 VIDEO_UPDATE( superchs );
@@ -88,13 +89,13 @@ static WRITE16_HANDLER( shared_ram_w )
 static WRITE32_HANDLER( cpua_ctrl_w )
 {
 	/*
-	CPUA writes 0x00, 22, 72, f2 in that order.
-	f2 seems to be the standard in-game value.
-	..x...x.
-	.xxx..x.
-	xxxx..x.
-	is there an irq enable in the top nibble?
-	*/
+    CPUA writes 0x00, 22, 72, f2 in that order.
+    f2 seems to be the standard in-game value.
+    ..x...x.
+    .xxx..x.
+    xxxx..x.
+    is there an irq enable in the top nibble?
+    */
 
 	if (ACCESSING_MSB)
 	{
@@ -229,14 +230,14 @@ static READ32_HANDLER( superchs_stick_r )
 static WRITE32_HANDLER( superchs_stick_w )
 {
 	/* This is guess work - the interrupts are in groups of 4, with each writing to a
-		different byte in this long word before the RTE.  I assume all but the last
-		(top) byte cause an IRQ with the final one being an ACK.  (Total guess but it works). */
+        different byte in this long word before the RTE.  I assume all but the last
+        (top) byte cause an IRQ with the final one being an ACK.  (Total guess but it works). */
 	if (mem_mask!=0x00ffffff)
 		cpunum_set_input_line(0,3,HOLD_LINE);
 }
 
 /***********************************************************
-			 MEMORY STRUCTURES
+             MEMORY STRUCTURES
 ***********************************************************/
 
 static ADDRESS_MAP_START( superchs_readmem, ADDRESS_SPACE_PROGRAM, 32 )
@@ -366,7 +367,7 @@ INPUT_PORTS_START( superchs )
 INPUT_PORTS_END
 
 /***********************************************************
-				GFX DECODING
+                GFX DECODING
 **********************************************************/
 
 static struct GfxLayout tile16x16_layout =
@@ -401,7 +402,7 @@ static struct GfxDecodeInfo superchs_gfxdecodeinfo[] =
 
 
 /***********************************************************
-			     MACHINE DRIVERS
+                 MACHINE DRIVERS
 ***********************************************************/
 
 static MACHINE_INIT( superchs )
@@ -420,12 +421,9 @@ static MACHINE_INIT( superchs )
 
 static struct ES5505interface es5505_interface =
 {
-	1,					/* total number of chips */
-	{ 13343000 },		/* freq - 26.686MHz/2??  May be 16MHz but Nancy sounds too high-pitched */
-	{ REGION_SOUND1 },	/* Bank 0: Unused by F3 games? */
-	{ REGION_SOUND1 },	/* Bank 1: All games seem to use this */
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },		/* master volume */
-	{ 0 }				/* irq callback */
+	REGION_SOUND1,	/* Bank 0: Unused by F3 games? */
+	REGION_SOUND1,	/* Bank 1: All games seem to use this */
+	0				/* irq callback */
 };
 
 static struct EEPROM_interface superchs_eeprom_interface =
@@ -473,7 +471,7 @@ static MACHINE_DRIVER_START( superchs )
 	MDRV_CPU_VBLANK_INT(irq2_line_hold,1)/* VBL */
 
 	MDRV_CPU_ADD(M68000, 16000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 16 MHz */
+	/* audio CPU */	/* 16 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_CPU_ADD(M68000, 16000000)	/* 16 MHz */
@@ -498,8 +496,12 @@ static MACHINE_DRIVER_START( superchs )
 	MDRV_VIDEO_UPDATE(superchs)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(ES5505, es5505_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(ES5505, 	13343000)
+	MDRV_SOUND_CONFIG(es5505_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 /***************************************************************************/
