@@ -55,9 +55,6 @@ TODO:
   at the end of a game without it. Note that the bootleg replaces that call with
   something else.
 
-- bitmapram2 is uncertain, it is tested during startup but never actually used
-  to draw anything during the game.
-
 
 Prebillian :
 ------------
@@ -116,6 +113,8 @@ DSW2 stored @ $f237
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/samples.h"
 
 
 extern data8_t *superqix_videoram;
@@ -136,22 +135,17 @@ VIDEO_UPDATE( superqix );
 
 
 /* pbillian sample playback */
-static int channel;
-static INT8 *samplebuf;
+static INT16 *samplebuf;
 
-int pbillian_sh_start(const struct MachineSound *msound)
+void pbillian_sh_start(void)
 {
+	UINT8 *src = memory_region(REGION_SOUND1);
 	int i;
 
-	channel = mixer_allocate_channel(50);
-	mixer_set_name(channel,"Samples");
-
 	/* convert 8-bit unsigned samples to 8-bit signed */
-	samplebuf = (INT8 *)memory_region(REGION_SOUND1);
+	samplebuf = auto_malloc(memory_region_length(REGION_SOUND1) * 2);
 	for (i = 0;i < memory_region_length(REGION_SOUND1);i++)
-		samplebuf[i] ^= 0x80;
-
-	return 0;
+		samplebuf[i] = (INT8)(src[i] ^ 0x80) * 256;
 }
 
 static WRITE8_HANDLER( pbillian_sample_trigger_w )
@@ -164,7 +158,7 @@ static WRITE8_HANDLER( pbillian_sample_trigger_w )
 	while (end < 0x8000 && samplebuf[end] != (0xff^0x80))
 		end++;
 
-	mixer_play_sample(channel, samplebuf + start, end - start, 5000, 0); /* 5khz ? */
+	sample_start_raw(0, samplebuf + start, end - start, 5000, 0); /* 5khz ? */
 }
 
 
@@ -204,13 +198,13 @@ static int from_mcu_pending, from_z80_pending, invert_coin_lockout;
 
 static READ8_HANDLER( in4_mcu_r )
 {
-/*	logerror("%04x: in4_mcu_r\n",activecpu_get_pc()); */
+/*  logerror("%04x: in4_mcu_r\n",activecpu_get_pc()); */
 	return readinputport(4) | (from_mcu_pending << 6) | (from_z80_pending << 7);
 }
 
 static READ8_HANDLER( sqix_from_mcu_r )
 {
-/*	logerror("%04x: read mcu answer (%02x)\n",activecpu_get_pc(),from_mcu); */
+/*  logerror("%04x: read mcu answer (%02x)\n",activecpu_get_pc(),from_mcu); */
 	return from_mcu;
 }
 
@@ -218,7 +212,7 @@ void mcu_acknowledge_callback(int data)
 {
 	from_z80_pending = 1;
 	from_z80 = portb;
-/*	logerror("Z80->MCU %02x\n",from_z80); */
+/*  logerror("Z80->MCU %02x\n",from_z80); */
 }
 
 static READ8_HANDLER( mcu_acknowledge_r )
@@ -229,7 +223,7 @@ static READ8_HANDLER( mcu_acknowledge_r )
 
 static WRITE8_HANDLER( sqix_z80_mcu_w )
 {
-/*	logerror("%04x: sqix_z80_mcu_w %02x\n",activecpu_get_pc(),data); */
+/*  logerror("%04x: sqix_z80_mcu_w %02x\n",activecpu_get_pc(),data); */
 	portb = data;
 }
 
@@ -265,7 +259,7 @@ static WRITE8_HANDLER( mcu_p1_w )
 		case 7:
 			if ((data & 1) == 0)
 			{
-/*				logerror("%04x: MCU -> Z80 %02x\n",activecpu_get_pc(),port3); */
+/*              logerror("%04x: MCU -> Z80 %02x\n",activecpu_get_pc(),port3); */
 				from_mcu = port3_latch;
 				from_mcu_pending = 1;
 				from_z80_pending = 0;	/* ???? */
@@ -286,7 +280,7 @@ static READ8_HANDLER( mcu_p3_r )
 	}
 	else if ((port1 & 0x40) == 0)
 	{
-/*		logerror("%04x: read Z80 command %02x\n",activecpu_get_pc(),from_z80); */
+/*      logerror("%04x: read Z80 command %02x\n",activecpu_get_pc(),from_z80); */
 		from_z80_pending = 0;
 		return from_z80;
 	}
@@ -353,26 +347,26 @@ static READ8_HANDLER(pbillian_from_mcu_r)
 		int points_per_game = ((readinputport(1) & 0x10) >> 4) + 4;
 
 		/*
-			When a goal is scored, the Z80 sends a special command - 0x80 or
-			0x81, depending on who scored. It expects the MCU to return a few
-			special commands, telling it what to do (remove ball, increase
-			score etc.)
+            When a goal is scored, the Z80 sends a special command - 0x80 or
+            0x81, depending on who scored. It expects the MCU to return a few
+            special commands, telling it what to do (remove ball, increase
+            score etc.)
 
-			0x80 = ?
-			0x81 = ?
-			0x82 = stop ball
-			0x83 = time over
-			0x84 = P1 score++
-			0x85 = P2 score++
-			0x86 = P1 game++
-			0x87 = P2 game++
-			0x88 = P1 WIN
-			0x89 = P2 WIN
-			0x8a = restart P1 side
-			0x8b = restart P2 side
-			0x8c = next game
-			0x8d = ?
-		*/
+            0x80 = ?
+            0x81 = ?
+            0x82 = stop ball
+            0x83 = time over
+            0x84 = P1 score++
+            0x85 = P2 score++
+            0x86 = P1 game++
+            0x87 = P2 game++
+            0x88 = P1 WIN
+            0x89 = P2 WIN
+            0x8a = restart P1 side
+            0x8b = restart P2 side
+            0x8c = next game
+            0x8d = ?
+        */
 
 		switch (from_z80)
 		{
@@ -429,7 +423,7 @@ static READ8_HANDLER(pbillian_from_mcu_r)
 					}
 				}
 				return 0;
-/*			case 0xf0: return 0;	// resync? */
+/*          case 0xf0: return 0;    // resync? */
 		}
 	}
 
@@ -443,7 +437,7 @@ static READ8_HANDLER(ay_port_a_r)
 	if (activecpu_get_pc() == 0x21a)
 		return 0xff;
 
-/*	logerror("%04x: ay_port_a_r\n",activecpu_get_pc()); */
+/*  logerror("%04x: ay_port_a_r\n",activecpu_get_pc()); */
 	 /* bits 76------  MCU status bits */
 	return (rand()&0xc0)|readinputport(3);
 }
@@ -805,44 +799,43 @@ static struct GfxDecodeInfo sqix_gfxdecodeinfo[] =
 
 
 
-static struct CustomSound_interface custom_interface =
+static struct Samplesinterface custom_interface =
 {
-	pbillian_sh_start,
-	0,
-	0
+	1,
+	NULL,
+	pbillian_sh_start
 };
 
 static struct AY8910interface pbillian_ay8910_interface =
 {
-	1,	/* 1 chip */
-	12000000/8,	/* 1.5 MHz */
-	{ 30 },
-	{ ay_port_a_r },					/* port Aread */
-	{ input_port_2_r },					/* port Bread */
-	{ 0 },								/* port Awrite */
-	{ 0 }								/* port Bwrite */
+	ay_port_a_r,					/* port Aread */
+	input_port_2_r					/* port Bread */
 };
 
-static struct AY8910interface sqix_ay8910_interface =
+static struct AY8910interface sqix_ay8910_interface_1 =
 {
-	2,	/* 2 chips */
-	12000000/8,	/* 1.5 MHz */
-	{ 25, 25 },
-	{ input_port_3_r, input_port_1_r },	/* port Aread */
-	{ in4_mcu_r, sqix_from_mcu_r },		/* port Bread */
-	{ 0 },								/* port Awrite */
-	{ 0, sqix_z80_mcu_w }				/* port Bwrite */
+	input_port_3_r,	/* port Aread */
+	in4_mcu_r,		/* port Bread */
 };
 
-static struct AY8910interface bootleg_ay8910_interface =
+static struct AY8910interface sqix_ay8910_interface_2 =
 {
-	2,	/* 2 chips */
-	12000000/8,	/* 1.5 MHz */
-	{ 25, 25 },
-	{ input_port_3_r, input_port_1_r },	/* port Aread */
-	{ input_port_4_r, bootleg_in0_r },	/* port Bread */
-	{ 0 },								/* port Awrite */
-	{ 0 }								/* port Bwrite */
+	input_port_1_r,	/* port Aread */
+	sqix_from_mcu_r,		/* port Bread */
+	0,								/* port Awrite */
+	sqix_z80_mcu_w				/* port Bwrite */
+};
+
+static struct AY8910interface bootleg_ay8910_interface_1 =
+{
+	input_port_3_r,	/* port Aread */
+	input_port_4_r	/* port Bread */
+};
+
+static struct AY8910interface bootleg_ay8910_interface_2 =
+{
+	input_port_1_r,	/* port Aread */
+	bootleg_in0_r	/* port Bread */
 };
 
 
@@ -867,7 +860,6 @@ static MACHINE_DRIVER_START( pbillian )
 	MDRV_CPU_ADD(Z80,12000000/2)		 /* 6 MHz */
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
 	MDRV_CPU_IO_MAP(pbillian_port_map,0)
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -883,8 +875,15 @@ static MACHINE_DRIVER_START( pbillian )
 	MDRV_VIDEO_START(pbillian)
 	MDRV_VIDEO_UPDATE(pbillian)
 
-	MDRV_SOUND_ADD(AY8910, pbillian_ay8910_interface)
-	MDRV_SOUND_ADD(CUSTOM, custom_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 12000000/8)
+	MDRV_SOUND_CONFIG(pbillian_ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(custom_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -892,7 +891,6 @@ static MACHINE_DRIVER_START( sqix )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 12000000/2)	/* 6 MHz */
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
 	MDRV_CPU_IO_MAP(sqix_port_map,0)
 	MDRV_CPU_VBLANK_INT(sqix_interrupt,6)	/* ??? */
@@ -916,7 +914,15 @@ static MACHINE_DRIVER_START( sqix )
 	MDRV_VIDEO_UPDATE(superqix)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, sqix_ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 12000000/8)
+	MDRV_SOUND_CONFIG(sqix_ay8910_interface_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 12000000/8)
+	MDRV_SOUND_CONFIG(sqix_ay8910_interface_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -924,7 +930,6 @@ static MACHINE_DRIVER_START( sqixbl )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 12000000/2)	/* 6 MHz */
-	MDRV_CPU_FLAGS(CPU_16BIT_PORT)
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
 	MDRV_CPU_IO_MAP(bootleg_port_map,0)
 	MDRV_CPU_VBLANK_INT(bootleg_interrupt,6)	/* ??? */
@@ -943,7 +948,15 @@ static MACHINE_DRIVER_START( sqixbl )
 	MDRV_VIDEO_UPDATE(superqix)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, bootleg_ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 12000000/8)
+	MDRV_SOUND_CONFIG(bootleg_ay8910_interface_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 12000000/8)
+	MDRV_SOUND_CONFIG(bootleg_ay8910_interface_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
