@@ -1,16 +1,16 @@
-/*	System18 Hardware
+/*  System18 Hardware
 **
-**	MC68000 + Z80
-**	2xYM3438 + Custom PCM
+**  MC68000 + Z80
+**  2xYM3438 + Custom PCM
 **
-**	Alien Storm
-**	Bloxeed
-**	Clutch Hitter
-**	D.D. Crew
-**	Laser Ghost
-**	Michael Jackson's Moonwalker
-**	Shadow Dancer
-**	Search Wally
+**  Alien Storm
+**  Bloxeed
+**  Clutch Hitter
+**  D.D. Crew
+**  Laser Ghost
+**  Michael Jackson's Moonwalker
+**  Shadow Dancer
+**  Search Wally
 */
 
 /*
@@ -67,10 +67,12 @@ Other notes:
 #include "system16.h"
 #include "cpu/m68000/m68000.h"
 #include "machine/fd1094.h"
+#include "sound/msm5205.h"
+#include "sound/2612intf.h"
+#include "sound/rf5c68.h"
 
 void fd1094_machine_init(void);
 void fd1094_driver_init(void);
-extern WRITE16_HANDLER( sys18_extrombank_w );
 
 /* vidhrdw/segac2.c */
 extern void update_system18_vdp( struct mame_bitmap *bitmap, const struct rectangle *cliprect );
@@ -132,37 +134,37 @@ static void set_bg2_page( int data ){
 
 /***************************************************************************/
 /*
-	Sound hardware for Shadow Dancer (Datsu bootleg)
+    Sound hardware for Shadow Dancer (Datsu bootleg)
 
-	Z80 memory map
-	0000-7FFF : ROM (fixed)
-	8000-BFFF : ROM (banked)
-	C000-C007 : ?
-	C400      : Sound command (r/o)
-	C800      : MSM5205 sample data output (w/o)
-	CC00-CC03 : YM3438 #1
-	D000-D003 : YM3438 #2
-	D400      : ROM bank control (w/o)
-	DF00-DFFF : ?
-	E000-FFFF : Work RAM
+    Z80 memory map
+    0000-7FFF : ROM (fixed)
+    8000-BFFF : ROM (banked)
+    C000-C007 : ?
+    C400      : Sound command (r/o)
+    C800      : MSM5205 sample data output (w/o)
+    CC00-CC03 : YM3438 #1
+    D000-D003 : YM3438 #2
+    D400      : ROM bank control (w/o)
+    DF00-DFFF : ?
+    E000-FFFF : Work RAM
 
-	The unused memory locations and I/O port access seem to be remnants of the original code that were not patched out:
+    The unused memory locations and I/O port access seem to be remnants of the original code that were not patched out:
 
-	- Program accesses RF5C68A channel registes at $C000-$C007
-	- Program clears RF5C68A wave memory at $DF00-$DFFF
-	- Program writes to port $A0 to access sound ROM banking control latch
-	- Program reads port $C0 to access sound command
+    - Program accesses RF5C68A channel registes at $C000-$C007
+    - Program clears RF5C68A wave memory at $DF00-$DFFF
+    - Program writes to port $A0 to access sound ROM banking control latch
+    - Program reads port $C0 to access sound command
 
-	Interrupts
+    Interrupts
 
-	IRQ = Triggered when 68000 writes sound command. Z80 reads from $C400.
-	NMI = Triggered when second nibble of sample data has been output to the MSM5205.
-	      Program copies sample data from ROM bank to the MSM5205 sample data buffer at $C800.
+    IRQ = Triggered when 68000 writes sound command. Z80 reads from $C400.
+    NMI = Triggered when second nibble of sample data has been output to the MSM5205.
+          Program copies sample data from ROM bank to the MSM5205 sample data buffer at $C800.
 
-	ROM banking seems correct.
-	It doesn't look like there's a way to reset the MSM5205, unless that's related to bit 7 of the
-	ROM bank control register.
-	MSM5205 clock speed hasn't been confirmed.
+    ROM banking seems correct.
+    It doesn't look like there's a way to reset the MSM5205, unless that's related to bit 7 of the
+    ROM bank control register.
+    MSM5205 clock speed hasn't been confirmed.
 */
 /***************************************************************************/
 
@@ -185,11 +187,8 @@ static void shdancbl_msm5205_callback(int data)
 
 static struct MSM5205interface shdancbl_msm5205_interface =
 {
-	1,
-	200000, /* 200KHz */
-	{ shdancbl_msm5205_callback },
-	{ MSM5205_S48_4B},
-	{ 80 }
+	shdancbl_msm5205_callback,
+	MSM5205_S48_4B
 };
 
 UINT8* shdancbl_soundbank_ptr = NULL;		/* Pointer to currently selected portion of ROM */
@@ -236,14 +235,14 @@ static ADDRESS_MAP_START( shdancbl_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
 	AM_RANGE(0x8000, 0xbfff) AM_READ(shdancbl_soundbank_r)
 	AM_RANGE(0xc400, 0xc400) AM_READ(soundlatch_r)
-	AM_RANGE(0xcc00, 0xcc00) AM_READ(YM2612_status_port_0_A_r)
-	AM_RANGE(0xcc01, 0xcc01) AM_READ(YM2612_status_port_0_B_r)
-	AM_RANGE(0xcc02, 0xcc02) AM_READ(YM2612_status_port_0_B_r)
-	AM_RANGE(0xcc03, 0xcc03) AM_READ(YM2612_status_port_0_B_r)
-	AM_RANGE(0xd000, 0xd000) AM_READ(YM2612_status_port_1_A_r)
-	AM_RANGE(0xd001, 0xd001) AM_READ(YM2612_status_port_1_B_r)
-	AM_RANGE(0xd002, 0xd002) AM_READ(YM2612_status_port_1_B_r)
-	AM_RANGE(0xd003, 0xd003) AM_READ(YM2612_status_port_1_B_r)
+	AM_RANGE(0xcc00, 0xcc00) AM_READ(YM3438_status_port_0_A_r)
+	AM_RANGE(0xcc01, 0xcc01) AM_READ(YM3438_status_port_0_B_r)
+	AM_RANGE(0xcc02, 0xcc02) AM_READ(YM3438_status_port_0_B_r)
+	AM_RANGE(0xcc03, 0xcc03) AM_READ(YM3438_status_port_0_B_r)
+	AM_RANGE(0xd000, 0xd000) AM_READ(YM3438_status_port_1_A_r)
+	AM_RANGE(0xd001, 0xd001) AM_READ(YM3438_status_port_1_B_r)
+	AM_RANGE(0xd002, 0xd002) AM_READ(YM3438_status_port_1_B_r)
+	AM_RANGE(0xd003, 0xd003) AM_READ(YM3438_status_port_1_B_r)
 	AM_RANGE(0xdf00, 0xdfff) AM_READ(MRA8_NOP)
 	AM_RANGE(0xe000, 0xffff) AM_READ(MRA8_RAM)
 ADDRESS_MAP_END
@@ -253,24 +252,26 @@ static ADDRESS_MAP_START(shdancbl_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0xbfff) AM_WRITE(MWA8_NOP) /* ROM bank */
 	AM_RANGE(0xc000, 0xc00f) AM_WRITE(MWA8_NOP)
 	AM_RANGE(0xc800, 0xc800) AM_WRITE(shdancbl_msm5205_data_w)
-	AM_RANGE(0xcc00, 0xcc00) AM_WRITE(YM2612_control_port_0_A_w)
-	AM_RANGE(0xcc01, 0xcc01) AM_WRITE(YM2612_data_port_0_A_w)
-	AM_RANGE(0xcc02, 0xcc02) AM_WRITE(YM2612_control_port_0_B_w)
-	AM_RANGE(0xcc03, 0xcc03) AM_WRITE(YM2612_data_port_0_B_w)
-	AM_RANGE(0xd000, 0xd000) AM_WRITE(YM2612_control_port_1_A_w)
-	AM_RANGE(0xd001, 0xd001) AM_WRITE(YM2612_data_port_1_A_w)
-	AM_RANGE(0xd002, 0xd002) AM_WRITE(YM2612_control_port_1_B_w)
-	AM_RANGE(0xd003, 0xd003) AM_WRITE(YM2612_data_port_1_B_w)
+	AM_RANGE(0xcc00, 0xcc00) AM_WRITE(YM3438_control_port_0_A_w)
+	AM_RANGE(0xcc01, 0xcc01) AM_WRITE(YM3438_data_port_0_A_w)
+	AM_RANGE(0xcc02, 0xcc02) AM_WRITE(YM3438_control_port_0_B_w)
+	AM_RANGE(0xcc03, 0xcc03) AM_WRITE(YM3438_data_port_0_B_w)
+	AM_RANGE(0xd000, 0xd000) AM_WRITE(YM3438_control_port_1_A_w)
+	AM_RANGE(0xd001, 0xd001) AM_WRITE(YM3438_data_port_1_A_w)
+	AM_RANGE(0xd002, 0xd002) AM_WRITE(YM3438_control_port_1_B_w)
+	AM_RANGE(0xd003, 0xd003) AM_WRITE(YM3438_data_port_1_B_w)
 	AM_RANGE(0xd400, 0xd400) AM_WRITE(shdancbl_bankctrl_w)
 	AM_RANGE(0xdf00, 0xdfff) AM_WRITE(MWA8_NOP)
 	AM_RANGE(0xe000, 0xffff) AM_WRITE(MWA8_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( shdancbl_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xc0, 0xdf) AM_READ(MRA8_NOP)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( shdancbl_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xa0, 0xbf) AM_WRITE(MWA8_NOP)
 ADDRESS_MAP_END
 
@@ -315,22 +316,24 @@ static WRITE8_HANDLER( sys18_soundbank_w )
 
 
 static ADDRESS_MAP_START( sound_readport_18, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x80, 0x80) AM_READ(YM2612_status_port_0_A_r)
-/*	AM_RANGE(0x82, 0x82) AM_READ(YM2612_status_port_0_B_r) */
-/*	AM_RANGE(0x90, 0x90) AM_READ(YM2612_status_port_1_A_r) */
-/*	AM_RANGE(0x92, 0x92) AM_READ(YM2612_status_port_1_B_r) */
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x80, 0x80) AM_READ(YM3438_status_port_0_A_r)
+/*  AM_RANGE(0x82, 0x82) AM_READ(YM3438_status_port_0_B_r) */
+/*  AM_RANGE(0x90, 0x90) AM_READ(YM3438_status_port_1_A_r) */
+/*  AM_RANGE(0x92, 0x92) AM_READ(YM3438_status_port_1_B_r) */
 	AM_RANGE(0xc0, 0xc0) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport_18, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x80, 0x80) AM_WRITE(YM2612_control_port_0_A_w)
-	AM_RANGE(0x81, 0x81) AM_WRITE(YM2612_data_port_0_A_w)
-	AM_RANGE(0x82, 0x82) AM_WRITE(YM2612_control_port_0_B_w)
-	AM_RANGE(0x83, 0x83) AM_WRITE(YM2612_data_port_0_B_w)
-	AM_RANGE(0x90, 0x90) AM_WRITE(YM2612_control_port_1_A_w)
-	AM_RANGE(0x91, 0x91) AM_WRITE(YM2612_data_port_1_A_w)
-	AM_RANGE(0x92, 0x92) AM_WRITE(YM2612_control_port_1_B_w)
-	AM_RANGE(0x93, 0x93) AM_WRITE(YM2612_data_port_1_B_w)
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	AM_RANGE(0x80, 0x80) AM_WRITE(YM3438_control_port_0_A_w)
+	AM_RANGE(0x81, 0x81) AM_WRITE(YM3438_data_port_0_A_w)
+	AM_RANGE(0x82, 0x82) AM_WRITE(YM3438_control_port_0_B_w)
+	AM_RANGE(0x83, 0x83) AM_WRITE(YM3438_data_port_0_B_w)
+	AM_RANGE(0x90, 0x90) AM_WRITE(YM3438_control_port_1_A_w)
+	AM_RANGE(0x91, 0x91) AM_WRITE(YM3438_data_port_1_A_w)
+	AM_RANGE(0x92, 0x92) AM_WRITE(YM3438_control_port_1_B_w)
+	AM_RANGE(0x93, 0x93) AM_WRITE(YM3438_data_port_1_B_w)
 	AM_RANGE(0xa0, 0xa0) AM_WRITE(sys18_soundbank_w)
 ADDRESS_MAP_END
 
@@ -344,7 +347,7 @@ static WRITE16_HANDLER( sound_command_nmi_w ){
 /***************************************************************************/
 
 /*
-	315-5313 Video Display Processor (VDP) emulation
+    315-5313 Video Display Processor (VDP) emulation
 */
 
 struct {
@@ -469,30 +472,11 @@ static READ16_HANDLER( vdp_r )
 /***************************************************************************/
 
 /*
-	315-5296 I/O chip emulation
+    315-5296 I/O chip emulation
 */
 
 static int io_reg[0x10];
 
-void sys18_io_reset(void)
-{
-	/* All output latches are reset */
-	io_reg[0x00] = 0x00;
-	io_reg[0x01] = 0x00;
-	io_reg[0x02] = 0x00;
-	io_reg[0x03] = 0x00;
-	io_reg[0x04] = 0x00;
-	io_reg[0x05] = 0x00;
-	io_reg[0x06] = 0x00;
-	io_reg[0x07] = 0x00;
-
-	/* CNT2-0 pins reset */
-	io_reg[0x0E] = 0x00;
-
-	/* All ports are inputs */
-	io_reg[0x0F] = 0x00;
-}
-
 static READ16_HANDLER( sys18_io_r )
 {
 	if(ACCESSING_LSB)
@@ -655,216 +639,59 @@ static WRITE16_HANDLER( sys18_io_w )
 				break;
 
 			case 0x3000/2: /* Expansion connector */
-/*				logerror("write expansion area %06X = %04X (%06X)\n", offset, data, activecpu_get_pc()); */
+/*              logerror("write expansion area %06X = %04X (%06X)\n", offset, data, activecpu_get_pc()); */
 				break;
 		}
 	}
 }
 
-/***************************************************************************/
-/*
-	Shadow Dancer (Export)
-*/
-/***************************************************************************/
 
-static ADDRESS_MAP_START( shdancer_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x400000, 0x40ffff) AM_READ(SYS16_MRA16_TILERAM)
-	AM_RANGE(0x410000, 0x410fff) AM_READ(SYS16_MRA16_TEXTRAM)
-	AM_RANGE(0x440000, 0x440fff) AM_READ(SYS16_MRA16_SPRITERAM)
-	AM_RANGE(0x840000, 0x840fff) AM_READ(SYS16_MRA16_PALETTERAM)
-	AM_RANGE(0xc00000, 0xc0ffff) AM_READ(vdp_r);
-	AM_RANGE(0xe40000, 0xe4ffff) AM_READ(sys18_io_r)
-	AM_RANGE(0xffc000, 0xffffff) AM_READ(SYS16_MRA16_WORKINGRAM)
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( shdancer_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x400000, 0x40ffff) AM_WRITE(SYS16_MWA16_TILERAM) AM_BASE(&sys16_tileram)
-	AM_RANGE(0x410000, 0x410fff) AM_WRITE(SYS16_MWA16_TEXTRAM) AM_BASE(&sys16_textram)
-	AM_RANGE(0x440000, 0x440fff) AM_WRITE(SYS16_MWA16_SPRITERAM) AM_BASE(&sys16_spriteram)
-	AM_RANGE(0x840000, 0x840fff) AM_WRITE(SYS16_MWA16_PALETTERAM) AM_BASE(&paletteram16)
-	AM_RANGE(0xc00000, 0xc0ffff) AM_WRITE(vdp_w)
-	AM_RANGE(0xe40000, 0xe4ffff) AM_WRITE(sys18_io_w)
-	AM_RANGE(0xfe0006, 0xfe0007) AM_WRITE(sound_command_nmi_w)
-	AM_RANGE(0xfe0020, 0xfe003f) AM_WRITE(MWA16_NOP) /* config regs */
-	AM_RANGE(0xffc000, 0xffffff) AM_WRITE(SYS16_MWA16_WORKINGRAM) AM_BASE(&sys16_workingram)
-ADDRESS_MAP_END
 
 /***************************************************************************/
 
-static void shdancer_update_proc( void ){
-	sys16_fg_scrolly = sys16_textram[0x0e90/2];
-	sys16_bg_scrolly = sys16_textram[0x0e92/2];
-	sys16_fg_scrollx = sys16_textram[0x0e98/2];
-	sys16_bg_scrollx = sys16_textram[0x0e9a/2];
 
-	set_fg_page( sys16_textram[0x0e80/2] );
-	set_bg_page( sys16_textram[0x0e82/2] );
 
-	sys16_fg2_scrollx = sys16_textram[0x0e9c/2];
-	sys16_bg2_scrollx = sys16_textram[0x0e9e/2];
-	sys16_fg2_scrolly = sys16_textram[0x0e94/2];
-	sys16_bg2_scrolly = sys16_textram[0x0e96/2];
-
-	set_fg2_page( sys16_textram[0x0e84/2] );
-	set_bg2_page( sys16_textram[0x0e86/2] );
-
-	sys18_bg2_active=0;
-	sys18_fg2_active=0;
-
-	if(sys16_fg2_scrollx | sys16_fg2_scrolly | sys16_textram[0x0e84/2]) sys18_fg2_active=1;
-	if(sys16_bg2_scrollx | sys16_bg2_scrolly | sys16_textram[0x0e86/2]) sys18_bg2_active=1;
-}
-
-static MACHINE_INIT( shdancer ){
-	sys16_update_proc = shdancer_update_proc;
-
-	sys18_io_reset();
-}
-
-static READ16_HANDLER( shdancer_skip_r ){
-	if (activecpu_get_pc()==0x2f76) {cpu_spinuntil_int(); return 0xffff;}
-	return sys16_workingram[0];
-}
-
-static DRIVER_INIT( shdancer ){
-	unsigned char *RAM = memory_region(REGION_CPU2);
-	static const int shdancer_sound_info[] =
-	{
-		0x0f, 0x00000, /* ROM #1 = 128K */
-		0x1f, 0x20000, /* ROM #2 = 256K */
-		0x1f, 0x60000, /* ROM #3 = 256K */
-		0x1f, 0xA0000  /* ROM #4 = 256K */
-	};
-
-	machine_init_sys16_onetime();
-	sys18_splittab_fg_x=&sys16_textram[0x0f80/2];
-	sys18_splittab_bg_x=&sys16_textram[0x0fc0/2];
-	sys16_MaxShadowColors=0;
-	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0xffc000, 0xffc001, 0, 0, shdancer_skip_r );
-
-	memcpy(sys18_sound_info, shdancer_sound_info, sizeof(sys18_sound_info));
-	memcpy(RAM,&RAM[0x10000],0xa000);
-}
-
-/***************************************************************************/
-/*
-	Shadow Dancer (Japan)
-*/
-/***************************************************************************/
-
-static READ16_HANDLER( shdancrj_skip_r ){
-	if (activecpu_get_pc()==0x2f70) {cpu_spinuntil_int(); return 0xffff;}
-	return sys16_workingram[0];
-}
-
-static MACHINE_INIT( shdancrj ){
-/*	sys16_patch_code(0x6821, 0xdf);    ?    */
-	sys16_update_proc = shdancer_update_proc;
-}
-
-static DRIVER_INIT( shdancrj ){
-	unsigned char *RAM = memory_region(REGION_CPU2);
-	static const int shdancrj_sound_info[] =
-	{
-		0x0f, 0x00000, /* ROM #1 = 128K */
-		0x1f, 0x20000, /* ROM #2 = 256K */
-		0x1f, 0x60000, /* ROM #3 = 256K */
-		0x1f, 0xA0000  /* ROM #4 = 256K */
-	};
-
-	machine_init_sys16_onetime();
-	sys18_splittab_fg_x=&sys16_textram[0x0f80/2];
-	sys18_splittab_bg_x=&sys16_textram[0x0fc0/2];
-	sys16_MaxShadowColors=0;
-	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0xffc000, 0xffc001, 0, 0, shdancrj_skip_r );
-
-	memcpy(sys18_sound_info, shdancrj_sound_info, sizeof(sys18_sound_info));
-	memcpy(RAM,&RAM[0x10000],0xa000);
-}
 
 
 /***************************************************************************/
 /*
-	Shadow Dancer (Export, Rev.B)
+    Shadow Dancer (Bootleg)
 
-	- Program code has more similarities with shdancrj than shdancer
-	- Input test only shows 1P joystick (all other versions include 2P)
-	- It does not display the warning screen and has English text in the attract sequence like shdancer
-	- ROM board has a sticker with 'Rev.B' printed on it
-*/
-/***************************************************************************/
+    This seems to be a modified version of shdancer. It has no warning screen, displays English text during the
+    attract sequence, and has a 2P input test. The 'Sega' copyright text was changed to 'Datsu', and their
+    logo is missing.
 
-static READ16_HANDLER( shdancrb_skip_r ){
-	if (activecpu_get_pc()==0x2f70) {  cpu_spinuntil_int(); return 0xffff; }
-	return sys16_workingram[0];
-}
+    Access to the configuration registers, I/O chip, and VDP are done even though it's likely none of this hardware
+    exists in the bootleg. For example:
 
-static MACHINE_INIT( shdancrb ){
-	sys16_update_proc = shdancer_update_proc;
-}
+    - Most I/O port access has been redirected to new addresses.
+    - Z80 sound command has been redirected to a new address.
+    - The tilebank routine which saves the bank value in VDP VRAM has a form of protection has been modified to store
+      the tilebank value directly to $E4001F.
+    - Implementing screen blanking control via $E4001D leaves the screen blanked at the wrong times (after coin-up).
 
-static DRIVER_INIT( shdancrb ){
-	unsigned char *RAM = memory_region(REGION_CPU2);
-	static const int shdancrb_sound_info[] =
-	{
-		0x0f, 0x00000, /* ROM #1 = 128K */
-		0x1f, 0x20000, /* ROM #2 = 256K */
-		0x1f, 0x60000, /* ROM #3 = 256K */
-		0x1f, 0xA0000  /* ROM #4 = 256K */
-	};
+    This is probably due to unmodified parts of the original code accessing these components, which would be ignored
+    on the bootleg hardware. Both the I/O chip and VDP are supported in this driver, just as I don't know for certain
+    how much of either are present on the real board.
 
-	machine_init_sys16_onetime();
-	sys18_splittab_fg_x=&sys16_textram[0x0f80/2];
-	sys18_splittab_bg_x=&sys16_textram[0x0fc0/2];
-	sys16_MaxShadowColors=0;
-	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0xffc000, 0xffc001, 0, 0, shdancrb_skip_r );
+    Bootleg specific addresses:
 
-	memcpy(sys18_sound_info, shdancrb_sound_info, sizeof(sys18_sound_info));
-	memcpy(RAM,&RAM[0x10000],0xa000);
-}
+    C40001 = DIP switch #1
+    C40003 = DIP switch #2
+    C40007 = Z80 sound command
+    C41001 = Service input
+    C41003 = Player 1 input
+    C41005 = Player 2 input
+    C44000 = Has 'clr.w' done after setting tile bank in $E4000F.
+    C460xx = Extra video hardware controls
 
-/***************************************************************************/
-/*
-	Shadow Dancer (Bootleg)
+    Here are the I/O chip addresses accessed:
 
-	This seems to be a modified version of shdancer. It has no warning screen, displays English text during the
-	attract sequence, and has a 2P input test. The 'Sega' copyright text was changed to 'Datsu', and their
-	logo is missing.
-
-	Access to the configuration registers, I/O chip, and VDP are done even though it's likely none of this hardware
-	exists in the bootleg. For example:
-
-	- Most I/O port access has been redirected to new addresses.
-	- Z80 sound command has been redirected to a new address.
-	- The tilebank routine which saves the bank value in VDP VRAM has a form of protection has been modified to store
-	  the tilebank value directly to $E4001F.
-	- Implementing screen blanking control via $E4001D leaves the screen blanked at the wrong times (after coin-up).
-
-	This is probably due to unmodified parts of the original code accessing these components, which would be ignored
-	on the bootleg hardware. Both the I/O chip and VDP are supported in this driver, just as I don't know for certain
-	how much of either are present on the real board.
-
-	Bootleg specific addresses:
-
-	C40001 = DIP switch #1
-	C40003 = DIP switch #2
-	C40007 = Z80 sound command
-	C41001 = Service input
-	C41003 = Player 1 input
-	C41005 = Player 2 input
-	C44000 = Has 'clr.w' done after setting tile bank in $E4000F.
-	C460xx = Extra video hardware controls
-
-	Here are the I/O chip addresses accessed:
-
-	E40001 = Player 1
-	E40007 = Miscellaneous outputs (coin control, etc.)
-	E4000F = Tile bank
-	E4001D = CNT2-0 pin output state
-	E4001F = I/O chip port direction
+    E40001 = Player 1
+    E40007 = Miscellaneous outputs (coin control, etc.)
+    E4000F = Tile bank
+    E4001D = CNT2-0 pin output state
+    E4001F = I/O chip port direction
 */
 /***************************************************************************/
 
@@ -964,7 +791,7 @@ static DRIVER_INIT( shdancbl )
 
 /***************************************************************************/
 /*
-	Moonwalker (Bootleg)
+    Moonwalker (Bootleg)
 */
 /***************************************************************************/
 
@@ -973,29 +800,6 @@ static READ16_HANDLER( mwalkbl_skip_r ){
 	return sys16_workingram[0x202c/2];
 }
 
-static ADDRESS_MAP_START( mwalk_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x400000, 0x40ffff) AM_READ(SYS16_MRA16_TILERAM)
-	AM_RANGE(0x410000, 0x410fff) AM_READ(SYS16_MRA16_TEXTRAM)
-	AM_RANGE(0x440000, 0x440fff) AM_READ(SYS16_MRA16_SPRITERAM)
-	AM_RANGE(0x840000, 0x840fff) AM_READ(SYS16_MRA16_PALETTERAM)
-	AM_RANGE(0xe40000, 0xe4ffff) AM_READ(sys18_io_r)
-	AM_RANGE(0xc00000, 0xc0ffff) AM_READ(segac2_vdp_r)
-	AM_RANGE(0xffc000, 0xffffff) AM_READ(SYS16_MRA16_WORKINGRAM)
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( mwalk_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x400000, 0x40ffff) AM_WRITE(SYS16_MWA16_TILERAM) AM_BASE(&sys16_tileram)
-	AM_RANGE(0x410000, 0x410fff) AM_WRITE(SYS16_MWA16_TEXTRAM) AM_BASE(&sys16_textram)
-	AM_RANGE(0x440000, 0x440fff) AM_WRITE(SYS16_MWA16_SPRITERAM) AM_BASE(&sys16_spriteram)
-	AM_RANGE(0x840000, 0x840fff) AM_WRITE(SYS16_MWA16_PALETTERAM) AM_BASE(&paletteram16)
-	AM_RANGE(0xe40000, 0xe4ffff) AM_WRITE(sys18_io_w)
-	AM_RANGE(0xc00000, 0xc0ffff) AM_WRITE(segac2_vdp_w)
-	AM_RANGE(0xfe0020, 0xfe003f) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xffc000, 0xffffff) AM_WRITE(SYS16_MWA16_WORKINGRAM) AM_BASE(&sys16_workingram)
-ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( mwalkbl_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM)
@@ -1126,33 +930,8 @@ static DRIVER_INIT( mwalkbl ){
 
 /***************************************************************************/
 
-static ADDRESS_MAP_START( astorm_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_READ(SYS16_MRA16_TILERAM)
-	AM_RANGE(0x110000, 0x110fff) AM_READ(SYS16_MRA16_TEXTRAM)
-	AM_RANGE(0x140000, 0x140fff) AM_READ(SYS16_MRA16_PALETTERAM)
-	AM_RANGE(0x200000, 0x200fff) AM_READ(SYS16_MRA16_SPRITERAM)
-	AM_RANGE(0xa00000, 0xa0ffff) AM_READ(sys18_io_r)
-	AM_RANGE(0xc00000, 0xc0ffff) AM_READ(segac2_vdp_r)
-	AM_RANGE(0xffc000, 0xffffff) AM_READ(SYS16_MRA16_WORKINGRAM)
-ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( astorm_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(SYS16_MWA16_TILERAM) AM_BASE(&sys16_tileram)
-	AM_RANGE(0x110000, 0x110fff) AM_WRITE(SYS16_MWA16_TEXTRAM) AM_BASE(&sys16_textram)
-	AM_RANGE(0x140000, 0x140fff) AM_WRITE(SYS16_MWA16_PALETTERAM) AM_BASE(&paletteram16)
-	AM_RANGE(0x200000, 0x200fff) AM_WRITE(SYS16_MWA16_SPRITERAM) AM_BASE(&sys16_spriteram)
-	AM_RANGE(0xa00006, 0xa00007) AM_WRITE(sound_command_nmi_w)
-	AM_RANGE(0xa0000e, 0xa0000f) AM_WRITE(sys18_tilebank_w)
-	AM_RANGE(0xa0001c, 0xa0001d) AM_WRITE(sys18_refreshenable_w)
-	AM_RANGE(0xc00000, 0xc0ffff) AM_WRITE(segac2_vdp_w)
-/*	AM_RANGE(0xc46600, 0xc46601) AM_WRITE(sys18_refreshenable_w) */
-	AM_RANGE(0xfe0020, 0xfe003f) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xffc000, 0xffffff) AM_WRITE(SYS16_MWA16_WORKINGRAM) AM_BASE(&sys16_workingram)
-ADDRESS_MAP_END
-
 /* bootleg doesn't have real vdp or i/o */
 
 static ADDRESS_MAP_START( astormbl_readmem, ADDRESS_SPACE_PROGRAM, 16 )
@@ -1187,77 +966,8 @@ static ADDRESS_MAP_START( astormbl_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( cltchitr_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x200000, 0x27ffff) AM_READ(MRA16_ROM)
-
-	AM_RANGE(0x400000, 0x40ffff) AM_READ(SYS16_MRA16_TILERAM)
-	AM_RANGE(0x410000, 0x410fff) AM_READ(SYS16_MRA16_TEXTRAM)
-	AM_RANGE(0x840000, 0x840fff) AM_READ(SYS16_MRA16_PALETTERAM)
-	AM_RANGE(0x440000, 0x440fff) AM_READ(SYS16_MRA16_SPRITERAM)
-	AM_RANGE(0xa40000, 0xa4ffff) AM_READ(sys18_io_r)
-	AM_RANGE(0xc00000, 0xc0ffff) AM_READ(segac2_vdp_r)
 
 
-	AM_RANGE(0xffc000, 0xffffff) AM_READ(SYS16_MRA16_WORKINGRAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( cltchitr_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x200000, 0x27ffff) AM_WRITE(MWA16_ROM)
-
-	AM_RANGE(0x3e0000, 0x3e001f) AM_WRITE(sys18_extrombank_w)
-
-	AM_RANGE(0x400000, 0x40ffff) AM_WRITE(SYS16_MWA16_TILERAM) AM_BASE(&sys16_tileram)
-	AM_RANGE(0x410000, 0x410fff) AM_WRITE(SYS16_MWA16_TEXTRAM) AM_BASE(&sys16_textram)
-	AM_RANGE(0x840000, 0x840fff) AM_WRITE(SYS16_MWA16_PALETTERAM) AM_BASE(&paletteram16)
-	AM_RANGE(0x440000, 0x440fff) AM_WRITE(SYS16_MWA16_SPRITERAM) AM_BASE(&sys16_spriteram)
-	AM_RANGE(0xa40006, 0xa40007) AM_WRITE(sound_command_nmi_w)
-
-	AM_RANGE(0xa4001c, 0xa4001d) AM_WRITE(sys18_refreshenable_w)
-	AM_RANGE(0xa4001e, 0xa4001f) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa42000, 0xa42001) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa43034, 0xa43035) AM_WRITE(MWA16_NOP)
-
-	AM_RANGE(0xc00000, 0xc0ffff) AM_WRITE(segac2_vdp_w)
-
-	AM_RANGE(0xfe0006, 0xfe0007) AM_WRITE(sound_command_nmi_w)
-
-	AM_RANGE(0xfe0020, 0xfe003f) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xffc000, 0xffffff) AM_WRITE(SYS16_MWA16_WORKINGRAM) AM_BASE(&sys16_workingram)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( ddcrew_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x2fffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x400000, 0x40ffff) AM_READ(SYS16_MRA16_TILERAM)
-	AM_RANGE(0x410000, 0x410fff) AM_READ(SYS16_MRA16_TEXTRAM)
-	AM_RANGE(0x840000, 0x840fff) AM_READ(SYS16_MRA16_PALETTERAM)
-	AM_RANGE(0x440000, 0x440fff) AM_READ(SYS16_MRA16_SPRITERAM)
-	AM_RANGE(0xe40000, 0xe4ffff) AM_READ(sys18_io_r)
-	AM_RANGE(0xc00000, 0xc0ffff) AM_READ(segac2_vdp_r)
-	AM_RANGE(0xffc000, 0xffffff) AM_READ(SYS16_MRA16_WORKINGRAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( ddcrew_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x2fffff) AM_WRITE(MWA16_ROM)
-
-	AM_RANGE(0x3e0000, 0x3e001f) AM_WRITE(sys18_extrombank_w)
-
-	AM_RANGE(0x400000, 0x40ffff) AM_WRITE(SYS16_MWA16_TILERAM) AM_BASE(&sys16_tileram)
-	AM_RANGE(0x410000, 0x410fff) AM_WRITE(SYS16_MWA16_TEXTRAM) AM_BASE(&sys16_textram)
-	AM_RANGE(0x840000, 0x840fff) AM_WRITE(SYS16_MWA16_PALETTERAM) AM_BASE(&paletteram16)
-	AM_RANGE(0x440000, 0x440fff) AM_WRITE(SYS16_MWA16_SPRITERAM) AM_BASE(&sys16_spriteram)
-	AM_RANGE(0xe40006, 0xe40007) AM_WRITE(sound_command_nmi_w)
-
-	AM_RANGE(0xe4001c, 0xe4001d) AM_WRITE(sys18_refreshenable_w)
-
-
-
-/*	AM_RANGE(0xe4000e, 0xe4000f) AM_WRITE(sys18_tilebank_w) */
-	AM_RANGE(0xc00000, 0xc0ffff) AM_WRITE(segac2_vdp_w)
-	AM_RANGE(0xfe0020, 0xfe003f) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xffc000, 0xffffff) AM_WRITE(SYS16_MWA16_WORKINGRAM) AM_BASE(&sys16_workingram)
-ADDRESS_MAP_END
 
 /***************************************************************************/
 
@@ -1378,13 +1088,6 @@ static MACHINE_INIT( astormbl ){
 
 
 
-static MACHINE_INIT( astorm )
-{
-	fd1094_machine_init();
-
-/*	sys16_fgxoffset = sys16_bgxoffset = -9; */
-	sys16_update_proc = shdancer_update_proc;
-}
 
 
 
@@ -1407,38 +1110,9 @@ static DRIVER_INIT( astormbl ){
 	memcpy(RAM,&RAM[0x10000],0xa000);
 }
 
-static DRIVER_INIT( astorm )
-{
-	init_astormbl();
-
-	fd1094_driver_init();
-}
 
 
 
-
-static MACHINE_INIT( ddcrew )
-{
-	fd1094_machine_init();
-
-/*	sys16_fgxoffset = sys16_bgxoffset = -9; */
-	sys16_update_proc = shdancer_update_proc;
-}
-
-static DRIVER_INIT( cltchitr )
-{
-	machine_init_sys16_onetime();
-
-	fd1094_driver_init();
-}
-
-static DRIVER_INIT( ddcrew )
-{
-	machine_init_sys16_onetime();
-
-	fd1094_driver_init();
-}
-
 /*****************************************************************************/
 
 static MACHINE_DRIVER_START( system18 )
@@ -1448,7 +1122,7 @@ static MACHINE_DRIVER_START( system18 )
 	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
 
 	MDRV_CPU_ADD_TAG("sound", Z80, 8000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem_18,sound_writemem_18)
 	MDRV_CPU_IO_MAP(sound_readport_18,sound_writeport_18)
 
@@ -1466,21 +1140,26 @@ static MACHINE_DRIVER_START( system18 )
 	MDRV_VIDEO_UPDATE(system18old)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD_TAG("3438", YM3438, sys18_ym3438_interface)
-	MDRV_SOUND_ADD_TAG("5c68", RF5C68, sys18_rf5c68_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD_TAG("3438.0", YM3438, 8000000)
+	MDRV_SOUND_ROUTE(0, "left", 0.40)
+	MDRV_SOUND_ROUTE(1, "right", 0.40)
+	MDRV_SOUND_ROUTE(2, "left", 0.40)
+	MDRV_SOUND_ROUTE(3, "right", 0.40)
+
+	MDRV_SOUND_ADD_TAG("3438.1", YM3438, 8000000)
+	MDRV_SOUND_ROUTE(0, "left", 0.40)
+	MDRV_SOUND_ROUTE(1, "right", 0.40)
+	MDRV_SOUND_ROUTE(2, "left", 0.40)
+	MDRV_SOUND_ROUTE(3, "right", 0.40)
+
+	MDRV_SOUND_ADD_TAG("5c68", RF5C68, 8000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 
-static MACHINE_DRIVER_START( astorm )
-
-	/* basic machine hardware */
-	MDRV_IMPORT_FROM(system18)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(astorm_readmem,astorm_writemem)
-
-	MDRV_MACHINE_INIT(astorm)
-MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( astormbl )
 
@@ -1492,35 +1171,7 @@ static MACHINE_DRIVER_START( astormbl )
 	MDRV_MACHINE_INIT(astormbl)
 MACHINE_DRIVER_END
 
-static MACHINE_DRIVER_START( cltchitr )
 
-	/* basic machine hardware */
-	MDRV_IMPORT_FROM(system18)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(cltchitr_readmem,cltchitr_writemem)
-
-	MDRV_MACHINE_INIT(ddcrew)
-MACHINE_DRIVER_END
-
-static MACHINE_DRIVER_START( ddcrew )
-
-	/* basic machine hardware */
-	MDRV_IMPORT_FROM(system18)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(ddcrew_readmem,ddcrew_writemem)
-
-	MDRV_MACHINE_INIT(ddcrew)
-MACHINE_DRIVER_END
-
-static MACHINE_DRIVER_START( mwalk )
-
-	/* basic machine hardware */
-	MDRV_IMPORT_FROM(system18)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(mwalk_readmem,mwalk_writemem)
-
-	MDRV_MACHINE_INIT(astorm)
-MACHINE_DRIVER_END
 
 
 static MACHINE_DRIVER_START( mwalkbl )
@@ -1534,15 +1185,6 @@ static MACHINE_DRIVER_START( mwalkbl )
 MACHINE_DRIVER_END
 
 
-static MACHINE_DRIVER_START( shdancer )
-
-	/* basic machine hardware */
-	MDRV_IMPORT_FROM(system18)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_PROGRAM_MAP(shdancer_readmem,shdancer_writemem)
-
-	MDRV_MACHINE_INIT(shdancer)
-MACHINE_DRIVER_END
 
 
 static MACHINE_DRIVER_START( shdancbl )
@@ -1553,91 +1195,23 @@ static MACHINE_DRIVER_START( shdancbl )
 	MDRV_CPU_PROGRAM_MAP(shdancbl_readmem,shdancbl_writemem)
 
 	MDRV_CPU_MODIFY("sound")
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(shdancbl_sound_readmem,shdancbl_sound_writemem)
 	MDRV_CPU_IO_MAP(shdancbl_sound_readport,shdancbl_sound_writeport)
 	MDRV_SOUND_REMOVE("5c68")
-	MDRV_SOUND_ADD_TAG("5205", MSM5205, shdancbl_msm5205_interface)
+
+	MDRV_SOUND_ADD_TAG("5205", MSM5205, 200000)
+	MDRV_SOUND_CONFIG(shdancbl_msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.80)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.80)
 
 	MDRV_MACHINE_INIT(shdancbl)
 MACHINE_DRIVER_END
 
 
-static MACHINE_DRIVER_START( shdancrj )
-
-	/* basic machine hardware */
-	MDRV_IMPORT_FROM(shdancer)
-
-	MDRV_MACHINE_INIT(shdancrj)
-MACHINE_DRIVER_END
-
-static MACHINE_DRIVER_START( shdancrb )
-
-	/* basic machine hardware */
-	MDRV_IMPORT_FROM(shdancer)
-
-	MDRV_MACHINE_INIT(shdancrb)
-MACHINE_DRIVER_END
-
-
 /***************************************************************************/
 
-INPUT_PORTS_START( astorm )
-	PORT_START /* player 1 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
-	PORT_START /* player 2 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
-	SYS16_SERVICE
-	SYS16_COINAGE
-	PORT_START	/* DSW1 */
-	PORT_DIPNAME( 0x01, 0x01, "2 Credits to Start" )
-	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x1c, 0x1c, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x04, "Easiest" )
-	PORT_DIPSETTING(    0x08, "Easier" )
-	PORT_DIPSETTING(    0x0c, DEF_STR( Easy ) )
-	PORT_DIPSETTING(    0x1c, DEF_STR( Normal ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( Hard ) )
-	PORT_DIPSETTING(    0x14, DEF_STR( Harder ) )
-	PORT_DIPSETTING(    0x18, DEF_STR( Hardest ) )
-	PORT_DIPSETTING(    0x00, "Special" )
-	PORT_DIPNAME( 0x20, 0x20, "Coin Chutes" )
-	PORT_DIPSETTING(    0x20, "3" )
-	PORT_DIPSETTING(    0x00, "1" )
-	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unused ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unused ) )
-	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_START /* player 3 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(3)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(3)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(3)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(3)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(3)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(3)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(3)
-INPUT_PORTS_END
+
 
 INPUT_PORTS_START( astormbl )
 	PORT_START /* player 1 */
@@ -1676,8 +1250,8 @@ INPUT_PORTS_START( astormbl )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x1c, 0x1c, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x04, "Easiest" )
-	PORT_DIPSETTING(    0x08, "Easier" )
+	PORT_DIPSETTING(    0x04, DEF_STR( Easiest ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( Easier ) )
 	PORT_DIPSETTING(    0x0c, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x1c, DEF_STR( Normal ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( Hard ) )
@@ -1761,7 +1335,7 @@ INPUT_PORTS_START( mwalkbl )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(3)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(3)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(3)
-/*	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN ) */
+/*  PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN ) */
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START3 )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(3)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(3)
@@ -1769,50 +1343,6 @@ INPUT_PORTS_START( mwalkbl )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(3)
 INPUT_PORTS_END
 
-INPUT_PORTS_START( shdancer )
-	PORT_START /* player 1 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
-	PORT_START /* player 2 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
-	SYS16_SERVICE
-	SYS16_COINAGE
-	PORT_START	/* DSW1 */
-	PORT_DIPNAME( 0x01, 0x01, "2 Credits to Start" )
-	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Lives ) )
-	PORT_DIPSETTING(    0x00, "2" )
-	PORT_DIPSETTING(    0x0c, "3" )
-	PORT_DIPSETTING(    0x08, "4" )
-	PORT_DIPSETTING(    0x04, "5" )
-	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x20, DEF_STR( Easy ) )
-	PORT_DIPSETTING(    0x30, DEF_STR( Normal ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( Hard ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Hardest ) )
-	PORT_DIPNAME( 0xc0, 0xc0, "Time Adjust" )
-	PORT_DIPSETTING(    0x00, "2.20" )
-	PORT_DIPSETTING(    0x40, "2.40" )
-	PORT_DIPSETTING(    0xc0, "3.00" )
-	PORT_DIPSETTING(    0x80, "3.30" )
-INPUT_PORTS_END
 
 /*****************************************************************************/
 
@@ -1915,10 +1445,10 @@ ROM_START( shdancbl )
 
 	/* 12718 */
 	ROM_LOAD16_BYTE( "ic77", 0x080001, 0x10000, CRC(f93470b7) SHA1(1041afa43aa8d0589d6def9743721cdbda617f78) )
-/*	ROM_LOAD16_BYTE( "ic78", 0x0A0001, 0x10000, CRC(4d523ea3) SHA1(053c30778017127dddeae0783af463aef17bcc9a) ) // corrupt? (bad sprite when dog attacts in attract mode) */
+/*  ROM_LOAD16_BYTE( "ic78", 0x0A0001, 0x10000, CRC(4d523ea3) SHA1(053c30778017127dddeae0783af463aef17bcc9a) ) // corrupt? (bad sprite when dog attacts in attract mode) */
 	ROM_LOAD16_BYTE( "sdbl.78", 0x0A0001, 0x10000, CRC(e533be5d) SHA1(926d6ba3f7a3ac289b0ae40d7633c70b2819df4d) )
 	ROM_LOAD16_BYTE( "ic95", 0x0C0001, 0x10000, CRC(828b8294) SHA1(f2cdb882fb0709a909e6ef98f0315aceeb8bf283) )
-/*	ROM_LOAD16_BYTE( "ic94", 0x0E0001, 0x10000, CRC(542b2d1e) SHA1(1ce91aea6c49e6e365a91c30ca3049682c2162da) ) */
+/*  ROM_LOAD16_BYTE( "ic94", 0x0E0001, 0x10000, CRC(542b2d1e) SHA1(1ce91aea6c49e6e365a91c30ca3049682c2162da) ) */
 	ROM_LOAD16_BYTE( "sdbl.94", 0x0E0001, 0x10000, CRC(e2fa2b41) SHA1(7186107734dac5763dee43addcea7c14fb0d9d74) )
 
 	/* 12725 */
@@ -1963,5 +1493,5 @@ GAME( 1990, astormbl, astorm,   astormbl, astormbl, astormbl, ROT0, "bootleg", "
 
 GAME( 1990, mwalkbl,  mwalk,    mwalkbl,  mwalkbl,  mwalkbl,  ROT0, "bootleg", "Michael Jackson's Moonwalker (bootleg)" )
 
-GAMEX(1989, shdancbl, shdancer, shdancbl, shdancer, shdancbl, ROT0, "bootleg", "Shadow Dancer (bootleg)", GAME_IMPERFECT_GRAPHICS)
+GAMEX(1989, shdancbl, shdancer, shdancbl, mwalkbl, shdancbl, ROT0, "bootleg", "Shadow Dancer (bootleg)", GAME_IMPERFECT_GRAPHICS)
 
