@@ -228,6 +228,8 @@ its place. The East Technology games on this hardware follow Daisenpu.
 #include "vidhrdw/generic.h"
 #include "sndhrdw/taitosnd.h"
 #include "seta.h"
+#include "sound/2610intf.h"
+#include "sound/2151intf.h"
 
 MACHINE_INIT( cchip1 );
 READ16_HANDLER ( cchip1_word_r );
@@ -363,8 +365,8 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( daisenpu_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_WRITE(MWA16_ROM)
-/*	AM_RANGE(0x400000, 0x400001) AM_WRITE(MWA16_NOP)	   written each frame at $2ac, values change    */
-/*	AM_RANGE(0x600000, 0x600001) AM_WRITE(MWA16_NOP)	   written each frame at $2a2, values change    */
+/*  AM_RANGE(0x400000, 0x400001) AM_WRITE(MWA16_NOP)       written each frame at $2ac, values change    */
+/*  AM_RANGE(0x600000, 0x600001) AM_WRITE(MWA16_NOP)       written each frame at $2a2, values change    */
 	AM_RANGE(0x800000, 0x800001) AM_WRITE(taitosound_port16_lsb_w)
 	AM_RANGE(0x800002, 0x800003) AM_WRITE(taitosound_comm16_lsb_w)
 	AM_RANGE(0x900000, 0x90000f) AM_WRITE(daisenpu_input_w)
@@ -1031,41 +1033,21 @@ static void irqhandler(int irq)
 
 static struct YM2610interface ym2610_interface =
 {
-	1,	/* 1 chip */
-	8000000,	/* 8 MHz ?????? */
-	{ 25 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler },
-	{ REGION_SOUND1 },
-	{ REGION_SOUND1 },
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) }
+	irqhandler,
+	REGION_SOUND1,
+	REGION_SOUND1
 };
 
 static struct YM2610interface ballbros_ym2610_interface =
 {
-	1,	/* 1 chip */
-	8000000,	/* 8 MHz ?????? */
-	{ 25 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler },
-	{ REGION_SOUND1 },
-	{ REGION_SOUND2 },
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) }
+	irqhandler,
+	REGION_SOUND1,
+	REGION_SOUND2
 };
 
 static struct YM2151interface ym2151_interface =
 {
-	1,	/* 1 chip */
-	4000000,	/* 4 MHz ?????? */
-	{ YM3012_VOL(45,MIXER_PAN_LEFT,45,MIXER_PAN_RIGHT) },
-	{ irqhandler },
-	{ 0 }
+	irqhandler
 };
 
 
@@ -1097,8 +1079,14 @@ static MACHINE_DRIVER_START( superman )
 	MDRV_VIDEO_UPDATE(seta_no_layers)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2610, ym2610_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.25)
+	MDRV_SOUND_ROUTE(0, "right", 0.25)
+	MDRV_SOUND_ROUTE(1, "left",  1.0)
+	MDRV_SOUND_ROUTE(2, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1128,8 +1116,12 @@ static MACHINE_DRIVER_START( daisenpu )
 	MDRV_VIDEO_UPDATE(seta_no_layers)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 4000000)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( gigandes )
@@ -1158,8 +1150,14 @@ static MACHINE_DRIVER_START( gigandes )
 	MDRV_VIDEO_UPDATE(seta_no_layers)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2610, ballbros_ym2610_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ballbros_ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.25)
+	MDRV_SOUND_ROUTE(0, "right", 0.25)
+	MDRV_SOUND_ROUTE(1, "left",  1.0)
+	MDRV_SOUND_ROUTE(2, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1190,8 +1188,14 @@ static MACHINE_DRIVER_START( ballbros )
 	MDRV_VIDEO_UPDATE(seta_no_layers)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2610, ballbros_ym2610_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ballbros_ym2610_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.25)
+	MDRV_SOUND_ROUTE(0, "right", 0.25)
+	MDRV_SOUND_ROUTE(1, "left",  1.0)
+	MDRV_SOUND_ROUTE(2, "right", 1.0)
 MACHINE_DRIVER_END
 
 
