@@ -1,76 +1,78 @@
 /***************************************************************************
 
-	Apache 3											ATF-011
-	Round Up 5											ATC-011
-	Cycle Warriors										ABA-011
+    Apache 3                                            ATF-011
+    Round Up 5                                          ATC-011
+    Cycle Warriors                                      ABA-011
 
-	Incredibly complex hardware!  These are all different boards, but share
-	a similar sprite chip (TZB215 on Apache 3, TZB315 on others).  Other
-	graphics (road, sky, bg/fg layers) all differ between games.
+    Incredibly complex hardware!  These are all different boards, but share
+    a similar sprite chip (TZB215 on Apache 3, TZB315 on others).  Other
+    graphics (road, sky, bg/fg layers) all differ between games.
 
-	Todo:
-		Sprite rotation
-		Finish road layer (Round Up 5)
-		Implement road layer (Apache 3, Cycle Warriors)
-		BG layer(s) (Cycle Warriors)
-		BG layer (Round Up 5) - May be driven by missing VRAM data
-		Round Up 5 always boots with a coin inserted
-		Round Up 5 doesn't survive a reset
-		Dip switches
-		Various other things..
+    Todo:
+        Sprite rotation
+        Finish road layer (Round Up 5)
+        Implement road layer (Apache 3, Cycle Warriors)
+        BG layer(s) (Cycle Warriors)
+        BG layer (Round Up 5) - May be driven by missing VRAM data
+        Round Up 5 always boots with a coin inserted
+        Round Up 5 doesn't survive a reset
+        Dip switches
+        Various other things..
 
-	Emulation by Bryan McPhail, mish@tendril.co.uk
+    Emulation by Bryan McPhail, mish@tendril.co.uk
 
 
-	Cycle Warriors Board Layout
+    Cycle Warriors Board Layout
 
-	ABA-011
+    ABA-011
 
 
-			6296             CW24A                   5864
-								CW25A                   5864
-			YM2151                  50MHz
+            6296             CW24A                   5864
+                                CW25A                   5864
+            YM2151                  50MHz
 
-								TZ8315                 CW26A
-													5864
-		TC51821  TC51832                               D780C-1
-		TC51821  TC51832
-		TC51821  TC51832                     16MHz
-		TC51821  TC51832
+                                TZ8315                 CW26A
+                                                    5864
+        TC51821  TC51832                               D780C-1
+        TC51821  TC51832
+        TC51821  TC51832                     16MHz
+        TC51821  TC51832
 
-		CW00A   CW08A
-		CW01A   CW09A
-		CW02A   CW10A
-		CW03A   CW11A            68000-12              81C78
-		CW04A   CW12A                                  81C78
-		CW05A   CW13A                CW16B  CW18B      65256
-		CW06A   CW14A                CW17A  CW19A      65256
-		CW07A   CW15A                       CW20A
-											CW21       65256
-								68000-12   CW22A      65256
-											CW23
+        CW00A   CW08A
+        CW01A   CW09A
+        CW02A   CW10A
+        CW03A   CW11A            68000-12              81C78
+        CW04A   CW12A                                  81C78
+        CW05A   CW13A                CW16B  CW18B      65256
+        CW06A   CW14A                CW17A  CW19A      65256
+        CW07A   CW15A                       CW20A
+                                            CW21       65256
+                                68000-12   CW22A      65256
+                                            CW23
 
-	ABA-012
+    ABA-012
 
-							HD6445
+                            HD6445
 
 
-							51832
-							51832
-							51832
-							51832
+                            51832
+                            51832
+                            51832
+                            51832
 
-							CW28
-							CW29
-							CW30
+                            CW28
+                            CW29
+                            CW30
 
-	CW27
+    CW27
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "tatsumi.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 static data16_t *cyclwarr_cpub_ram;
 data16_t *tatsumi_c_ram, *apache3_g_ram;
@@ -82,8 +84,8 @@ data8_t *apache3_bg_ram;
 
 /***************************************************************************/
 
-static READ16_HANDLER(cyclwarr_cpu_b_r) { return cyclwarr_cpub_ram[offset+0x800]; }
-static WRITE16_HANDLER(cyclwarr_cpu_b_w){ COMBINE_DATA(&cyclwarr_cpub_ram[offset+0x800]); }
+/*static READ16_HANDLER(cyclwarr_cpu_b_r) { return cyclwarr_cpub_ram[offset+0x800]; } */
+/*static WRITE16_HANDLER(cyclwarr_cpu_b_w){ COMBINE_DATA(&cyclwarr_cpub_ram[offset+0x800]); } */
 static READ16_HANDLER(cyclwarr_cpu_bb_r){ return cyclwarr_cpub_ram[offset]; }
 static WRITE16_HANDLER(cyclwarr_cpu_bb_w) { COMBINE_DATA(&cyclwarr_cpub_ram[offset]); }
 static READ16_HANDLER(cyclwarr_palette_r) { return paletteram16[offset]; }
@@ -98,7 +100,7 @@ static ADDRESS_MAP_START( readmem_apache3, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x07fff) AM_READ(MRA8_RAM)
 	AM_RANGE(0x08000, 0x08fff) AM_READ(MRA8_RAM)
 	AM_RANGE(0x0c000, 0x0dfff) AM_READ(MRA8_RAM)
-/*	AM_RANGE(0x0e800, 0x0e803) AM_READ(MRA_NOP) // CRT */
+/*  AM_RANGE(0x0e800, 0x0e803) AM_READ(MRA_NOP) // CRT */
 	AM_RANGE(0x0f000, 0x0f000) AM_READ(input_port_3_r) /* Dip 1 */
 	AM_RANGE(0x0f001, 0x0f001) AM_READ(input_port_4_r) /* Dip 2 */
 	AM_RANGE(0x0f800, 0x0f801) AM_READ(apache3_bank_r)
@@ -299,7 +301,7 @@ static ADDRESS_MAP_START( readmem_cyclwarr_c, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xfff4, 0xfff4) AM_READ(tatsumi_hack_oki_r) /* OKIM6295_status_0_r) */
 	AM_RANGE(0xfff8, 0xfff8) AM_READ(input_port_0_r)
 	AM_RANGE(0xfff9, 0xfff9) AM_READ(input_port_1_r)
-/*	AM_RANGE(0xfffa, 0xfffa) AM_READ(input_port_0_r)// MRA_NOP) //irq ack??? */
+/*  AM_RANGE(0xfffa, 0xfffa) AM_READ(input_port_0_r)// MRA_NOP) //irq ack??? */
 	AM_RANGE(0xfffc, 0xfffc) AM_READ(input_port_2_r)/* MRA_NOP) */
 ADDRESS_MAP_END
 
@@ -598,18 +600,7 @@ static void sound_irq(int state)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	16000000/4, /* ? */
-	{ YM3012_VOL(45,MIXER_PAN_LEFT,45,MIXER_PAN_RIGHT) },
-	{ sound_irq }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,
-	{ 20000000/8/132 }, /* Frequency */ /* ? */
-	{ REGION_SOUND1 },
-	{ 75 }
+	sound_irq
 };
 
 static INTERRUPT_GEN( roundup5_interrupt )
@@ -648,9 +639,17 @@ static MACHINE_DRIVER_START( apache3 )
 	MDRV_VIDEO_UPDATE(apache3)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 16000000/4)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 20000000/8/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.75)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.75)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( roundup5 )
@@ -681,9 +680,17 @@ static MACHINE_DRIVER_START( roundup5 )
 	MDRV_VIDEO_UPDATE(roundup5)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 16000000/4)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 20000000/8/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.75)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.75)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( cyclwarr )
@@ -715,9 +722,17 @@ static MACHINE_DRIVER_START( cyclwarr )
 	MDRV_VIDEO_UPDATE(cyclwarr)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 16000000/4)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 20000000/8/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.75)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.75)
 MACHINE_DRIVER_END
 
 /***************************************************************************/
