@@ -1,9 +1,9 @@
 /*
- *	Thunder Ceptor board
- *	(C) 1986 Namco
+ *  Thunder Ceptor board
+ *  (C) 1986 Namco
  *
- *	Hardware analyzed by nono
- *	Driver by BUT
+ *  Hardware analyzed by nono
+ *  Driver by BUT
  */
 
 #include "driver.h"
@@ -13,12 +13,9 @@
 #include "cpu/m6800/m6800.h"
 #include "cpu/m68000/m68000.h"
 #include "namcoic.h"
-
-#ifdef TINY_COMPILE
-/* to avoid link error */
-int namcos2_gametype;
-#endif
-
+#include "sound/dac.h"
+#include "sound/2151intf.h"
+#include "sound/namco.h"
 
 extern PALETTE_INIT( tceptor );
 extern VIDEO_START( tceptor );
@@ -492,30 +489,13 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /*******************************************************************/
 
-static struct YM2151interface ym2151_interface =
-{
-	1,			/* 1 chip */
-	14318180/4,		/* 3.579545 MHz */
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },
-	{ 0 },
-	{ 0 }
-};
-
 static struct namco_interface namco_interface =
 {
-	49152000/2048,		/* 24000Hz */
 	8,			/* number of voices */
-	40,			/* playback volume */
 	-1,			/* memory region */
 	1			/* stereo */
 };
 
-static struct DACinterface dac_interface =
-{
-	1,			/* 1 channel */
-	{ 40 }			/* mixing level */
-};
-
 
 /*******************************************************************/
 
@@ -536,11 +516,11 @@ static MACHINE_DRIVER_START( tceptor )
 	MDRV_CPU_VBLANK_INT(m6809_vb_interrupt,1)
 
 	MDRV_CPU_ADD(M65C02, 49152000/24)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(m6502_a_readmem,m6502_a_writemem)
 
 	MDRV_CPU_ADD(M65C02, 49152000/24)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(m6502_b_readmem,m6502_b_writemem)
 
 	MDRV_CPU_ADD(M68000, 49152000/4)
@@ -573,10 +553,20 @@ static MACHINE_DRIVER_START( tceptor )
 	MDRV_VIDEO_UPDATE(tceptor)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(NAMCO_CUS30, namco_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 14318180/4)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+
+	MDRV_SOUND_ADD(NAMCO_CUS30, 49152000/2048)
+	MDRV_SOUND_CONFIG(namco_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.40)
+	MDRV_SOUND_ROUTE(1, "right", 0.40)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.40)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.40)
 MACHINE_DRIVER_END
 
 
