@@ -2,7 +2,7 @@
 
   Ganbare Ginkun  (Japan)  (c)1995 TECMO
   Final StarForce (US)     (c)1992 TECMO
-  Riot			  (Japan)  (c)1992 NMK
+  Riot            (Japan)  (c)1992 NMK
 
 
 --
@@ -22,6 +22,8 @@ buttons 1 and 2 during P.O.S.T.
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 
 extern data16_t *tecmo16_videoram;
@@ -428,18 +430,7 @@ static void irqhandler(int irq)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,
-	8000000/2,	/* 4MHz */
-	{ YM3012_VOL(60,MIXER_PAN_LEFT,60,MIXER_PAN_RIGHT) },
-	{ irqhandler }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,			/* 1 chip */
-	{ 7575 },		/* 7575Hz playback */
-	{ REGION_SOUND1 },
-	{ 40 }
+	irqhandler
 };
 
 /******************************************************************************/
@@ -452,7 +443,7 @@ static MACHINE_DRIVER_START( fstarfrc )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,8000000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)			/* 4MHz */
+	/* audio CPU */			/* 4MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 								/* NMIs are triggered by the main CPU */
 	MDRV_FRAMES_PER_SECOND(60)
@@ -470,9 +461,17 @@ static MACHINE_DRIVER_START( fstarfrc )
 	MDRV_VIDEO_UPDATE(tecmo16)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 8000000/2)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.60)
+	MDRV_SOUND_ROUTE(1, "right", 0.60)
+
+	MDRV_SOUND_ADD(OKIM6295, 7575)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.40)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.40)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( ginkun )
@@ -483,7 +482,7 @@ static MACHINE_DRIVER_START( ginkun )
 	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,8000000/2)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)			/* 4MHz */
+	/* audio CPU */			/* 4MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 								/* NMIs are triggered by the main CPU */
 	MDRV_FRAMES_PER_SECOND(60)
@@ -501,9 +500,17 @@ static MACHINE_DRIVER_START( ginkun )
 	MDRV_VIDEO_UPDATE(tecmo16)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 8000000/2)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.60)
+	MDRV_SOUND_ROUTE(1, "right", 0.60)
+
+	MDRV_SOUND_ADD(OKIM6295, 7575)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.40)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.40)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( riot )
@@ -614,7 +621,7 @@ Notes:
       PAL1 - AMI 18CV8 stamped 'T-11'
       PAL2 - AMI 18CV8 stamped 'T-12'
 
-      Custom Tecmo IC's - 
+      Custom Tecmo IC's -
                          TECMO-5   MCU? clock input 6.000MHz on pin15 (SDIP64)
                          TECMO-06, also stamped 'YM6048' (QFP160)
                          TECMO-07, also stamped 'YM6621' (QFP160)
@@ -687,7 +694,7 @@ ROM_START( riot )
 	ROM_LOAD16_BYTE( "6.ic16", 0x00001, 0x80000, CRC(96ef61da) SHA1(c306e4d1eee19af0229a47c2f115f98c74f33d33) )
 
 	ROM_REGION( 0x20000, REGION_SOUND1, 0 )
-	ROM_LOAD( "8.ic18", 0x00000, 0x20000, CRC(4b70e266) SHA1(4ed23de9223cc7359fbaff9dd500ef6daee00fb0) )	
+	ROM_LOAD( "8.ic18", 0x00000, 0x20000, CRC(4b70e266) SHA1(4ed23de9223cc7359fbaff9dd500ef6daee00fb0) )
 ROM_END
 
 /******************************************************************************/
