@@ -105,6 +105,9 @@ ae500w07.ad1 - M6295 Samples (23c4001)
 #include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "cpu/m68000/m68k.h"
+#include "sound/okim6295.h"
+#include "sound/262intf.h"
+#include "sound/ymz280b.h"
 
 static int gametype;
 
@@ -152,7 +155,7 @@ static READ16_HANDLER(reg_f80000_r)
 		/* 68k code. */
 		if (device_write_ptr == 0x10000)
 		{
-/*			logerror("DEVICE write finished\n"); */
+/*          logerror("DEVICE write finished\n"); */
 			device_status = DS_READ_ACK;
 			device_write_ptr = 0;
 			device_read_ptr = 0;
@@ -172,14 +175,14 @@ static READ16_HANDLER(reg_f80000_r)
 
 	if (device_status == DS_READ_ACK)
 	{
-/*		logerror("Read ACK\n"); */
+/*      logerror("Read ACK\n"); */
 		device_status = DS_READ;
 		return 0;
 	}
 
 	dt = device[device_read_ptr];
 
-/*	logerror("DEVICE read %x: %x (at %x)\n", device_read_ptr, dt, cpunum_get_pc(0)); */
+/*  logerror("DEVICE read %x: %x (at %x)\n", device_read_ptr, dt, cpunum_get_pc(0)); */
 
 	device_read_ptr++;
 	device_read_ptr &= 0xFFFF;
@@ -216,7 +219,7 @@ static WRITE16_HANDLER(reg_e80000_w)
 		switch (data)
 		{
 		case 0x13:
-/*			logerror("DEVICE mode WRITE (cmd 0x13)\n"); */
+/*          logerror("DEVICE mode WRITE (cmd 0x13)\n"); */
 			device_status = DS_WRITE;
 			device_write_ptr = 0;
 			break;
@@ -228,7 +231,7 @@ static WRITE16_HANDLER(reg_e80000_w)
 	/* @@@ Should skip the writes while in read mode? */
 	if (device_status == DS_READ || device_status == DS_READ_ACK)
 	{
-/*		logerror("EEPROM write %x: %x\n", device_write_ptr, data); */
+/*      logerror("EEPROM write %x: %x\n", device_write_ptr, data); */
 		return;
 	}
 
@@ -371,12 +374,14 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(YMF262_status_0_r)
 	AM_RANGE(0x40, 0x40) AM_READ(soundlatch_r)
 	/*AM_RANGE(0x60, 0x60) AM_READ(YMZ280B_status_0_r) */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YMF262_register_A_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YMF262_data_A_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(YMF262_register_B_0_w)
@@ -413,7 +418,7 @@ VIDEO_UPDATE(deroon)
 
 #if 0
 /* simulate sound commands writes here ... to test OPL3 emulator */
-	int j,trueorientation;
+	int j;
 	char buf[64];
 	static int command_data=0;
 
@@ -427,9 +432,6 @@ VIDEO_UPDATE(deroon)
 	}
 	command_data &= 0xff;
 
-	trueorientation = Machine->orientation;
-	Machine->orientation = ROT0;
-
 	sprintf(buf,"keys: Q,A and C");
 	for (j = 0;j < 16;j++)
 		drawgfx(bitmap,Machine->uifont,buf[j],0,0,0,10+6*j,20,0,TRANSPARENCY_NONE,0);
@@ -437,8 +439,6 @@ VIDEO_UPDATE(deroon)
 	for (j = 0;j < 16;j++)
 		drawgfx(bitmap,Machine->uifont,buf[j],0,0,0,10+6*j,40,0,TRANSPARENCY_NONE,0);
 
-	Machine->orientation = trueorientation;
-
 
 	if (code_pressed_memory(KEYCODE_C))
 	{
@@ -531,29 +531,14 @@ static void sound_irq(int irq)
 
 static struct YMF262interface ymf262_interface =
 {
-	1,					/* 1 chip */
-	14318180,			/* X1 ? */
-	{ YAC512_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },	/* channels A and B */
-	{ YAC512_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },	/* channels C and D */
-	{ sound_irq },		/* irq */
+	sound_irq		/* irq */
 };
 
 
-static struct OKIM6295interface okim6295_interface =
-{
-	1,					/* 1 chip */
-	{ 14318180/2048 },	/* = 6991 Hz ? */
-	{ REGION_SOUND2 },
-	{ 50 }
-};
-
 static struct YMZ280Binterface ymz280b_interface =
 {
-	1,					/* 1 chip */
-	{ 16900000 },		/* X4 ? */
-	{ REGION_SOUND1 },
-	{ YM3012_VOL(30,MIXER_PAN_LEFT,30,MIXER_PAN_RIGHT) },
-	{ 0 }	/* irq */
+	REGION_SOUND1,
+	0	/* irq */
 };
 
 static MACHINE_DRIVER_START( deroon )
@@ -562,7 +547,7 @@ static MACHINE_DRIVER_START( deroon )
 	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 16000000/2 )	/* 8 MHz ??? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(readport,writeport)
 
@@ -581,10 +566,24 @@ static MACHINE_DRIVER_START( deroon )
 	MDRV_VIDEO_UPDATE(deroon)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YMF262,   ymf262_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
-	MDRV_SOUND_ADD(YMZ280B,  ymz280b_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YMF262, 14318180)
+	MDRV_SOUND_CONFIG(ymf262_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+	MDRV_SOUND_ROUTE(2, "left", 1.0)
+	MDRV_SOUND_ROUTE(3, "right", 1.0)
+
+	MDRV_SOUND_ADD(OKIM6295, 14318180/2048)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
+
+	MDRV_SOUND_ADD(YMZ280B, 16900000)
+	MDRV_SOUND_CONFIG(ymz280b_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.30)
+	MDRV_SOUND_ROUTE(1, "right", 0.30)
 MACHINE_DRIVER_END
 
 
