@@ -81,6 +81,8 @@ TO DO :
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/ay8910.h"
+#include "sound/msm5205.h"
 
 
 extern UINT8 *tehkanwc_videoram2;
@@ -415,11 +417,13 @@ static ADDRESS_MAP_START( writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(AY8910_read_port_0_r)
 	AM_RANGE(0x02, 0x02) AM_READ(AY8910_read_port_1_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(AY8910_write_port_1_w)
@@ -551,12 +555,12 @@ INPUT_PORTS_START( gridiron )
 	PORT_DIPNAME( 0x03, 0x03, "Start Credits (P1&P2)/Extra" )
 	PORT_DIPSETTING (   0x01, "1&1/200%" )
 	PORT_DIPSETTING (   0x03, "1&2/100%" )
-/*	PORT_DIPSETTING (   0x00, "2&1/200%" )				// Is this setting possible ? */
+/*  PORT_DIPSETTING (   0x00, "2&1/200%" )              // Is this setting possible ? */
 	PORT_DIPSETTING (   0x02, "2&2/100%" )
 	/* This Dip Switch only has an effect in a 2 players game.
-	   If offense player selects his formation before defense player,
-	   defense formation time will be set to 3, 5 or 7 seconds.
-	   Check code at 0x3ed9 and table at 0x3f89. */
+       If offense player selects his formation before defense player,
+       defense formation time will be set to 3, 5 or 7 seconds.
+       Check code at 0x3ed9 and table at 0x3f89. */
 	PORT_DIPNAME( 0x0c, 0x0c, "Formation Time (Defense)" )
 	PORT_DIPSETTING (   0x0c, "Same as Offense" )
 	PORT_DIPSETTING (   0x00, "7" )
@@ -771,24 +775,24 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct AY8910interface ay8910_interface =
+static struct AY8910interface ay8910_interface_1 =
 {
-	2,	/* 2 chips */
-	1536000, 	/* ??? */
-	{ 25, 25 },
-	{ 0, tehkanwc_portA_r },
-	{ 0, tehkanwc_portB_r },
-	{ tehkanwc_portA_w, 0 },
-	{ tehkanwc_portB_w, 0 }
+	0,
+	0,
+	tehkanwc_portA_w,
+	tehkanwc_portB_w
+};
+
+static struct AY8910interface ay8910_interface_2 =
+{
+	tehkanwc_portA_r,
+	tehkanwc_portB_r
 };
 
 static struct MSM5205interface msm5205_interface =
 {
-	1,					/* 1 chip             */
-	384000,				/* 384KHz             */
-	{ tehkanwc_adpcm_int },/* interrupt function */
-	{ MSM5205_S48_4B },	/* 8KHz               */
-	{ 45 }
+	tehkanwc_adpcm_int,	/* interrupt function */
+	MSM5205_S48_4B		/* 8KHz               */
 };
 
 static MACHINE_DRIVER_START( tehkanwc )
@@ -822,8 +826,19 @@ static MACHINE_DRIVER_START( tehkanwc )
 	MDRV_VIDEO_UPDATE(tehkanwc)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1536000)
+	MDRV_SOUND_CONFIG(ay8910_interface_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 1536000)
+	MDRV_SOUND_CONFIG(ay8910_interface_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.45)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( gridiron )
@@ -850,18 +865,18 @@ static DRIVER_INIT( teedoff )
 
 	/* Code at 0x0233 (main CPU) :
 
-		0233: 3A 00 DA    ld   a,($DA00)
-		0236: CB 7F       bit  7,a
-		0238: CA 00 C8    jp   z,$C800
+        0233: 3A 00 DA    ld   a,($DA00)
+        0236: CB 7F       bit  7,a
+        0238: CA 00 C8    jp   z,$C800
 
-	   changed to :
+       changed to :
 
-		0233: 3A 00 DA    ld   a,($DA00)
-		0236: CB 7F       bit  7,a
-		0238: 00          nop
-		0239: 00          nop
-		023A: 00          nop
-	*/
+        0233: 3A 00 DA    ld   a,($DA00)
+        0236: CB 7F       bit  7,a
+        0238: 00          nop
+        0239: 00          nop
+        023A: 00          nop
+    */
 
 	data8_t *ROM = memory_region(REGION_CPU1);
 
