@@ -10,25 +10,27 @@ NATO Defense
 (C) 1982 PACIFIC NOVELTY MFG. INC.
 
 Credits:
-	Shark Driver by Victor Trucco and Mike Balfour
-	Driver for Thief and NATO Defense by Phil Stroffolino
+    Shark Driver by Victor Trucco and Mike Balfour
+    Driver for Thief and NATO Defense by Phil Stroffolino
 
 - 8255 emulation (ports 0x30..0x3f) could be better abstracted
 
 - TMS9927 VTAC: do we need to emulate this?
-	The video controller registers effect screen size (currently
-	hard-coded on a per-game basis).
+    The video controller registers effect screen size (currently
+    hard-coded on a per-game basis).
 
 - minor blitting glitches in playfield of Thief (XOR vs copy?)
 
 - Nato Defense gfx ROMs may be hooked up wrong;
-	see screenshots from flyers
+    see screenshots from flyers
 
 ******************************************************************/
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/samples.h"
 
 static UINT8 thief_input_select;
 
@@ -61,13 +63,13 @@ static INTERRUPT_GEN( thief_interrupt )
 /**********************************************************/
 
 
-/*	Following is an attempt to simulate the behavior of the
-**	cassette tape used in several Pacific Novelty games.
+/*  Following is an attempt to simulate the behavior of the
+**  cassette tape used in several Pacific Novelty games.
 **
-**	It is a leaderless tape that is constructed so that it will
-**	loop continuously.  The IO controller can start and stop the
-**	tape player's motor, and enable/disable each of two audio
-**	tracks.
+**  It is a leaderless tape that is constructed so that it will
+**  loop continuously.  The IO controller can start and stop the
+**  tape player's motor, and enable/disable each of two audio
+**  tracks.
 */
 
 enum
@@ -77,7 +79,7 @@ enum
 
 static void tape_set_audio( int track, int bOn )
 {
-	sample_set_volume( track, bOn?100:0 );
+	sample_set_volume( track, bOn?1.0:0 );
 }
 
 static void tape_set_motor( int bOn )
@@ -186,12 +188,14 @@ static ADDRESS_MAP_START( thief_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x31, 0x31) AM_READ(thief_io_r) /* 8255 */
 	AM_RANGE(0x41, 0x41) AM_READ(AY8910_read_port_0_r)
 	AM_RANGE(0x43, 0x43) AM_READ(AY8910_read_port_1_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(MWA8_NOP) /* watchdog */
 	AM_RANGE(0x10, 0x10) AM_WRITE(thief_video_control_w)
 	AM_RANGE(0x30, 0x30) AM_WRITE(thief_input_select_w) /* 8255 */
@@ -221,7 +225,7 @@ INPUT_PORTS_START( sharkatt )
 	PORT_DIPSETTING(	0x00, "3" )
 	PORT_DIPSETTING(	0x01, "4" )
 	PORT_DIPSETTING(	0x02, "5" )
-/*	PORT_DIPSETTING(	0x03, "5" ) */
+/*  PORT_DIPSETTING(    0x03, "5" ) */
 	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( No ) )
 	PORT_DIPSETTING(	0x04, DEF_STR( Yes ) )
@@ -398,18 +402,6 @@ INPUT_PORTS_START( natodef )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
-/**********************************************************/
-
-static struct AY8910interface ay8910_interface =
-{
-	2,	/* 2 chips */
-	4000000/4,	/* Z80 Clock / 4 */
-	{ 50, 50 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
 
 /***********************************************************/
 
@@ -424,7 +416,6 @@ static const char *sharkatt_sample_names[] =
 static struct Samplesinterface sharkatt_samples_interface =
 {
 	2,	/* number of channels */
-	50,	/* volume */
 	sharkatt_sample_names
 };
 
@@ -441,7 +432,6 @@ static const char *thief_sample_names[] =
 static struct Samplesinterface thief_samples_interface =
 {
 	2,	/* number of channels */
-	50,	/* volume */
 	thief_sample_names
 };
 
@@ -458,7 +448,6 @@ static const char *natodef_sample_names[] =
 static struct Samplesinterface natodef_samples_interface =
 {
 	2,	/* number of channels */
-	50,	/* volume */
 	natodef_sample_names
 };
 
@@ -485,8 +474,17 @@ static MACHINE_DRIVER_START( sharkatt )
 	MDRV_VIDEO_UPDATE(thief)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(SAMPLES, sharkatt_samples_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 4000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(AY8910, 4000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(sharkatt_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -511,8 +509,17 @@ static MACHINE_DRIVER_START( thief )
 	MDRV_VIDEO_UPDATE(thief)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(SAMPLES, thief_samples_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 4000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(AY8910, 4000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(thief_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -537,8 +544,17 @@ static MACHINE_DRIVER_START( natodef )
 	MDRV_VIDEO_UPDATE(thief)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(SAMPLES, natodef_samples_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 4000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(AY8910, 4000000/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(natodef_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 /**********************************************************/
