@@ -8,20 +8,22 @@ regarding this driver.
 F1 Dream protection workaround by Eric Hustvedt
 
 Memory Overview:
-	0xfe0800    sprites
-	0xfec000    text
-	0xfe4000    input ports,dip switches (read); sound out, video reg (write)
-	0xfe4002	protection (F1 Dream only)
-	0xfe8000    scroll registers
-	0xff8200    palette
-	0xffC000    working RAM
-	0xffEC70    high scores (not saved)
+    0xfe0800    sprites
+    0xfec000    text
+    0xfe4000    input ports,dip switches (read); sound out, video reg (write)
+    0xfe4002    protection (F1 Dream only)
+    0xfe8000    scroll registers
+    0xff8200    palette
+    0xffC000    working RAM
+    0xffEC70    high scores (not saved)
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/2203intf.h"
+#include "sound/msm5205.h"
 
 
 extern WRITE16_HANDLER( tigeroad_videoram_w );
@@ -43,11 +45,11 @@ static data16_t *ram16;
 
  Some notes:
  - The 8751 is triggered via location 0xfe4002, in place of the soundlatch normally
- 	present. The main cpu writes 0 to the location when it wants the 8751 to perform some work.
+    present. The main cpu writes 0 to the location when it wants the 8751 to perform some work.
  - The 8751 has memory which shadows locations 0xffffe0-0xffffff of the main cpu's address space.
  - The word at 0xffffe0 contains an 'opcode' which is written just before the write to 0xfe4002.
  - Some of the writes to the soundlatch may not be handled. 0x27fc is the main sound routine, the
- 	other locations are less frequently used.
+    other locations are less frequently used.
 */
 
 static int f1dream_613ea_lookup[16] = {
@@ -214,6 +216,7 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x7f, 0x7f) AM_WRITE(soundlatch2_w)
 ADDRESS_MAP_END
 
@@ -227,10 +230,12 @@ static ADDRESS_MAP_START( sample_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sample_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(soundlatch2_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sample_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x01, 0x01) AM_WRITE(msm5205_w)
 ADDRESS_MAP_END
 
@@ -531,23 +536,13 @@ static void irqhandler(int irq)
 
 static struct YM2203interface ym2203_interface =
 {
-	2,          /* 2 chips */
-	3579545,    /* 3.579 MHz ? */
-	{ YM2203_VOL(25,25), YM2203_VOL(25,25) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
+	0,0,0,0,irqhandler
 };
 
 static struct MSM5205interface msm5205_interface =
 {
-	1,		/* 1 chip */
-	384000,	/* 384KHz ? */
-	{ 0 },	/* interrupt function */
-	{ MSM5205_SEX_4B },	/* 4KHz playback ?  */
-	{ 100 }
+	0,				/* interrupt function */
+	MSM5205_SEX_4B	/* 4KHz playback ?  */
 };
 
 
@@ -559,7 +554,7 @@ static MACHINE_DRIVER_START( tigeroad )
 	MDRV_CPU_VBLANK_INT(irq2_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)    /* 4 MHz ??? */
+	/* audio CPU */    /* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(0,sound_writeport)
 								/* IRQs are triggered by the YM2203 */
@@ -578,7 +573,14 @@ static MACHINE_DRIVER_START( tigeroad )
 	MDRV_VIDEO_UPDATE(tigeroad)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3579545)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(YM2203, 3579545)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
@@ -589,13 +591,15 @@ static MACHINE_DRIVER_START( toramich )
 	MDRV_IMPORT_FROM(tigeroad)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* ? */
+	/* audio CPU */	/* ? */
 	MDRV_CPU_PROGRAM_MAP(sample_readmem,sample_writemem)
 	MDRV_CPU_IO_MAP(sample_readport,sample_writeport)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold,4000)	/* ? */
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
