@@ -8,6 +8,13 @@ Notes:
   3) "tnzso". Standard hardware. Harder gameplay, old Taito logo. Maybe a prototype?
   The three versions all have different levels!
 
+- TNZS hidden level select: keep service coin pressed (default:9) and reset the game.
+  When SERVICE SWITCH ERROR appears, release service coin and press 1 player start
+  three times, service coin again, and 1 player start. Use up/down to select the
+  starting level and press 1 player start to start. You'll also get 255 lives.
+  If you have enough patience and go up until the level reads "Q-1" (which corresponds
+  to 1-1), AND the "Invulnerability" dip switch is On, you'll be invulnerable.
+
 
 Hardware datails for the newer tnzs board (from pictures):
 
@@ -36,23 +43,26 @@ Hardware datails for the newer tnzs board (from pictures):
 
 
 
-TODO: - Find out how the hardware credit-counter works (MPU)
-	  - Verify dip switches
-	  - Fix video offsets (See Dr Toppel in Flip-Screen - also
-	       affects Chuka Taisen)
-	  - Video scroll side flicker in Chuka Taisen, Insector X and Dr Toppel
+TODO:
+-----
+- Find out how the hardware credit-counter works (MPU)
+- Verify dip switches
+- Fix video offsets (See Dr Toppel in Flip-Screen - also affects Chuka Taisen)
+- Video scroll side flicker in Chuka Taisen, Insector X, Dr Toppel, Kabuki Z
+- Sprite/background sync during scrolling, e.g. insectorx, kabukiz.
+- Merge video driver with seta.c (it's the same thing but seta.c assumes a 16-bit CPU)
 
-	Arkanoid 2:
-	  - What do writes at $f400 do ?
-	  - Why does the game zero the $fd00 area ?
-	Extrmatn:
-	  - What do reads from $f600 do ? (discarded)
-	Chuka Taisen:
-	  - What do writes at  $f400 do ? (value 40h)
-	  - What do reads from $f600 do in service mode ?
-	Dr Toppel:
-	  - What do writes at  $f400 do ? (value 40h)
-	  - What do reads from $f600 do in service mode ?
+Arkanoid 2:
+  - What do writes at $f400 do ?
+  - Why does the game zero the $fd00 area ?
+Extrmatn:
+  - What do reads from $f600 do ? (discarded)
+Chuka Taisen:
+  - What do writes at  $f400 do ? (value 40h)
+  - What do reads from $f600 do in service mode ?
+Dr Toppel:
+  - What do writes at  $f400 do ? (value 40h)
+  - What do reads from $f600 do in service mode ?
 
 ****************************************************************************
 
@@ -116,48 +126,48 @@ f000-f003 inputs (used only by Arkanoid 2)
 ****************************************************************************/
 /***************************************************************************
 
-				Arkanoid 2 - Revenge of Doh!
-					(C) 1987 Taito
+                Arkanoid 2 - Revenge of Doh!
+                    (C) 1987 Taito
 
-						driver by
+                        driver by
 
-				Luca Elia (l.elia@tin.it)
-				Mirko Buffoni
+                Luca Elia (l.elia@tin.it)
+                Mirko Buffoni
 
 - The game doesn't write to f800-fbff (static palette)
 
 
 
-			Interesting routines (main cpu)
-			-------------------------------
+            Interesting routines (main cpu)
+            -------------------------------
 
-1ed	prints the test screen (first string at 206)
+1ed prints the test screen (first string at 206)
 
-47a	prints dipsw1&2 e 1p&2p paddleL values:
-	e821		IN DIPSW1		e823-4	1P PaddleL (lo-hi)
-	e822		IN DIPSW2		e825-6	2P PaddleL (lo-hi)
+47a prints dipsw1&2 e 1p&2p paddleL values:
+    e821        IN DIPSW1       e823-4  1P PaddleL (lo-hi)
+    e822        IN DIPSW2       e825-6  2P PaddleL (lo-hi)
 
-584	prints OK or NG on each entry:
-	if (*addr)!=0 { if (*addr)!=2 OK else NG }
-	e880	1P PADDLEL		e88a	IN SERVICE
-	e881	1P PADDLER		e88b	IN TILT
-	e882	1P BUTTON		e88c	OUT LOCKOUT1
-	e883	1P START		e88d	OUT LOCKOUT2
-	e884	2P PADDLEL		e88e	IN DIP-SW1
-	e885	2P PADDLER		e88f	IN DIP-SW2
-	e886	2P BUTTON		e890	SND OPN
-	e887	2P START		e891	SND SSGCH1
-	e888	IN COIN1		e892	SND SSGCH2
-	e889	IN COIN2		e893	SND SSGCH3
+584 prints OK or NG on each entry:
+    if (*addr)!=0 { if (*addr)!=2 OK else NG }
+    e880    1P PADDLEL      e88a    IN SERVICE
+    e881    1P PADDLER      e88b    IN TILT
+    e882    1P BUTTON       e88c    OUT LOCKOUT1
+    e883    1P START        e88d    OUT LOCKOUT2
+    e884    2P PADDLEL      e88e    IN DIP-SW1
+    e885    2P PADDLER      e88f    IN DIP-SW2
+    e886    2P BUTTON       e890    SND OPN
+    e887    2P START        e891    SND SSGCH1
+    e888    IN COIN1        e892    SND SSGCH2
+    e889    IN COIN2        e893    SND SSGCH3
 
-672	prints a char
-715	prints a string (0 terminated)
+672 prints a char
+715 prints a string (0 terminated)
 
-		Shared Memory (values written mainly by the sound cpu)
-		------------------------------------------------------
+        Shared Memory (values written mainly by the sound cpu)
+        ------------------------------------------------------
 
-e001=dip-sw A 	e399=coin counter value		e72c-d=1P paddle (lo-hi)
-e002=dip-sw B 	e3a0-2=1P score/10 (BCD)	e72e-f=2P paddle (lo-hi)
+e001=dip-sw A   e399=coin counter value     e72c-d=1P paddle (lo-hi)
+e002=dip-sw B   e3a0-2=1P score/10 (BCD)    e72e-f=2P paddle (lo-hi)
 e008=level=2*(shown_level-1)+x <- remember it's a binary tree (42 last)
 e7f0=country code(from 9fde in sound rom)
 e807=counter, reset by sound cpu, increased by main cpu each vblank
@@ -165,31 +175,31 @@ e80b=test progress=0(start) 1(first 8) 2(all ok) 3(error)
 ec09-a~=ed05-6=xy pos of cursor in hi-scores
 ec81-eca8=hi-scores(8bytes*5entries)
 
-addr	bit	name		active	addr	bit	name		active
-e72d	6	coin[1]		low		e729	1	2p select	low
-		5	service		high			0	1p select	low
-		4	coin[2]		low
+addr    bit name        active  addr    bit name        active
+e72d    6   coin[1]     low     e729    1   2p select   low
+        5   service     high            0   1p select   low
+        4   coin[2]     low
 
-addr	bit	name		active	addr	bit	name		active
-e730	7	tilt		low		e7e7	4	1p fire		low
-										0	2p fire		low
+addr    bit name        active  addr    bit name        active
+e730    7   tilt        low     e7e7    4   1p fire     low
+                                        0   2p fire     low
 
-			Interesting routines (sound cpu)
-			--------------------------------
+            Interesting routines (sound cpu)
+            --------------------------------
 
-4ae	check starts	B73,B7a,B81,B99	coin related
-8c1	check coins		62e lockout check		664	dsw check
+4ae check starts    B73,B7a,B81,B99 coin related
+8c1 check coins     62e lockout check       664 dsw check
 
-			Interesting locations (sound cpu)
-			---------------------------------
+            Interesting locations (sound cpu)
+            ---------------------------------
 
 d006=each bit is on if a corresponding location (e880-e887) has changed
 d00b=(c001)>>4=tilt if 0E (security sequence must be reset?)
-addr	bit	name		active
-d00c	7	tilt
-		6	?service?
-		5	coin2		low
-		4	coin1		low
+addr    bit name        active
+d00c    7   tilt
+        6   ?service?
+        5   coin2       low
+        4   coin1       low
 
 d00d=each bit is on if the corresponding location (e880-e887) is 1 (OK)
 d00e=each of the 4 MSBs is on if ..
@@ -210,18 +220,21 @@ Driver by Takahiro Nogi (nogi@kt.rim.or.jp) 1999/11/06
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/i8x41/i8x41.h"
-
-
+#include "sound/2203intf.h"
+#include "sound/dac.h"
+#include "sound/samples.h"
 
 /* prototypes for functions in ../machine/tnzs.c */
-unsigned char *tnzs_objram, *tnzs_workram;
-unsigned char *tnzs_vdcram, *tnzs_scrollram;
+unsigned char *tnzs_objram, *tnzs_sharedram;
+unsigned char *tnzs_vdcram, *tnzs_scrollram, *tnzs_objctrl;
+DRIVER_INIT( plumpop );
 DRIVER_INIT( extrmatn );
 DRIVER_INIT( arknoid2 );
 DRIVER_INIT( drtoppel );
 DRIVER_INIT( chukatai );
 DRIVER_INIT( tnzs );
 DRIVER_INIT( tnzsb );
+DRIVER_INIT( kabukiz );
 DRIVER_INIT( insectx );
 DRIVER_INIT( kageki );
 READ8_HANDLER( arknoid2_sh_f000_r );
@@ -231,10 +244,8 @@ READ8_HANDLER( tnzs_port1_r );
 READ8_HANDLER( tnzs_port2_r );
 WRITE8_HANDLER( tnzs_port2_w );
 READ8_HANDLER( tnzs_mcu_r );
-READ8_HANDLER( tnzs_workram_r );
-READ8_HANDLER( tnzs_workram_sub_r );
-WRITE8_HANDLER( tnzs_workram_w );
-WRITE8_HANDLER( tnzs_workram_sub_w );
+READ8_HANDLER( tnzs_sharedram_r );
+WRITE8_HANDLER( tnzs_sharedram_w );
 WRITE8_HANDLER( tnzs_mcu_w );
 WRITE8_HANDLER( tnzs_bankswitch_w );
 WRITE8_HANDLER( tnzs_bankswitch1_w );
@@ -243,27 +254,24 @@ WRITE8_HANDLER( tnzs_bankswitch1_w );
 /* prototypes for functions in ../vidhrdw/tnzs.c */
 PALETTE_INIT( arknoid2 );
 VIDEO_UPDATE( tnzs );
+VIDEO_EOF( tnzs );
 
 
 
 /* max samples */
 #define	MAX_SAMPLES	0x2f
 
-int kageki_init_samples(const struct MachineSound *msound)
+static INT16 *sampledata[MAX_SAMPLES];
+static int samplesize[MAX_SAMPLES];
+
+void kageki_init_samples(void)
 {
-	struct GameSamples *samples;
-	unsigned char *scan, *src, *dest;
+	unsigned char *scan, *src;
+	INT16 *dest;
 	int start, size;
 	int i, n;
 
-	size = sizeof(struct GameSamples) + MAX_SAMPLES * sizeof(struct GameSamples *);
-
-	if ((Machine->samples = auto_malloc(size)) == NULL) return 1;
-
-	samples = Machine->samples;
-	samples->total = MAX_SAMPLES;
-
-	for (i = 0; i < samples->total; i++)
+	for (i = 0; i < MAX_SAMPLES; i++)
 	{
 		src = memory_region(REGION_SOUND1) + 0x0090;
 		start = (src[(i * 2) + 1] * 256) + src[(i * 2)];
@@ -280,25 +288,20 @@ int kageki_init_samples(const struct MachineSound *msound)
 				size++;
 			}
 		}
-		if ((samples->sample[i] = auto_malloc(sizeof(struct GameSample) + size * sizeof(unsigned char))) == NULL) return 1;
+		sampledata[i] = auto_malloc(size * sizeof(sampledata[0]));
+		samplesize[i] = size;
 
 		if (start < 0x100) start = size = 0;
 
-		samples->sample[i]->smpfreq = 7000;	/* 7 KHz??? */
-		samples->sample[i]->resolution = 8;	/* 8 bit */
-		samples->sample[i]->length = size;
-
 		/* signed 8-bit sample to unsigned 8-bit sample convert */
-		dest = (unsigned char *)samples->sample[i]->data;
+		dest = sampledata[i];
 		scan = &src[start];
 		for (n = 0; n < size; n++)
 		{
-			*dest++ = ((*scan++) ^ 0x80);
+			*dest++ = (INT8)((*scan++) ^ 0x80) * 256;
 		}
-	/*	logerror("samples num:%02X ofs:%04X lng:%04X\n", i, start, size); */
+	/*  logerror("samples num:%02X ofs:%04X lng:%04X\n", i, start, size); */
 	}
-
-	return 0;
 }
 
 
@@ -326,7 +329,7 @@ static READ8_HANDLER( kageki_csport_r )
 			break;
 		default:
 			dsw = 0x00;
-		/*	logerror("kageki_csport_sel error !! (0x%08X)\n", kageki_csport_sel); */
+		/*  logerror("kageki_csport_sel error !! (0x%08X)\n", kageki_csport_sel); */
 	}
 
 	return (dsw & 0xff);
@@ -348,19 +351,35 @@ static WRITE8_HANDLER( kageki_csport_w )
 			sprintf(mess, "VOICE:%02X STOP", data);
 		} else {
 			/* play samples */
-			sample_start(0, data, 0);
+			sample_start_raw(0, sampledata[data], samplesize[data], 7000, 0);
 			sprintf(mess, "VOICE:%02X PLAY", data);
 		}
-	/*	usrintf_showmessage(mess); */
+	/*  usrintf_showmessage(mess); */
 	}
 }
 
+static WRITE8_HANDLER( kabukiz_sound_bank_w )
+{
+	/* to avoid the write when the sound chip is initialized */
+	if(data != 0xff)
+	{
+		data8_t *ROM = memory_region(REGION_CPU3);
+		cpu_setbank(3, &ROM[0x10000 + 0x4000 * (data & 0x07)]);
+	}
+}
+
+static WRITE8_HANDLER( kabukiz_sample_w )
+{
+	/* to avoid the write when the sound chip is initialized */
+	if(data != 0xff)
+		DAC_0_data_w(0, data );
+}
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
 	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK1) /* ROM + RAM */
 	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe000, 0xefff) AM_READ(tnzs_workram_r)	/* WORK RAM (shared by the 2 z80's */
+	AM_RANGE(0xe000, 0xefff) AM_READ(tnzs_sharedram_r)	/* WORK RAM (shared by the 2 z80's) */
 	AM_RANGE(0xf000, 0xf1ff) AM_READ(MRA8_RAM)	/* VDC RAM */
 	AM_RANGE(0xf600, 0xf600) AM_READ(MRA8_NOP)	/* ? */
 	AM_RANGE(0xf800, 0xfbff) AM_READ(MRA8_RAM)	/* not in extrmatn and arknoid2 (PROMs instead) */
@@ -370,9 +389,10 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
 	AM_RANGE(0x8000, 0xbfff) AM_WRITE(MWA8_BANK1)	/* ROM + RAM */
 	AM_RANGE(0xc000, 0xdfff) AM_WRITE(MWA8_RAM) AM_BASE(&tnzs_objram)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(tnzs_workram_w) AM_BASE(&tnzs_workram)
+	AM_RANGE(0xe000, 0xefff) AM_WRITE(tnzs_sharedram_w) AM_BASE(&tnzs_sharedram)
 	AM_RANGE(0xf000, 0xf1ff) AM_WRITE(MWA8_RAM) AM_BASE(&tnzs_vdcram)
-	AM_RANGE(0xf200, 0xf3ff) AM_WRITE(MWA8_RAM) AM_BASE(&tnzs_scrollram) /* scrolling info */
+	AM_RANGE(0xf200, 0xf2ff) AM_WRITE(MWA8_RAM) AM_BASE(&tnzs_scrollram) /* scrolling info */
+	AM_RANGE(0xf300, 0xf303) AM_MIRROR(0xfc) AM_WRITE(MWA8_RAM) AM_BASE(&tnzs_objctrl) /* control registers (0x80 mirror used by Arkanoid 2) */
 	AM_RANGE(0xf400, 0xf400) AM_WRITE(MWA8_NOP)	/* ? */
 	AM_RANGE(0xf600, 0xf600) AM_WRITE(tnzs_bankswitch_w)
 	/* arknoid2, extrmatn, plumppop and drtoppel have PROMs instead of RAM */
@@ -381,6 +401,20 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf800, 0xfbff) AM_WRITE(paletteram_xRRRRRGGGGGBBBBB_w) AM_BASE(&paletteram)
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( cpu0_type2, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_RAMBANK(1)	/* ROM + RAM */
+	AM_RANGE(0xc000, 0xdfff) AM_RAM AM_BASE(&tnzs_objram)
+	AM_RANGE(0xe000, 0xefff) AM_READWRITE(tnzs_sharedram_r, tnzs_sharedram_w) AM_BASE(&tnzs_sharedram) /* WORK RAM (shared by the 2 z80's) */
+	AM_RANGE(0xf000, 0xf1ff) AM_RAM AM_BASE(&tnzs_vdcram)
+	AM_RANGE(0xf200, 0xf2ff) AM_WRITE(MWA8_RAM) AM_BASE(&tnzs_scrollram) /* scrolling info */
+	AM_RANGE(0xf300, 0xf303) AM_MIRROR(0xfc) AM_WRITE(MWA8_RAM) AM_BASE(&tnzs_objctrl) /* control registers (0x80 mirror used by Arkanoid 2) */
+	AM_RANGE(0xf400, 0xf400) AM_WRITENOP	/* ? */
+	AM_RANGE(0xf600, 0xf600) AM_WRITE(tnzs_bankswitch_w)
+	/* kabukiz still writes here but it's not used (it's paletteram in type1 map) */
+	AM_RANGE(0xf800, 0xfbff) AM_WRITENOP
+ADDRESS_MAP_END
+
 static ADDRESS_MAP_START( sub_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
 	AM_RANGE(0x8000, 0x9fff) AM_READ(MRA8_BANK2)
@@ -389,7 +423,7 @@ static ADDRESS_MAP_START( sub_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xc001) AM_READ(tnzs_mcu_r)	/* plain input ports in insectx (memory handler */
 									/* changed in insectx_init() ) */
 	AM_RANGE(0xd000, 0xdfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe000, 0xefff) AM_READ(tnzs_workram_sub_r)
+	AM_RANGE(0xe000, 0xefff) AM_READ(tnzs_sharedram_r)
 	AM_RANGE(0xf000, 0xf003) AM_READ(arknoid2_sh_f000_r)	/* paddles in arkanoid2/plumppop. The ports are */
 						/* read but not used by the other games, and are not read at */
 						/* all by insectx. */
@@ -402,7 +436,7 @@ static ADDRESS_MAP_START( sub_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xb001, 0xb001) AM_WRITE(YM2203_write_port_0_w)
 	AM_RANGE(0xc000, 0xc001) AM_WRITE(tnzs_mcu_w)	/* not present in insectx */
 	AM_RANGE(0xd000, 0xdfff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(tnzs_workram_sub_w)
+	AM_RANGE(0xe000, 0xefff) AM_WRITE(tnzs_sharedram_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( kageki_sub_readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -414,7 +448,7 @@ static ADDRESS_MAP_START( kageki_sub_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc001, 0xc001) AM_READ(input_port_3_r)
 	AM_RANGE(0xc002, 0xc002) AM_READ(input_port_4_r)
 	AM_RANGE(0xd000, 0xdfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe000, 0xefff) AM_READ(tnzs_workram_sub_r)
+	AM_RANGE(0xe000, 0xefff) AM_READ(tnzs_sharedram_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( kageki_sub_writemem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -423,10 +457,10 @@ static ADDRESS_MAP_START( kageki_sub_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xb000, 0xb000) AM_WRITE(YM2203_control_port_0_w)
 	AM_RANGE(0xb001, 0xb001) AM_WRITE(YM2203_write_port_0_w)
 	AM_RANGE(0xd000, 0xdfff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(tnzs_workram_sub_w)
+	AM_RANGE(0xe000, 0xefff) AM_WRITE(tnzs_sharedram_w)
 ADDRESS_MAP_END
 
-/* the bootleg board is different, it has a third CPU (and of course no mcu) */
+/* the later board is different, it has a third CPU (and of course no mcu) */
 
 static WRITE8_HANDLER( tnzsb_sound_command_w )
 {
@@ -434,25 +468,19 @@ static WRITE8_HANDLER( tnzsb_sound_command_w )
 	cpunum_set_input_line_and_vector(2,0,HOLD_LINE,0xff);
 }
 
-static ADDRESS_MAP_START( tnzsb_readmem1, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0x9fff) AM_READ(MRA8_BANK2)
+static ADDRESS_MAP_START( tnzsb_cpu1_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0x9fff) AM_ROMBANK(2)
+	AM_RANGE(0xa000, 0xa000) AM_WRITE(tnzs_bankswitch1_w)
 	AM_RANGE(0xb002, 0xb002) AM_READ(input_port_0_r)
 	AM_RANGE(0xb003, 0xb003) AM_READ(input_port_1_r)
+	AM_RANGE(0xb004, 0xb004) AM_WRITE(tnzsb_sound_command_w)
 	AM_RANGE(0xc000, 0xc000) AM_READ(input_port_2_r)
 	AM_RANGE(0xc001, 0xc001) AM_READ(input_port_3_r)
 	AM_RANGE(0xc002, 0xc002) AM_READ(input_port_4_r)
-	AM_RANGE(0xd000, 0xdfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe000, 0xefff) AM_READ(tnzs_workram_sub_r)
+	AM_RANGE(0xd000, 0xdfff) AM_RAM
+	AM_RANGE(0xe000, 0xefff) AM_READWRITE(tnzs_sharedram_r, tnzs_sharedram_w)
 	AM_RANGE(0xf000, 0xf003) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( tnzsb_writemem1, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x9fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xa000, 0xa000) AM_WRITE(tnzs_bankswitch1_w)
-	AM_RANGE(0xb004, 0xb004) AM_WRITE(tnzsb_sound_command_w)
-	AM_RANGE(0xd000, 0xdfff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(tnzs_workram_sub_w)
 	AM_RANGE(0xf000, 0xf3ff) AM_WRITE(paletteram_xRRRRRGGGGGBBBBB_w) AM_BASE(&paletteram)
 ADDRESS_MAP_END
 
@@ -467,31 +495,29 @@ static ADDRESS_MAP_START( kabukiz_cpu1_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc001, 0xc001) AM_READ(input_port_3_r)
 	AM_RANGE(0xc002, 0xc002) AM_READ(input_port_4_r)
 	AM_RANGE(0xd000, 0xdfff) AM_RAM
-	AM_RANGE(0xe000, 0xefff) AM_READ(tnzs_workram_sub_r) AM_WRITE(tnzs_workram_sub_w)
+	AM_RANGE(0xe000, 0xefff) AM_READWRITE(tnzs_sharedram_r, tnzs_sharedram_w)
 	AM_RANGE(0xf800, 0xfbff) AM_WRITE(paletteram_xRRRRRGGGGGBBBBB_w) AM_BASE(&paletteram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( tnzsb_readmem2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( tnzsb_writemem2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc000, 0xdfff) AM_WRITE(MWA8_RAM)
+static ADDRESS_MAP_START( tnzsb_cpu2_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0xc000, 0xdfff) AM_RAM
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( kabukiz_cpu2_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(3)
 	AM_RANGE(0xe000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( tnzsb_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(YM2203_status_port_0_r)
 	AM_RANGE(0x02, 0x02) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( tnzsb_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM2203_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM2203_write_port_0_w)
 ADDRESS_MAP_END
@@ -941,7 +967,7 @@ INPUT_PORTS_START( tnzs )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
+	PORT_DIPNAME( 0x08, 0x08, "Invulnerability (Debug)" )	/* see notes */
 	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	TAITO_COINAGE_JAPAN_8
@@ -966,7 +992,7 @@ INPUT_PORTS_START( tnzsb )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
+	PORT_DIPNAME( 0x08, 0x08, "Invulnerability (Debug)" )	/* see notes */
 	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	TAITO_COINAGE_WORLD_8
@@ -1052,9 +1078,9 @@ INPUT_PORTS_START( kabukiz )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x08, 0x00, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
 	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -1256,13 +1282,8 @@ static struct GfxDecodeInfo insectx_gfxdecodeinfo[] =
 
 static struct YM2203interface ym2203_interface =
 {
-	1,			/* 1 chip */
-	3000000,	/* 3 MHz  */
-	{ YM2203_VOL(30,30) },
-	{ input_port_0_r },		/* DSW1 connected to port A */
-	{ input_port_1_r },		/* DSW2 connected to port B */
-	{ 0 },
-	{ 0 }
+	input_port_0_r,		/* DSW1 connected to port A */
+	input_port_1_r		/* DSW2 connected to port B */
 };
 
 
@@ -1272,43 +1293,33 @@ static void irqhandler(int irq)
 	cpunum_set_input_line(2, INPUT_LINE_NMI, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static struct YM2203interface ym2203b_interface =
-{
-	1,			/* 1 chip */
-	3000000,	/* 3 MHz ??? */
-	{ YM2203_VOL(100,100) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler }
-};
-
 static struct YM2203interface kageki_ym2203_interface =
 {
-	1,					/* 1 chip */
-	3000000,			/* 12000000/4 ??? */
-	{ YM2203_VOL(35, 15) },
-	{ kageki_csport_r },
-	{ 0 },
-	{ 0 },
-	{ kageki_csport_w },
+	kageki_csport_r,
+	0,
+	0,
+	kageki_csport_w
+};
+
+static struct YM2203interface ym2203b_interface =
+{
+	0,0,0,0,
+	irqhandler
+};
+
+static struct YM2203interface kabukiz_ym2203_interface =
+{
+	0,0,kabukiz_sound_bank_w,kabukiz_sample_w,
+	irqhandler
 };
 
 static struct Samplesinterface samples_interface =
 {
-	1,					/* 1 channel */
-	100					/* volume */
+	1,
+	NULL,
+	kageki_init_samples
 };
 
-static struct CustomSound_interface custom_interface =
-{
-	kageki_init_samples,
-	0,
-	0
-};
-
-
 static MACHINE_DRIVER_START( arknoid2 )
 
 	/* basic machine hardware */
@@ -1336,9 +1347,14 @@ static MACHINE_DRIVER_START( arknoid2 )
 
 	MDRV_PALETTE_INIT(arknoid2)
 	MDRV_VIDEO_UPDATE(tnzs)
+	MDRV_VIDEO_EOF(tnzs)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 
@@ -1368,9 +1384,14 @@ static MACHINE_DRIVER_START( drtoppel )
 
 	MDRV_PALETTE_INIT(arknoid2)
 	MDRV_VIDEO_UPDATE(tnzs)
+	MDRV_VIDEO_EOF(tnzs)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 
@@ -1391,8 +1412,8 @@ static MACHINE_DRIVER_START( tnzs )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(500)	/* 500 CPU slices per frame - heavy sync required in order to*/
-							/* avoid crashes/hangs -kal 14 jul 2002 */
+	MDRV_INTERLEAVE(100)
+
 	MDRV_MACHINE_INIT(tnzs)
 
 	/* video hardware */
@@ -1403,44 +1424,14 @@ static MACHINE_DRIVER_START( tnzs )
 	MDRV_PALETTE_LENGTH(512)
 
 	MDRV_VIDEO_UPDATE(tnzs)
+	MDRV_VIDEO_EOF(tnzs)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-MACHINE_DRIVER_END
+	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-
-static MACHINE_DRIVER_START( tnzsb )
-
-	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, 6000000)		/* 6 MHz */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-
-	MDRV_CPU_ADD(Z80, 6000000)		/* 6 MHz */
-	MDRV_CPU_PROGRAM_MAP(tnzsb_readmem1,tnzsb_writemem1)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-
-	MDRV_CPU_ADD(Z80, 6000000)		/* 6 MHz */
-	MDRV_CPU_PROGRAM_MAP(tnzsb_readmem2,tnzsb_writemem2)
-	MDRV_CPU_IO_MAP(tnzsb_readport,tnzsb_writeport)
-
-	MDRV_FRAMES_PER_SECOND(60)
-	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(200)	/* 200 CPU slices per frame - an high value to ensure proper */
-							/* synchronization of the CPUs */
-	MDRV_MACHINE_INIT(tnzs)
-
-	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MDRV_GFXDECODE(tnzs_gfxdecodeinfo)
-	MDRV_PALETTE_LENGTH(512)
-
-	MDRV_VIDEO_UPDATE(tnzs)
-
-	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203b_interface)
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 
@@ -1457,8 +1448,8 @@ static MACHINE_DRIVER_START( insectx )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(200)	/* 200 CPU slices per frame - an high value to ensure proper */
-							/* synchronization of the CPUs */
+	MDRV_INTERLEAVE(100)
+
 	MDRV_MACHINE_INIT(tnzs)
 
 	/* video hardware */
@@ -1469,9 +1460,14 @@ static MACHINE_DRIVER_START( insectx )
 	MDRV_PALETTE_LENGTH(512)
 
 	MDRV_VIDEO_UPDATE(tnzs)
+	MDRV_VIDEO_EOF(tnzs)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
 
@@ -1488,8 +1484,8 @@ static MACHINE_DRIVER_START( kageki )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(200)	/* 200 CPU slices per frame - an high value to ensure proper */
-							/* synchronization of the CPUs */
+	MDRV_INTERLEAVE(100)
+
 	MDRV_MACHINE_INIT(tnzs)
 
 	/* video hardware */
@@ -1500,48 +1496,91 @@ static MACHINE_DRIVER_START( kageki )
 	MDRV_PALETTE_LENGTH(512)
 
 	MDRV_VIDEO_UPDATE(tnzs)
+	MDRV_VIDEO_EOF(tnzs)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, kageki_ym2203_interface)
-	MDRV_SOUND_ADD(SAMPLES, samples_interface)
-	MDRV_SOUND_ADD(CUSTOM, custom_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_CONFIG(kageki_ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.35)
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_DRIVER_END
+
+
+static MACHINE_DRIVER_START( tnzsb )
+
+	/* basic machine hardware */
+	MDRV_CPU_ADD_TAG("cpu0", Z80, 6000000)		/* 6 MHz */
+	MDRV_CPU_PROGRAM_MAP(cpu0_type2,0)
+	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+
+	MDRV_CPU_ADD_TAG("cpu1", Z80, 6000000)		/* 6 MHz */
+	MDRV_CPU_PROGRAM_MAP(tnzsb_cpu1_map,0)
+	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+
+	MDRV_CPU_ADD_TAG("cpu2", Z80, 6000000)		/* 6 MHz */
+	MDRV_CPU_PROGRAM_MAP(tnzsb_cpu2_map,0)
+	MDRV_CPU_IO_MAP(tnzsb_readport,tnzsb_writeport)
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(100)
+
+	MDRV_MACHINE_INIT(tnzs)
+
+	/* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(32*8, 32*8)
+	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MDRV_GFXDECODE(tnzs_gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(512)
+
+	MDRV_VIDEO_UPDATE(tnzs)
+	MDRV_VIDEO_EOF(tnzs)
+
+	/* sound hardware */
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD_TAG("ym2203", YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203b_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 1.0)
+	MDRV_SOUND_ROUTE(1, "mono", 1.0)
+	MDRV_SOUND_ROUTE(2, "mono", 1.0)
+	MDRV_SOUND_ROUTE(3, "mono", 2.0)
 MACHINE_DRIVER_END
 
 
 static MACHINE_DRIVER_START( kabukiz )
 
+	MDRV_IMPORT_FROM(tnzsb)
+
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, 6000000)		/* 6 MHz */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-
-	MDRV_CPU_ADD(Z80, 6000000)		/* 6 MHz */
+	MDRV_CPU_MODIFY("cpu1")
 	MDRV_CPU_PROGRAM_MAP(kabukiz_cpu1_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
-	MDRV_CPU_ADD(Z80, 6000000)		/* 6 MHz */
+	MDRV_CPU_MODIFY("cpu2")
 	MDRV_CPU_PROGRAM_MAP(kabukiz_cpu2_map,0)
-	MDRV_CPU_IO_MAP(tnzsb_readport,tnzsb_writeport)
 
-	MDRV_FRAMES_PER_SECOND(60)
-	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(500)	/* 500 CPU slices per frame - heavy sync required in order to*/
-							/* avoid crashes/hangs -kal 14 jul 2002 */
-	MDRV_MACHINE_INIT(tnzs)
+	MDRV_SOUND_MODIFY("ym2203")
+	MDRV_SOUND_CONFIG(kabukiz_ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 1.0)
+	MDRV_SOUND_ROUTE(1, "mono", 1.0)
+	MDRV_SOUND_ROUTE(2, "mono", 1.0)
+	MDRV_SOUND_ROUTE(3, "mono", 2.0)
 
-	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MDRV_GFXDECODE(tnzs_gfxdecodeinfo)
-	MDRV_PALETTE_LENGTH(512)
-
-	MDRV_VIDEO_UPDATE(tnzs)
-
-	/* sound hardware */
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
+
+
 /***************************************************************************
 
   Game driver(s)
@@ -2004,12 +2043,33 @@ ROM_START( kabukiz )
 	ROM_LOAD( "b50_05.u1",  0x00000, 0x08000, CRC(9cccb129) SHA1(054faf7657bad7237182e36bcc4388b1748af935) )
 	ROM_CONTINUE(           0x18000, 0x18000 )		/* banked at 8000-bfff */
 
+	ROM_REGION( 0x18000, REGION_CPU2, 0 )	/* 64k for the second CPU */
+	ROM_LOAD( "b50-08.1e",  0x00000, 0x08000, CRC(cb92d34c) SHA1(3a666f0e3ff9d3daa599123edee228d94eeae754) )
+	ROM_CONTINUE(           0x10000, 0x08000 )		/* banked at 8000-9fff */
+
+	ROM_REGION( 0x30000, REGION_CPU3, 0 )	/* 64k + bankswitch areas for the third CPU */
+	ROM_LOAD( "b50_07.u34", 0x00000, 0x08000, CRC(bf7fc2ed) SHA1(77008d12d9bdbfa100dcd87cd6ca7de3748408c5) )
+	ROM_CONTINUE(           0x18000, 0x18000 )		/* banked at 8000-bfff */
+
+	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "b50-04.u35", 0x000000, 0x80000, CRC(04829aa9) SHA1(a501ec7c802478fc41ec8ef4270b1a6872bcbf34) )
+	ROM_LOAD( "b50-03.u39", 0x080000, 0x80000, CRC(31489a4c) SHA1(a4b7e00e2074287b47c7e16add963c1470534376) )
+	ROM_LOAD( "b50-02.u43", 0x100000, 0x80000, CRC(90b8a8e7) SHA1(a55e327307606142fbb9d500e757655b35e1f252) )
+	ROM_LOAD( "b50-01.u46", 0x180000, 0x80000, CRC(f4277751) SHA1(8f50f843f0eda30d639ba397889236ff0a3edce5) )
+ROM_END
+
+ROM_START( kabukizj )
+	ROM_REGION( 0x30000, REGION_CPU1, 0 )	/* 64k + bankswitch areas for the first CPU */
+	ROM_LOAD( "b50_05.u1",  0x00000, 0x08000, CRC(9cccb129) SHA1(054faf7657bad7237182e36bcc4388b1748af935) )
+	ROM_CONTINUE(           0x18000, 0x18000 )		/* banked at 8000-bfff */
+
 	ROM_REGION( 0x18000, REGION_CPU2, 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "b50_06.u3",  0x00000, 0x08000, CRC(45650aab) SHA1(00d1fc6044a6ad1e82476ccbe730907b4d780cb9) )
 	ROM_CONTINUE(           0x10000, 0x08000 )		/* banked at 8000-9fff */
 
-	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* 64k for the third CPU */
-	ROM_LOAD( "b50_07.u34", 0x00000, 0x10000, CRC(fdc300c9) SHA1(1b576662b7b824c8f20a45aad6f88b90c82c5553) )
+	ROM_REGION( 0x30000, REGION_CPU3, 0 )	/* 64k + bankswitch areas for the third CPU */
+	ROM_LOAD( "b50_07.u34", 0x00000, 0x08000, CRC(bf7fc2ed) SHA1(77008d12d9bdbfa100dcd87cd6ca7de3748408c5) )
+	ROM_CONTINUE(           0x18000, 0x18000 )		/* banked at 8000-bfff */
 
 	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_DISPOSE )
 	ROM_LOAD( "b50-04.u35", 0x000000, 0x80000, CRC(04829aa9) SHA1(a501ec7c802478fc41ec8ef4270b1a6872bcbf34) )
@@ -2034,7 +2094,7 @@ ROM_END
 
 
 /*  ( YEAR  NAME      PARENT    MACHINE   INPUT     INIT      MONITOR COMPANY    FULLNAME     FLAGS ) */
-GAME( 1987, plumppop, 0,        drtoppel, plumppop, drtoppel, ROT0,   "Taito Corporation", "Plump Pop (Japan)" )
+GAME( 1987, plumppop, 0,        drtoppel, plumppop, plumpop,  ROT0,   "Taito Corporation", "Plump Pop (Japan)" )
 GAME( 1987, extrmatn, 0,        arknoid2, extrmatn, extrmatn, ROT270, "[Taito] World Games", "Extermination (US)" )
 GAME( 1987, arknoid2, 0,        arknoid2, arknoid2, arknoid2, ROT270, "Taito Corporation Japan", "Arkanoid - Revenge of DOH (World)" )
 GAME( 1987, arknid2u, arknoid2, arknoid2, arknid2u, arknoid2, ROT270, "Taito America Corporation (Romstar license)", "Arkanoid - Revenge of DOH (US)" )
@@ -2050,5 +2110,6 @@ GAME( 1988, chukataj, chukatai, tnzs,     chukatau, chukatai, ROT0,   "Taito Cor
 GAME( 1988, tnzs,     0,        tnzsb,    tnzsb,    tnzsb,    ROT0,   "Taito Corporation Japan", "The NewZealand Story (World, newer)" )
 GAME( 1988, tnzsj,    tnzs,     tnzs,     tnzs,     tnzs,     ROT0,   "Taito Corporation", "The NewZealand Story (Japan)" )
 GAME( 1988, tnzso,    tnzs,     tnzs,     tnzs2,    tnzs,     ROT0,   "Taito Corporation Japan", "The NewZealand Story (World, older)" )
-GAMEX(1988, kabukiz,  0,		kabukiz,  kabukiz,  tnzsb,    ROT0,   "Taito Corporation", "Kabuki-Z (Japan)", GAME_IMPERFECT_GRAPHICS | GAME_NO_SOUND )
+GAME( 1988, kabukiz,  0,        kabukiz,  kabukiz,  kabukiz,  ROT0,   "Taito Corporation Japan", "Kabuki-Z (World)" )
+GAME( 1988, kabukizj, kabukiz,  kabukiz,  kabukiz,  kabukiz,  ROT0,   "Taito Corporation", "Kabuki-Z (Japan)" )
 GAME( 1989, insectx,  0,        insectx,  insectx,  insectx,  ROT0,   "Taito Corporation Japan", "Insector X (World)" )
