@@ -5,12 +5,12 @@ Top Speed / Full Throttle    (c) Taito 1987
 
 David Graves
 
-Sources:		Rastan driver by Jarek Burczynski
-			MAME Taito F2 & Z drivers
-			Raine source - special thanks to Richard Bush
-			  and the Raine Team.
+Sources:        Rastan driver by Jarek Burczynski
+            MAME Taito F2 & Z drivers
+            Raine source - special thanks to Richard Bush
+              and the Raine Team.
 
-				*****
+                *****
 
 Top Speed / Full Throttle is the forerunner of the Taito Z system on
 which Taito's driving games were based from 1988-91. (You can spot some
@@ -59,6 +59,17 @@ TODO Lists
 
 (Want to verify 68000 clocks)
 
+I don't know about the MSM5205 playback frequency, I set it to 4kHz because
+otherwise the samples plays at the beginning of a game would play past the end.
+The samples are stopped by the Z80, they don't stop automatically. So, if they
+should play at a higher frequency, the Z80 should stop them sooner - which
+would mean a higher interrupt rate, therefore a higher YM2151 clock rate.
+
+I haven't found how the second MSM5205 ROM is selected (I haven't even found
+when samples from that ROM should be played)
+
+Many unknown writes from the Z80: c000, c400, c800, cc00, d000, d200, d400, d600, b400.
+
 Accel and brake bits work differently depending on cab DSW
 Mame cannot yet support this, so accel/brake are not hooked up
 sensibly when upright cabinet is selected.
@@ -111,24 +122,24 @@ to top of screen):
 
 (i) White lines in center of road
 
-12	%10010
-1f	%11111
-00	%00000
-0d	%01101
+12  %10010
+1f  %11111
+00  %00000
+0d  %01101
 
 (ii) No lines in center of road
 
-08	%01000
-0c	%01100
-1a	%11010
-1e	%11110
+08  %01000
+0c  %01100
+1a  %11010
+1e  %11110
 
 (iii) Under bridge or in tunnel [note almost identical to (i)]
 
-ffe0	%00000
-ffed	%01101
-fff2	%10010
-ffef	%01111
+ffe0    %00000
+ffed    %01101
+fff2    %10010
+ffef    %01111
 
 (iv) Unknown 4th group for tunnels in later parts of the game that have
 no white lines, analogous to (ii) ?
@@ -186,6 +197,8 @@ Maybe the second area for each layer contains colscroll ?
 #include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
+#include "sound/2151intf.h"
+#include "sound/msm5205.h"
 
 WRITE16_HANDLER( rainbow_spritectrl_w );
 WRITE16_HANDLER( rastan_spriteflip_w );
@@ -193,10 +206,6 @@ WRITE16_HANDLER( rastan_spriteflip_w );
 VIDEO_START( topspeed );
 VIDEO_UPDATE( topspeed );
 
-WRITE8_HANDLER( rastan_adpcm_trigger_w );
-WRITE8_HANDLER( rastan_c000_w );
-WRITE8_HANDLER( rastan_d000_w );
-
 static UINT16 cpua_ctrl = 0xff;
 static int ioc220_port = 0;
 
@@ -222,7 +231,7 @@ static void parse_control(void)	/* assumes Z80 sandwiched between 68Ks */
 {
 	/* bit 0 enables cpu B */
 	/* however this fails when recovering from a save state
-	   if cpu B is disabled !! */
+       if cpu B is disabled !! */
 	cpunum_set_input_line(2, INPUT_LINE_RESET, (cpua_ctrl &0x1) ? CLEAR_LINE : ASSERT_LINE);
 
 }
@@ -302,7 +311,7 @@ static READ16_HANDLER( topspeed_input_bypass_r )
 			steer = 0xff80;
 
 		/* To allow hiscore input we must let you return to
-		   continuous input type while you press up */
+           continuous input type while you press up */
 
 		if (fake & 0x4)	/* pressing up */
 			steer = analogue_steer;
@@ -364,6 +373,37 @@ static WRITE8_HANDLER( sound_bankswitch_w )	/* assumes Z80 sandwiched between 68
 	reset_sound_region();
 }
 
+static int adpcm_pos;
+
+static void topspeed_msm5205_vck(int chip)
+{
+	static int adpcm_data = -1;
+
+	if (adpcm_data != -1)
+	{
+		MSM5205_data_w(0, adpcm_data & 0x0f);
+		adpcm_data = -1;
+	}
+	else
+	{
+		adpcm_data = memory_region(REGION_SOUND1)[adpcm_pos];
+		adpcm_pos = (adpcm_pos + 1) & 0x1ffff;
+		MSM5205_data_w(0, adpcm_data >> 4);
+	}
+}
+
+static WRITE8_HANDLER( topspeed_msm5205_address_w )
+{
+	adpcm_pos = (adpcm_pos & 0x00ff) | (data << 8);
+	MSM5205_reset_w(0, 0);
+}
+
+static WRITE8_HANDLER( topspeed_msm5205_stop_w )
+{
+	MSM5205_reset_w(0, 1);
+	adpcm_pos &= 0xff00;
+}
+
 
 /***********************************************************
                       MEMORY STRUCTURES
@@ -429,7 +469,6 @@ static ADDRESS_MAP_START( z80_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK10)
 	AM_RANGE(0x8000, 0x8fff) AM_READ(MRA8_RAM)
 	AM_RANGE(0x9001, 0x9001) AM_READ(YM2151_status_port_0_r)
-	AM_RANGE(0x9002, 0x9100) AM_READ(MRA8_RAM)
 	AM_RANGE(0xa001, 0xa001) AM_READ(taitosound_slave_comm_r)
 ADDRESS_MAP_END
 
@@ -440,9 +479,14 @@ static ADDRESS_MAP_START( z80_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x9001, 0x9001) AM_WRITE(YM2151_data_port_0_w)
 	AM_RANGE(0xa000, 0xa000) AM_WRITE(taitosound_slave_port_w)
 	AM_RANGE(0xa001, 0xa001) AM_WRITE(taitosound_slave_comm_w)
-	AM_RANGE(0xb000, 0xb000) AM_WRITE(rastan_adpcm_trigger_w)
-	AM_RANGE(0xc000, 0xc000) AM_WRITE(rastan_c000_w)
-	AM_RANGE(0xd000, 0xd000) AM_WRITE(rastan_d000_w)
+	AM_RANGE(0xb000, 0xb000) AM_WRITE(topspeed_msm5205_address_w)
+/*  AM_RANGE(0xb400, 0xb400) // msm5205 start? doesn't seem to work right */
+	AM_RANGE(0xb800, 0xb800) AM_WRITE(topspeed_msm5205_stop_w)
+/*  AM_RANGE(0xc000, 0xc000) // ?? */
+/*  AM_RANGE(0xc400, 0xc400) // ?? */
+/*  AM_RANGE(0xc800, 0xc800) // ?? */
+/*  AM_RANGE(0xcc00, 0xcc00) // ?? */
+/*  AM_RANGE(0xd000, 0xd000) // ?? */
 ADDRESS_MAP_END
 
 
@@ -550,8 +594,8 @@ INPUT_PORTS_START( topspeed )
 	PORT_START      /* IN2, unused */
 
 	/* Note that sensitivity is chosen to suit keyboard control (for
-	   sound selection in test mode and hi score name entry). With
-	   an analogue wheel, the user will need to adjust this. */
+       sound selection in test mode and hi score name entry). With
+       an analogue wheel, the user will need to adjust this. */
 
 	PORT_START	/* continuous steer */
 	PORT_BIT( 0xffff, 0x00, IPT_AD_STICK_X ) PORT_MINMAX(0xff7f,0x80) PORT_SENSITIVITY(10) PORT_KEYDELTA(2) PORT_PLAYER(1)
@@ -623,8 +667,8 @@ INPUT_PORTS_START( topspedu )
 	PORT_START      /* IN2, unused */
 
 	/* Note that sensitivity is chosen to suit keyboard control (for
-	   sound selection in test mode and hi score name entry). With
-	   an analogue wheel, the user will need to adjust this. */
+       sound selection in test mode and hi score name entry). With
+       an analogue wheel, the user will need to adjust this. */
 
 	PORT_START	/* continuous steer */
 	PORT_BIT( 0xffff, 0x00, IPT_AD_STICK_X ) PORT_MINMAX(0xff7f,0x80) PORT_SENSITIVITY(10) PORT_KEYDELTA(2) PORT_PLAYER(1)
@@ -696,8 +740,8 @@ INPUT_PORTS_START( fullthrl )
 	PORT_START      /* IN2, unused */
 
 	/* Note that sensitivity is chosen to suit keyboard control (for
-	   sound selection in test mode and hi score name entry). With
-	   an analogue wheel, the user will need to adjust this. */
+       sound selection in test mode and hi score name entry). With
+       an analogue wheel, the user will need to adjust this. */
 
 	PORT_START	/* continuous steer */
 	PORT_BIT( 0xffff, 0x00, IPT_AD_STICK_X ) PORT_MINMAX(0xff7f,0x80) PORT_SENSITIVITY(10) PORT_KEYDELTA(2) PORT_PLAYER(1)
@@ -761,19 +805,14 @@ static void irq_handler(int irq)	/* assumes Z80 sandwiched between 68Ks */
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	4000000,	/* 4 MHz ? */
-	{ YM3012_VOL(20,MIXER_PAN_CENTER,20,MIXER_PAN_CENTER) },
-	{ irq_handler },
-	{ sound_bankswitch_w }
+	irq_handler,
+	sound_bankswitch_w
 };
 
-static struct ADPCMinterface adpcm_interface =
+static struct MSM5205interface msm5205_interface =
 {
-	1,			/* 1 chip */
-	8000,       /* 8000Hz playback */
-	REGION_SOUND1,	/* memory region */
-	{ 60 }
+	topspeed_msm5205_vck,	/* VCK function */
+	MSM5205_S96_4B			/* 4 kHz? */
 };
 
 
@@ -789,7 +828,7 @@ static MACHINE_DRIVER_START( topspeed )
 	MDRV_CPU_VBLANK_INT(topspeed_interrupt,1)
 
 	MDRV_CPU_ADD(Z80,16000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 4 MHz ??? */
+	/* audio CPU */	/* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(z80_readmem,z80_writemem)
 
 	MDRV_CPU_ADD(M68000, 12000000)	/* 12 MHz ??? */
@@ -810,8 +849,16 @@ static MACHINE_DRIVER_START( topspeed )
 	MDRV_VIDEO_UPDATE(topspeed)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(ADPCM, adpcm_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2151, 4000000)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.30)
+	MDRV_SOUND_ROUTE(1, "mono", 0.30)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
 MACHINE_DRIVER_END
 
 
@@ -949,7 +996,7 @@ ROM_END
 
 DRIVER_INIT( topspeed )
 {
-/*	taitosnd_setz80_soundcpu( 2 ); */
+/*  taitosnd_setz80_soundcpu( 2 ); */
 
 	cpua_ctrl = 0xff;
 	state_save_register_UINT16("main1", 0, "control", &cpua_ctrl, 1);
