@@ -32,6 +32,7 @@ TODO:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "machine/namcoio.h"
+#include "sound/namco.h"
 
 
 /* vidhrdw\toypop.c */
@@ -225,12 +226,6 @@ INTERRUPT_GEN( toypop_m68000_interrupt )
 		cpunum_set_input_line(2, 6, HOLD_LINE);
 }
 
-static WRITE8_HANDLER( toypop_68k_irq_trigger_w )
-{
-	if (interrupt_enable_68k)
-		cpunum_set_input_line(2, 6, HOLD_LINE);
-}
-
 WRITE16_HANDLER( toypop_m68000_interrupt_enable_w )
 {
 	interrupt_enable_68k = 1;
@@ -245,7 +240,7 @@ WRITE16_HANDLER( toypop_m68000_interrupt_disable_w )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -309,7 +304,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
@@ -330,7 +325,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	68k CPU memory handlers
+ *  68k CPU memory handlers
  *
  *************************************/
 
@@ -560,9 +555,7 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 static struct namco_interface namco_interface =
 {
-	24000,	/* sample rate */
 	8,		/* number of voices */
-	100,	/* playback volume */
 	REGION_SOUND1	/* memory region */
 };
 
@@ -576,7 +569,7 @@ static MACHINE_DRIVER_START( liblrabl )
 	MDRV_CPU_VBLANK_INT(toypop_main_interrupt,1)
 
 	MDRV_CPU_ADD(M6809, 1536000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 1.536 MHz (measured on Libble Rabble board) */
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_soundCPU,writemem_soundCPU)
 	MDRV_CPU_VBLANK_INT(irq0_line_assert,1)
 
@@ -603,7 +596,11 @@ static MACHINE_DRIVER_START( liblrabl )
 	MDRV_VIDEO_UPDATE(toypop)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(NAMCO_15XX, namco_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(NAMCO_15XX, 24000)
+	MDRV_SOUND_CONFIG(namco_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( toypop )
@@ -618,7 +615,7 @@ MACHINE_DRIVER_END
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
