@@ -31,8 +31,8 @@ Write
  3001      OUT2  Coin Counter 2
  3002      OUT1  Coin Counter 1
  3003      MUT
- 3004      HREV	 Flip Screen X
- 3005      VREV	 Flip Screen Y
+ 3004      HREV  Flip Screen X
+ 3005      VREV  Flip Screen Y
  3006      -
  3007      GMED
  3800      SON   Sound on
@@ -83,6 +83,8 @@ C004      76489 #4 trigger
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/sn76496.h"
+#include "sound/flt_rc.h"
 
 
 extern UINT8 *tp84_videoram2, *tp84_colorram2;
@@ -136,23 +138,23 @@ static WRITE8_HANDLER( tp84_filter_w )
 	C = 0;
 	if (offset & 0x008) C +=  47000;	/*  47000pF = 0.047uF */
 	if (offset & 0x010) C += 470000;	/* 470000pF = 0.47uF */
-	set_RC_filter(0,1000,2200,1000,C);
+	filter_rc_set_RC(0,1000,2200,1000,C);
 
 	/* 76489 #1 (optional) */
 	C = 0;
 	if (offset & 0x020) C +=  47000;	/*  47000pF = 0.047uF */
 	if (offset & 0x040) C += 470000;	/* 470000pF = 0.47uF */
-/*	set_RC_filter(1,1000,2200,1000,C); */
+/*  filter_rc_set_RC(1,1000,2200,1000,C); */
 
 	/* 76489 #2 */
 	C = 0;
 	if (offset & 0x080) C += 470000;	/* 470000pF = 0.47uF */
-	set_RC_filter(1,1000,2200,1000,C);
+	filter_rc_set_RC(1,1000,2200,1000,C);
 
 	/* 76489 #3 */
 	C = 0;
 	if (offset & 0x100) C += 470000;	/* 470000pF = 0.47uF */
-	set_RC_filter(2,1000,2200,1000,C);
+	filter_rc_set_RC(2,1000,2200,1000,C);
 }
 
 static WRITE8_HANDLER( tp84_sh_irqtrigger_w )
@@ -196,7 +198,7 @@ ADDRESS_MAP_END
 
 /* CPU 2 read addresses */
 static ADDRESS_MAP_START( readmem_cpu2, ADDRESS_SPACE_PROGRAM, 8 )
-/*	AM_RANGE(0x0000, 0x0000) AM_READ(MRA8_RAM) */
+/*  AM_RANGE(0x0000, 0x0000) AM_READ(MRA8_RAM) */
 	AM_RANGE(0x2000, 0x2000) AM_READ(tp84_scanline_r) /* beam position */
 	AM_RANGE(0x6000, 0x67ff) AM_READ(MRA8_RAM)
 	AM_RANGE(0x8000, 0x87ff) AM_READ(sharedram_r)
@@ -205,7 +207,7 @@ ADDRESS_MAP_END
 
 /* CPU 2 write addresses */
 static ADDRESS_MAP_START( writemem_cpu2, ADDRESS_SPACE_PROGRAM, 8 )
-/*	AM_RANGE(0x0000, 0x0000) AM_WRITE(MWA8_RAM)    Watch dog ?   */
+/*  AM_RANGE(0x0000, 0x0000) AM_WRITE(MWA8_RAM)    Watch dog ?   */
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(interrupt_enable_w) /* IRQ enable */
 	AM_RANGE(0x6000, 0x679f) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0x67a0, 0x67ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)	/* REAL (multiplexed) */
@@ -448,15 +450,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-static struct SN76496interface sn76496_interface =
-{
-	3,	/* 3 chips */
-	{ 14318180/8, 14318180/8, 14318180/8 },
-	{ 75, 75, 75 }
-};
-
-
-
 static MACHINE_DRIVER_START( tp84 )
 
 	/* basic machine hardware */
@@ -469,7 +462,7 @@ static MACHINE_DRIVER_START( tp84 )
 	MDRV_CPU_VBLANK_INT(tp84_6809_interrupt,256)
 
 	MDRV_CPU_ADD(Z80,14318180/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -490,7 +483,23 @@ static MACHINE_DRIVER_START( tp84 )
 	MDRV_VIDEO_UPDATE(tp84)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 14318180/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "filter1", 0.75)
+
+	MDRV_SOUND_ADD(SN76496, 14318180/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "filter2", 0.75)
+
+	MDRV_SOUND_ADD(SN76496, 14318180/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "filter3", 0.75)
+
+	MDRV_SOUND_ADD_TAG("filter1", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ADD_TAG("filter2", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ADD_TAG("filter3", FILTER_RC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
