@@ -20,6 +20,10 @@ MAIN BOARD:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
+#include "sound/sn76496.h"
+#include "sound/vlm5030.h"
+#include "sound/dac.h"
+#include "sound/msm5205.h"
 
 
 extern void konami1_decode(void);
@@ -45,10 +49,6 @@ extern WRITE8_HANDLER( trackfld_sound_w );
 extern READ8_HANDLER( hyprolyb_speech_r );
 extern WRITE8_HANDLER( hyprolyb_ADPCM_data_w );
 
-extern struct SN76496interface konami_sn76496_interface;
-extern struct DACinterface konami_dac_interface;
-extern struct ADPCMinterface hyprolyb_adpcm_interface;
-
 /*
  Track'n'Field has 1k of battery backed RAM which can be erased by setting a dipswitch
 */
@@ -215,7 +215,7 @@ static ADDRESS_MAP_START( mastkin_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x1200, 0x1200) AM_READ(input_port_4_r) /* DIP 2 */
 	AM_RANGE(0x1280, 0x1280) AM_READ(input_port_0_r) /* IO Coin */
 	AM_RANGE(0x1281, 0x1281) AM_READ(input_port_1_r) /* P1 IO */
-/*	AM_RANGE(0x1282, 0x1282) AM_READ(input_port_2_r)    unused    */
+/*  AM_RANGE(0x1282, 0x1282) AM_READ(input_port_2_r)    unused    */
 	AM_RANGE(0x1283, 0x1283) AM_READ(input_port_3_r) /* DIP 1 */
 	AM_RANGE(0x1800, 0x1fff) AM_READ(MRA8_RAM)
 	AM_RANGE(0x2800, 0x3fff) AM_READ(MRA8_RAM)
@@ -285,9 +285,9 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xc000) AM_WRITE(MWA8_NOP)		/* This address triggers the SN chip to read the data port. */
 	AM_RANGE(0xe000, 0xe000) AM_WRITE(DAC_0_data_w)
 /* There are lots more addresses which are used for setting a two bit volume
-	controls for speech and music
+    controls for speech and music
 
-	Currently these are un-supported by Mame
+    Currently these are un-supported by Mame
 */
 	AM_RANGE(0xe001, 0xe001) AM_WRITE(MWA8_NOP) /* watch dog ? */
 	AM_RANGE(0xe004, 0xe004) AM_WRITE(VLM5030_data_w)
@@ -309,9 +309,9 @@ static ADDRESS_MAP_START( hyprolyb_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xc000) AM_WRITE(MWA8_NOP)		/* This address triggers the SN chip to read the data port. */
 	AM_RANGE(0xe000, 0xe000) AM_WRITE(DAC_0_data_w)
 /* There are lots more addresses which are used for setting a two bit volume
-	controls for speech and music
+    controls for speech and music
 
-	Currently these are un-supported by Mame
+    Currently these are un-supported by Mame
 */
 	AM_RANGE(0xe001, 0xe001) AM_WRITE(MWA8_NOP) /* watch dog ? */
 	AM_RANGE(0xe004, 0xe004) AM_WRITE(hyprolyb_ADPCM_data_w)
@@ -565,11 +565,11 @@ INPUT_PORTS_START( mastkin )
 	PORT_DIPSETTING(    0x02, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 1C_5C ) )
-/*	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x0d, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x0e, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0x0f, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0b, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0d, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0e, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0x0f, DEF_STR( 1C_1C ) ) */
 	PORT_DIPNAME( 0xf0, 0x00, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 3C_1C ) )
@@ -582,11 +582,11 @@ INPUT_PORTS_START( mastkin )
 	PORT_DIPSETTING(    0x20, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x30, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x40, DEF_STR( 1C_5C ) )
-/*	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0xd0, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0xe0, DEF_STR( 1C_1C ) ) */
-/*	PORT_DIPSETTING(    0xf0, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0xb0, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0xc0, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0xd0, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0xe0, DEF_STR( 1C_1C ) ) */
+/*  PORT_DIPSETTING(    0xf0, DEF_STR( 1C_1C ) ) */
 INPUT_PORTS_END
 
 INPUT_PORTS_START( wizzquiz )
@@ -718,12 +718,16 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 struct VLM5030interface trackfld_vlm5030_interface =
 {
-	3580000,    /* master clock  */
-	100,        /* volume        */
 	REGION_SOUND1,	/* memory region  */
 	0           /* memory size    */
 };
 
+static struct MSM5205interface msm5205_interface =
+{
+	NULL,				/* VCK function */
+	MSM5205_S48_4B		/* 8 kHz */
+};
+
 
 
 static MACHINE_DRIVER_START( trackfld )
@@ -734,7 +738,7 @@ static MACHINE_DRIVER_START( trackfld )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,14318180/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Z80 Clock is derived from a 14.31818 MHz crystal */
+	/* audio CPU */	/* Z80 Clock is derived from a 14.31818 MHz crystal */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -755,9 +759,17 @@ static MACHINE_DRIVER_START( trackfld )
 	MDRV_VIDEO_UPDATE(trackfld)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, konami_dac_interface)
-	MDRV_SOUND_ADD(SN76496, konami_sn76496_interface)
-	MDRV_SOUND_ADD(VLM5030, trackfld_vlm5030_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+
+	MDRV_SOUND_ADD(SN76496, 14318180/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(VLM5030, 3580000)
+	MDRV_SOUND_CONFIG(trackfld_vlm5030_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 /* same as the original, but uses ADPCM instead of VLM5030 */
@@ -770,7 +782,7 @@ static MACHINE_DRIVER_START( hyprolyb )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,14318180/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* Z80 Clock is derived from a 14.31818 MHz crystal */
+	/* audio CPU */	/* Z80 Clock is derived from a 14.31818 MHz crystal */
 	MDRV_CPU_PROGRAM_MAP(hyprolyb_sound_readmem,hyprolyb_sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -791,9 +803,17 @@ static MACHINE_DRIVER_START( hyprolyb )
 	MDRV_VIDEO_UPDATE(trackfld)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(DAC, konami_dac_interface)
-	MDRV_SOUND_ADD(SN76496, konami_sn76496_interface)
-	MDRV_SOUND_ADD(ADPCM, hyprolyb_adpcm_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+
+	MDRV_SOUND_ADD(SN76496, 14318180/8)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -1053,7 +1073,7 @@ ROM_START( wizzquiz )
 	ROM_REGION( 0x0220, REGION_PROMS, 0 )
 	ROM_LOAD( "tfprom.1",     0x0000, 0x0020, CRC(d55f30b5) SHA1(4d6a851f4886778307f75771645078b97ad55f5f) ) /* palette */
 	ROM_LOAD( "tfprom.3",     0x0020, 0x0100, CRC(d2ba4d32) SHA1(894b5cedf01ba9225a0d6215291857e455b84903) ) /* sprite lookup table */
-	ROM_LOAD( "tfprom.2",     0x0120, 0x0100, CRC(053e5861) SHA1(6740a62cf7b6938a4f936a2fed429704612060a5) ) /* char lookup table */	
+	ROM_LOAD( "tfprom.2",     0x0120, 0x0100, CRC(053e5861) SHA1(6740a62cf7b6938a4f936a2fed429704612060a5) ) /* char lookup table */
 
 	ROM_REGION( 0x10000, REGION_SOUND1, 0 )	/* 64k for speech rom */
 	ROM_LOAD( "361-d18.9c",   0x0000, 0x2000, CRC(f546a56b) SHA1(caee3d8546eb7a75ce2a578c6a1a630246aec6b8) )
@@ -1176,7 +1196,7 @@ static DRIVER_INIT( wizzquiz )
 GAME( 1983, trackfld, 0,        trackfld, trackfld, trackfld, ROT0, "Konami", "Track & Field" )
 GAME( 1983, trackflc, trackfld, trackfld, trackfld, trackfld, ROT0, "Konami (Centuri license)", "Track & Field (Centuri)" )
 GAME( 1983, hyprolym, trackfld, trackfld, trackfld, trackfld, ROT0, "Konami", "Hyper Olympic" )
-GAME( 1983, hyprolyb, trackfld, hyprolyb, trackfld, trackfld, ROT0, "bootleg", "Hyper Olympic (bootleg)" )
+GAMEX(1983, hyprolyb, trackfld, hyprolyb, trackfld, trackfld, ROT0, "bootleg", "Hyper Olympic (bootleg)", GAME_IMPERFECT_SOUND )
 GAME( 1996, atlantol, trackfld, hyprolyb, atlantol,	atlantol, ROT0, "bootleg", "Atlant Olimpic" )
 GAMEX(1988, mastkin,  0,        mastkin,  mastkin,  mastkin,  ROT0, "Du Tech", "The Masters of Kin", GAME_WRONG_COLORS )
 GAMEX(1985, wizzquiz, 0,        wizzquiz, wizzquiz, wizzquiz, ROT0, "Konami", "Wizz Quiz (version ?)", GAME_NOT_WORKING )
