@@ -1,12 +1,12 @@
 /****************************************************************************
 
-	Preliminary driver for Samurai, Nunchackun, Yuke Yuke Yamaguchi-kun
-	(c) Taito 1985
+    Preliminary driver for Samurai, Nunchackun, Yuke Yuke Yamaguchi-kun
+    (c) Taito 1985
 
-	Known Issues:
-	- some color problems (need screenshots)
-	- Nunchackun has wrong colors; sprites look better if you subtract sprite color from 0x2d
-	- Yuke Yuke Yamaguchi-kun isn't playable (sprite problem only?)
+    Known Issues:
+    - some color problems (need screenshots)
+    - Nunchackun has wrong colors; sprites look better if you subtract sprite color from 0x2d
+    - Yuke Yuke Yamaguchi-kun isn't playable (sprite problem only?)
 
 driver by Phil Stroffolino
 
@@ -15,7 +15,7 @@ Mission 660 extensions by Paul Swan (swan@easynet.co.uk)
 The game appears to use the same video board as Samurai et al. There is a
 character column scroll feature that I have added. Its used to scroll in
 the "660" logo on the title screen at the beginning. Not sure if Samurai
-at al use it but it's likely their boards have the feature.	Extra banking
+at al use it but it's likely their boards have the feature. Extra banking
 of the forground is done using an extra register. A bit in the background
 video RAM selects the additional background character space.
 
@@ -44,6 +44,8 @@ TODO:
 #include "driver.h"
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
 
 WRITE8_HANDLER( vsgongf_color_w );
 
@@ -63,29 +65,6 @@ extern unsigned char *tsamurai_videoram;
 extern VIDEO_START( vsgongf );
 extern VIDEO_UPDATE( vsgongf );
 
-static struct AY8910interface ay8910_interface =
-{
-	1, /* number of chips */
-	2000000, /* 2 MHz */
-	{ 10 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-static struct DACinterface dac_interface =
-{
-	2,			/* number of chips */
-	{ 20, 20 }
-};
-
-static struct DACinterface vsgongf_dac_interface =
-{
-	1,			/* number of chips */
-	{ 20 }
-};
-
 static int nmi_enabled;
 static int sound_command1, sound_command2, sound_command3;
 
@@ -247,14 +226,17 @@ static ADDRESS_MAP_START( writemem_m660, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( z80_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( z80_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( z80_writeport_m660, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(MWA8_NOP)		       /* ? */
 	AM_RANGE(0x01, 0x01) AM_WRITE(MWA8_NOP)               /* Written continuously. Increments with level. */
 	AM_RANGE(0x02, 0x02) AM_WRITE(MWA8_NOP)               /* Always follows above with 0x01 data */
@@ -345,9 +327,11 @@ ADDRESS_MAP_END
 /*******************************************************************************/
 
 static ADDRESS_MAP_START( readport_sound3_m660, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writeport_sound3_m660, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
 ADDRESS_MAP_END
@@ -773,11 +757,11 @@ static MACHINE_DRIVER_START( tsamurai )
 	MDRV_CPU_VBLANK_INT(samurai_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 2000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound1,writemem_sound1)
 
 	MDRV_CPU_ADD(Z80, 2000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound2,writemem_sound2)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -795,8 +779,16 @@ static MACHINE_DRIVER_START( tsamurai )
 	MDRV_VIDEO_UPDATE(tsamurai)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 MACHINE_DRIVER_END
 
 
@@ -809,15 +801,15 @@ static MACHINE_DRIVER_START( m660 )
 	MDRV_CPU_VBLANK_INT(samurai_interrupt,1)
 
 	MDRV_CPU_ADD(Z80, 2000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound1_m660,writemem_sound1_m660)
 
 	MDRV_CPU_ADD(Z80, 2000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound2_m660,writemem_sound2_m660)
 
 	MDRV_CPU_ADD(Z80, 2000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound3_m660,writemem_sound3_m660)
 	MDRV_CPU_IO_MAP(readport_sound3_m660,writeport_sound3_m660)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
@@ -837,8 +829,16 @@ static MACHINE_DRIVER_START( m660 )
 	MDRV_VIDEO_UPDATE(tsamurai)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 MACHINE_DRIVER_END
 
 
@@ -869,8 +869,13 @@ static MACHINE_DRIVER_START( vsgongf )
 	MDRV_VIDEO_UPDATE(vsgongf)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(DAC, vsgongf_dac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 2000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 MACHINE_DRIVER_END
 
 /*******************************************************************************/
