@@ -105,6 +105,8 @@ TP-S.1 TP-S.2 TP-S.3 TP-B.1  8212 TP-B.2 TP-B.3          TP-B.4
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/ay8910.h"
+#include "sound/msm5205.h"
 
 #include "tubep.h"
 
@@ -152,16 +154,16 @@ static WRITE8_HANDLER( tubep_LS259_w )
 		case 0:
 		case 1:
 				/*
-					port b0: bit0 - coin 1 counter
-					port b1	 bit0 - coin 2 counter
-				*/
+                    port b0: bit0 - coin 1 counter
+                    port b1  bit0 - coin 2 counter
+                */
 				coin_counter_w(offset,data&1);
 				break;
 		case 2:
 				/*something... */
 				break;
 		case 5:
-				/*screen_flip_w(offset,data&1);	   bit 0 = screen flip, active high    */
+				/*screen_flip_w(offset,data&1);    bit 0 = screen flip, active high    */
 				break;
 		case 6:
 				tubep_background_romselect_w(offset,data);	/* bit0 = 0->select roms: B1,B3,B5; bit0 = 1->select roms: B2,B4,B6 */
@@ -194,6 +196,7 @@ static ADDRESS_MAP_START( tubep_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( tubep_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x80, 0x80) AM_READ(input_port_3_r)
 	AM_RANGE(0x90, 0x90) AM_READ(input_port_4_r)
 	AM_RANGE(0xa0, 0xa0) AM_READ(input_port_5_r)
@@ -207,7 +210,7 @@ ADDRESS_MAP_END
 
 static WRITE8_HANDLER( main_cpu_irq_line_clear_w )
 {
-/*	cpunum_set_input_line(0,CLEAR_LINE); */
+/*  cpunum_set_input_line(0,CLEAR_LINE); */
 /*not used - handled by MAME anyway (because it is usual Vblank int) */
 	return;
 }
@@ -218,6 +221,7 @@ static WRITE8_HANDLER( tubep_soundlatch_w )
 }
 
 static ADDRESS_MAP_START( tubep_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x80, 0x80) AM_WRITE(main_cpu_irq_line_clear_w)
 	AM_RANGE(0xb0, 0xb7) AM_WRITE(tubep_LS259_w)
 	AM_RANGE(0xd0, 0xd0) AM_WRITE(tubep_soundlatch_w)
@@ -282,10 +286,12 @@ static ADDRESS_MAP_START( tubep_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( tubep_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x06, 0x06) AM_READ(tubep_soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( tubep_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(AY8910_control_port_1_w)
@@ -334,7 +340,7 @@ static WRITE8_HANDLER( rjammer_LS259_w )
 				coin_counter_w(offset,data&1);	/* bit 0 = coin counter */
 				break;
 		case 5:
-				/*screen_flip_w(offset,data&1);	   bit 0 = screen flip, active high    */
+				/*screen_flip_w(offset,data&1);    bit 0 = screen flip, active high    */
 				break;
 		default:
 				break;
@@ -348,6 +354,7 @@ static WRITE8_HANDLER( rjammer_soundlatch_w )
 }
 
 static ADDRESS_MAP_START( rjammer_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_2_r)	/* a bug in game code (during attract mode) */
 	AM_RANGE(0x80, 0x80) AM_READ(input_port_2_r)
 	AM_RANGE(0x90, 0x90) AM_READ(input_port_3_r)
@@ -357,6 +364,7 @@ static ADDRESS_MAP_START( rjammer_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( rjammer_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xd0, 0xd7) AM_WRITE(rjammer_LS259_w)
 	AM_RANGE(0xe0, 0xe0) AM_WRITE(main_cpu_irq_line_clear_w)	/* clear IRQ interrupt */
 	AM_RANGE(0xf0, 0xf0) AM_WRITE(rjammer_soundlatch_w)
@@ -379,6 +387,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( rjammer_slave_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0xb0, 0xb0) AM_WRITE(rjammer_background_page_w)
 	AM_RANGE(0xd0, 0xd0) AM_WRITE(rjammer_background_LS377_w)
 ADDRESS_MAP_END
@@ -478,9 +487,9 @@ static WRITE8_HANDLER( rjammer_voice_input_w )
 
 
 	/* NOTE: game resets interrupt line on ANY access to ANY I/O port.
-			I do it here because this port (0x80) is first one accessed
-			in the interrupt routine.
-	*/
+            I do it here because this port (0x80) is first one accessed
+            in the interrupt routine.
+    */
 	cpunum_set_input_line(2, 0, CLEAR_LINE );
 	return;
 }
@@ -503,10 +512,12 @@ static ADDRESS_MAP_START( rjammer_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( rjammer_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(rjammer_soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( rjammer_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x10, 0x10) AM_WRITE(rjammer_voice_startstop_w)
 	AM_RANGE(0x18, 0x18) AM_WRITE(rjammer_voice_frequency_select_w)
 	AM_RANGE(0x80, 0x80) AM_WRITE(rjammer_voice_input_w)
@@ -760,24 +771,34 @@ static struct GfxDecodeInfo rjammer_gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static struct AY8910interface ay8910_interface =
+static struct AY8910interface ay8910_interface_1 =
 {
-	3,					/* 3 chips */
-	19968000 / 8 / 2,	/* Xtal3 div by LS669 Q2, div by LS669 Q0 (signal RH1) */
-	{ 15, 15, 15 },		/* volume */
-	{ 0, 0, 0 },		/* read port A */
-	{ 0, 0, 0 },		/* read port B */
-	{ ay8910_portA_0_w, ay8910_portA_1_w, ay8910_portA_2_w }, /* write port A */
-	{ ay8910_portB_0_w, ay8910_portB_1_w, ay8910_portB_2_w }  /* write port B */
+	0,
+	0,
+	ay8910_portA_0_w, /* write port A */
+	ay8910_portB_0_w  /* write port B */
+};
+
+static struct AY8910interface ay8910_interface_2 =
+{
+	0,
+	0,
+	ay8910_portA_1_w, /* write port A */
+	ay8910_portB_1_w  /* write port B */
+};
+
+static struct AY8910interface ay8910_interface_3 =
+{
+	0,
+	0,
+	ay8910_portA_2_w, /* write port A */
+	ay8910_portB_2_w  /* write port B */
 };
 
 static struct MSM5205interface msm5205_interface =
 {
-	1,								/* 1 chip */
-	384000, 						/* 384 KHz */
-	{ rjammer_adpcm_vck },			/* VCK function */
-	{ MSM5205_S48_4B},				/* 8 KHz (changes at run time) */
-	{ 100 }							/* volume */
+	rjammer_adpcm_vck,			/* VCK function */
+	MSM5205_S48_4B				/* 8 KHz (changes at run time) */
 };
 
 
@@ -795,7 +816,7 @@ static MACHINE_DRIVER_START( tubep )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,19968000 / 8)	/* X2 19968000 Hz divided by LS669 (on Qc output) (signal RH0) */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(tubep_sound_readmem,tubep_sound_writemem)
 	MDRV_CPU_IO_MAP(tubep_sound_readport,tubep_sound_writeport)
 
@@ -822,7 +843,19 @@ static MACHINE_DRIVER_START( tubep )
 	MDRV_VIDEO_UPDATE(tubep)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_CONFIG(ay8910_interface_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_CONFIG(ay8910_interface_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_CONFIG(ay8910_interface_3)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
 MACHINE_DRIVER_END
 
 
@@ -840,7 +873,7 @@ static MACHINE_DRIVER_START( rjammer )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80,19968000 / 8)	/* Xtal3 divided by LS669 (on Qc output) (signal RH0) */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(rjammer_sound_readmem,rjammer_sound_writemem)
 	MDRV_CPU_IO_MAP(rjammer_sound_readport,rjammer_sound_writeport)
 
@@ -866,8 +899,23 @@ static MACHINE_DRIVER_START( rjammer )
 	MDRV_VIDEO_UPDATE(rjammer)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
-	MDRV_SOUND_ADD(MSM5205, msm5205_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_CONFIG(ay8910_interface_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_CONFIG(ay8910_interface_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_CONFIG(ay8910_interface_3)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
