@@ -1,22 +1,22 @@
 /***************************************************************************
 
-							  -= Unico Games =-
+                              -= Unico Games =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
-CPU			:	M68000 or M68EC020
-Sound Chips	:	OKI M6295 (AD-65) + YM3812 (K-666) or YM2151
-Video Chips	:	3 x Actel A1020B (Square 84 Pin Socketed) [Or A40MX04-F]
-				MACH211 (Square 44 Pin Socketed) [Or MACH210-15JC]
+CPU         :   M68000 or M68EC020
+Sound Chips :   OKI M6295 (AD-65) + YM3812 (K-666) or YM2151
+Video Chips :   3 x Actel A1020B (Square 84 Pin Socketed) [Or A40MX04-F]
+                MACH211 (Square 44 Pin Socketed) [Or MACH210-15JC]
 
 
 ---------------------------------------------------------------------------
-Year + Game			PCB				Notes
+Year + Game         PCB             Notes
 ---------------------------------------------------------------------------
-97	Burglar X		?
-98	Zero Point		ZPM1001A/B		Has Light Guns.
-99	Zero Point 2	UZP21001A/B		Has Light Guns.
+97  Burglar X       ?
+98  Zero Point      ZPM1001A/B      Has Light Guns.
+99  Zero Point 2    UZP21001A/B     Has Light Guns.
 ---------------------------------------------------------------------------
 
 
@@ -26,6 +26,9 @@ Year + Game			PCB				Notes
 #include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "unico.h"
+#include "sound/2151intf.h"
+#include "sound/3812intf.h"
+#include "sound/okim6295.h"
 
 /* Variables needed by vidhrdw: */
 
@@ -34,7 +37,7 @@ int unico_has_lightgun;
 /***************************************************************************
 
 
-								Memory Maps
+                                Memory Maps
 
 
 ***************************************************************************/
@@ -51,7 +54,7 @@ WRITE16_HANDLER( YM3812_data_port_0_msb_w )		{	if (ACCESSING_MSB)	YM3812_write_p
 */
 
 /***************************************************************************
-								Burglar X
+                                Burglar X
 ***************************************************************************/
 
 static WRITE16_HANDLER( burglarx_sound_bank_w )
@@ -106,7 +109,7 @@ ADDRESS_MAP_END
 
 
 /***************************************************************************
-								Zero Point
+                                Zero Point
 ***************************************************************************/
 
 static WRITE16_HANDLER( zeropnt_sound_bank_w )
@@ -114,7 +117,7 @@ static WRITE16_HANDLER( zeropnt_sound_bank_w )
 	if (ACCESSING_MSB)
 	{
 		/* Banked sound samples. The 3rd quarter of the ROM
-		   contains garbage. Indeed, only banks 0&1 are used */
+           contains garbage. Indeed, only banks 0&1 are used */
 
 		int bank = (data >> 8 ) & 1;
 		unsigned char *dst	= memory_region(REGION_SOUND1);
@@ -213,7 +216,7 @@ ADDRESS_MAP_END
 
 
 /***************************************************************************
-								Zero Point 2
+                                Zero Point 2
 ***************************************************************************/
 
 static READ32_HANDLER( zeropnt2_coins_r )			{ return (readinputportbytag("IN0") << 16) | 0xffff; }
@@ -320,13 +323,13 @@ ADDRESS_MAP_END
 /***************************************************************************
 
 
-								Input Ports
+                                Input Ports
 
 
 ***************************************************************************/
 
 /***************************************************************************
-								Burglar X
+                                Burglar X
 ***************************************************************************/
 
 INPUT_PORTS_START( burglarx )
@@ -415,7 +418,7 @@ INPUT_PORTS_END
 
 
 /***************************************************************************
-								Zero Point
+                                Zero Point
 ***************************************************************************/
 
 INPUT_PORTS_START( zeropnt )
@@ -508,7 +511,7 @@ INPUT_PORTS_END
 
 
 /***************************************************************************
-								Zero Point 2
+                                Zero Point 2
 ***************************************************************************/
 
 INPUT_PORTS_START( zeropnt2 )
@@ -535,7 +538,7 @@ INPUT_PORTS_START( zeropnt2 )
 	PORT_DIPSETTING(      0x0800, DEF_STR(No) )
 	PORT_DIPSETTING(      0x0400, DEF_STR(Yes) )
 	PORT_DIPSETTING(      0x0c00, "Factory Setting" )
-/*	PORT_DIPSETTING(      0x0000, "unused?" ) */
+/*  PORT_DIPSETTING(      0x0000, "unused?" ) */
 	PORT_DIPNAME( 0x1000, 0x1000, DEF_STR( Language ) )
 	PORT_DIPSETTING(      0x1000, DEF_STR( English ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Japanese ) )
@@ -563,9 +566,9 @@ INPUT_PORTS_START( zeropnt2 )
 	PORT_DIPSETTING(      0x1c00, "4" )
 	PORT_DIPSETTING(      0x1800, "5" )
 	PORT_DIPSETTING(      0x1400, "6" )
-/*	PORT_DIPSETTING(      0x0800, "4" ) */
-/*	PORT_DIPSETTING(      0x0400, "4" ) */
-/*	PORT_DIPSETTING(      0x0000, "4" ) */
+/*  PORT_DIPSETTING(      0x0800, "4" ) */
+/*  PORT_DIPSETTING(      0x0400, "4" ) */
+/*  PORT_DIPSETTING(      0x0000, "4" ) */
 	PORT_DIPNAME( 0x2000, 0x2000, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -604,7 +607,7 @@ INPUT_PORTS_END
 /***************************************************************************
 
 
-							Graphics Layouts
+                            Graphics Layouts
 
 
 ***************************************************************************/
@@ -636,7 +639,7 @@ static struct GfxDecodeInfo unico_gfxdecodeinfo[] =
 /***************************************************************************
 
 
-								Machine Drivers
+                                Machine Drivers
 
 
 ***************************************************************************/
@@ -646,50 +649,18 @@ MACHINE_INIT( unico )
 	unico_has_lightgun = 0;
 }
 
-static struct YM3812interface unico_ym3812_intf =
-{
-	1,
-	3579545,		/* ? */ /*Would guess it as identical to zeropt2, any samples for confirmation? */
-	{ 40 },
-	{ 0 },	/* IRQ Line */
-};
-
-static struct OKIM6295interface unico_m6295_intf =
-{
-	1,
-	{ 8000 },		/* ? */
-	{ REGION_SOUND1 },
-	{ 80 }
-};
-
-static struct OKIM6295interface zeropnt2_m6295_intf =
-{
-	2,
-	{ 8000, 30000 },		/* Appears to be spot on for both interfaces. */
-	{ REGION_SOUND1, REGION_SOUND2 },
-	{ MIXER(40,MIXER_PAN_LEFT), MIXER(20,MIXER_PAN_RIGHT) }
-};
-
-static struct YM2151interface zeropnt2_ym2151_intf =
-{
-	1,
-	3579545, /* measured on actual PCB*/
-	{ YM3012_VOL(70,MIXER_PAN_LEFT,70,MIXER_PAN_RIGHT) },
-	{ 0 }
-};
-
 
 struct EEPROM_interface zeropnt2_eeprom_interface =
 {
-	7,				/* address bits	7 */
-	8,				/* data bits	8 */
-	"*110",			/* read			1 10 aaaaaaa */
-	"*101",			/* write		1 01 aaaaaaa dddddddd */
-	"*111",			/* erase		1 11 aaaaaaa */
-	"*10000xxxx",	/* lock			1 00 00xxxx */
-	"*10011xxxx",	/* unlock		1 00 11xxxx */
-/*	"*10001xxxx"	// write all	1 00 01xxxx dddddddd */
-/*	"*10010xxxx"	// erase all	1 00 10xxxx */
+	7,				/* address bits 7 */
+	8,				/* data bits    8 */
+	"*110",			/* read         1 10 aaaaaaa */
+	"*101",			/* write        1 01 aaaaaaa dddddddd */
+	"*111",			/* erase        1 11 aaaaaaa */
+	"*10000xxxx",	/* lock         1 00 00xxxx */
+	"*10011xxxx",	/* unlock       1 00 11xxxx */
+/*  "*10001xxxx"    // write all    1 00 01xxxx dddddddd */
+/*  "*10010xxxx"    // erase all    1 00 10xxxx */
 };
 
 void nvram_handler_zeropnt2(mame_file *file,int read_or_write)
@@ -705,7 +676,7 @@ void nvram_handler_zeropnt2(mame_file *file,int read_or_write)
 
 
 /***************************************************************************
-								Burglar X
+                                Burglar X
 ***************************************************************************/
 
 static MACHINE_DRIVER_START( burglarx )
@@ -731,15 +702,22 @@ static MACHINE_DRIVER_START( burglarx )
 	MDRV_VIDEO_UPDATE(unico)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM3812, unico_ym3812_intf)
-	MDRV_SOUND_ADD(OKIM6295, unico_m6295_intf)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM3812, 3579545)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.40)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.40)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.80)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.80)
 MACHINE_DRIVER_END
 
 
 
 /***************************************************************************
-								Zero Point
+                                Zero Point
 ***************************************************************************/
 
 MACHINE_INIT( zeropt )
@@ -771,15 +749,22 @@ static MACHINE_DRIVER_START( zeropnt )
 	MDRV_VIDEO_UPDATE(unico)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM3812, unico_ym3812_intf)
-	MDRV_SOUND_ADD(OKIM6295, unico_m6295_intf)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM3812, 3579545)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.40)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.40)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.80)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.80)
 MACHINE_DRIVER_END
 
 
 
 /***************************************************************************
-								Zero Point 2
+                                Zero Point 2
 ***************************************************************************/
 
 static MACHINE_DRIVER_START( zeropnt2 )
@@ -807,16 +792,26 @@ static MACHINE_DRIVER_START( zeropnt2 )
 	MDRV_VIDEO_UPDATE(zeropnt2)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD( YM2151,		zeropnt2_ym2151_intf )
-	MDRV_SOUND_ADD( OKIM6295,	zeropnt2_m6295_intf  )
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_ROUTE(0, "left", 0.70)
+	MDRV_SOUND_ROUTE(1, "right", 0.70)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.40)
+
+	MDRV_SOUND_ADD(OKIM6295, 30000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.20)
 MACHINE_DRIVER_END
 
 
 /***************************************************************************
 
 
-								ROMs Loading
+                                ROMs Loading
 
 
 ***************************************************************************/
@@ -825,7 +820,7 @@ MACHINE_DRIVER_END
 
 /***************************************************************************
 
-								Burglar X
+                                Burglar X
 
 by Unico
 
@@ -869,7 +864,7 @@ ROM_END
 
 /***************************************************************************
 
-								Zero Point
+                                Zero Point
 
 (C) 1998 Unico
 
@@ -948,7 +943,7 @@ ROM_END
 
 /***************************************************************************
 
-									Zero Point 2
+                                    Zero Point 2
 
 (c) 1999 Unico
 
@@ -1024,12 +1019,12 @@ DB6DB7ZP.212  -/
 SPECIAL NOTICE - Sound wiring change:
 
 For cabinets with one speaker:
-	JAMMA pin 10 goes to speaker (+)
-	Run a ground to the negative side of speaker.
+    JAMMA pin 10 goes to speaker (+)
+    Run a ground to the negative side of speaker.
 For cabinets with two speakers:
-	JAMMA pin 10 goes to right speaker (+)
-	JAMMA pin L goes to left speaker (+)
-	Run a ground to the negative side of each speaker.
+    JAMMA pin 10 goes to right speaker (+)
+    JAMMA pin L goes to left speaker (+)
+    Run a ground to the negative side of each speaker.
 
 Using Original Unico Light Guns & connectors:
 
@@ -1137,7 +1132,7 @@ ROM_END
 /***************************************************************************
 
 
-								Game Drivers
+                                Game Drivers
 
 
 ***************************************************************************/
