@@ -91,6 +91,8 @@ Notes:
 #include "vidhrdw/konamiic.h"
 #include "cpu/konami/konami.h" /* for the callback and the firq irq definition */
 #include "machine/eeprom.h"
+#include "sound/2151intf.h"
+#include "sound/k053260.h"
 
 /* prototypes */
 static MACHINE_INIT( vendetta );
@@ -260,7 +262,7 @@ READ8_HANDLER( vendetta_sound_interrupt_r )
 READ8_HANDLER( vendetta_sound_r )
 {
 	/* If the sound CPU is running, read the status, otherwise
-	   just make it pass the test */
+       just make it pass the test */
 	if (Machine->sample_rate != 0) 	return K053260_0_r(2 + offset);
 	else
 	{
@@ -364,7 +366,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************
 
-	Input Ports
+    Input Ports
 
 ***************************************************************************/
 
@@ -531,25 +533,13 @@ INPUT_PORTS_END
 
 /***************************************************************************
 
-	Machine Driver
+    Machine Driver
 
 ***************************************************************************/
 
-static struct YM2151interface ym2151_interface =
-{
-	1,			/* 1 chip */
-	4000000,	/* adjusted to be in sync with Z80 CPU */
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },	/* music volume */
-	{ 0 }
-};
-
 static struct K053260_interface k053260_interface =
 {
-	1,
-	{ 4000000 },	/* adjusted to be in sync with Z80 CPU */
-	{ REGION_SOUND1 }, /* memory region */
-	{ { MIXER(75,MIXER_PAN_LEFT), MIXER(75,MIXER_PAN_RIGHT) } },
-	{ 0 }
+	REGION_SOUND1 /* memory region */
 };
 
 static INTERRUPT_GEN( vendetta_irq )
@@ -561,12 +551,13 @@ static INTERRUPT_GEN( vendetta_irq )
 static MACHINE_DRIVER_START( vendetta )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", KONAMI, 3000000)	/* seems correct, was 6MHz an overclock? */
+	MDRV_CPU_ADD_TAG("main", KONAMI, 6000000)	/* this is strange, seems an overclock but */
+/*  MDRV_CPU_ADD_TAG("main", KONAMI, 3000000)      is needed to have correct music speed    */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
 	MDRV_CPU_VBLANK_INT(vendetta_irq,1)
 
-	MDRV_CPU_ADD(Z80, 4000000)	/* verified with M1, guessed but accurate */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	MDRV_CPU_ADD(Z80, 3579545)	/* verified with PCB */
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
                             /* interrupts are triggered by the main CPU */
 	MDRV_FRAMES_PER_SECOND(60)
@@ -585,9 +576,16 @@ static MACHINE_DRIVER_START( vendetta )
 	MDRV_VIDEO_UPDATE(vendetta)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(K053260, k053260_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)	/* verified with PCB */
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+
+	MDRV_SOUND_ADD(K053260, 3579545)	/* verified with PCB */
+	MDRV_SOUND_CONFIG(k053260_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.75)
+	MDRV_SOUND_ROUTE(1, "right", 0.75)
 MACHINE_DRIVER_END
 
 
