@@ -1,96 +1,96 @@
 /***************************************************************************
 
-	Victory system
+    Victory system
 
     driver by Aaron Giles
 
 ****************************************************************************
 
-	Memory map
+    Memory map
 
 ****************************************************************************
 
-	========================================================================
-	CPU #1
-	========================================================================
-	0000-BFFF   R     xxxxxxxx   Program ROM
-	C000        R     xxxxxxxx   Foreground collision X position
-	C001        R     xxxxxxxx   Foreground collision Y position/IRQ clear
-	C002        R     xxxxxx--   Background collision X position
-	C003        R     xxxxxxxx   Background collision Y position/IRQ clear
-	C004        R     xxxxx---   Interrupt/microcode status
-	            R     x-------      (Microcode busy)
-	            R     -x------      (Foreground collision IRQ)
-	            R     --x-----      (Video VBLANK IRQ)
-	            R     ---x----      (Background collision IRQ)
-	            R     ----x---      (Scanline bit 8)
-	C100-C101     W   xxxxxxxx   Microcode register I
-	C102          W   xxxxxxxx   Microcode command register
-	C103          W   xxxxxxxx   Microcode register G
-	C104          W   xxxxxxxx   Microcode register X
-	C105          W   xxxxxxxx   Microcode register Y
-	C106          W   xxxxxxxx   Microcode register R
-	C107          W   xxxxxxxx   Microcode register B
-	C108          W   xxxxxxxx   Background X scroll
-	C109          W   xxxxxxxx   Background Y scroll
-	C10A          W   xxxxxxx-   Video control register
-	              W   x-------      (HLMBK??)
-	              W   -x------      (VLMBK??)
-	              W   --x-----      (Background collision IRQ enable)
-	              W   ---x----      (Refresh rate select 50/60)
-	              W   ----x---      (Screen invert)
-	              W   -----x--      (Background collision select)
-	              W   ------x-      (SELOVER??)
-	C10B          W   --------   Video IRQ clear
-	C200-C3FF     W   xxxxxxxx   Palette RAM
-	              W   xx------      (Red, 2 LSB; MSB comes from A7)
-	              W   --xxx---      (Blue)
-	              W   -----xxx      (Green)
-	C400-C7FF   R/W   xxxxxxxx   Background tile RAM
-	C800-CFFF   R/W   xxxxxxxx   Red background character RAM
-	D000-D7FF   R/W   xxxxxxxx   Blue background character RAM
-	D800-DFFF   R/W   xxxxxxxx   Green background character RAM
-	E000-EFFF   R/W   xxxxxxxx   Program RAM
-	F000-F7FF   R/W   xxxxxxxx   NVRAM
-	F800        R     xxxxxxxx   Sound CPU response
-	F800          W   xxxxxxxx   Sound CPU command
-	F801        R     xx------   Sound CPU status
-	            R     x-------      (Command pending)
-	            R     -x------      (Response pending)
-	========================================================================
-	  00-03     R     xxxxxxxx   DIP switch 1
-	            R     x-------      (Refresh rate select 50/60)
-	            R     -----xxx      (Unknown)
-	  04-07     R     xxxxxxxx   DIP switch 2
-	  08-0B     R/W   xxxxxxxx   PIO #1
-	  0C-0F     R/W   xxxxxxxx   PIO #2
-	  10-13       W   xxxxx---   Lamp/coin control
-	              W   x-------      (Thrust button lamp)
-	              W   -x------      (Fire button lamp)
-	              W   --x-----      (Doomsday button lamp)
-	              W   ---x----      (Shields button lamp)
-	              W   ----x---      (Coin counter)
-	========================================================================
-	Interrupts:
-	   INT generated by collision IRQs and VBLANK
-	========================================================================
+    ========================================================================
+    CPU #1
+    ========================================================================
+    0000-BFFF   R     xxxxxxxx   Program ROM
+    C000        R     xxxxxxxx   Foreground collision X position
+    C001        R     xxxxxxxx   Foreground collision Y position/IRQ clear
+    C002        R     xxxxxx--   Background collision X position
+    C003        R     xxxxxxxx   Background collision Y position/IRQ clear
+    C004        R     xxxxx---   Interrupt/microcode status
+                R     x-------      (Microcode busy)
+                R     -x------      (Foreground collision IRQ)
+                R     --x-----      (Video VBLANK IRQ)
+                R     ---x----      (Background collision IRQ)
+                R     ----x---      (Scanline bit 8)
+    C100-C101     W   xxxxxxxx   Microcode register I
+    C102          W   xxxxxxxx   Microcode command register
+    C103          W   xxxxxxxx   Microcode register G
+    C104          W   xxxxxxxx   Microcode register X
+    C105          W   xxxxxxxx   Microcode register Y
+    C106          W   xxxxxxxx   Microcode register R
+    C107          W   xxxxxxxx   Microcode register B
+    C108          W   xxxxxxxx   Background X scroll
+    C109          W   xxxxxxxx   Background Y scroll
+    C10A          W   xxxxxxx-   Video control register
+                  W   x-------      (HLMBK??)
+                  W   -x------      (VLMBK??)
+                  W   --x-----      (Background collision IRQ enable)
+                  W   ---x----      (Refresh rate select 50/60)
+                  W   ----x---      (Screen invert)
+                  W   -----x--      (Background collision select)
+                  W   ------x-      (SELOVER??)
+    C10B          W   --------   Video IRQ clear
+    C200-C3FF     W   xxxxxxxx   Palette RAM
+                  W   xx------      (Red, 2 LSB; MSB comes from A7)
+                  W   --xxx---      (Blue)
+                  W   -----xxx      (Green)
+    C400-C7FF   R/W   xxxxxxxx   Background tile RAM
+    C800-CFFF   R/W   xxxxxxxx   Red background character RAM
+    D000-D7FF   R/W   xxxxxxxx   Blue background character RAM
+    D800-DFFF   R/W   xxxxxxxx   Green background character RAM
+    E000-EFFF   R/W   xxxxxxxx   Program RAM
+    F000-F7FF   R/W   xxxxxxxx   NVRAM
+    F800        R     xxxxxxxx   Sound CPU response
+    F800          W   xxxxxxxx   Sound CPU command
+    F801        R     xx------   Sound CPU status
+                R     x-------      (Command pending)
+                R     -x------      (Response pending)
+    ========================================================================
+      00-03     R     xxxxxxxx   DIP switch 1
+                R     x-------      (Refresh rate select 50/60)
+                R     -----xxx      (Unknown)
+      04-07     R     xxxxxxxx   DIP switch 2
+      08-0B     R/W   xxxxxxxx   PIO #1
+      0C-0F     R/W   xxxxxxxx   PIO #2
+      10-13       W   xxxxx---   Lamp/coin control
+                  W   x-------      (Thrust button lamp)
+                  W   -x------      (Fire button lamp)
+                  W   --x-----      (Doomsday button lamp)
+                  W   ---x----      (Shields button lamp)
+                  W   ----x---      (Coin counter)
+    ========================================================================
+    Interrupts:
+       INT generated by collision IRQs and VBLANK
+    ========================================================================
 
-	========================================================================
-	CPU #2
-	========================================================================
-	0000-01FF   R/W   xxxxxxxx   Program RAM
-	1000-1FFF   R/W   xxxxxxxx   6532 RIOT timer and I/O
-	2000-2FFF   R/W   xxxxxxxx   6821 PIA I/O
-	3000-3FFF   R/W   xxxxxxxx   8253 timer
-	5000-5FFF   R/W   xxxxxxxx   6840 timer
-	6000-6FFF     W   ------xx   Control bits
-	              W   ------x-      (6840 Channel 1 output enable)
-	              W   -------x      (sound effects noise frequency select)
-	C000-FFFF   R     xxxxxxxx   Program ROM
-	========================================================================
-	Interrupts:
-	   INT generated by 6532 RIOT
-	========================================================================
+    ========================================================================
+    CPU #2
+    ========================================================================
+    0000-01FF   R/W   xxxxxxxx   Program RAM
+    1000-1FFF   R/W   xxxxxxxx   6532 RIOT timer and I/O
+    2000-2FFF   R/W   xxxxxxxx   6821 PIA I/O
+    3000-3FFF   R/W   xxxxxxxx   8253 timer
+    5000-5FFF   R/W   xxxxxxxx   6840 timer
+    6000-6FFF     W   ------xx   Control bits
+                  W   ------x-      (6840 Channel 1 output enable)
+                  W   -------x      (sound effects noise frequency select)
+    C000-FFFF   R     xxxxxxxx   Program ROM
+    ========================================================================
+    Interrupts:
+       INT generated by 6532 RIOT
+    ========================================================================
 
 ***************************************************************************/
 
@@ -98,6 +98,7 @@
 #include "driver.h"
 #include "exidy.h"
 #include "machine/6821pia.h"
+#include "sound/5220intf.h"
 #include "vidhrdw/generic.h"
 
 
@@ -126,7 +127,7 @@ WRITE8_HANDLER( victory_charram_w );
 
 /*************************************
  *
- *	Sound CPU control
+ *  Sound CPU control
  *
  *************************************/
 
@@ -184,7 +185,7 @@ WRITE8_HANDLER( victory_main_ack_w )
 
 /*************************************
  *
- *	Misc I/O
+ *  Misc I/O
  *
  *************************************/
 
@@ -200,7 +201,7 @@ static WRITE8_HANDLER( lamp_control_w )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -219,6 +220,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( main_iomap, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x03) AM_READ(input_port_0_r)
 	AM_RANGE(0x04, 0x07) AM_READ(input_port_1_r)
 	AM_RANGE(0x08, 0x08) AM_READ(input_port_2_r)
@@ -232,7 +234,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
@@ -251,7 +253,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -301,7 +303,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Sound definitions
+ *  Sound definitions
  *
  *************************************/
 
@@ -313,18 +315,10 @@ static struct CustomSound_interface custom_interface =
 };
 
 
-static struct TMS5220interface tms5220_interface =
-{
-	640000,
-	100,
-	0
-};
-
-
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -337,12 +331,12 @@ static MACHINE_DRIVER_START( victory )
 	MDRV_CPU_VBLANK_INT(victory_vblank_interrupt,1)
 
 	MDRV_CPU_ADD(M6502,3579545/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_map,0)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	
+
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
@@ -356,15 +350,20 @@ static MACHINE_DRIVER_START( victory )
 	MDRV_VIDEO_UPDATE(victory)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(CUSTOM, custom_interface)
-	MDRV_SOUND_ADD(TMS5220, tms5220_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_CONFIG(custom_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(TMS5220, 640000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -437,7 +436,7 @@ ROM_END
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
