@@ -1,18 +1,19 @@
 /*************************************************************************
 
-	Atari Video Pinball driver
+    Atari Video Pinball driver
 
-	by Sebastien Monassa (smonassa@mail.dotcom.fr) / overhaul by SJ
+    by Sebastien Monassa (smonassa@mail.dotcom.fr) / overhaul by SJ
 
-	Known issues:
+    Known issues:
 
-		- plunger doesn't work in test mode - bug in the game code?
+        - plunger doesn't work in test mode - bug in the game code?
 
 *************************************************************************/
 
 #include "driver.h"
 #include "artwork.h"
 #include "videopin.h"
+#include "sound/discrete.h"
 
 extern UINT8* videopin_video_ram;
 
@@ -203,7 +204,7 @@ static WRITE8_HANDLER( videopin_note_dvsr_w )
 
 /*************************************
  *
- *	Main CPU memory handlers
+ *  Main CPU memory handlers
  *
  *************************************/
 
@@ -233,7 +234,7 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Port definitions
+ *  Port definitions
  *
  *************************************/
 
@@ -290,7 +291,7 @@ INPUT_PORTS_END
 
 /*************************************
  *
- *	Graphics definitions
+ *  Graphics definitions
  *
  *************************************/
 
@@ -340,7 +341,7 @@ static struct GfxDecodeInfo videopin_gfxdecodeinfo[] =
 
 /*************************************
  *
- *	Machine driver
+ *  Machine driver
  *
  *************************************/
 
@@ -366,14 +367,18 @@ static MACHINE_DRIVER_START( videopin )
 	MDRV_VIDEO_UPDATE(videopin)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, videopin_discrete_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, 0)
+	MDRV_SOUND_CONFIG(videopin_discrete_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	ROM definitions
+ *  ROM definitions
  *
  *************************************/
 
@@ -413,7 +418,7 @@ ROM_END
 
 /*************************************
  *
- *	Game drivers
+ *  Game drivers
  *
  *************************************/
 
