@@ -8,13 +8,18 @@ ask.  - Mike Balfour (mab22@po.cwru.edu)
 
 TS 2004.12.26.:
 - Buccaneers - incomplete dump, different sound hw (YM2203x2)
-	(to enter test mode press any button durning memory test)
+    (to enter test mode press any button durning memory test)
+
+Buccaneers has a 5.6888 Mhz and a 18.432 Mhz OSC
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "sndhrdw/m72.h"
+#include "sound/dac.h"
+#include "sound/2203intf.h"
+#include "sound/2151intf.h"
 
 /* vidhrdw/vigilant.c */
 VIDEO_START( vigilant );
@@ -48,6 +53,8 @@ WRITE8_HANDLER( vigilant_out2_w )
 	/* The hardware has both coin counters hooked up to a single meter. */
 	coin_counter_w(0,data & 0x02);
 	coin_counter_w(1,data & 0x04);
+
+/*  data & 0x01 cocktail mode */
 }
 
 WRITE8_HANDLER( kikcubic_coin_w )
@@ -81,6 +88,7 @@ static ADDRESS_MAP_START( vigilant_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( vigilant_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)
 	AM_RANGE(0x01, 0x01) AM_READ(input_port_1_r)
 	AM_RANGE(0x02, 0x02) AM_READ(input_port_2_r)
@@ -89,6 +97,7 @@ static ADDRESS_MAP_START( vigilant_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( vigilant_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(m72_sound_command_w)  /* SD */
 	AM_RANGE(0x01, 0x01) AM_WRITE(vigilant_out2_w) /* OUT2 */
 	AM_RANGE(0x04, 0x04) AM_WRITE(vigilant_bank_select_w) /* PBANK */
@@ -115,6 +124,7 @@ static ADDRESS_MAP_START( kikcubic_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( kikcubic_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_3_r)
 	AM_RANGE(0x01, 0x01) AM_READ(input_port_4_r)
 	AM_RANGE(0x02, 0x02) AM_READ(input_port_0_r)
@@ -123,10 +133,11 @@ static ADDRESS_MAP_START( kikcubic_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( kikcubic_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(kikcubic_coin_w)	/* also flip screen, and...? */
 	AM_RANGE(0x04, 0x04) AM_WRITE(vigilant_bank_select_w)
 	AM_RANGE(0x06, 0x06) AM_WRITE(m72_sound_command_w)
-/*	AM_RANGE(0x07, 0x07) AM_WRITE(MWA8_NOP)	   ??    */
+/*  AM_RANGE(0x07, 0x07) AM_WRITE(MWA8_NOP)    ??    */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -140,12 +151,14 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x01, 0x01) AM_READ(YM2151_status_port_0_r)
 	AM_RANGE(0x80, 0x80) AM_READ(soundlatch_r)	/* SDRE */
 	AM_RANGE(0x84, 0x84) AM_READ(m72_sample_r)	/* S ROM C */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM2151_register_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM2151_data_port_0_w)
 	AM_RANGE(0x80, 0x81) AM_WRITE(vigilant_sample_addr_w)	/* STL / STH */
@@ -165,6 +178,7 @@ static ADDRESS_MAP_START( buccanrs_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( buccanrs_sound_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(YM2203_status_port_0_r)
 	AM_RANGE(0x01, 0x01) AM_READ(YM2203_read_port_0_r)
 	AM_RANGE(0x02, 0x02) AM_READ(YM2203_status_port_1_r)
@@ -174,6 +188,7 @@ static ADDRESS_MAP_START( buccanrs_sound_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( buccanrs_sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(YM2203_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(YM2203_write_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(YM2203_control_port_1_w)
@@ -188,7 +203,7 @@ INPUT_PORTS_START( vigilant )
 	PORT_START_TAG("IN0")
 	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_START2 )
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_COIN3 )
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT(0xF0, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
@@ -328,10 +343,10 @@ INPUT_PORTS_START( kikcubic )
 	PORT_DIPSETTING(	0x40, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(	0x30, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( Free_Play ) )
-/*	PORT_DIPSETTING(	0x10, "Undefined" ) */
-/*	PORT_DIPSETTING(	0x20, "Undefined" ) */
-/*	PORT_DIPSETTING(	0x80, "Undefined" ) */
-/*	PORT_DIPSETTING(	0x90, "Undefined" ) */
+/*  PORT_DIPSETTING(    0x10, "Undefined" ) */
+/*  PORT_DIPSETTING(    0x20, "Undefined" ) */
+/*  PORT_DIPSETTING(    0x80, "Undefined" ) */
+/*  PORT_DIPSETTING(    0x90, "Undefined" ) */
 
 	PORT_START_TAG("DSW1")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Flip_Screen ) )
@@ -359,14 +374,103 @@ INPUT_PORTS_START( kikcubic )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 INPUT_PORTS_END
 
+INPUT_PORTS_START( buccanrs )
+	PORT_START_TAG("IN0")
+	PORT_SERVICE( 0x2f, IP_ACTIVE_LOW ) /* any of these bits while booting will enable service mode */
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START1 )
+
+	PORT_START_TAG("IN1")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT )
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
+
+	PORT_START_TAG("IN2")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_COCKTAIL
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_COCKTAIL
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_COCKTAIL
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_COCKTAIL
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
+
+	PORT_START_TAG("DSW0")
+	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(	0x04, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(	0x07, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(	0x00, "5 Coins/2 Credits" )
+	PORT_DIPSETTING(	0x0a, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(	0x06, DEF_STR( 3C_2C ) )
+	PORT_DIPSETTING(	0x03, DEF_STR( 4C_3C ) )
+	PORT_DIPSETTING(	0x0f, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(	0x05, "3 Coins/5 Credits" )
+	PORT_DIPSETTING(	0x0e, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(	0x0d, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(	0x0c, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(	0x0b, DEF_STR( 1C_5C ) )
+	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(	0x40, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(	0x70, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(	0x00, "5 Coins/2 Credits" )
+	PORT_DIPSETTING(	0xa0, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(	0x60, DEF_STR( 3C_2C ) )
+	PORT_DIPSETTING(	0x30, DEF_STR( 4C_3C ) )
+	PORT_DIPSETTING(	0xf0, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(	0x50, "3 Coins/5 Credits" )
+	PORT_DIPSETTING(	0xe0, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(	0xd0, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(	0xc0, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(	0xb0, DEF_STR( 1C_5C ) )
+
+	PORT_START_TAG("DSW1")
+	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Flip_Screen ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x06, 0x06, DEF_STR( Lives ) )
+	PORT_DIPSETTING(    0x06, "2" )
+	PORT_DIPSETTING(    0x04, "3" )
+	PORT_DIPSETTING(    0x02, "4" )
+	PORT_DIPSETTING(    0x00, "5" )
+	PORT_DIPNAME( 0x18, 0x18, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( Hard ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( Medium ) )
+	PORT_DIPSETTING(    0x18, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x00, "Invicibility (time still decrease)" )
+	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Cabinet ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( Upright ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Allow_Continue ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( No ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Yes ) )
+INPUT_PORTS_END
+
+INPUT_PORTS_START( buccanra )
+	PORT_INCLUDE( buccanrs )
+
+	PORT_MODIFY("IN0") /* this port is reversed on this set.. */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_SERVICE( 0xf4, IP_ACTIVE_LOW ) /* any of these bits while booting will enable service mode */
+INPUT_PORTS_END
 
 
 static struct GfxLayout text_layout =
 {
 	8,8, /* tile size */
-	4096, /* number of tiles */
+	RGN_FRAC(1,2), /* number of tiles */
 	4, /* bits per pixel */
-	{64*1024*8,64*1024*8+4,0,4}, /* plane offsets */
+	{RGN_FRAC(1,2),RGN_FRAC(1,2)+4,0,4}, /* plane offsets */
 	{ 0,1,2,3, 64+0,64+1,64+2,64+3 }, /* x offsets */
 	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8 }, /* y offsets */
 	128
@@ -375,9 +479,9 @@ static struct GfxLayout text_layout =
 static struct GfxLayout sprite_layout =
 {
 	16,16,	/* tile size */
-	4096,	/* number of sprites ($1000) */
+	RGN_FRAC(1,2),	/* number of sprites ($1000) */
 	4,		/* bits per pixel */
-	{0x40000*8,0x40000*8+4,0,4}, /* plane offsets */
+	{RGN_FRAC(1,2),RGN_FRAC(1,2)+4,0,4}, /* plane offsets */
 	{ /* x offsets */
 		0x00*8+0,0x00*8+1,0x00*8+2,0x00*8+3,
 		0x10*8+0,0x10*8+1,0x10*8+2,0x10*8+3,
@@ -396,14 +500,14 @@ static struct GfxLayout sprite_layout =
 static struct GfxLayout sprite_layout_buccanrs =
 {
 	16,16,	/* tile size */
-	4096,	/* number of sprites ($1000) */
+	RGN_FRAC(1,2),	/* number of sprites ($1000) */
 	4,		/* bits per pixel */
-	{0x40000*8,0x40000*8+4,0,4}, /* plane offsets */
+	{RGN_FRAC(1,2),RGN_FRAC(1,2)+4,0,4}, /* plane offsets */
 	{ /* x offsets */
-		0x30*8+0,0x30*8+1,0x30*8+2,0x30*8+3,
-		0x20*8+0,0x20*8+1,0x20*8+2,0x20*8+3,
-		0x10*8+0,0x10*8+1,0x10*8+2,0x10*8+3,
-		0x00*8+0,0x00*8+1,0x00*8+2,0x00*8+3
+		0x00*8+3,0x00*8+2,0x00*8+1,0x00*8+0,
+		0x10*8+3,0x10*8+2,0x10*8+1,0x10*8+0,
+		0x20*8+3,0x20*8+2,0x20*8+1,0x20*8+0,
+		0x30*8+3,0x30*8+2,0x30*8+1,0x30*8+0
 	},
 	{ /* y offsets */
 		0x00*8, 0x01*8, 0x02*8, 0x03*8,
@@ -418,7 +522,7 @@ static struct GfxLayout sprite_layout_buccanrs =
 static struct GfxLayout back_layout =
 {
 	32,1, /* tile size */
-	3*512*8, /* number of tiles */
+	RGN_FRAC(1,1), /* number of tiles */
 	4, /* bits per pixel */
 	{0,2,4,6}, /* plane offsets */
 	{ 0*8+1, 0*8,  1*8+1, 1*8, 2*8+1, 2*8, 3*8+1, 3*8, 4*8+1, 4*8, 5*8+1, 5*8,
@@ -428,6 +532,19 @@ static struct GfxLayout back_layout =
 	16*8
 };
 
+static struct GfxLayout buccaneer_back_layout =
+{
+	32,1, /* tile size */
+	RGN_FRAC(1,1), /* number of tiles */
+	4, /* bits per pixel */
+	{6,4,2,0}, /* plane offsets */
+	{ 0*8+1, 0*8,  1*8+1, 1*8, 2*8+1, 2*8, 3*8+1, 3*8, 4*8+1, 4*8, 5*8+1, 5*8,
+	6*8+1, 6*8, 7*8+1, 7*8, 8*8+1, 8*8, 9*8+1, 9*8, 10*8+1, 10*8, 11*8+1, 11*8,
+	12*8+1, 12*8, 13*8+1, 13*8, 14*8+1, 14*8, 15*8+1, 15*8 }, /* x offsets */
+	{ 0 }, /* y offsets */
+	16*8
+};
+
 static struct GfxDecodeInfo vigilant_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   256, 16 },	/* colors 256-511 */
@@ -442,7 +559,7 @@ static struct GfxDecodeInfo buccanrs_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   256, 16 },	/* colors 256-511 */
 	{ REGION_GFX2, 0, &sprite_layout_buccanrs,   0, 16 },	/* colors   0-255 */
-	{ REGION_GFX3, 0, &back_layout,   512,  2 },	/* actually the background uses colors */
+	{ REGION_GFX3, 0, &buccaneer_back_layout,   512,  2 },	/* actually the background uses colors */
 													/* 256-511, but giving it exclusive */
 													/* pens we can handle it more easily. */
 	{ -1 } /* end of array */
@@ -459,30 +576,12 @@ static struct GfxDecodeInfo kikcubic_gfxdecodeinfo[] =
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	3579645,	/* 3.579645 MHz */
-	{ YM3012_VOL(55,MIXER_PAN_LEFT,55,MIXER_PAN_RIGHT) },
-	{ m72_ym2151_irq_handler },
-	{ 0 }
+	m72_ym2151_irq_handler
 };
 
 static struct YM2203interface ym2203_interface =
 {
-	2,			/* 2 chips */
-	3579545,	/* guess */
-	{ YM2203_VOL(50,35), YM2203_VOL(50,35) },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{m72_ym2151_irq_handler }
-};
-
-
-static struct DACinterface dac_interface =
-{
-	1,
-	{ 100 }
+	0,0,0,0,m72_ym2151_irq_handler
 };
 
 
@@ -495,7 +594,7 @@ static MACHINE_DRIVER_START( vigilant )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 3579645)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		   /* 3.579645 MHz */
+	/* audio CPU */		   /* 3.579645 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,128)	/* clocked by V1 */
@@ -515,21 +614,28 @@ static MACHINE_DRIVER_START( vigilant )
 	MDRV_VIDEO_UPDATE(vigilant)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579645)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.55)
+	MDRV_SOUND_ROUTE(1, "right", 0.55)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( buccanrs )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, 3579645)		   /* 3.579645 MHz */
+	MDRV_CPU_ADD(Z80, 5688800)		   /* 5.688800 MHz */
 	MDRV_CPU_PROGRAM_MAP(vigilant_readmem,vigilant_writemem)
 	MDRV_CPU_IO_MAP(vigilant_readport,vigilant_writeport)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
-	MDRV_CPU_ADD(Z80, 3579645)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		   /* 3.579645 MHz */
+	MDRV_CPU_ADD(Z80, 18432000/6)
+	/* audio CPU */		   /* 3.072000 MHz */
 	MDRV_CPU_PROGRAM_MAP(buccanrs_sound_readmem,buccanrs_sound_writemem)
 	MDRV_CPU_IO_MAP(buccanrs_sound_readport,buccanrs_sound_writeport)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,128)	/* clocked by V1 */
@@ -549,9 +655,32 @@ static MACHINE_DRIVER_START( buccanrs )
 	MDRV_VIDEO_UPDATE(vigilant)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2203, ym2203_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2203, 18432000/6)
+	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "left",  0.35)
+	MDRV_SOUND_ROUTE(0, "right", 0.35)
+	MDRV_SOUND_ROUTE(1, "left",  0.35)
+	MDRV_SOUND_ROUTE(1, "right", 0.35)
+	MDRV_SOUND_ROUTE(2, "left",  0.35)
+	MDRV_SOUND_ROUTE(2, "right", 0.35)
+	MDRV_SOUND_ROUTE(3, "left",  0.50)
+	MDRV_SOUND_ROUTE(3, "right", 0.50)
+
+	MDRV_SOUND_ADD(YM2203, 18432000/6)
+	MDRV_SOUND_ROUTE(0, "left",  0.35)
+	MDRV_SOUND_ROUTE(0, "right", 0.35)
+	MDRV_SOUND_ROUTE(1, "left",  0.35)
+	MDRV_SOUND_ROUTE(1, "right", 0.35)
+	MDRV_SOUND_ROUTE(2, "left",  0.35)
+	MDRV_SOUND_ROUTE(2, "right", 0.35)
+	MDRV_SOUND_ROUTE(3, "left",  0.50)
+	MDRV_SOUND_ROUTE(3, "right", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.35)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.35)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( kikcubic )
@@ -563,7 +692,7 @@ static MACHINE_DRIVER_START( kikcubic )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 3579645)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)		   /* 3.579645 MHz */
+	/* audio CPU */		   /* 3.579645 MHz */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,128)	/* clocked by V1 */
@@ -583,9 +712,16 @@ static MACHINE_DRIVER_START( kikcubic )
 	MDRV_VIDEO_UPDATE(kikcubic)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(DAC, dac_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579645)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.55)
+	MDRV_SOUND_ROUTE(1, "right", 0.55)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -619,7 +755,7 @@ ROM_START( vigilant )
 	ROM_LOAD( "v07_c17.bin",  0x60000, 0x10000, CRC(959ba3c7) SHA1(dcd2a885ae7b61210cbd55a38ccbe91c73d071b0) )
 	ROM_LOAD( "s07_c15.bin",  0x70000, 0x10000, CRC(7f2e91c5) SHA1(27dcc9b696834897c36c0b7a1c6202d93f41ad8d) )
 
-	ROM_REGION( 0x30000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_DISPOSE )
 	ROM_LOAD( "d01_c05.bin",  0x00000, 0x10000, CRC(81b1ee5c) SHA1(2014165ec71f089fecb5a3e60b939cc0f565d7f1) )
 	ROM_LOAD( "e01_c06.bin",  0x10000, 0x10000, CRC(d0d33673) SHA1(39761d97a71deaf7f17233d5bd5a55dbb1e6b30e) )
 	ROM_LOAD( "f01_c07.bin",  0x20000, 0x10000, CRC(aae81695) SHA1(ca8e136eca3543b27f3a61b105d4a280711cd6ea) )
@@ -651,7 +787,7 @@ ROM_START( vigilntu )
 	ROM_LOAD( "v07_c17.bin",  0x60000, 0x10000, CRC(959ba3c7) SHA1(dcd2a885ae7b61210cbd55a38ccbe91c73d071b0) )
 	ROM_LOAD( "s07_c15.bin",  0x70000, 0x10000, CRC(7f2e91c5) SHA1(27dcc9b696834897c36c0b7a1c6202d93f41ad8d) )
 
-	ROM_REGION( 0x30000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_DISPOSE )
 	ROM_LOAD( "d01_c05.bin",  0x00000, 0x10000, CRC(81b1ee5c) SHA1(2014165ec71f089fecb5a3e60b939cc0f565d7f1) )
 	ROM_LOAD( "e01_c06.bin",  0x10000, 0x10000, CRC(d0d33673) SHA1(39761d97a71deaf7f17233d5bd5a55dbb1e6b30e) )
 	ROM_LOAD( "f01_c07.bin",  0x20000, 0x10000, CRC(aae81695) SHA1(ca8e136eca3543b27f3a61b105d4a280711cd6ea) )
@@ -683,7 +819,7 @@ ROM_START( vigilntj )
 	ROM_LOAD( "v07_c17.bin",  0x60000, 0x10000, CRC(959ba3c7) SHA1(dcd2a885ae7b61210cbd55a38ccbe91c73d071b0) )
 	ROM_LOAD( "s07_c15.bin",  0x70000, 0x10000, CRC(7f2e91c5) SHA1(27dcc9b696834897c36c0b7a1c6202d93f41ad8d) )
 
-	ROM_REGION( 0x30000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_DISPOSE )
 	ROM_LOAD( "d01_c05.bin",  0x00000, 0x10000, CRC(81b1ee5c) SHA1(2014165ec71f089fecb5a3e60b939cc0f565d7f1) )
 	ROM_LOAD( "e01_c06.bin",  0x10000, 0x10000, CRC(d0d33673) SHA1(39761d97a71deaf7f17233d5bd5a55dbb1e6b30e) )
 	ROM_LOAD( "f01_c07.bin",  0x20000, 0x10000, CRC(aae81695) SHA1(ca8e136eca3543b27f3a61b105d4a280711cd6ea) )
@@ -720,39 +856,75 @@ ROM_END
 
 ROM_START( buccanrs )
 	ROM_REGION( 0x30000, REGION_CPU1, 0 ) /* 64k for code + 128k for bankswitching */
-	ROM_LOAD( "bc-011",  0x00000, 0x08000, CRC(6b657ef1) SHA1(a3356654d4b04177af23b39e924cc5ad64930bb6) )
-	ROM_LOAD( "bc-012",  0x10000, 0x10000, NO_DUMP )
+	ROM_LOAD( "11.u58",  0x00000, 0x10000, CRC(bf1d7e6f) SHA1(55dcf993515b57c3eb1fab98097a2171df3e38ed) ) /* both halves are identical (correct for rom type on this board tho) */
+	ROM_LOAD( "12.u25",  0x10000, 0x10000, CRC(87303ba8) SHA1(49a25393e853b9adf7df00a6f9c38a526a02ea4e) )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for sound */
-	ROM_LOAD( "bc-001",  0x00000, 0x10000, CRC(eb65f8c3) SHA1(82566becb630ce92303905dc0c5bef9e80e9caad) )
+	ROM_LOAD( "1.u128",  0x00000, 0x10000, CRC(eb65f8c3) SHA1(82566becb630ce92303905dc0c5bef9e80e9caad) )
 
 	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "bc-003",  0x00000, 0x10000, CRC(95e3c517) SHA1(9954830ebc3a6414a3236f4e41981db082e5ea19) )
-	ROM_LOAD( "bc-004",  0x10000, 0x10000, CRC(fe2377ab) SHA1(8578c5466d98f140fdfc41e91cd841e725786e32) )
+	ROM_LOAD( "7.u212",  0x00000, 0x10000, CRC(95e3c517) SHA1(9954830ebc3a6414a3236f4e41981db082e5ea19) )
+	ROM_LOAD( "8.u189",  0x10000, 0x10000, CRC(fe2377ab) SHA1(8578c5466d98f140fdfc41e91cd841e725786e32) )
 
 	ROM_REGION( 0x80000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "bc-005",  0x20000, 0x20000, CRC(16dc435f) SHA1(0c13e9786b356770c84f94684697e43d0ea9e7cc) )
-	ROM_LOAD( "bc-006",  0x00000, 0x20000, CRC(35c0e0ab) SHA1(e543fd17a28b9bc88801c51501d3dac41759826a) )
-	ROM_LOAD( "bc-007",  0x60000, 0x20000, CRC(acf0270c) SHA1(404f383b16bfa9e4268ea4d3f61f82e851324bb7) )
-	ROM_LOAD( "bc-008",  0x40000, 0x20000, CRC(078aef7f) SHA1(72e60d39d8af8bd31e9ae019b12620797eb0af7f) )
+	ROM_LOAD( "3.u100",  0x00000, 0x10000, CRC(16dc435f) SHA1(0c13e9786b356770c84f94684697e43d0ea9e7cc) )
+	ROM_CONTINUE(        0x20000, 0x10000 )
+	ROM_LOAD( "4.u80",   0x10000, 0x10000, CRC(4fe3bf97) SHA1(7910ace1eed80bfafa1f9f057ed67e23aa446a22) )
+	ROM_LOAD( "6.u52",   0x40000, 0x10000, CRC(078aef7f) SHA1(72e60d39d8af8bd31e9ae019b12620797eb0af7f) )
+	ROM_CONTINUE(        0x60000, 0x10000 )
+	ROM_LOAD( "5.u70",   0x50000, 0x10000, CRC(f650fa90) SHA1(c87081b4d6b09f865d08c5120da3d0fb3196a2c3) )
 
 	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_DISPOSE )
-	ROM_LOAD( "bc-009",  0x00000, 0x20000, CRC(0c6188fb) SHA1(d49034384c6d0e94db2890223b32a2a49e79a639) )
-	ROM_LOAD( "bc-010",  0x20000, 0x20000, CRC(2d383ff8) SHA1(3062baac27feba69c6ed94935c5ced72d89ed4fb) )
-	
+	ROM_LOAD( "9.u49",   0x20000, 0x20000, CRC(0c6188fb) SHA1(d49034384c6d0e94db2890223b32a2a49e79a639) )
+	ROM_LOAD( "10.u27",  0x00000, 0x20000, CRC(2d383ff8) SHA1(3062baac27feba69c6ed94935c5ced72d89ed4fb) )
+
 	ROM_REGION( 0x10000, REGION_SOUND1, 0 ) /* samples */
-	ROM_LOAD( "bc-002",  0x00000, 0x10000, CRC(36ee1dac) SHA1(6dfd2a885c0b1c9347abc4b204ade66551c4b404) )
+	ROM_LOAD( "2.u74",  0x00000, 0x10000, CRC(36ee1dac) SHA1(6dfd2a885c0b1c9347abc4b204ade66551c4b404) )
 
 	ROM_REGION( 0x400, REGION_PROMS, 0 )
-	ROM_LOAD( "82s129.1",  0x0000, 0x0100, CRC(c324835e) SHA1(cf6ffe38523badfda211d341410e93e647de87a9) )
-	ROM_LOAD( "82s129.2",  0x0100, 0x0100, CRC(e6506ef4) SHA1(079841da7640b14d94aaaeb572bf018932b58293) )
-	ROM_LOAD( "82s129.3",  0x0200, 0x0100, CRC(b43d094f) SHA1(2bed4892d8a91d7faac5a07bf858d9294eb30606) )
-	ROM_LOAD( "82s129.4",  0x0300, 0x0100, CRC(e0aa8869) SHA1(ac8bdfeba69420ba56ec561bf3d0f1229d02cea2) )
+	ROM_LOAD( "prom1.u54",  0x0000, 0x0100, CRC(c324835e) SHA1(cf6ffe38523badfda211d341410e93e647de87a9) )
+	ROM_LOAD( "prom4.u79",  0x0100, 0x0100, CRC(e6506ef4) SHA1(079841da7640b14d94aaaeb572bf018932b58293) )
+	ROM_LOAD( "prom3.u88",  0x0200, 0x0100, CRC(b43d094f) SHA1(2bed4892d8a91d7faac5a07bf858d9294eb30606) )
+	ROM_LOAD( "prom2.u99",  0x0300, 0x0100, CRC(e0aa8869) SHA1(ac8bdfeba69420ba56ec561bf3d0f1229d02cea2) )
+ROM_END
 
+ROM_START( buccanra )
+	ROM_REGION( 0x30000, REGION_CPU1, 0 ) /* 64k for code + 128k for bankswitching */
+	ROM_LOAD( "bc-011",  0x00000, 0x08000, CRC(6b657ef1) SHA1(a3356654d4b04177af23b39e924cc5ad64930bb6) )
+	ROM_LOAD( "12.u25",  0x10000, 0x10000, CRC(87303ba8) SHA1(49a25393e853b9adf7df00a6f9c38a526a02ea4e) ) /* not from this set, hopefully its only a data rom */
+
+	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for sound */
+	ROM_LOAD( "1.u128",  0x00000, 0x10000, CRC(eb65f8c3) SHA1(82566becb630ce92303905dc0c5bef9e80e9caad) )
+
+	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "7.u212",  0x00000, 0x10000, CRC(95e3c517) SHA1(9954830ebc3a6414a3236f4e41981db082e5ea19) )
+	ROM_LOAD( "8.u189",  0x10000, 0x10000, CRC(fe2377ab) SHA1(8578c5466d98f140fdfc41e91cd841e725786e32) )
+
+	ROM_REGION( 0x80000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_LOAD( "3.u100",  0x00000, 0x10000, CRC(16dc435f) SHA1(0c13e9786b356770c84f94684697e43d0ea9e7cc) )
+	ROM_CONTINUE(        0x20000, 0x10000 )
+	ROM_LOAD( "4.u80",   0x10000, 0x10000, CRC(4fe3bf97) SHA1(7910ace1eed80bfafa1f9f057ed67e23aa446a22) ) /* was double size (2nd half blank) in this set) */
+	ROM_LOAD( "6.u52",   0x40000, 0x10000, CRC(078aef7f) SHA1(72e60d39d8af8bd31e9ae019b12620797eb0af7f) )
+	ROM_CONTINUE(        0x60000, 0x10000 )
+	ROM_LOAD( "5.u70",   0x50000, 0x10000, CRC(f650fa90) SHA1(c87081b4d6b09f865d08c5120da3d0fb3196a2c3) ) /* was double size (2nd half blank) in this set) */
+
+	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_LOAD( "9.u49",   0x20000, 0x20000, CRC(0c6188fb) SHA1(d49034384c6d0e94db2890223b32a2a49e79a639) )
+	ROM_LOAD( "10.u27",  0x00000, 0x20000, CRC(2d383ff8) SHA1(3062baac27feba69c6ed94935c5ced72d89ed4fb) )
+
+	ROM_REGION( 0x10000, REGION_SOUND1, 0 ) /* samples */
+	ROM_LOAD( "2.u74",  0x00000, 0x10000, CRC(36ee1dac) SHA1(6dfd2a885c0b1c9347abc4b204ade66551c4b404) )
+
+	ROM_REGION( 0x400, REGION_PROMS, 0 )
+	ROM_LOAD( "prom1.u54",  0x0000, 0x0100, CRC(c324835e) SHA1(cf6ffe38523badfda211d341410e93e647de87a9) )
+	ROM_LOAD( "prom4.u79",  0x0100, 0x0100, CRC(e6506ef4) SHA1(079841da7640b14d94aaaeb572bf018932b58293) )
+	ROM_LOAD( "prom3.u88",  0x0200, 0x0100, CRC(b43d094f) SHA1(2bed4892d8a91d7faac5a07bf858d9294eb30606) )
+	ROM_LOAD( "prom2.u99",  0x0300, 0x0100, CRC(e0aa8869) SHA1(ac8bdfeba69420ba56ec561bf3d0f1229d02cea2) )
 ROM_END
 
 GAMEX( 1988, vigilant, 0,        vigilant, vigilant, 0, ROT0, "Irem", "Vigilante (World)", GAME_NO_COCKTAIL )
 GAMEX( 1988, vigilntu, vigilant, vigilant, vigilant, 0, ROT0, "Irem (Data East USA license)", "Vigilante (US)", GAME_NO_COCKTAIL )
 GAMEX( 1988, vigilntj, vigilant, vigilant, vigilant, 0, ROT0, "Irem", "Vigilante (Japan)", GAME_NO_COCKTAIL )
 GAMEX( 1988, kikcubic, 0,        kikcubic, kikcubic, 0, ROT0, "Irem", "Meikyu Jima (Japan)", GAME_NO_COCKTAIL )	/* English title is Kickle Cubicle */
-GAMEX( 1989, buccanrs, 0,        buccanrs, vigilant, 0, ROT0, "Duintronic", "Buccaneers", GAME_NOT_WORKING )
+GAMEX( 1989, buccanrs, 0,        buccanrs, buccanrs, 0, ROT0, "Duintronic", "Buccaneers (set 1)", GAME_NO_COCKTAIL )
+GAMEX( 1989, buccanra, buccanrs, buccanrs, buccanra, 0, ROT0, "Duintronic", "Buccaneers (set 2)", GAME_NO_COCKTAIL )
