@@ -54,6 +54,7 @@ Press one of the start buttons to exit.
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
+#include "sound/2608intf.h"
 
 
 extern data8_t *wc90_fgvideoram,*wc90_bgvideoram,*wc90_txvideoram;
@@ -342,16 +343,8 @@ static void irqhandler(int irq)
 
 static struct YM2608interface ym2608_interface =
 {
-	1,
-	8000000,
-	{ 50 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ irqhandler },
-	{ REGION_SOUND1 },
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) }
+	0,0,0,0,irqhandler,
+	REGION_SOUND1
 };
 
 static MACHINE_DRIVER_START( wc90 )
@@ -366,7 +359,7 @@ static MACHINE_DRIVER_START( wc90 )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 4 MHz ???? */
+	/* audio CPU */	/* 4 MHz ???? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 								/* NMIs are triggered by the main CPU */
 	MDRV_FRAMES_PER_SECOND(60)
@@ -383,7 +376,13 @@ static MACHINE_DRIVER_START( wc90 )
 	MDRV_VIDEO_UPDATE(wc90)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(YM2608, ym2608_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2608, 8000000)
+	MDRV_SOUND_CONFIG(ym2608_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.50)
+	MDRV_SOUND_ROUTE(1, "mono", 1.0)
+	MDRV_SOUND_ROUTE(2, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( wc90t )
