@@ -1,7 +1,7 @@
 /***************************************************************************
 
-Wily Tower				(c) 1984 Irem
-Fighting Basketball		(c) 1984 Paradise Co. Ltd.
+Wily Tower              (c) 1984 Irem
+Fighting Basketball     (c) 1984 Paradise Co. Ltd.
 
 driver by Nicola Salmoria
 
@@ -24,8 +24,10 @@ TODO:
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/i8039/i8039.h"
+#include "sound/ay8910.h"
+#include "sound/samples.h"
 
-extern int fghtbskt_sh_start(const struct MachineSound *msound);
+extern void fghtbskt_sh_start(void);
 extern WRITE8_HANDLER( fghtbskt_samples_w );
 
 UINT8 *wilytowr_videoram2, *wilytowr_scrollram;
@@ -161,13 +163,13 @@ static void get_fg_tile_info(int tile_index)
 
 VIDEO_START( wilytowr )
 {
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows, 
+	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows,
 		TILEMAP_OPAQUE, 8, 8, 32, 32);
 
 	if ( !bg_tilemap )
 		return 1;
 
-	fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_rows, 
+	fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_rows,
 		TILEMAP_TRANSPARENT, 8, 8, 32, 32);
 
 	if ( !fg_tilemap )
@@ -329,8 +331,8 @@ static ADDRESS_MAP_START( i8039_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( i8039_readport, ADDRESS_SPACE_IO, 8 )
-/*	AM_RANGE(0x00, 0xff) */
-/*	AM_RANGE(I8039_t1, I8039_t1) */
+/*  AM_RANGE(0x00, 0xff) */
+/*  AM_RANGE(I8039_t1, I8039_t1) */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( i8039_writeport, ADDRESS_SPACE_IO, 8 )
@@ -519,33 +521,11 @@ static struct GfxDecodeInfo fghtbskt_gfxdecodeinfo[] =
 };
 
 
-static struct AY8910interface ay8910_interface =
+static struct Samplesinterface custom_interface =
 {
-	2,	/* 2 chips */
-	3579545/4,	/* ??? using the same as other Irem games */
-	{ 20, 20 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 },
-	{ 0, 0 }
-};
-
-static struct AY8910interface fghtbskt_ay8910_interface =
-{
-	1,             /* 1 chip */
-	12000000/4/2,  /* 1.5 Mhz */
-	{ 100 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-static struct CustomSound_interface custom_interface =
-{
-	fghtbskt_sh_start,
-	0,
-	0
+	1,
+	NULL,
+	fghtbskt_sh_start
 };
 
 
@@ -557,7 +537,7 @@ static MACHINE_DRIVER_START( wilytowr )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(I8039,8000000/15)	/* ????? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(i8039_readmem,i8039_writemem)
 	MDRV_CPU_IO_MAP(i8039_readport,i8039_writeport)
 
@@ -576,7 +556,13 @@ static MACHINE_DRIVER_START( wilytowr )
 	MDRV_VIDEO_UPDATE(wilytowr)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 3579545/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+
+	MDRV_SOUND_ADD(AY8910, 3579545/4)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( fghtbskt )
@@ -587,7 +573,7 @@ static MACHINE_DRIVER_START( fghtbskt )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(I8039,12000000/4/I8039_CLOCK_DIVIDER)	/* ????? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(i8039_readmem,i8039_writemem)
 	MDRV_CPU_IO_MAP(i8039_readport,i8039_writeport)
 
@@ -606,8 +592,14 @@ static MACHINE_DRIVER_START( fghtbskt )
 	MDRV_VIDEO_UPDATE(wilytowr)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, fghtbskt_ay8910_interface)
-	MDRV_SOUND_ADD(CUSTOM, custom_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 12000000/4/2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(custom_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -727,7 +719,7 @@ ROM_START( fghtbskt )
 	ROM_LOAD( "fb18.32a",     0x4000, 0x2000, CRC(c23ddcd7) SHA1(f73d142ac0baae519ed633a923e132eb1836adbb) )
 	ROM_LOAD( "fb17.34a",     0x6000, 0x2000, CRC(7db28013) SHA1(305e6a6254f69625c81ae107f4420fd76f9a24ba) )
 	ROM_LOAD( "fb20.29a",     0x8000, 0x2000, CRC(1a1b48f8) SHA1(62f7774807aea86f73f0b9380bb1c237d55bf451) )
-	ROM_LOAD( "fb19.31a",     0xa000, 0x2000, CRC(7ff7e321) SHA1(4fe4eee9c6260599950080c600187ce8e9dab7d2) )	
+	ROM_LOAD( "fb19.31a",     0xa000, 0x2000, CRC(7ff7e321) SHA1(4fe4eee9c6260599950080c600187ce8e9dab7d2) )
 
 	ROM_REGION( 0xa000, REGION_SOUND1, 0 ) /* Samples */
 	ROM_LOAD( "fb01.42a",     0x0000, 0x2000, CRC(1200b220) SHA1(8a5f896441c6a6507e72b9b302a8183cc361d118) )
