@@ -56,9 +56,9 @@ I/O read:
 7000 Sound Command Read (Wiz)
 
 I/O write:
-3000 NMI enable	(Stinger/Scion)
-4000 AY8910 Control Port #1	(Wiz)
-4001 AY8910 Write Port #1	(Wiz)
+3000 NMI enable (Stinger/Scion)
+4000 AY8910 Control Port #1 (Wiz)
+4001 AY8910 Write Port #1   (Wiz)
 5000 AY8910 Control Port #2
 5001 AY8910 Write Port #2
 6000 AY8910 Control Port #3
@@ -159,6 +159,8 @@ Stephh's notes (based on the games Z80 code and some tests) :
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
+#include "sound/discrete.h"
 
 extern unsigned char *wiz_videoram2;
 extern unsigned char *wiz_colorram2;
@@ -432,13 +434,13 @@ COMMON_IN01
 	PORT_DIPSETTING(    0x10, DEF_STR( 1C_2C ) )
 	PORT_DIPNAME( 0x20, 0x00, DEF_STR( Unused ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
-/*	PORT_DIPSETTING(    0x20, DEF_STR( On ) )		   See notes    */
+/*  PORT_DIPSETTING(    0x20, DEF_STR( On ) )          See notes    */
 	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Unused ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
-/*	PORT_DIPSETTING(    0x40, DEF_STR( On ) )		   See notes    */
+/*  PORT_DIPSETTING(    0x40, DEF_STR( On ) )          See notes    */
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unused ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
-/*	PORT_DIPSETTING(    0x80, DEF_STR( On ) )		   See notes    */
+/*  PORT_DIPSETTING(    0x80, DEF_STR( On ) )          See notes    */
 INPUT_PORTS_END
 
 INPUT_PORTS_START( kungfut )
@@ -504,7 +506,7 @@ INPUT_PORTS_START( kungfut )
 	PORT_DIPSETTING(    0x18, "5" )
 	PORT_DIPNAME( 0x60, 0x00, DEF_STR( Bonus_Life ) )
 	PORT_DIPSETTING(    0x00, "20000 40000" )
-/*	PORT_DIPSETTING(    0x20, "20000 40000" )		// duplicated setting */
+/*  PORT_DIPSETTING(    0x20, "20000 40000" )       // duplicated setting */
 	PORT_DIPSETTING(    0x10, "20000 80000" )
 	PORT_DIPSETTING(    0x30, "30000 90000" )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unused ) )
@@ -634,33 +636,12 @@ static struct GfxDecodeInfo stinger_gfxdecodeinfo[] =
 };
 
 
-static struct AY8910interface wiz_ay8910_interface =
-{
-	3,				/* 3 chips */
-	18432000/12,	/* ? */
-	{ 10, 10, 10 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-static struct AY8910interface stinger_ay8910_interface =
-{
-	2,				/* 2 chips */
-	18432000/12,	/* ? */
-	{ 12, 12 },		/* 25 causes clipping */
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
 
 /** ANALOG SOUND STARTS */
 
 /* cut-and-pasted from Asteroid */
 const struct discrete_lfsr_desc stinger_lfsr={
+	DISC_CLK_IS_FREQ,
 	16,			/* Bit Length */
 	0,			/* Reset Value */
 	6,			/* Use Bit 6 as XOR input 0 */
@@ -734,7 +715,7 @@ static MACHINE_DRIVER_START( wiz )
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
 
 	MDRV_CPU_ADD(Z80, 14318000/8)	/* ? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_VBLANK_INT(nmi_line_pulse,4)	/* ??? */
 
@@ -754,8 +735,16 @@ static MACHINE_DRIVER_START( wiz )
 	MDRV_VIDEO_UPDATE(wiz)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD_TAG("8910", AY8910, wiz_ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
 
+	MDRV_SOUND_ADD_TAG("8910.1", AY8910, 18432000/12)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+
+	MDRV_SOUND_ADD_TAG("8910.2", AY8910, 18432000/12)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+
+	MDRV_SOUND_ADD_TAG("8910.3", AY8910, 18432000/12)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 MACHINE_DRIVER_END
 
 
@@ -769,9 +758,17 @@ static MACHINE_DRIVER_START( stinger )
 	MDRV_VIDEO_UPDATE(stinger)
 
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("8910", AY8910, stinger_ay8910_interface)
-	MDRV_SOUND_ADD(DISCRETE, stinger_discrete_interface)
+	MDRV_SOUND_MODIFY("8910.1")
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.12)
 
+	MDRV_SOUND_MODIFY("8910.2")
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.12)
+
+	MDRV_SOUND_REMOVE("8910.3")
+
+	MDRV_SOUND_ADD(DISCRETE, 0)
+	MDRV_SOUND_CONFIG(stinger_discrete_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -1064,6 +1061,12 @@ static DRIVER_INIT( stinger )
 }
 
 
+static DRIVER_INIT( scion )
+{
+	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x4000, 0x4001, 0, 0, MWA8_NOP);
+}
+
+
 static DRIVER_INIT( wiz )
 {
 	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd400, 0xd400, 0, 0, wiz_protection_r);
@@ -1072,8 +1075,8 @@ static DRIVER_INIT( wiz )
 
 GAMEX(1983, stinger,  0,       stinger, stinger,  stinger, ROT90,  "Seibu Denshi", "Stinger", GAME_IMPERFECT_SOUND )
 GAMEX(1983, stinger2, stinger, stinger, stinger2, stinger, ROT90,  "Seibu Denshi", "Stinger (prototype?)", GAME_IMPERFECT_SOUND )
-GAMEX(1984, scion,    0,       scion,   scion,    0,       ROT0,   "Seibu Denshi", "Scion", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS )
-GAMEX(1984, scionc,   scion,   scion,   scion,    0,       ROT0,   "Seibu Denshi (Cinematronics license)", "Scion (Cinematronics)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS )
+GAMEX(1984, scion,    0,       scion,   scion,    scion,   ROT0,   "Seibu Denshi", "Scion", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS )
+GAMEX(1984, scionc,   scion,   scion,   scion,    scion,   ROT0,   "Seibu Denshi (Cinematronics license)", "Scion (Cinematronics)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS )
 GAME( 1984, kungfut,  0,       kungfut, kungfut,  0,       ROT0,   "Seibu Kaihatsu Inc.", "Kung-Fu Taikun" )
 GAME( 1984, kungfuta, kungfut, kungfut, kungfut,  0,       ROT0,   "Seibu Kaihatsu Inc.", "Kung-Fu Taikun (alt)" ) /* board was a bootleg but set might still be original */
 GAME( 1985, wiz,      0,       wiz,     wiz,      wiz,     ROT270, "Seibu Kaihatsu Inc.", "Wiz" )
