@@ -27,16 +27,16 @@
 ********************************************************************************
 
  Change Log:
- 04 Mar 2002	 | Fixed Dip Switches and Inputs	(Steph)
-			 | Fixed screen flipping by using similar routine to the one
-			 | in src/vidhrdw/wwfwfest.c		(Steph)
- 18 Jun 2001	 | Changed Interrupt Function .. its not fully understood whats
-			 | is meant to be going on ..
- 15 Jun 2001	 | Cleaned up Sprite Drawing a bit, correcting some clipping probs,
-			 | mapped DSW's
- 15 Jun 2001	 | First Submission of Driver,
- 14 Jun 2001	 | Started Driver, using Raine Source as a reference for getting it
-			 | up and running
+ 04 Mar 2002     | Fixed Dip Switches and Inputs    (Steph)
+             | Fixed screen flipping by using similar routine to the one
+             | in src/vidhrdw/wwfwfest.c        (Steph)
+ 18 Jun 2001     | Changed Interrupt Function .. its not fully understood whats
+             | is meant to be going on ..
+ 15 Jun 2001     | Cleaned up Sprite Drawing a bit, correcting some clipping probs,
+             | mapped DSW's
+ 15 Jun 2001     | First Submission of Driver,
+ 14 Jun 2001     | Started Driver, using Raine Source as a reference for getting it
+             | up and running
 
 ********************************************************************************
 
@@ -53,8 +53,8 @@
    non-responsive to controls.  It seems both interrupts must happen during the
    vblank period or something.
    Steph's update : I don't have this problem, but I have this message in the log file :
-	"Warning: you are using IPT_VBLANK with vblank_duration = 0.
-	You need to increase vblank_duration for IPT_VBLANK to work."
+    "Warning: you are using IPT_VBLANK with vblank_duration = 0.
+    You need to increase vblank_duration for IPT_VBLANK to work."
 
 *******************************************************************************/
 
@@ -62,6 +62,8 @@
 #include "vidhrdw/generic.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
 
 WRITE16_HANDLER ( wwfsstar_scrollwrite );
 
@@ -335,18 +337,7 @@ static void wwfsstar_ymirq_handler(int irq)
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	3579545,	/* Guess */
-	{ YM3012_VOL(45,MIXER_PAN_LEFT,45,MIXER_PAN_RIGHT) },
-	{ wwfsstar_ymirq_handler }
-};
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,				/* 1 chip */
-	{ 8500 },		/* frequency (Hz) */
-	{ REGION_SOUND1 },	/* memory region */
-	{ 47 }
+	wwfsstar_ymirq_handler
 };
 
 /*******************************************************************************
@@ -363,7 +354,7 @@ static MACHINE_DRIVER_START( wwfsstar )
 	MDRV_CPU_VBLANK_INT(wwfsstar_interrupt,262)
 
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* unknown */
+	/* audio CPU */	/* unknown */
 	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -380,9 +371,17 @@ static MACHINE_DRIVER_START( wwfsstar )
 	MDRV_VIDEO_UPDATE(wwfsstar)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.45)
+	MDRV_SOUND_ROUTE(1, "right", 0.45)
+
+	MDRV_SOUND_ADD(OKIM6295, 8500)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.47)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.47)
 MACHINE_DRIVER_END
 
 /*******************************************************************************
