@@ -4,7 +4,7 @@
 
 /***************************************************************************
 
-	Xexex  (c) 1991 Konami
+    Xexex  (c) 1991 Konami
 
 
 Change Log
@@ -23,15 +23,15 @@ The following bugs appear to be fixed:
 General:
 
 - game doesn't slow down like the arcade
-	IRQ 5 is the "OBJDMA end interrupt" and shouldn't be triggered
-	if DMA didn't complete within the frame.
+    IRQ 5 is the "OBJDMA end interrupt" and shouldn't be triggered
+    if DMA didn't complete within the frame.
 
-	* game speed may not be 100% correct but close to that on the
-	Gamest video especially in stage 6. Xexex is 384x256 which suggests
-	an 8Mhz horizontal dotclock and DMA delay can range up to 32.0us(clear)
-	+ 256.0us(transfer). Increase XE_DMADELAY if emulation runs faster
-	than the original or use cheat to overclock CPU 0 if you prefer faster
-	gameplay.
+    * game speed may not be 100% correct but close to that on the
+    Gamest video especially in stage 6. Xexex is 384x256 which suggests
+    an 8Mhz horizontal dotclock and DMA delay can range up to 32.0us(clear)
+    + 256.0us(transfer). Increase XE_DMADELAY if emulation runs faster
+    than the original or use cheat to overclock CPU 0 if you prefer faster
+    gameplay.
 
 - sprite lag, dithering, flicking (DMA)
 - line effects go out of sync (K053250 also does DMA)
@@ -69,6 +69,8 @@ Unresolved Issues:
 #include "cpu/z80/z80.h"
 #include "machine/eeprom.h"
 #include "sound/k054539.h"
+#include "sound/2151intf.h"
+#include "sound/flt_vol.h"
 
 VIDEO_START( xexex );
 VIDEO_UPDATE( xexex );
@@ -292,16 +294,10 @@ static WRITE8_HANDLER( sound_bankswitch_w )
 
 static void ym_set_mixing(double left, double right)
 {
-	if(Machine->sample_rate) {
-		int l = 71*left;
-		int r = 71*right;
-		int ch;
-		for(ch=0; ch<MIXER_MAX_CHANNELS; ch++) {
-			const char *name = mixer_get_name(ch);
-			if(name && name[0] == 'Y')
-				mixer_set_stereo_volume(ch, l, r);
-		}
-	}
+	flt_volume_set_volume(0, (71.0*left)/55.0);
+	flt_volume_set_volume(1, (71.0*right)/55.0);
+	flt_volume_set_volume(2, (71.0*left)/55.0);
+	flt_volume_set_volume(3, (71.0*right)/55.0);
 }
 
 static void dmaend_callback(int data)
@@ -467,21 +463,12 @@ INPUT_PORTS_START( xexex )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 INPUT_PORTS_END
 
-static struct YM2151interface ym2151_interface =
-{
-	1,
-	4000000,	/* 4Mhz (based on AMUSE) */
-	{ YM3012_VOL(50,MIXER_PAN_CENTER,50,MIXER_PAN_CENTER) },
-	{ 0 }
-};
+
 
 static struct K054539interface k054539_interface =
 {
-	1,			/* 1 chip */
-	48000,
-	{ REGION_SOUND1 },
-	{ { 100, 100 } },
-	{ ym_set_mixing }
+	REGION_SOUND1,
+	ym_set_mixing
 };
 
 static MACHINE_DRIVER_START( xexex )
@@ -495,7 +482,7 @@ static MACHINE_DRIVER_START( xexex )
 	/* more likely 32MHz since 18.432MHz yields 4.608MHz(too slow) or 9.216MHz(too fast) with integer divisors */
 	MDRV_CPU_ADD(Z80, 8000000)
 
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_INTERLEAVE(32);
@@ -516,9 +503,29 @@ static MACHINE_DRIVER_START( xexex )
 	MDRV_VIDEO_UPDATE(xexex)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, ym2151_interface)
-	MDRV_SOUND_ADD(K054539, k054539_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 4000000)
+	MDRV_SOUND_ROUTE(0, "filter1l", 0.50)
+	MDRV_SOUND_ROUTE(0, "filter1r", 0.50)
+	MDRV_SOUND_ROUTE(1, "filter2l", 0.50)
+	MDRV_SOUND_ROUTE(1, "filter2r", 0.50)
+
+	MDRV_SOUND_ADD(K054539, 48000)
+	MDRV_SOUND_CONFIG(k054539_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(0, "right", 1.0)
+	MDRV_SOUND_ROUTE(1, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+
+	MDRV_SOUND_ADD_TAG("filter1l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter1r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+	MDRV_SOUND_ADD_TAG("filter2l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ADD_TAG("filter2r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -584,6 +591,7 @@ MACHINE_INIT( xexex )
 {
 	cur_sound_region = 0;
 	suspension_active = 0;
+	K054539_init_flags(0, K054539_REVERSE_STEREO);
 }
 
 static DRIVER_INIT( xexex )
@@ -591,8 +599,8 @@ static DRIVER_INIT( xexex )
 	if (!strcmp(Machine->gamedrv->name, "xexex"))
 	{
 		/* Invulnerability */
-/*		*(data16_t *)(memory_region(REGION_CPU1) + 0x648d4) = 0x4a79; */
-/*		*(data16_t *)(memory_region(REGION_CPU1) + 0x00008) = 0x5500; */
+/*      *(data16_t *)(memory_region(REGION_CPU1) + 0x648d4) = 0x4a79; */
+/*      *(data16_t *)(memory_region(REGION_CPU1) + 0x00008) = 0x5500; */
 		xexex_strip0x1a = 1;
 	}
 
@@ -608,8 +616,6 @@ static DRIVER_INIT( xexex )
 	resume_trigger = 1000;
 
 	dmadelay_timer = timer_alloc(dmaend_callback);
-
-	K054539_init_flags(K054539_REVERSE_STEREO);
 }
 
 
