@@ -1,7 +1,7 @@
 /***************************************************************************
 
-	Yie Ar Kung-Fu memory map (preliminary)
-	enrique.sanchez@cs.us.es
+    Yie Ar Kung-Fu memory map (preliminary)
+    enrique.sanchez@cs.us.es
 
 CPU:    Motorola 6809
 
@@ -9,40 +9,40 @@ Normal 6809 IRQs must be generated each video frame (60 fps).
 The 6809 NMI is used for sound timing.
 
 
-0000	  	R	VLM5030 status ???
-4000	 	 W  control port
-					bit 0 - flip screen
-					bit 1 - NMI enable
-					bit 2 - IRQ enable
-					bit 3 - coin counter A
-					bit 4 - coin counter B
-4800	 	 W	sound latch write
-4900	 	 W  copy sound latch to SN76496
-4a00	 	 W  VLM5030 control
-4b00	 	 W  VLM5030 data
-4c00		R   DSW #0
-4d00		R   DSW #1
-4e00		R   IN #0
-4e01		R   IN #1
-4e02		R   IN #2
-4e03		R   DSW #2
-4f00	 	 W  watchdog
-5000-502f	 W  sprite RAM 1 (18 sprites)
-					byte 0 - bit 0 - sprite code MSB
-							 bit 6 - flip X
-							 bit 7 - flip Y
-					byte 1 - Y position
-5030-53ff	RW  RAM
+0000        R   VLM5030 status ???
+4000         W  control port
+                    bit 0 - flip screen
+                    bit 1 - NMI enable
+                    bit 2 - IRQ enable
+                    bit 3 - coin counter A
+                    bit 4 - coin counter B
+4800         W  sound latch write
+4900         W  copy sound latch to SN76496
+4a00         W  VLM5030 control
+4b00         W  VLM5030 data
+4c00        R   DSW #0
+4d00        R   DSW #1
+4e00        R   IN #0
+4e01        R   IN #1
+4e02        R   IN #2
+4e03        R   DSW #2
+4f00         W  watchdog
+5000-502f    W  sprite RAM 1 (18 sprites)
+                    byte 0 - bit 0 - sprite code MSB
+                             bit 6 - flip X
+                             bit 7 - flip Y
+                    byte 1 - Y position
+5030-53ff   RW  RAM
 5400-542f    W  sprite RAM 2
-					byte 0 - X position
-					byte 1 - sprite code LSB
-5430-57ff	RW  RAM
-5800-5fff	RW  video RAM
-					byte 0 - bit 4 - character code MSB
-							 bit 6 - flip Y
-							 bit 7 - flip X
-					byte 1 - character code LSB
-8000-ffff	R   ROM
+                    byte 0 - X position
+                    byte 1 - sprite code LSB
+5430-57ff   RW  RAM
+5800-5fff   RW  video RAM
+                    byte 0 - bit 4 - character code MSB
+                             bit 6 - flip Y
+                             bit 7 - flip X
+                    byte 1 - character code LSB
+8000-ffff   R   ROM
 
 
 ***************************************************************************/
@@ -50,6 +50,8 @@ The 6809 NMI is used for sound timing.
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
+#include "sound/sn76496.h"
+#include "sound/vlm5030.h"
 
 extern int nmi_enable;
 
@@ -211,7 +213,7 @@ INPUT_PORTS_START( yiear )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 INPUT_PORTS_END
 
 
@@ -249,17 +251,8 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 
 
-struct SN76496interface sn76496_interface =
-{
-	1,			/* 1 chip */
-	{ 18432000/12 },	/*  1.536 MHz */
-	{ 100 }
-};
-
 struct VLM5030interface vlm5030_interface =
 {
-	3580000,    /* master clock  */
-	100,        /* volume        */
 	REGION_SOUND1,	/* memory region  */
 	0           /* memory size of speech rom */
 };
@@ -290,8 +283,14 @@ static MACHINE_DRIVER_START( yiear )
 	MDRV_VIDEO_UPDATE(yiear)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, sn76496_interface)
-	MDRV_SOUND_ADD(VLM5030, vlm5030_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SN76496, 18432000/12)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(VLM5030, 3580000)
+	MDRV_SOUND_CONFIG(vlm5030_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
