@@ -1,14 +1,14 @@
 /***************************************************************************
 
-						  -= Yun Sung 8 Bit Games =-
+                          -= Yun Sung 8 Bit Games =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
 Main  CPU    :  Z80B
 Sound CPU    :  Z80A
-Video Chips  :	?
-Sound Chips  :	OKI M5205 + YM3812
+Video Chips  :  ?
+Sound Chips  :  OKI M5205 + YM3812
 
 ---------------------------------------------------------------------------
 Year + Game         Board#
@@ -30,6 +30,8 @@ To Do:
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
+#include "sound/3812intf.h"
+#include "sound/msm5205.h"
 
 /* Variables defined in vidhrdw: */
 
@@ -63,7 +65,7 @@ MACHINE_INIT( yunsung8 )
 /***************************************************************************
 
 
-							Memory Maps - Main CPU
+                            Memory Maps - Main CPU
 
 
 ***************************************************************************/
@@ -85,12 +87,12 @@ WRITE8_HANDLER( yunsung8_bankswitch_w )
 }
 
 /*
-	Banked Video RAM:
+    Banked Video RAM:
 
-	c000-c7ff	Palette	(bit 1 of port 0 switches between 2 banks)
+    c000-c7ff   Palette (bit 1 of port 0 switches between 2 banks)
 
-	c800-cfff	Color	(bit 0 of port 0 switches between 2 banks)
-	d000-dfff	Tiles	""
+    c800-cfff   Color   (bit 0 of port 0 switches between 2 banks)
+    d000-dfff   Tiles   ""
 */
 
 static ADDRESS_MAP_START( yunsung8_readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -110,6 +112,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( yunsung8_readport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r		)	/* Coins */
 	AM_RANGE(0x01, 0x01) AM_READ(input_port_1_r		)	/* P1 */
 	AM_RANGE(0x02, 0x02) AM_READ(input_port_2_r		)	/* P2 */
@@ -118,6 +121,7 @@ static ADDRESS_MAP_START( yunsung8_readport, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( yunsung8_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(yunsung8_videobank_w	)	/* Video RAM Bank */
 	AM_RANGE(0x01, 0x01) AM_WRITE(yunsung8_bankswitch_w	)	/* ROM Bank + Layers Enable */
 	AM_RANGE(0x02, 0x02) AM_WRITE(soundlatch_w			)	/* To Sound CPU */
@@ -130,7 +134,7 @@ ADDRESS_MAP_END
 /***************************************************************************
 
 
-							Memory Maps - Sound CPU
+                            Memory Maps - Sound CPU
 
 
 ***************************************************************************/
@@ -184,13 +188,13 @@ ADDRESS_MAP_END
 /***************************************************************************
 
 
-								Input Ports
+                                Input Ports
 
 
 ***************************************************************************/
 
 /***************************************************************************
-									Magix
+                                    Magix
 ***************************************************************************/
 
 INPUT_PORTS_START( magix )
@@ -278,7 +282,7 @@ INPUT_PORTS_END
 
 
 /***************************************************************************
-								Cannon Ball
+                                Cannon Ball
 ***************************************************************************/
 
 INPUT_PORTS_START( cannball )
@@ -368,7 +372,7 @@ INPUT_PORTS_END
 /***************************************************************************
 
 
-								Graphics Layouts
+                                Graphics Layouts
 
 
 ***************************************************************************/
@@ -410,7 +414,7 @@ static struct GfxDecodeInfo yunsung8_gfxdecodeinfo[] =
 /***************************************************************************
 
 
-								Machine Drivers
+                                Machine Drivers
 
 
 ***************************************************************************/
@@ -428,21 +432,10 @@ static void yunsung8_adpcm_int(int irq)
 		cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE);
 }
 
-static struct YM3812interface yunsung8_ym3812_interface =
+static struct MSM5205interface yunsung8_msm5205_interface =
 {
-	1,
-	4000000,	/* ? */
-	{ 100 },
-	{  0 },
-};
-
-struct MSM5205interface yunsung8_msm5205_interface =
-{
-	1,
-	384000,
-	{ yunsung8_adpcm_int },	/* interrupt function */
-	{ MSM5205_S96_4B },		/* 4KHz, 4 Bits */
-	{ 80 }
+	yunsung8_adpcm_int,	/* interrupt function */
+	MSM5205_S96_4B		/* 4KHz, 4 Bits */
 };
 
 
@@ -455,7 +448,7 @@ static MACHINE_DRIVER_START( yunsung8 )
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)	/* No nmi routine */
 
 	MDRV_CPU_ADD(Z80, 4000000)			/* ? */
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(yunsung8_sound_readmem,yunsung8_sound_writemem)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)	/* NMI caused by the MSM5205? */
 
@@ -475,23 +468,30 @@ static MACHINE_DRIVER_START( yunsung8 )
 	MDRV_VIDEO_UPDATE(yunsung8)
 
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM3812, yunsung8_ym3812_interface)
-	MDRV_SOUND_ADD(MSM5205, yunsung8_msm5205_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM3812, 4000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD(MSM5205, 384000)
+	MDRV_SOUND_CONFIG(yunsung8_msm5205_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.80)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.80)
 MACHINE_DRIVER_END
 
 
 /***************************************************************************
 
 
-								ROMs Loading
+                                ROMs Loading
 
 
 ***************************************************************************/
 
 /***************************************************************************
 
-									Magix
+                                    Magix
 
 Yun Sung, 1995.
 CPU : Z80B
@@ -527,7 +527,7 @@ ROM_END
 
 /***************************************************************************
 
-								Cannon Ball
+                                Cannon Ball
 
 01, 02, 03, 04  are 27c020
 05, 06, 07, 08  are 27c010
@@ -568,7 +568,7 @@ ROM_END
 /***************************************************************************
 
 
-								Game Drivers
+                                Game Drivers
 
 
 ***************************************************************************/
