@@ -22,12 +22,13 @@ Stephh's notes :
   IPF_CHEAT flag for the Dip Switch and the 3rd button of each player.
 
 TODO:
-	* adpcm samples don't seem to be playing at the proper tempo - too fast?
+    * adpcm samples don't seem to be playing at the proper tempo - too fast?
 
 
 ***************************************************************************/
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/okim6295.h"
 
 VIDEO_START( zerozone );
 VIDEO_UPDATE( zerozone );
@@ -201,14 +202,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct OKIM6295interface okim6295_interface =
-{
-	1,              /* 1 chip */
-	{ 8000 },           /* 8000Hz ??? TODO: find out the real frequency */
-	{ REGION_SOUND1 },	/* memory region 3 */
-	{ 100 }
-};
-
 static MACHINE_DRIVER_START( zerozone )
 
 	/* basic machine hardware */
@@ -217,7 +210,7 @@ static MACHINE_DRIVER_START( zerozone )
 	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 1000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)	/* 1 MHz ??? */
+	/* audio CPU */	/* 1 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -235,7 +228,11 @@ static MACHINE_DRIVER_START( zerozone )
 	MDRV_VIDEO_UPDATE(zerozone)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
