@@ -9,7 +9,7 @@ Memory Mapped:
 
 I/O Ports:
 
-00-01		W   AY8910 #0
+00-01       W   AY8910 #0
 
 
 TODO:
@@ -20,6 +20,7 @@ TODO:
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/ay8910.h"
 
 extern UINT8 *zodiack_videoram2;
 extern UINT8 *zodiack_attributesram;
@@ -112,6 +113,7 @@ static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
 ADDRESS_MAP_END
@@ -489,18 +491,6 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 };
 
 
-static struct AY8910interface ay8910_interface =
-{
-	1,	/* 1 chip */
-	1789750,	/* 1.78975 MHz? */
-	{ 50 },
-	{ 0 },
-	{ 0 },
-	{ 0 },
-	{ 0 }
-};
-
-
 static MACHINE_DRIVER_START( zodiack )
 
 	/* basic machine hardware */
@@ -531,7 +521,10 @@ static MACHINE_DRIVER_START( zodiack )
 	MDRV_VIDEO_UPDATE(zodiack)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 1789750)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( percuss )
@@ -539,10 +532,6 @@ static MACHINE_DRIVER_START( percuss )
 	MDRV_MACHINE_INIT(percuss)
 MACHINE_DRIVER_END
 
-static MACHINE_DRIVER_START( moguchan )
-	MDRV_IMPORT_FROM(zodiack)
-	MDRV_MACHINE_INIT(percuss)
-MACHINE_DRIVER_END
 
 /***************************************************************************
 
