@@ -75,9 +75,9 @@ static void print_game_switch(FILE* out, const struct GameDriver* game)
 	const struct InputPort* input;
 
 	begin_resource_tracking();
-	
+
 	input = input_port_allocate(game->construct_ipt);
-	
+
 	while (input->type != IPT_END)
 	{
 		if (input->type==IPT_DIPSWITCH_NAME)
@@ -108,7 +108,7 @@ static void print_game_switch(FILE* out, const struct GameDriver* game)
 		else
 			++input;
 	}
-	
+
 	end_resource_tracking();
 }
 
@@ -123,9 +123,9 @@ static void print_game_input(FILE* out, const struct GameDriver* game)
 	const char* tilt = 0;
 
 	begin_resource_tracking();
-	
+
 	input = input_port_allocate(game->construct_ipt);
-	
+
 	while (input->type != IPT_END)
 			{
 		if (nplayer < input->player+1)
@@ -285,7 +285,7 @@ static void print_game_rom(FILE* out, const struct GameDriver* game)
 {
 	const struct RomModule *region, *rom, *chunk;
 	const struct RomModule *pregion, *prom, *fprom=NULL;
-/*	extern struct GameDriver driver_0; */
+/*  extern struct GameDriver driver_0; */
 
 	if (!game->rom)
 		return;
@@ -345,7 +345,7 @@ static void print_game_rom(FILE* out, const struct GameDriver* game)
 
 			if (*name)
 				fprintf(out, " name=\"%s\"", normalize_string(name));
-			if (!is_disk && in_parent)
+			if (in_parent)
 				fprintf(out, " merge=\"%s\"", normalize_string(ROM_GETNAME(fprom)));
 			if (!is_disk && found_bios)
 				fprintf(out, " bios=\"%s\"", normalize_string(bios_name));
@@ -407,12 +407,13 @@ static void print_game_rom(FILE* out, const struct GameDriver* game)
 				default: fprintf(out, " region=\"0x%x\"", ROMREGION_GETTYPE(region));
 		}
 
+		if (hash_data_has_info(ROM_GETHASHDATA(rom), HASH_INFO_NO_DUMP))
+			fprintf(out, " status=\"nodump\"");
+		if (hash_data_has_info(ROM_GETHASHDATA(rom), HASH_INFO_BAD_DUMP))
+			fprintf(out, " status=\"baddump\"");
+
 		if (!is_disk)
 		{
-			if (hash_data_has_info(ROM_GETHASHDATA(rom), HASH_INFO_NO_DUMP))
-				fprintf(out, " status=\"nodump\"");
-			if (hash_data_has_info(ROM_GETHASHDATA(rom), HASH_INFO_BAD_DUMP))
-				fprintf(out, " status=\"baddump\"");
 			if (ROMREGION_GETFLAGS(region) & ROMREGION_DISPOSE)
 				fprintf(out, " dispose=\"yes\"");
 			if (ROMREGION_GETFLAGS(region) & ROMREGION_SOUNDONLY)
@@ -441,7 +442,7 @@ static void print_game_sampleof(FILE* out, const struct GameDriver* game)
 	{
 		const char **samplenames = NULL;
 		if( drv.sound[i].sound_type == SOUND_SAMPLES )
-			samplenames = ((struct Samplesinterface *)drv.sound[i].sound_interface)->samplenames;
+			samplenames = ((struct Samplesinterface *)drv.sound[i].config)->samplenames;
 		if (samplenames != 0 && samplenames[0] != 0) {
 			int k = 0;
 			if (samplenames[k][0]=='*')
@@ -468,7 +469,7 @@ static void print_game_sample(FILE* out, const struct GameDriver* game)
 	{
 		const char **samplenames = NULL;
 		if( drv.sound[i].sound_type == SOUND_SAMPLES )
-			samplenames = ((struct Samplesinterface *)drv.sound[i].sound_interface)->samplenames;
+			samplenames = ((struct Samplesinterface *)drv.sound[i].config)->samplenames;
 		if (samplenames != 0 && samplenames[0] != 0) {
 			int k = 0;
 			if (samplenames[k][0]=='*')
@@ -508,10 +509,7 @@ static void print_game_micro(FILE* out, const struct GameDriver* game)
 		if (cpu[j].cpu_type!=0)
 		{
 			fprintf(out, "\t\t<chip");
-			if (cpu[j].cpu_flags & CPU_AUDIO_CPU)
-				fprintf(out, " type=\"cpu\" soundonly=\"yes\"");
-			else
-				fprintf(out, " type=\"cpu\"");
+			fprintf(out, " type=\"cpu\"");
 
 			fprintf(out, " name=\"%s\"", normalize_string(cputype_name(cpu[j].cpu_type)));
 
@@ -524,20 +522,12 @@ static void print_game_micro(FILE* out, const struct GameDriver* game)
 	{
 		if (sound[j].sound_type)
 		{
-			int num = sound_num(&sound[j]);
-			int l;
-
-			if (num == 0) num = 1;
-
-			for(l=0;l<num;++l)
-			{
-				fprintf(out, "\t\t<chip");
-				fprintf(out, " type=\"audio\"");
-				fprintf(out, " name=\"%s\"", normalize_string(sound_name(&sound[j])));
-				if (sound_clock(&sound[j]))
-					fprintf(out, " clock=\"%d\"", sound_clock(&sound[j]));
-				fprintf(out, "/>\n");
-			}
+			fprintf(out, "\t\t<chip");
+			fprintf(out, " type=\"audio\"");
+			fprintf(out, " name=\"%s\"", normalize_string(sndtype_name(sound[j].sound_type)));
+			if (sound[j].clock)
+				fprintf(out, " clock=\"%d\"", sound[j].clock);
+			fprintf(out, "/>\n");
 		}
 	}
 }
@@ -627,23 +617,17 @@ static void print_game_sound(FILE* out, const struct GameDriver* game)
 			has_sound = 1;
 		++i;
 	}
-	i = 0;
-	while (i < MAX_CPU && !has_sound)
-	{
-		if  ((cpu[i].cpu_flags & CPU_AUDIO_CPU)!=0)
-			has_sound = 1;
-		++i;
-	}
 
 	fprintf(out, "\t\t<sound");
 
 	/* sound channel */
 	if (has_sound)
 	{
-		if (driver.sound_attributes & SOUND_SUPPORTS_STEREO)
-			fprintf(out, " channels=\"2\"");
-		else
-			fprintf(out, " channels=\"1\"");
+		int speakers;
+		for (speakers = 0; speakers < MAX_SPEAKER; speakers++)
+			if (driver.speaker[speakers].tag == NULL)
+				break;
+		fprintf(out, " channels=\"%d\"", speakers);
 	}
 	else
 		fprintf(out, " channels=\"0\"");
@@ -814,10 +798,12 @@ static void print_game_info(FILE* out, const struct GameDriver* game)
 	fprintf(out, "\t</" XML_TOP ">\n");
 }
 
-#if !defined(MESS) && !defined(TINY_COMPILE)
+#if !defined(MESS)
 /* Print the resource info */
 static void print_resource_info(FILE* out, const struct GameDriver* game)
 {
+	const char *start;
+
 	/* The runnable entry is an hint for frontend authors */
 	/* to easily know which game can be started. */
 	/* Games marked as runnable=yes can be started putting */
@@ -827,6 +813,13 @@ static void print_resource_info(FILE* out, const struct GameDriver* game)
 
 	fprintf(out, " name=\"%s\"", normalize_string(game->name) );
 
+	start = strrchr(game->source_file, '/');
+	if (!start)
+		start = strrchr(game->source_file, '\\');
+	if (!start)
+		start = game->source_file - 1;
+	fprintf(out, " sourcefile=\"%s\"", normalize_string(start + 1));
+
 	fprintf(out, ">\n");
 
 	if (game->description)
@@ -893,7 +886,7 @@ static void print_mame_data(FILE* out, const struct GameDriver* games[])
 	for(j=0;games[j];++j)
 		print_game_info(out, games[j]);
 
-#if !defined(MESS) && !defined(TINY_COMPILE)
+#if !defined(MESS)
 	/* print resources */
 	print_resources_data(out, games);
 #endif
@@ -942,8 +935,10 @@ void print_mame_xml(FILE* out, const struct GameDriver* games[])
 		"\t\t\t<!ATTLIST disk name CDATA #REQUIRED>\n"
 		"\t\t\t<!ATTLIST disk md5 CDATA #IMPLIED>\n"
 		"\t\t\t<!ATTLIST disk sha1 CDATA #IMPLIED>\n"
+		"\t\t\t<!ATTLIST disk merge CDATA #IMPLIED>\n"
 		"\t\t\t<!ATTLIST disk region CDATA #IMPLIED>\n"
 		"\t\t\t<!ATTLIST disk index CDATA #IMPLIED>\n"
+		"\t\t\t<!ATTLIST disk status (baddump|nodump|good) \"good\">\n"
 		"\t\t<!ELEMENT sample EMPTY>\n"
 		"\t\t\t<!ATTLIST sample name CDATA #REQUIRED>\n"
 		"\t\t<!ELEMENT chip EMPTY>\n"
