@@ -1,8 +1,8 @@
 /***************************************************************************
 
-	inptport.h
+    inptport.h
 
-	Handle input ports and mappings.
+    Handle input ports and mappings.
 
 ***************************************************************************/
 
@@ -24,7 +24,7 @@ extern "C" {
 
 /*************************************
  *
- *	Constants
+ *  Constants
  *
  *************************************/
 
@@ -155,6 +155,37 @@ enum
 	IPT_VOLUME_UP,
 	IPT_VOLUME_DOWN,
 
+	/* mahjong inputs */
+	IPT_MAHJONG_A,
+	IPT_MAHJONG_B,
+	IPT_MAHJONG_C,
+	IPT_MAHJONG_D,
+	IPT_MAHJONG_E,
+	IPT_MAHJONG_F,
+	IPT_MAHJONG_G,
+	IPT_MAHJONG_H,
+	IPT_MAHJONG_I,
+	IPT_MAHJONG_J,
+	IPT_MAHJONG_K,
+	IPT_MAHJONG_L,
+	IPT_MAHJONG_M,
+	IPT_MAHJONG_N,
+	IPT_MAHJONG_O,
+	IPT_MAHJONG_P,
+	IPT_MAHJONG_Q,
+	IPT_MAHJONG_KAN,
+	IPT_MAHJONG_PON,
+	IPT_MAHJONG_CHI,
+	IPT_MAHJONG_REACH,
+	IPT_MAHJONG_RON,
+	IPT_MAHJONG_BET,
+	IPT_MAHJONG_LAST_CHANCE,
+	IPT_MAHJONG_SCORE,
+	IPT_MAHJONG_DOUBLE_UP,
+	IPT_MAHJONG_FLIP_FLOP,
+	IPT_MAHJONG_BIG,
+	IPT_MAHJONG_SMALL,
+
 	/* analog inputs */
 #define __ipt_analog_start IPT_PADDLE
 	IPT_PADDLE,			/* absolute */
@@ -314,6 +345,8 @@ enum
 	STR_Italian,
 	STR_Spanish,
 	STR_Very_Easy,
+	STR_Easiest,
+	STR_Easier,
 	STR_Easy,
 	STR_Normal,
 	STR_Medium,
@@ -356,7 +389,7 @@ enum
 
 /*************************************
  *
- *	Type definitions
+ *  Type definitions
  *
  *************************************/
 
@@ -449,7 +482,7 @@ struct InputPort
 
 /*************************************
  *
- *	Macros for building input ports
+ *  Macros for building input ports
  *
  *************************************/
 
@@ -588,7 +621,7 @@ struct InputPort
 
 /*************************************
  *
- *	Helper macros
+ *  Helper macros
  *
  *************************************/
 
@@ -604,7 +637,7 @@ struct InputPort
 
 /*************************************
  *
- *	Global variables
+ *  Global variables
  *
  *************************************/
 
@@ -616,7 +649,7 @@ extern const char *inptport_default_strings[];
 
 /*************************************
  *
- *	Function prototypes
+ *  Function prototypes
  *
  *************************************/
 
