@@ -14,20 +14,15 @@ Ernesto Corvi & Mariusz Wojcieszek
 #define LOG_CUSTOM	1
 #define LOG_CIA		0
 
-#ifdef MESS
-#include "machine/amigafdc.h"
-#else
-/* coin counters */
-static unsigned char coin_counter[2];
-#endif
-
 /* from vidhrdw */
 extern void copper_setpc( unsigned long pc );
 extern void copper_enable( void );
 
+static const struct amiga_machine_interface *amiga_intf;
+
 /***************************************************************************
 
-	General routines and registers
+    General routines and registers
 
 ***************************************************************************/
 
@@ -85,7 +80,7 @@ static void check_ints( void ) {
 
 /***************************************************************************
 
-	Blitter emulation
+    Blitter emulation
 
 ***************************************************************************/
 
@@ -378,8 +373,8 @@ static void blitter_proc( int param ) {
 		custom_regs.BLTxPTH[3] = ( ptr[3] >> 16 ) & 0x1f;
 		custom_regs.BLTxPTL[3] = ptr[3] & 0xffff;
 
-/*		custom_regs.BLTxDAT[0] = dataA; */
-/*		custom_regs.BLTxDAT[1] = dataB; */
+/*      custom_regs.BLTxDAT[0] = dataA; */
+/*      custom_regs.BLTxDAT[1] = dataB; */
 
 	} else { /* Blit mode */
 		if ( custom_regs.BLTCON0 & 0x0f00 ) {
@@ -401,7 +396,11 @@ static void blitter_proc( int param ) {
 				ptr[2] = ( custom_regs.BLTxPTH[2] << 16 ) | custom_regs.BLTxPTL[2];
 
 			if ( custom_regs.BLTCON0 & 0x100 )
+			{
 				ptr[3] = ( custom_regs.BLTxPTH[3] << 16 ) | custom_regs.BLTxPTL[3];
+				if ( ptr[3] > 0x7ffff )
+					goto done;
+			}
 
 			if ( custom_regs.BLTCON1 & 0x0002 ) { /* Descending mode */
 				blit_func = blit_func_d;
@@ -417,6 +416,7 @@ static void blitter_proc( int param ) {
 				height = 0x400;
 
 			for ( y = 0; y < height; y++ ) {
+				fc = ( custom_regs.BLTCON1 >> 2 ) & 1; /* fill carry setup */
 				for ( x = 0; x < width; x++ ) {
 					int dst_data = 0;
 
@@ -531,6 +531,7 @@ static void blitter_proc( int param ) {
 		}
 	}
 
+done:
 	custom_regs.DMACON ^= 0x4000; /* signal we're done */
 
 	if ( blt_total )
@@ -581,13 +582,13 @@ static void blitter_setup( void ) {
 
 /***************************************************************************
 
-	8520 CIA emulation
+    8520 CIA emulation
 
 ***************************************************************************/
 
 /* required prototype */
 static void cia_fire_timer( int cia, int timer );
-static void *cia_hblank_timer;
+static mame_timer *cia_hblank_timer;
 static int cia_hblank_timer_set;
 
 typedef struct {
@@ -615,8 +616,8 @@ typedef struct {
 	int				icr;
 	int				ics;
 	/* MESS timers */
-	void			*timerA;
-	void			*timerB;
+	mame_timer		*timerA;
+	mame_timer		*timerB;
 	int				timerA_started;
 	int				timerB_started;
 } cia_8520_def;
@@ -767,72 +768,48 @@ void amiga_cia_issue_index( void ) {
 	}
 }
 
-static int cia_0_portA_r( void ) {
-	int ret = readinputport( 0 ) & 0xc0;
-
-#ifdef MESS
-	ret |= amiga_fdc_status_r();
-#else
-	ret |= 0x3f;
-#endif
-	
-	return ret; /* Gameport 1 and 0 buttons */
-}
-
-static int cia_0_portB_r( void ) {
-
-	/* parallel port */
-	int ret = 0;
-
-#ifndef MESS
-	ret = readinputport( 1 ) & 0x0f;
-
-	ret |= ( coin_counter[0] & 3 ) << 4;
-	ret |= ( coin_counter[1] & 3 ) << 6;
-
-	logerror( "Coin counter read at PC=%06x\n", activecpu_get_pc() );
-#endif
-	return ret;
-}
-
-static void cia_0_portA_w( int data ) 
+static int cia_0_portA_r( void )
 {
-	if ( (data & 1) == 1)
-	{
-		/* overlay enabled, map Amiga system ROM on 0x000000 */
-		memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x000000, 0x07ffff, 0, 0, MRA16_BANK3 );
-		memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x000000, 0x07ffff, 0, 0, MWA16_ROM );
-	}
-	else if ( ((data & 1) == 0))
-	{
-		/* overlay disabled, map RAM on 0x000000 */
-		memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x000000, 0x07ffff, 0, 0, MRA16_RAM );
-		memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x000000, 0x07ffff, 0, 0, MWA16_RAM );
-	}
-
-	set_led_status( 0, ( data & 2 ) ? 0 : 1 ); /* bit 2 = Power Led on Amiga*/
+	return (amiga_intf->cia_0_portA_r) ? amiga_intf->cia_0_portA_r() : 0x00;
 }
 
-static void cia_0_portB_w( int data ) {
-	/* parallel port */
-	/* bit 0 = coin counter reset? */
+static int cia_0_portB_r( void )
+{
+	return (amiga_intf->cia_0_portB_r) ? amiga_intf->cia_0_portB_r() : 0x00;
 }
 
-static int cia_1_portA_r( void ) {
-	return 0x0;
+static void cia_0_portA_w( int data )
+{
+	if (amiga_intf->cia_0_portA_w)
+		amiga_intf->cia_0_portA_w(data);
 }
 
-static int cia_1_portB_r( void ) {
-	return 0x0;
+static void cia_0_portB_w( int data )
+{
+	if (amiga_intf->cia_0_portB_w)
+		amiga_intf->cia_0_portB_w(data);
 }
 
-static void cia_1_portA_w( int data ) {
+static int cia_1_portA_r( void )
+{
+	return (amiga_intf->cia_1_portA_r) ? amiga_intf->cia_1_portA_r() : 0x00;
 }
 
-static void cia_1_portB_w( int data ) {
-#ifdef MESS
-	amiga_fdc_control_w( data );
-#endif
+static int cia_1_portB_r( void )
+{
+	return (amiga_intf->cia_1_portB_r) ? amiga_intf->cia_1_portB_r() : 0x00;
+}
+
+static void cia_1_portA_w( int data )
+{
+	if (amiga_intf->cia_1_portA_w)
+		amiga_intf->cia_1_portA_w(data);
+}
+
+static void cia_1_portB_w( int data )
+{
+	if (amiga_intf->cia_1_portB_w)
+		amiga_intf->cia_1_portB_w(data);
 }
 
 static void cia_init( void ) {
@@ -886,7 +863,7 @@ READ16_HANDLER ( amiga_cia_r ) {
 	if ( offset >= 0x1000 )
 		cia_sel = 0;
 
-	switch ( offset & 0xffe ) {
+	switch( offset & 0xf00 ) {
 		case 0x000:
 			data = (*cia_8520[cia_sel].portA_read)();
 			mask = ~( cia_8520[cia_sel].ddra );
@@ -1117,7 +1094,7 @@ WRITE16_HANDLER ( amiga_cia_w ) {
 
 /***************************************************************************
 
-	Custom chips emulation
+    Custom chips emulation
 
 ***************************************************************************/
 
@@ -1126,7 +1103,7 @@ static void amiga_custom_init( void ) {
 	custom_regs.DDFSTOP = 0xd8;
 }
 
-READ16_HANDLER ( amiga_custom_r ) 
+READ16_HANDLER ( amiga_custom_r )
 {
 
     offset<<=1;
@@ -1136,100 +1113,28 @@ READ16_HANDLER ( amiga_custom_r )
 		case 0x0002: /* DMACON */
 			return custom_regs.DMACON;
 		break;
-		
+
 		case 0x0004: /* VPOSR */
 			return ( ( cpu_getscanline() >> 8 ) & 1 );
 		break;
-		
+
 		case 0x0006: /* VHPOSR */
 			{
 				int h, v;
-				
+
 				h = ( cpu_gethorzbeampos() >> 1 ); /* in color clocks */
 				v = ( cpu_getscanline() & 0xff );
-				
+
 				return ( v << 8 ) | h;
 			}
 		break;
-		
+
 		case 0x000a: /* JOY0DAT */
-#ifdef MESS
-			if ( readinputport( 0 ) & 0x20 ) {
-				int input = ( readinputport( 1 ) >> 4 );
-				int	top,bot,lft,rgt;
-
-				top = ( input >> 3 ) & 1;
-				bot = ( input >> 2 ) & 1;
-				lft = ( input >> 1 ) & 1;
-				rgt = input & 1;
-
-				if ( lft ) top ^= 1;
-				if ( rgt ) bot ^= 1;
-
-				return ( bot | ( rgt << 1 ) | ( top << 8 ) | ( lft << 9 ) );
-			} else {
-				int input = ( readinputport( 2 ) & 0xff );
-
-				input |= ( readinputport( 3 ) & 0xff ) << 8;
-
-				return input;
-			}
-#else
-			{
-				int input = ( readinputport( 2 ) >> 4 );
-				int	top,bot,lft,rgt;
-				
-				top = ( input >> 3 ) & 1;
-				bot = ( input >> 2 ) & 1;
-				lft = ( input >> 1 ) & 1;
-				rgt = input & 1;
-
-				if ( lft ) top ^= 1;
-				if ( rgt ) bot ^= 1;
-
-				return ( bot | ( rgt << 1 ) | ( top << 8 ) | ( lft << 9 ) );
-			}
-#endif
+			return amiga_intf->read_joy0dat();
 		break;
 
 		case 0x000c: /* JOY1DAT */
-#ifdef MESS
-			if ( readinputport( 0 ) & 0x10 ) {
-				int input = ( readinputport( 1 ) & 0x0f );
-				int	top,bot,lft,rgt;
-
-				top = ( input >> 3 ) & 1;
-				bot = ( input >> 2 ) & 1;
-				lft = ( input >> 1 ) & 1;
-				rgt = input & 1;
-
-				if ( lft ) top ^= 1;
-				if ( rgt ) bot ^= 1;
-
-				return ( bot | ( rgt << 1 ) | ( top << 8 ) | ( lft << 9 ) );
-			} else {
-				int input = ( readinputport( 4 ) & 0xff );
-
-				input |= ( readinputport( 5 ) & 0xff ) << 8;
-
-				return input;
-			}
-#else
-			{
-				int input = ( readinputport( 2 ) & 0x0f );
-				int	top,bot,lft,rgt;
-				
-				top = ( input >> 3 ) & 1;
-				bot = ( input >> 2 ) & 1;
-				lft = ( input >> 1 ) & 1;
-				rgt = input & 1;
-
-				if ( lft ) top ^= 1;
-				if ( rgt ) bot ^= 1;
-				
-				return ( bot | ( rgt << 1 ) | ( top << 8 ) | ( lft << 9 ) );
-			}
-#endif
+			return amiga_intf->read_joy1dat();
 		break;
 
 		case 0x0010: /* ADKCONR */
@@ -1244,14 +1149,10 @@ READ16_HANDLER ( amiga_custom_r )
 		break;
 
 		case 0x001a: /* DSKBYTR */
-#ifdef MESS
-			return amiga_fdc_get_byte();
-#else
-			return 0x00;
-#endif
+			return amiga_intf->read_dskbytr ? amiga_intf->read_dskbytr() : 0x00;
 		break;
 
-				
+
 		case 0x001c: /* INTENA */
 			return custom_regs.INTENA;
 		break;
@@ -1259,11 +1160,11 @@ READ16_HANDLER ( amiga_custom_r )
 		case 0x001e: /* INTREQ */
 			return custom_regs.INTREQ;
 		break;
-		
+
 		case 0x0088: /* COPJMPA */
 			copper_setpc( ( custom_regs.COPLCH[0] << 16 ) | custom_regs.COPLCL[0] );
 		break;
-		
+
 		case 0x008a: /* COPJMPB */
 			copper_setpc( ( custom_regs.COPLCH[1] << 16 ) | custom_regs.COPLCL[1] );
 		break;
@@ -1279,12 +1180,12 @@ READ16_HANDLER ( amiga_custom_r )
 }
 
 #define SETCLR( reg, data ) { \
-	if ( data & 0x8000 ) \
-		reg |= ( data & 0x7fff ); \
+	if ( (data) & 0x8000 ) \
+		reg |= ( (data) & 0x7fff ); \
 	else \
-		reg &= ~( data & 0x7fff ); }
+		reg &= ~( (data) & 0x7fff ); }
 
-WRITE16_HANDLER ( amiga_custom_w ) 
+WRITE16_HANDLER ( amiga_custom_w )
 {
     offset<<=1;
 	offset &= 0xfff;
@@ -1293,45 +1194,41 @@ WRITE16_HANDLER ( amiga_custom_w )
 		case 0x0020: /* DSKPTH */
 			custom_regs.DSKPTH = data;
 		break;
-		
+
 		case 0x0022: /* DSKPTL */
 			custom_regs.DSKPTL = data;
 		break;
-						
+
 		case 0x0024: /* DSKLEN */
-#ifdef MESS
-			if ( data & 0x8000 ) {
-				if ( custom_regs.DSKLEN & 0x8000 )
-					amiga_fdc_setup_dma();
-			}
-#endif
+			if (amiga_intf->write_dsklen)
+				amiga_intf->write_dsklen(data);
 			custom_regs.DSKLEN = data;
 		break;
-		
+
 		case 0x002e: /* COPCON */
 			custom_regs.COPCON = data & 2;
 		break;
-		
+
 		case 0x0034: /* POTGO */
 			custom_regs.POTGO = data;
 		break;
-		
+
 		case 0x0040: /* BLTCON0 */
 			custom_regs.BLTCON0 = data;
 		break;
-		
+
 		case 0x0042: /* BLTCON1 */
 			custom_regs.BLTCON1 = data;
 		break;
-		
+
 		case 0x0044: /* BLTAFWM */
 			custom_regs.BLTAFWM = data;
 		break;
-		
+
 		case 0x0046: /* BLTALWM */
 			custom_regs.BLTALWM = data;
 		break;
-		
+
 		case 0x0048: /* BLTCPTH */
 		case 0x004a: /* BLTCPTL */
 		case 0x004c: /* BLTBPTH */
@@ -1344,7 +1241,7 @@ WRITE16_HANDLER ( amiga_custom_w )
 				int lo = ( offset & 2 );
 				int loc = ( offset - 0x48 ) >> 2;
 				int order[4] = { 2, 1, 0, 3 };
-				
+
 				if ( lo )
 					custom_regs.BLTxPTL[order[loc]] = ( data & 0xfffe ); /* should be word aligned, we make sure is is */
 				else
@@ -1364,7 +1261,7 @@ WRITE16_HANDLER ( amiga_custom_w )
 			{
 				int loc = ( offset >> 1 ) & 3;
 				int order[4] = { 2, 1, 0, 3 };
-				
+
 				custom_regs.BLTxMOD[order[loc]] = ( signed short )( data & ~1 ); /* strip off lsb */
 			}
 		break;
@@ -1375,7 +1272,7 @@ WRITE16_HANDLER ( amiga_custom_w )
 			{
 				int loc = ( offset >> 1 ) & 3;
 				int order[3] = { 2, 1, 0 };
-				
+
 				custom_regs.BLTxDAT[order[loc]] = data;
 			}
 		break;
@@ -1391,7 +1288,7 @@ WRITE16_HANDLER ( amiga_custom_w )
 			{
 				int lo = ( offset & 2 );
 				int loc = ( offset >> 2 ) & 1;
-				
+
 				if ( lo )
 					custom_regs.COPLCL[loc] = ( data & ~1 ); /* should be word aligned, we make sure it is */
 				else
@@ -1402,48 +1299,49 @@ WRITE16_HANDLER ( amiga_custom_w )
 		case 0x0088: /* COPJMPA */
 			copper_setpc( ( custom_regs.COPLCH[0] << 16 ) | custom_regs.COPLCL[0] );
 		break;
-		
+
 		case 0x008a: /* COPJMPB */
 			copper_setpc( ( custom_regs.COPLCH[1] << 16 ) | custom_regs.COPLCL[1] );
 		break;
-		
+
 		case 0x008e: /* DIWSTRT */
 			custom_regs.DIWSTRT = data;
 		break;
-		
+
 		case 0x0090: /* DIWSTOP */
 			custom_regs.DIWSTOP = data;
 		break;
-		
+
 		case 0x0092: /* DDFSTRT */
 			custom_regs.DDFSTRT = data & 0xfc;
 			/* impose hardware limits ( HRM, page 75 ) */
 			if ( custom_regs.DDFSTRT < 0x18 )
 				custom_regs.DDFSTRT = 0x18;
 		break;
-		
+
 		case 0x0094: /* DDFSTOP */
 			custom_regs.DDFSTOP = data & 0xfc;
 			/* impose hardware limits ( HRM, page 75 ) */
 			if ( custom_regs.DDFSTOP > 0xd8 )
 				custom_regs.DDFSTOP = 0xd8;
 		break;
-			
+
 		case 0x0096: /* DMACON */
-			SETCLR( custom_regs.DMACON, data )
+			/* bits BBUSY (14) and BZERO (13) are read-only */
+			SETCLR( custom_regs.DMACON, data & 0x9fff )
 			copper_enable();
 		break;
-		
+
 		case 0x009a: /* INTENA */
 			SETCLR( custom_regs.INTENA, data )
 			check_ints();
 		break;
-		
+
 		case 0x009c: /* INTREQ */
 			SETCLR( custom_regs.INTREQ, data )
 			check_ints();
 		break;
-		
+
 		case 0x009e: /* ADKCON */
 			SETCLR( custom_regs.ADKCON, data )
 		break;
@@ -1463,7 +1361,7 @@ WRITE16_HANDLER ( amiga_custom_w )
 			{
 				int lo = ( offset & 2 );
 				int plane = ( offset >> 2 ) & 0x07;
-				
+
 				if ( lo ) {
 					custom_regs.BPLPTR[plane] &= 0x001f0000;
 					custom_regs.BPLPTR[plane] |= ( data & 0xfffe );
@@ -1476,14 +1374,14 @@ WRITE16_HANDLER ( amiga_custom_w )
 
 		case 0x0100: /* BPLCON0 */
 			custom_regs.BPLCON0 = data;
-			
+
 			if ( ( custom_regs.BPLCON0 & ( BPLCON0_BPU0 | BPLCON0_BPU1 | BPLCON0_BPU2 ) ) == ( BPLCON0_BPU0 | BPLCON0_BPU1 | BPLCON0_BPU2 ) ) {
 				/* planes go from 0 to 6, inclusive */
 				logerror( "This game is doing funky planes stuff. (planes > 6)\n" );
 				custom_regs.BPLCON0 &= ~BPLCON0_BPU0;
 			}
 		break;
-		
+
 		case 0x0102: /* BPLCON1 */
 			custom_regs.BPLCON1 = data & 0xff;
 		break;
@@ -1491,15 +1389,15 @@ WRITE16_HANDLER ( amiga_custom_w )
 		case 0x0104: /* BPLCON2 */
 			custom_regs.BPLCON2 = data & 0x7f;
 		break;
-		
+
 		case 0x0108: /* BPL1MOD */
 			custom_regs.BPL1MOD = data;
 		break;
-		
+
 		case 0x010a: /* BPL2MOD */
 			custom_regs.BPL2MOD = data;
 		break;
-		
+
 		case 0x0110: /* BPL1DAT */
 		case 0x0112: /* BPL2DAT */
 		case 0x0114: /* BPL3DAT */
@@ -1528,7 +1426,7 @@ WRITE16_HANDLER ( amiga_custom_w )
 			{
 				int lo = ( offset & 2 );
 				int num = ( offset >> 2 ) & 0x07;
-				
+
 				if ( lo ) {
 					custom_regs.SPRxPT[num] &= 0x001f0000;
 					custom_regs.SPRxPT[num] |= ( data & 0xfffe );
@@ -1539,7 +1437,7 @@ WRITE16_HANDLER ( amiga_custom_w )
 				}
 			}
 		break;
-		
+
 		case 0x180: /* COLOR00 */
 		case 0x182: /* COLOR01 */
 		case 0x184: /* COLOR02 */
@@ -1574,11 +1472,11 @@ WRITE16_HANDLER ( amiga_custom_w )
 		case 0x1be: /* COLOR31 */
 			{
 				int color = ( offset - 0x180 ) >> 1;
-		
+
 				custom_regs.COLOR[color] = data;
 			}
 		break;
-		
+
 		default:
 #if LOG_CUSTOM
 		logerror( "PC = %06x - Wrote to Custom %04x (%04x)\n", cpu_getactivecpu() != -1 ? activecpu_get_pc() : 0, offset, data );
@@ -1589,7 +1487,7 @@ WRITE16_HANDLER ( amiga_custom_w )
 
 /***************************************************************************
 
-	Interrupt handling
+    Interrupt handling
 
 ***************************************************************************/
 
@@ -1606,35 +1504,28 @@ INTERRUPT_GEN(amiga_vblank_irq)
 	}
 
 	amiga_custom_w( 0x009c>>1, 0x8020, 0);
-	
-#ifndef MESS
-	/* update coin counters */
 
-	/* check for a 0 -> 1 transition */
-	if ( readinputport( 0 ) & 0x20 ) {
-		if ( ( coin_counter[0] & 0x80 ) == 0 ) {
-			if ( coin_counter[0] < 3 )
-				coin_counter[0]++;
-			coin_counter[0] |= 0x80;
-		}
-	} else
-		coin_counter[0] = 0;
+	if (amiga_intf->interrupt_callback)
+		amiga_intf->interrupt_callback();
+}
 
-	/* check for a 0 -> 1 transition */
-	if ( readinputport( 0 ) & 0x10 ) {
-		if ( ( coin_counter[1] & 0x80 ) == 0 ) {
-			if ( coin_counter[1] < 3 )
-				coin_counter[1]++;
-			coin_counter[1] |= 0x80;
-		}
-	} else
-		coin_counter[1] = 0;
-#endif
+INTERRUPT_GEN(amiga_irq)
+{
+	int scanline = 261 - cpu_getiloops();
+
+	if ( scanline == 0 )
+	{
+		/* vblank start */
+		amiga_prepare_frame();
+		amiga_vblank_irq();
+	}
+
+	amiga_render_scanline(scanline);
 }
 
 /***************************************************************************
 
-	Init Machine
+    Init Machine
 
 ***************************************************************************/
 
@@ -1642,11 +1533,14 @@ void amiga_m68k_reset( void )
 {
 	logerror( "Executed RESET at PC=%06x\n", activecpu_get_pc() );
 	amiga_cia_w( 0x1001/2, 1, 0 );	/* enable overlay */
-	memory_set_opbase(0);
+	if ( activecpu_get_pc() < 0x80000 )
+	{
+		memory_set_opbase(0);
+	}
 }
 
 MACHINE_INIT(amiga)
-{	
+{
 	/* set m68k reset  function */
 	cpunum_set_info_fct(0, CPUINFO_PTR_M68K_RESET_CALLBACK, (genf *)amiga_m68k_reset);
 
@@ -1659,9 +1553,14 @@ MACHINE_INIT(amiga)
 	/* set the overlay bit */
 	amiga_cia_w( 0x1001/2, 1, 0 );
 
-#ifndef MESS
-	/* reset coin counters */
-	coin_counter[0] = coin_counter[1] = 0;
-#endif
+	if (amiga_intf->reset_callback)
+		amiga_intf->reset_callback();
 }
 
+void amiga_machine_config(const struct amiga_machine_interface *intf)
+{
+	amiga_intf = intf;
+}
+
+
+
