@@ -1,6 +1,6 @@
 /***************************************************************************
 
-	Bally/Sente SAC-1 system
+    Bally/Sente SAC-1 system
 
     driver by Aaron Giles
 
@@ -10,6 +10,7 @@
 #include "cpu/m6809/m6809.h"
 #include "vidhrdw/generic.h"
 #include "balsente.h"
+#include "sound/cem3394.h"
 #include <math.h>
 
 
@@ -29,6 +30,7 @@ UINT8 balsente_shooter_x;
 UINT8 balsente_shooter_y;
 UINT8 balsente_adc_shift;
 data16_t *shrike_shared;
+data16_t *shrike_io;
 
 
 /* 8253 counter state */
@@ -94,7 +96,7 @@ static UINT8 grudge_last_steering[3];
 
 /*************************************
  *
- *	Interrupt handling
+ *  Interrupt handling
  *
  *************************************/
 
@@ -190,10 +192,10 @@ MACHINE_INIT( balsente )
 
 /*************************************
  *
- *	MM5837 noise generator
+ *  MM5837 noise generator
  *
- *	NOTE: this is stolen straight from
- *			POKEY.c
+ *  NOTE: this is stolen straight from
+ *          POKEY.c
  *
  *************************************/
 
@@ -261,7 +263,7 @@ void balsente_noise_gen(int chip, int count, short *buffer)
 
 /*************************************
  *
- *	Hardware random numbers
+ *  Hardware random numbers
  *
  *************************************/
 
@@ -287,7 +289,7 @@ READ8_HANDLER( balsente_random_num_r )
 
 /*************************************
  *
- *	ROM banking
+ *  ROM banking
  *
  *************************************/
 
@@ -328,7 +330,7 @@ WRITE8_HANDLER( balsente_rombank2_select_w )
 
 /*************************************
  *
- *	Special outputs
+ *  Special outputs
  *
  *************************************/
 
@@ -345,7 +347,7 @@ WRITE8_HANDLER( balsente_misc_output_w )
 	}
 	else
 	{
-/*		set_led_status(offset, data); */
+/*      set_led_status(offset, data); */
 	}
 }
 
@@ -353,7 +355,7 @@ WRITE8_HANDLER( balsente_misc_output_w )
 
 /*************************************
  *
- *	6850 UART communications
+ *  6850 UART communications
  *
  *************************************/
 
@@ -445,7 +447,7 @@ static void m6850_update_io(void)
 
 /*************************************
  *
- *	6850 UART (main CPU)
+ *  6850 UART (main CPU)
  *
  *************************************/
 
@@ -514,7 +516,7 @@ WRITE8_HANDLER( balsente_m6850_w )
 
 /*************************************
  *
- *	6850 UART (sound CPU)
+ *  6850 UART (sound CPU)
  *
  *************************************/
 
@@ -563,7 +565,7 @@ WRITE8_HANDLER( balsente_m6850_sound_w )
 
 /*************************************
  *
- *	ADC handlers
+ *  ADC handlers
  *
  *************************************/
 
@@ -631,9 +633,9 @@ logerror("adc_select %d\n", offset & 7);
 
 /*************************************
  *
- *	8253-5 timer utilities
+ *  8253-5 timer utilities
  *
- *	NOTE: this is far from complete!
+ *  NOTE: this is far from complete!
  *
  *************************************/
 
@@ -676,9 +678,9 @@ INLINE void counter_update_count(int which)
 
 /*************************************
  *
- *	8253-5 timer internals
+ *  8253-5 timer internals
  *
- *	NOTE: this is far from complete!
+ *  NOTE: this is far from complete!
  *
  *************************************/
 
@@ -748,9 +750,9 @@ static void counter_callback(int param)
 
 /*************************************
  *
- *	8253-5 timer handlers
+ *  8253-5 timer handlers
  *
- *	NOTE: this is far from complete!
+ *  NOTE: this is far from complete!
  *
  *************************************/
 
@@ -858,7 +860,7 @@ WRITE8_HANDLER( balsente_counter_8253_w )
 
 /*************************************
  *
- *	Sound CPU counter 0 emulation
+ *  Sound CPU counter 0 emulation
  *
  *************************************/
 
@@ -928,7 +930,7 @@ static void update_counter_0_timer(void)
 
 /*************************************
  *
- *	Sound CPU counter handlers
+ *  Sound CPU counter handlers
  *
  *************************************/
 
@@ -955,12 +957,8 @@ WRITE8_HANDLER( balsente_counter_control_w )
 	if (diff_counter_control & 0x01)
 	{
 		int ch;
-		for (ch = 0; ch < MIXER_MAX_CHANNELS; ch++)
-		{
-			const char *name = mixer_get_name(ch);
-			if (name && strstr(name, "3394"))
-				mixer_set_volume(ch, (data & 0x01) ? 100 : 0);
-		}
+		for (ch = 0; ch < 6; ch++)
+			sndti_set_output_gain(SOUND_CEM3394, ch, 0, (data & 0x01) ? 1.0 : 0);
 	}
 
 	/* bit D1 is hooked to counter 0's gate */
@@ -992,7 +990,7 @@ WRITE8_HANDLER( balsente_counter_control_w )
 
 /*************************************
  *
- *	CEM3394 Interfaces
+ *  CEM3394 Interfaces
  *
  *************************************/
 
@@ -1083,7 +1081,7 @@ WRITE8_HANDLER( balsente_register_addr_w )
 
 /*************************************
  *
- *	Game-specific handlers
+ *  Game-specific handlers
  *
  *************************************/
 
@@ -1180,36 +1178,39 @@ READ8_HANDLER( grudge_steering_r )
 
 /*************************************
  *
- *	Shrike Avenger CPU memory handlers
+ *  Shrike Avenger CPU memory handlers
  *
  *************************************/
 
-READ16_HANDLER( shrike_shared_68k_r )
-{
-	return shrike_shared[offset] & 0xff;
-}
-
-
-WRITE16_HANDLER( shrike_shared_68k_w )
-{
-	COMBINE_DATA(&shrike_shared[offset]);
-}
-
-
 READ8_HANDLER( shrike_shared_6809_r )
 {
-	if (offset == 0)
-		return 0;
-	if (offset == 9)
-		return 0xaa;
-logerror("6809 read %02x = %02x\n", offset, shrike_shared[offset] & 0xff);
-	return shrike_shared[offset] & 0xff;
+  data16_t mem_mask = offset & 1 ? 0xff : 0xff00;
+
+  switch( offset )
+  {
+    case 6: /* return OK for 68k status register until motors hooked up */
+      return 0;
+    default:
+      return ( shrike_shared[offset >> 1] & mem_mask ) >> ( ~mem_mask & 8 );
+  }
 }
 
 
 WRITE8_HANDLER( shrike_shared_6809_w )
 {
-if (offset != 0x0a || data != 0x55)
-logerror("6809 wrote %02x = %02x\n", offset, data);
-	shrike_shared[offset] = (shrike_shared[offset] & ~0xff) | data;
+  data16_t mem_mask = offset & 1 ? 0xff : 0xff00;
+  shrike_shared[offset >> 1] = ( shrike_shared[offset >> 1] & ~mem_mask ) | ( data << ( ~mem_mask & 0x8 ) );
 }
+
+/* uses movep, so writes even 8 bit addresses to odd 16 bit addresses, reads as 16 bit from odd addresses */
+/* i.e. write 0xdeadbeef to 10000, read 0xde from 10001, 0xad from 10003, 0xbe from 10005... */
+WRITE16_HANDLER( shrike_io_68k_w )
+{
+  COMBINE_DATA( &shrike_io[offset] );
+}
+
+READ16_HANDLER( shrike_io_68k_r )
+{
+  return ( shrike_io[offset] & ~mem_mask ) >> ( 8 & mem_mask );
+}
+
