@@ -1,7 +1,7 @@
 /***************************************************************************
 
 
-							MCU Code Simulation
+                            MCU Code Simulation
 
 
 ***************************************************************************/
@@ -11,18 +11,21 @@
 
 #include "kanekotb.h"	/* TOYBOX MCU trojaning results */
 
+#define MCU_RESPONSE(d) memcpy(&mcu_ram[mcu_offset], d, sizeof(d))
+
 data16_t *mcu_ram;
 
 /***************************************************************************
-								Gals Panic (set 2)
-								Gals Panic (set 3)
-								Sand Scorpion
-								Bonk's Adventure
+                                Gals Panic (set 2)
+                                Gals Panic (set 3)
+                                Sand Scorpion
+                                Bonk's Adventure
+                                Blood Warrior
 ***************************************************************************/
 
 /*
-	- see notes about this "calculator" implementation in drivers\galpanic.c
-	- bonkadv only uses Random Number and XY Overlap Collision bit
+    - see notes about this "calculator" implementation in drivers\galpanic.c
+    - bonkadv only uses Random Number, XY Overlap Collision bit and register '0x02'
 */
 
 static struct {
@@ -43,6 +46,10 @@ READ16_HANDLER(galpanib_calc_r)
 		case 0x00/2: /* watchdog */
 			return watchdog_reset_r(0);
 
+		case 0x02/2: /* unknown (yet!), used by *MANY* games !!! */
+			/*usrintf_showmessage("unknown collision reg"); */
+			break;
+
 		case 0x04/2: /* similar to the hit detection from SuperNova, but much simpler */
 
 			/* X Absolute Collision */
@@ -97,6 +104,18 @@ WRITE16_HANDLER(galpanib_calc_w)
 		case 0x0e/2: hit.y2s    = data; break;
 		case 0x10/2: hit.mult_a = data; break;
 		case 0x12/2: hit.mult_b = data; break;
+
+		/* unknown (yet!), used by bloodwar */
+		case 0x20/2:
+		case 0x22/2:
+		case 0x24/2:
+		case 0x26/2:
+		case 0x2c/2:
+		case 0x2e/2:
+		case 0x30/2:
+		case 0x32/2:
+		case 0x38/2:
+
 		default:
 			logerror("CPU #0 PC %06x: warning - write unmapped hit address %06x\n",activecpu_get_pc(),offset<<1);
 	}
@@ -104,19 +123,19 @@ WRITE16_HANDLER(galpanib_calc_w)
 
 
 /***************************************************************************
-								CALC3 MCU:
+                                CALC3 MCU:
 
-								Shogun Warriors
-								Fujiyama Buster
-								B.Rap Boys
+                                Shogun Warriors
+                                Fujiyama Buster
+                                B.Rap Boys
 ***************************************************************************/
 /*
 ---------------------------------------------------------------------------
-								CALC 3
+                                CALC 3
 
-92	B.Rap Boys				KANEKO CALC3 508 (74 PIN PQFP)
-92	Shogun Warriors
-	Fujiyama Buster			KANEKO CALC3 508 (74 Pin PQFP)
+92  B.Rap Boys              KANEKO CALC3 508 (74 PIN PQFP)
+92  Shogun Warriors
+    Fujiyama Buster         KANEKO CALC3 508 (74 Pin PQFP)
 ---------------------------------------------------------------------------
 
 MCU Initialization command:
@@ -166,16 +185,16 @@ CALC3_MCU_COM_W(2)
 CALC3_MCU_COM_W(3)
 
 /***************************************************************************
-								Shogun Warriors
+                                Shogun Warriors
 ***************************************************************************/
 
 /* Preliminary simulation: the game doesn't work */
 
 /*
-	MCU Tasks:
+    MCU Tasks:
 
-	- Read the DSWs
-	- Supply code snippets to the 68000
+    - Read the DSWs
+    - Supply code snippets to the 68000
 */
 
 void calc3_mcu_run(void)
@@ -199,10 +218,10 @@ void calc3_mcu_run(void)
 			int param1 = mcu_ram[calc3_mcu_command_offset + 1];
 			int param2 = mcu_ram[calc3_mcu_command_offset + 2];
 			int param3 = mcu_ram[calc3_mcu_command_offset + 3];
-/*			int param4 = mcu_ram[calc3_mcu_command_offset + 4]; */
+/*          int param4 = mcu_ram[calc3_mcu_command_offset + 4]; */
 			int param5 = mcu_ram[calc3_mcu_command_offset + 5];
-/*			int param6 = mcu_ram[calc3_mcu_command_offset + 6]; */
-/*			int param7 = mcu_ram[calc3_mcu_command_offset + 7]; */
+/*          int param6 = mcu_ram[calc3_mcu_command_offset + 6]; */
+/*          int param7 = mcu_ram[calc3_mcu_command_offset + 7]; */
 
 			/* clear old command (handshake to main cpu) */
 			mcu_ram[calc3_mcu_command_offset] = 0x0000;
@@ -279,7 +298,7 @@ First code snippet provided by the MCU:
 208086: 317C 7000 0316           move.w  #$7000, ($316,A0)
 20808C: 5247                     addq.w  #1, D7
 
-20808E: 0839 0001 0010 2E15      btst    #$1, $102e15.l	; service mode
+20808E: 0839 0001 0010 2E15      btst    #$1, $102e15.l ; service mode
 208096: 6714                     beq     2080ac
 
 208098: 117C 0058 0318           move.b  #$58, ($318,A0)
@@ -299,7 +318,7 @@ First code snippet provided by the MCU:
 
 		case 0x0001:
 		{
-/*			int param1 = mcu_ram[calc3_mcu_command_offset + 1]; */
+/*          int param1 = mcu_ram[calc3_mcu_command_offset + 1]; */
 			int param2 = mcu_ram[calc3_mcu_command_offset + 2];
 
 			/* clear old command (handshake to main cpu) */
@@ -320,13 +339,13 @@ First code snippet provided by the MCU:
 
 		case 0x0002:
 		{
-/*			int param1 = mcu_ram[calc3_mcu_command_offset + 1]; */
-/*			int param2 = mcu_ram[calc3_mcu_command_offset + 2]; */
-/*			int param3 = mcu_ram[calc3_mcu_command_offset + 3]; */
-/*			int param4 = mcu_ram[calc3_mcu_command_offset + 4]; */
-/*			int param5 = mcu_ram[calc3_mcu_command_offset + 5]; */
-/*			int param6 = mcu_ram[calc3_mcu_command_offset + 6]; */
-/*			int param7 = mcu_ram[calc3_mcu_command_offset + 7]; */
+/*          int param1 = mcu_ram[calc3_mcu_command_offset + 1]; */
+/*          int param2 = mcu_ram[calc3_mcu_command_offset + 2]; */
+/*          int param3 = mcu_ram[calc3_mcu_command_offset + 3]; */
+/*          int param4 = mcu_ram[calc3_mcu_command_offset + 4]; */
+/*          int param5 = mcu_ram[calc3_mcu_command_offset + 5]; */
+/*          int param6 = mcu_ram[calc3_mcu_command_offset + 6]; */
+/*          int param7 = mcu_ram[calc3_mcu_command_offset + 7]; */
 
 			/* clear old command (handshake to main cpu) */
 			mcu_ram[calc3_mcu_command_offset] = 0x0000;
@@ -342,23 +361,23 @@ First code snippet provided by the MCU:
 
 
 /***************************************************************************
-								TOYBOX MCU:
+                                TOYBOX MCU:
 
-								Bonk's Adventure
-								Blood Warrior
-								Great 1000 Miles Rally
-								...
+                                Bonk's Adventure
+                                Blood Warrior
+                                Great 1000 Miles Rally
+                                ...
 ***************************************************************************/
 /*
 ---------------------------------------------------------------------------
-								TOYBOX
+                                TOYBOX
 
-94	Bonk's Adventure			TOYBOX?		       TBSOP01
-94	Blood Warrior				TOYBOX?		       TBS0P01 452 9339PK001
-94	Great 1000 Miles Rally		TOYBOX													"MM0525-TOYBOX199","USMM0713-TB1994 "
-95	Great 1000 Miles Rally 2	TOYBOX		KANEKO TBSOP02 454 9451MK002 (74 pin PQFP)	"USMM0713-TB1994 "
-95  Jackie Chan					TOYBOX													"USMM0713-TB1994 "
-95  Gals Panic 3				TOYBOX?		       TBSOP01
+94  Bonk's Adventure            TOYBOX?            TBSOP01
+94  Blood Warrior               TOYBOX?            TBS0P01 452 9339PK001
+94  Great 1000 Miles Rally      TOYBOX                                                  "MM0525-TOYBOX199","USMM0713-TB1994 "
+95  Great 1000 Miles Rally 2    TOYBOX      KANEKO TBSOP02 454 9451MK002 (74 pin PQFP)  "USMM0713-TB1994 "
+95  Jackie Chan                 TOYBOX                                                  "USMM0713-TB1994 "
+95  Gals Panic 3                TOYBOX?            TBSOP01
 ---------------------------------------------------------------------------
 
 All the considerations are based on the analysis of jchan, and to a fewer extent galpani3, and make references to the current driver sources:
@@ -368,26 +387,26 @@ MCU triggering:
 
 the 4 JCHAN_MCU_COM_W(...) are in fact 2 groups:
 
-AM_RANGE(0x330000, 0x330001) AM_WRITE(jchan_mcu_com0_w)	// _[ these 2 are set to 0xFFFF
-AM_RANGE(0x340000, 0x340001) AM_WRITE(jchan_mcu_com1_w)	//  [ for MCU to execute cmd
+AM_RANGE(0x330000, 0x330001) AM_WRITE(jchan_mcu_com0_w) // _[ these 2 are set to 0xFFFF
+AM_RANGE(0x340000, 0x340001) AM_WRITE(jchan_mcu_com1_w) //  [ for MCU to execute cmd
 
-AM_RANGE(0x350000, 0x350001) AM_WRITE(jchan_mcu_com2_w)	// _[ these 2 are set to 0xFFFF
-AM_RANGE(0x360000, 0x360001) AM_WRITE(jchan_mcu_com3_w)	//  [ for MCU to return its status
+AM_RANGE(0x350000, 0x350001) AM_WRITE(jchan_mcu_com2_w) // _[ these 2 are set to 0xFFFF
+AM_RANGE(0x360000, 0x360001) AM_WRITE(jchan_mcu_com3_w) //  [ for MCU to return its status
 
 
 MCU parameters:
 ---------------
 
-mcu_command = mcu_ram[0x0010/2];	// command nb
-mcu_offset  = mcu_ram[0x0012/2]/2;	// offset in shared RAM where MCU will write
-mcu_subcmd  = mcu_ram[0x0014/2];	// sub-command parameter, happens only for command #4
+mcu_command = mcu_ram[0x0010/2];    // command nb
+mcu_offset  = mcu_ram[0x0012/2]/2;  // offset in shared RAM where MCU will write
+mcu_subcmd  = mcu_ram[0x0014/2];    // sub-command parameter, happens only for command #4
 
 
-	the only MCU commands found in program code are:
-	- 0x04: protection: provide data (see below) and code <<<---!!!
-	- 0x03: read DSW
-	- 0x02: load game settings \ stored in ATMEL AT93C46 chip,
-	- 0x42: save game settings / 128 bytes serial EEPROM
+    the only MCU commands found in program code are:
+    - 0x04: protection: provide data (see below) and code <<<---!!!
+    - 0x03: read DSW
+    - 0x02: load game settings \ stored in ATMEL AT93C46 chip,
+    - 0x42: save game settings / 128 bytes serial EEPROM
 
 
 Current feeling of devs is that this EEPROM might also play a role in the protection scheme,
@@ -444,6 +463,7 @@ extern const struct GameDriver driver_gtmr;
 extern const struct GameDriver driver_gtmre;
 extern const struct GameDriver driver_gtmrusa;
 extern const struct GameDriver driver_gtmr2;
+extern const struct GameDriver driver_gtmr2u;
 extern const struct GameDriver driver_gtmr2a;
 
 void toybox_mcu_run(void)
@@ -462,6 +482,7 @@ void toybox_mcu_run(void)
 		 (Machine->gamedrv == &driver_gtmre)   ||
 		 (Machine->gamedrv == &driver_gtmrusa) ||
 		 (Machine->gamedrv == &driver_gtmr2)   ||
+		 (Machine->gamedrv == &driver_gtmr2u)  ||
 		 (Machine->gamedrv == &driver_gtmr2a) )
 	{
 		gtmr_mcu_run();
@@ -469,8 +490,18 @@ void toybox_mcu_run(void)
 }
 
 
+/*
+    bonkadv and bloodwar test bit 0
+*/
+READ16_HANDLER( toybox_mcu_status_r )
+{
+	logerror("CPU #%d (PC=%06X) : read MCU status\n", cpu_getactivecpu(), activecpu_get_previouspc());
+	return 0;
+}
+
+
 /***************************************************************************
-								Blood Warrior
+                                Blood Warrior
 ***************************************************************************/
 
 void bloodwar_mcu_run(void)
@@ -479,7 +510,7 @@ void bloodwar_mcu_run(void)
 	data16_t mcu_offset		=	mcu_ram[0x0012/2] / 2;
 	data16_t mcu_data		=	mcu_ram[0x0014/2];
 
-	logerror("CPU #0 PC %06X : MCU executed command: %04X %04X %04X\n",activecpu_get_pc(),mcu_command,mcu_offset*2,mcu_data);
+	logerror("CPU #0 (PC=%06X) : MCU executed command: %04X %04X %04X\n", activecpu_get_pc(), mcu_command, mcu_offset*2, mcu_data);
 
 	switch (mcu_command >> 8)
 	{
@@ -537,72 +568,57 @@ void bloodwar_mcu_run(void)
 			switch(mcu_data)
 			{
 				/* unknown data */
-				case 0x01:
-				case 0x02:
-				case 0x03:
-				case 0x04:
-				case 0x05:
-				case 0x06:
-				case 0x07:
-				case 0x08:
-				case 0x09:
-				break;
+				case 0x01: MCU_RESPONSE(bloodwar_mcu_4_01); break; /* Warrior 1 */
+				case 0x02: MCU_RESPONSE(bloodwar_mcu_4_02); break; /* Warrior 2 */
+				case 0x03: MCU_RESPONSE(bloodwar_mcu_4_03); break; /* Warrior 3 */
+				case 0x04: MCU_RESPONSE(bloodwar_mcu_4_04); break; /* Warrior 4 */
+				case 0x05: MCU_RESPONSE(bloodwar_mcu_4_05); break; /* Warrior 5 */
+				case 0x06: MCU_RESPONSE(bloodwar_mcu_4_06); break; /* Warrior 6 */
+				case 0x07: MCU_RESPONSE(bloodwar_mcu_4_07); break; /* Warrior 7 */
+				case 0x08: MCU_RESPONSE(bloodwar_mcu_4_08); break; /* Warrior 8 */
+				case 0x09: MCU_RESPONSE(bloodwar_mcu_4_09); break; /* Warrior 9 */
 
 				/* palette data */
-				case 0x0a:
-				case 0x0b:
-				case 0x0c:
-				case 0x0d:
-				case 0x0e:
-				case 0x0f:
-				case 0x10:
-				case 0x11:
-				case 0x12:
-				case 0x13:
-				case 0x14:
-				case 0x15:
-				case 0x16:
-				case 0x17:
-				case 0x18:
-				case 0x19:
-				{
-					mcu_ram[mcu_offset + 0] = 0x0001;	/* number of palettes (>=1) */
-					/* palette data follows (each palette is 0x200 byes long) */
-					mcu_ram[mcu_offset + 1] = 0x8000;	/* a negative word will end the palette */
-				}
-				break;
+				case 0x0a: MCU_RESPONSE(bloodwar_mcu_4_0a); break; /* Warrior 1 Player 1 */
+				case 0x0b: MCU_RESPONSE(bloodwar_mcu_4_0b); break; /* Warrior 1 Player 2 */
+				case 0x0c: MCU_RESPONSE(bloodwar_mcu_4_0c); break; /* Warrior 5 Player 1 */
+				case 0x0d: MCU_RESPONSE(bloodwar_mcu_4_0d); break; /* Warrior 5 Player 2 */
+				case 0x0e: MCU_RESPONSE(bloodwar_mcu_4_0e); break; /* Warrior 4 Player 2 */
+				case 0x0f: MCU_RESPONSE(bloodwar_mcu_4_0f); break; /* Warrior 4 Player 1 */
+				case 0x10: MCU_RESPONSE(bloodwar_mcu_4_10); break; /* Warrior 6 Player 1 */
+				case 0x11: MCU_RESPONSE(bloodwar_mcu_4_11); break; /* Warrior 6 Player 2 */
+				case 0x12: MCU_RESPONSE(bloodwar_mcu_4_12); break; /* Warrior 9 Player 1 */
+				case 0x13: MCU_RESPONSE(bloodwar_mcu_4_13); break; /* Warrior 9 Player 2 */
+				case 0x14: MCU_RESPONSE(bloodwar_mcu_4_14); break; /* Warrior 7 Player 1 */
+				case 0x15: MCU_RESPONSE(bloodwar_mcu_4_15); break; /* Warrior 7 Player 2 */
+				case 0x16: MCU_RESPONSE(bloodwar_mcu_4_16); break; /* Warrior 8 Player 1 */
+				case 0x17: MCU_RESPONSE(bloodwar_mcu_4_17); break; /* Warrior 8 Player 2 */
+				case 0x18: MCU_RESPONSE(bloodwar_mcu_4_18); break; /* Warrior 2 Player 2 */
+				case 0x19: MCU_RESPONSE(bloodwar_mcu_4_19); break; /* Warrior 2 Player 1 */
+				case 0x1a: MCU_RESPONSE(bloodwar_mcu_4_1a); break; /* Warrior 3 Player 1 */
+				case 0x1b: MCU_RESPONSE(bloodwar_mcu_4_1b); break; /* Warrior 3 Player 2 */
 
 				/* tilemap data */
-				case 0x1c:
-				case 0x1d:
-				case 0x1e:
-				case 0x1f:
-				case 0x20:
-				case 0x21:
-				case 0x22:
-				case 0x23:
-				case 0x24:
-				{
-					/* tile data (ff means no tiles) followed by routine index */
-					mcu_ram[mcu_offset + 0] = 0xff00;
-				}
-				break;
+				case 0x1c: MCU_RESPONSE(bloodwar_mcu_4_1c); break; /* Warrior 8 */
+				case 0x1d: MCU_RESPONSE(bloodwar_mcu_4_1d); break; /* Warrior 2 */
+				case 0x1e: MCU_RESPONSE(bloodwar_mcu_4_1e); break; /* Warrior 3 */
+				case 0x1f: MCU_RESPONSE(bloodwar_mcu_4_1f); break; /* Warrior 5 */
+				case 0x20: MCU_RESPONSE(bloodwar_mcu_4_20); break; /* Warrior 4 */
+				case 0x21: MCU_RESPONSE(bloodwar_mcu_4_21); break; /* Warrior 6 */
+				case 0x22: MCU_RESPONSE(bloodwar_mcu_4_22); break; /* Warrior 1 */
+				case 0x23: MCU_RESPONSE(bloodwar_mcu_4_23); break; /* Warrior 9 */
+				case 0x24: MCU_RESPONSE(bloodwar_mcu_4_24); break; /* Warrior 7 */
 
-				/* unknown long */
-				case 0x25:
-				case 0x26:
-				case 0x27:
-				case 0x28:
-				case 0x29:
-				case 0x2a:
-				case 0x2b:
-				case 0x2c:
-				case 0x2d:
-				{
-					mcu_ram[mcu_offset + 0] = 0x0000;
-					mcu_ram[mcu_offset + 1] = 0x0000;
-				}
-				break;
+				/* fighter data: pointers to ROM data */
+				case 0x25: MCU_RESPONSE(bloodwar_mcu_4_25); break; /* Warrior 1 */
+				case 0x26: MCU_RESPONSE(bloodwar_mcu_4_26); break; /* Warrior 2 */
+				case 0x27: MCU_RESPONSE(bloodwar_mcu_4_27); break; /* Warrior 3 */
+				case 0x28: MCU_RESPONSE(bloodwar_mcu_4_28); break; /* Warrior 4 */
+				case 0x29: MCU_RESPONSE(bloodwar_mcu_4_29); break; /* Warrior 5 */
+				case 0x2a: MCU_RESPONSE(bloodwar_mcu_4_2a); break; /* Warrior 6 */
+				case 0x2b: MCU_RESPONSE(bloodwar_mcu_4_2b); break; /* Warrior 7 */
+				case 0x2c: MCU_RESPONSE(bloodwar_mcu_4_2c); break; /* Warrior 8 */
+				case 0x2d: MCU_RESPONSE(bloodwar_mcu_4_2d); break; /* Warrior 9 */
 
 				default:
 					logerror("UNKNOWN PARAMETER %02X TO COMMAND 4\n",mcu_data);
@@ -617,7 +633,7 @@ void bloodwar_mcu_run(void)
 }
 
 /***************************************************************************
-								Bonk's Adventure
+                                Bonk's Adventure
 ***************************************************************************/
 
 void bonkadv_mcu_run(void)
@@ -639,7 +655,7 @@ void bonkadv_mcu_run(void)
 			}
 			else
 				memcpy(&mcu_ram[mcu_offset],memory_region(REGION_USER1),128);
-			logerror("PC=%06X : MCU executed command: %04X %04X (load NVRAM settings)\n",activecpu_get_pc(),mcu_command,mcu_offset*2);
+			logerror("PC=%06X : MCU executed command: %04X %04X (load NVRAM settings)\n", activecpu_get_pc(), mcu_command, mcu_offset*2);
 		}
 		break;
 
@@ -651,90 +667,90 @@ void bonkadv_mcu_run(void)
 				mame_fwrite(f,&mcu_ram[mcu_offset], 128);
 				mame_fclose(f);
 			}
-			logerror("PC=%06X : MCU executed command: %04X %04X (save NVRAM settings)\n",activecpu_get_pc(),mcu_command,mcu_offset*2);
+			logerror("PC=%06X : MCU executed command: %04X %04X (save NVRAM settings)\n", activecpu_get_pc(), mcu_command, mcu_offset*2);
 		}
 		break;
 
 		case 0x43:	/* Restore Default Data Set */
 		{
 			memcpy(&mcu_ram[mcu_offset],memory_region(REGION_USER1),128);
-			logerror("PC=%06X : MCU executed command: %04X %04X (restore default settings)\n",activecpu_get_pc(),mcu_command,mcu_offset*2);
+			logerror("PC=%06X : MCU executed command: %04X %04X (restore default settings)\n", activecpu_get_pc(), mcu_command, mcu_offset*2);
 		}
 		break;
 
 		case 0x03:	/* DSW */
 		{
 			mcu_ram[mcu_offset] = readinputport(4);
-			logerror("PC=%06X : MCU executed command: %04X %04X (read DSW)\n",activecpu_get_pc(),mcu_command,mcu_offset*2);
+			logerror("PC=%06X : MCU executed command: %04X %04X (read DSW)\n", activecpu_get_pc(), mcu_command, mcu_offset*2);
 		}
 		break;
 
 		case 0x04:	/* Protection */
 		{
-			logerror("PC=%06X : MCU executed command: %04X %04X %04X",activecpu_get_pc(),mcu_command,mcu_offset*2,mcu_data);
+			logerror("PC=%06X : MCU executed command: %04X %04X %04X\n", activecpu_get_pc(), mcu_command, mcu_offset*2, mcu_data);
 
 			switch(mcu_data)
 			{
 				/* static, in this order, at boot/reset */
-				case 0x34: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_34,sizeof(bonkadv_mcu_4_34)); logerror("\n"); break;
-				case 0x30: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_30,sizeof(bonkadv_mcu_4_30)); logerror("\n"); break;
-				case 0x31: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_31,sizeof(bonkadv_mcu_4_31)); logerror("\n"); break;
-				case 0x32: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_32,sizeof(bonkadv_mcu_4_32)); logerror("\n"); break;
-				case 0x33: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_33,sizeof(bonkadv_mcu_4_33)); logerror("\n"); break;
+				case 0x34: MCU_RESPONSE(bonkadv_mcu_4_34); break;
+				case 0x30: MCU_RESPONSE(bonkadv_mcu_4_30); break;
+				case 0x31: MCU_RESPONSE(bonkadv_mcu_4_31); break;
+				case 0x32: MCU_RESPONSE(bonkadv_mcu_4_32); break;
+				case 0x33: MCU_RESPONSE(bonkadv_mcu_4_33); break;
 
 				/* dynamic, per-level (29), in level order */
-				case 0x00: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_00,sizeof(bonkadv_mcu_4_00)); logerror("\n"); break;
-				case 0x02: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_02,sizeof(bonkadv_mcu_4_02)); logerror("\n"); break;
-				case 0x01: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_01,sizeof(bonkadv_mcu_4_01)); logerror("\n"); break;
-				case 0x05: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_05,sizeof(bonkadv_mcu_4_05)); logerror("\n"); break;
-				case 0x07: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_07,sizeof(bonkadv_mcu_4_07)); logerror("\n"); break;
-				case 0x06: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_06,sizeof(bonkadv_mcu_4_06)); logerror("\n"); break;
-				case 0x09: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_09,sizeof(bonkadv_mcu_4_09)); logerror("\n"); break;
-				case 0x0D: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_0D,sizeof(bonkadv_mcu_4_0D)); logerror("\n"); break;
-				case 0x03: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_03,sizeof(bonkadv_mcu_4_03)); logerror("\n"); break;
-				case 0x08: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_08,sizeof(bonkadv_mcu_4_08)); logerror("\n"); break;
-				case 0x04: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_04,sizeof(bonkadv_mcu_4_04)); logerror("\n"); break;
-				case 0x0C: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_0C,sizeof(bonkadv_mcu_4_0C)); logerror("\n"); break;
-				case 0x0A: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_0A,sizeof(bonkadv_mcu_4_0A)); logerror("\n"); break;
-				case 0x0B: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_0B,sizeof(bonkadv_mcu_4_0B)); logerror("\n"); break;
-				case 0x10: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_10,sizeof(bonkadv_mcu_4_10)); logerror("\n"); break;
-				case 0x0E: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_0E,sizeof(bonkadv_mcu_4_0E)); logerror("\n"); break;
-				case 0x13: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_13,sizeof(bonkadv_mcu_4_13)); logerror("\n"); break;
-				case 0x0F: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_0F,sizeof(bonkadv_mcu_4_0F)); logerror("\n"); break;
-				case 0x11: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_11,sizeof(bonkadv_mcu_4_11)); logerror("\n"); break;
-				case 0x14: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_14,sizeof(bonkadv_mcu_4_14)); logerror("\n"); break;
-				case 0x12: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_12,sizeof(bonkadv_mcu_4_12)); logerror("\n"); break;
-				case 0x17: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_17,sizeof(bonkadv_mcu_4_17)); logerror("\n"); break;
-				case 0x1A: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_1A,sizeof(bonkadv_mcu_4_1A)); logerror("\n"); break;
-				case 0x15: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_15,sizeof(bonkadv_mcu_4_15)); logerror("\n"); break;
-				case 0x18: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_18,sizeof(bonkadv_mcu_4_18)); logerror("\n"); break;
-				case 0x16: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_16,sizeof(bonkadv_mcu_4_16)); logerror("\n"); break;
-				case 0x19: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_19,sizeof(bonkadv_mcu_4_19)); logerror("\n"); break;
-				case 0x1B: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_1B,sizeof(bonkadv_mcu_4_1B)); logerror("\n"); break;
-				case 0x1C: memcpy(&mcu_ram[mcu_offset],bonkadv_mcu_4_1C,sizeof(bonkadv_mcu_4_1C)); logerror("\n"); break;
+				case 0x00: MCU_RESPONSE(bonkadv_mcu_4_00); break;
+				case 0x02: MCU_RESPONSE(bonkadv_mcu_4_02); break;
+				case 0x01: MCU_RESPONSE(bonkadv_mcu_4_01); break;
+				case 0x05: MCU_RESPONSE(bonkadv_mcu_4_05); break;
+				case 0x07: MCU_RESPONSE(bonkadv_mcu_4_07); break;
+				case 0x06: MCU_RESPONSE(bonkadv_mcu_4_06); break;
+				case 0x09: MCU_RESPONSE(bonkadv_mcu_4_09); break;
+				case 0x0D: MCU_RESPONSE(bonkadv_mcu_4_0D); break;
+				case 0x03: MCU_RESPONSE(bonkadv_mcu_4_03); break;
+				case 0x08: MCU_RESPONSE(bonkadv_mcu_4_08); break;
+				case 0x04: MCU_RESPONSE(bonkadv_mcu_4_04); break;
+				case 0x0C: MCU_RESPONSE(bonkadv_mcu_4_0C); break;
+				case 0x0A: MCU_RESPONSE(bonkadv_mcu_4_0A); break;
+				case 0x0B: MCU_RESPONSE(bonkadv_mcu_4_0B); break;
+				case 0x10: MCU_RESPONSE(bonkadv_mcu_4_10); break;
+				case 0x0E: MCU_RESPONSE(bonkadv_mcu_4_0E); break;
+				case 0x13: MCU_RESPONSE(bonkadv_mcu_4_13); break;
+				case 0x0F: MCU_RESPONSE(bonkadv_mcu_4_0F); break;
+				case 0x11: MCU_RESPONSE(bonkadv_mcu_4_11); break;
+				case 0x14: MCU_RESPONSE(bonkadv_mcu_4_14); break;
+				case 0x12: MCU_RESPONSE(bonkadv_mcu_4_12); break;
+				case 0x17: MCU_RESPONSE(bonkadv_mcu_4_17); break;
+				case 0x1A: MCU_RESPONSE(bonkadv_mcu_4_1A); break;
+				case 0x15: MCU_RESPONSE(bonkadv_mcu_4_15); break;
+				case 0x18: MCU_RESPONSE(bonkadv_mcu_4_18); break;
+				case 0x16: MCU_RESPONSE(bonkadv_mcu_4_16); break;
+				case 0x19: MCU_RESPONSE(bonkadv_mcu_4_19); break;
+				case 0x1B: MCU_RESPONSE(bonkadv_mcu_4_1B); break;
+				case 0x1C: MCU_RESPONSE(bonkadv_mcu_4_1C); break;
 
 				default:
-					logerror(" (UNKNOWN PARAMETER %02X)\n",mcu_data);
+					logerror(" (UNKNOWN PARAMETER %02X)\n", mcu_data);
 			}
 		}
 		break;
 
 		default:
-			logerror("PC=%06X : MCU executed command: %04X %04X %04X (UNKNOWN COMMAND)\n",activecpu_get_pc(),mcu_command,mcu_offset*2,mcu_data);
+			logerror("PC=%06X : MCU executed command: %04X %04X %04X (UNKNOWN COMMAND)\n", activecpu_get_pc(), mcu_command, mcu_offset*2, mcu_data);
 		break;
 	}
 }
 
 /***************************************************************************
-							Great 1000 Miles Rally
+                            Great 1000 Miles Rally
 ***************************************************************************/
 
 /*
-	MCU Tasks:
+    MCU Tasks:
 
-	- Write and ID string to shared RAM.
-	- Access the EEPROM
-	- Read the DSWs
+    - Write and ID string to shared RAM.
+    - Access the EEPROM
+    - Read the DSWs
 */
 
 void gtmr_mcu_run(void)
@@ -743,7 +759,7 @@ void gtmr_mcu_run(void)
 	data16_t mcu_offset		=	mcu_ram[0x0012/2] / 2;
 	data16_t mcu_data		=	mcu_ram[0x0014/2];
 
-	logerror("CPU #0 PC %06X : MCU executed command: %04X %04X %04X\n",activecpu_get_pc(),mcu_command,mcu_offset*2,mcu_data);
+	logerror("CPU #0 PC %06X : MCU executed command: %04X %04X %04X\n", activecpu_get_pc(), mcu_command, mcu_offset*2, mcu_data);
 
 	switch (mcu_command >> 8)
 	{
@@ -793,6 +809,7 @@ void gtmr_mcu_run(void)
 			else if ( (Machine->gamedrv == &driver_gtmre)  ||
 					  (Machine->gamedrv == &driver_gtmrusa) ||
 					  (Machine->gamedrv == &driver_gtmr2) ||
+					  (Machine->gamedrv == &driver_gtmr2u) ||
 					  (Machine->gamedrv == &driver_gtmr2a) )
 
 			{
