@@ -1,3 +1,8 @@
+/***************************************************************************
+
+    TOYBOX MCU data for Bonk's Adventure
+
+***************************************************************************/
 
 /* bonkadv_mcu_4_33 has 32 zeroed bytes every 64 bytes: it has been verified */
 /* that these zeroes are effectively written by the MCU */
@@ -301,3 +306,71 @@ static data16_t bonkadv_mcu_4_16[] = { 0x0000,0x02F0,0x0000,0x0100,0x0430,0x0100
 static data16_t bonkadv_mcu_4_19[] = { 0x0000,0x03A0,0x0000,0x0100,0x04E0,0x0100 };
 static data16_t bonkadv_mcu_4_1B[] = { 0x0000,0x0460,0x0000,0x0100,0x05A0,0x0100 };
 static data16_t bonkadv_mcu_4_1C[] = { 0x0000,0x02C0,0x0000,0x0100,0x0400,0x0100 };
+
+
+/***************************************************************************
+
+    TOYBOX MCU data for Blood Warrior
+
+***************************************************************************/
+
+/* --- unknown data --- */
+static data16_t bloodwar_mcu_4_01[] = {0x0000}; /* Warrior 1 */
+static data16_t bloodwar_mcu_4_02[] = {0x0000}; /* Warrior 2 */
+static data16_t bloodwar_mcu_4_03[] = {0x0000}; /* Warrior 3 */
+static data16_t bloodwar_mcu_4_04[] = {0x0000}; /* Warrior 4 */
+static data16_t bloodwar_mcu_4_05[] = {0x0000}; /* Warrior 5 */
+static data16_t bloodwar_mcu_4_06[] = {0x0000}; /* Warrior 6 */
+static data16_t bloodwar_mcu_4_07[] = {0x0000}; /* Warrior 7 */
+static data16_t bloodwar_mcu_4_08[] = {0x0000}; /* Warrior 8 */
+static data16_t bloodwar_mcu_4_09[] = {0x0000}; /* Warrior 9 */
+
+
+/* --- palette data --- */
+/*  number of palettes (>=1) */
+/*  palette data follows (each palette is 0x200 bytes long) */
+/*  a negative word will end the palette */
+static data16_t bloodwar_mcu_4_0a[] = {0x0001,0x8000}; /* Warrior 1 Player 1 */
+static data16_t bloodwar_mcu_4_0b[] = {0x0001,0x8000}; /* Warrior 1 Player 2 */
+static data16_t bloodwar_mcu_4_0c[] = {0x0001,0x8000}; /* Warrior 5 Player 1 */
+static data16_t bloodwar_mcu_4_0d[] = {0x0001,0x8000}; /* Warrior 5 Player 2 */
+static data16_t bloodwar_mcu_4_0e[] = {0x0001,0x8000}; /* Warrior 4 Player 2 */
+static data16_t bloodwar_mcu_4_0f[] = {0x0001,0x8000}; /* Warrior 4 Player 1 */
+static data16_t bloodwar_mcu_4_10[] = {0x0001,0x8000}; /* Warrior 6 Player 1 */
+static data16_t bloodwar_mcu_4_11[] = {0x0001,0x8000}; /* Warrior 6 Player 2 */
+static data16_t bloodwar_mcu_4_12[] = {0x0001,0x8000}; /* Warrior 9 Player 1 */
+static data16_t bloodwar_mcu_4_13[] = {0x0001,0x8000}; /* Warrior 9 Player 2 */
+static data16_t bloodwar_mcu_4_14[] = {0x0001,0x8000}; /* Warrior 7 Player 1 */
+static data16_t bloodwar_mcu_4_15[] = {0x0001,0x8000}; /* Warrior 7 Player 2 */
+static data16_t bloodwar_mcu_4_16[] = {0x0001,0x8000}; /* Warrior 8 Player 1 */
+static data16_t bloodwar_mcu_4_17[] = {0x0001,0x8000}; /* Warrior 8 Player 2 */
+static data16_t bloodwar_mcu_4_18[] = {0x0001,0x8000}; /* Warrior 2 Player 2 */
+static data16_t bloodwar_mcu_4_19[] = {0x0001,0x8000}; /* Warrior 2 Player 1 */
+static data16_t bloodwar_mcu_4_1a[] = {0x0001,0x8000}; /* Warrior 3 Player 1 */
+static data16_t bloodwar_mcu_4_1b[] = {0x0001,0x8000}; /* Warrior 3 Player 2 */
+
+
+/* --- tilemap data --- */
+/*  tile data (ff means no tiles) followed by routine index */
+static data16_t bloodwar_mcu_4_1c[] = {0xff00}; /* Warrior 8 */
+static data16_t bloodwar_mcu_4_1d[] = {0xff00}; /* Warrior 2 */
+static data16_t bloodwar_mcu_4_1e[] = {0xff00}; /* Warrior 3 */
+static data16_t bloodwar_mcu_4_1f[] = {0xff00}; /* Warrior 5 */
+static data16_t bloodwar_mcu_4_20[] = {0xff00}; /* Warrior 4 */
+static data16_t bloodwar_mcu_4_21[] = {0xff00}; /* Warrior 6 */
+static data16_t bloodwar_mcu_4_22[] = {0xff00}; /* Warrior 1 */
+static data16_t bloodwar_mcu_4_23[] = {0xff00}; /* Warrior 9 */
+static data16_t bloodwar_mcu_4_24[] = {0xff00}; /* Warrior 7 */
+
+
+/* --- fighter data: pointers to ROM data --- */
+static data16_t bloodwar_mcu_4_25[] = {0x0000,0x0000}; /* Warrior 1 */
+static data16_t bloodwar_mcu_4_26[] = {0x0000,0x0000}; /* Warrior 2 */
+static data16_t bloodwar_mcu_4_27[] = {0x0000,0x0000}; /* Warrior 3 */
+static data16_t bloodwar_mcu_4_28[] = {0x0000,0x0000}; /* Warrior 4 */
+static data16_t bloodwar_mcu_4_29[] = {0x0000,0x0000}; /* Warrior 5 */
+static data16_t bloodwar_mcu_4_2a[] = {0x0000,0x0000}; /* Warrior 6 */
+static data16_t bloodwar_mcu_4_2b[] = {0x0000,0x0000}; /* Warrior 7 */
+static data16_t bloodwar_mcu_4_2c[] = {0x0000,0x0000}; /* Warrior 8 */
+static data16_t bloodwar_mcu_4_2d[] = {0x0000,0x0000}; /* Warrior 9 */
+
