@@ -482,19 +482,19 @@ void K053936GP_1_zoom_draw(struct mame_bitmap *bitmap, const struct rectangle *c
 
 
 /*
-	Parameter Notes
-	---------------
-	clip    : *caller must supply a pointer to target clip rectangle
-	alpha   : 0 = invisible, 255 = solid
-	drawmode:
-		0 = all pens solid
-		1 = solid pens only
-		2 = all pens solid with alpha blending
-		3 = solid pens only with alpha blending
-		4 = shadow pens only
-		5 = all pens shadow
-	zcode   : 0 = closest, 255 = furthest (pixel z-depth), -1 = disable depth buffers and shadows
-	pri     : 0 = topmost, 255 = backmost (pixel priority)
+    Parameter Notes
+    ---------------
+    clip    : *caller must supply a pointer to target clip rectangle
+    alpha   : 0 = invisible, 255 = solid
+    drawmode:
+        0 = all pens solid
+        1 = solid pens only
+        2 = all pens solid with alpha blending
+        3 = solid pens only with alpha blending
+        4 = shadow pens only
+        5 = all pens shadow
+    zcode   : 0 = closest, 255 = furthest (pixel z-depth), -1 = disable depth buffers and shadows
+    pri     : 0 = topmost, 255 = backmost (pixel priority)
 */
 
 INLINE void zdrawgfxzoom32GP( struct mame_bitmap *bitmap, const struct GfxElement *gfx, const struct rectangle *cliprect,
@@ -632,298 +632,307 @@ INLINE void zdrawgfxzoom32GP( struct mame_bitmap *bitmap, const struct GfxElemen
 	dst_ptr += dst_y * dst_pitch + dst_x + dst_w;
 	dst_w = -dst_w;
 
-	if (!nozoom) goto DRAWZOOM;
-
-	src_ptr = src_base + (src_fby<<4) + src_fbx;
-	src_fdy = src_fdx * dst_w + src_pitch;
-	ecx = dst_w;
-
-	if (zcode < 0) /* no shadow and z-buffering */
+	if (!nozoom)
 	{
-		do {
-			do {
-				eax = *src_ptr;
-				src_ptr += src_fdx;
-				if (!eax || eax >= shdpen) continue;
-				dst_ptr[ecx] = pal_base[eax];
-			}
-			while (++ecx);
+		ecx = src_fby;   src_fby += src_fdy;
+		ecx >>= FP;      src_fx = src_fbx;
+		src_x = src_fbx; src_fx += src_fdx;
+		ecx <<= 4;       src_ptr = src_base;
+		src_x >>= FP;    src_ptr += ecx;
+		ecx = dst_w;
 
-			src_ptr += src_fdy;
-			dst_ptr += GX_BMPPW;
-			ecx = dst_w;
+		if (zcode < 0) /* no shadow and z-buffering */
+		{
+			do {
+				do {
+					eax = src_ptr[src_x];
+					src_x = src_fx;
+					src_fx += src_fdx;
+					src_x >>= FP;
+					if (!eax || eax >= shdpen) continue;
+					dst_ptr [ecx] = pal_base[eax];
+				}
+				while (++ecx);
+
+				ecx = src_fby;   src_fby += src_fdy;
+				dst_ptr += GX_BMPPW;
+				ecx >>= FP;      src_fx = src_fbx;
+				src_x = src_fbx; src_fx += src_fdx;
+				ecx <<= 4;       src_ptr = src_base;
+				src_x >>= FP;    src_ptr += ecx;
+				ecx = dst_w;
+			}
+			while (--dst_h);
 		}
-		while (--dst_h);
-	}
-	else if (drawmode == 0) /* all pens solid */
+		else
+		{
+			switch (drawmode)
+			{
+				case 0:	/* all pens solid */
+					do {
+						do {
+							eax = src_ptr[src_x];
+							src_x = src_fx;
+							src_fx += src_fdx;
+							src_x >>= FP;
+							if (!eax || ozbuf_ptr[ecx] < z8) continue;
+							eax = pal_base[eax];
+							ozbuf_ptr[ecx] = z8;
+							dst_ptr [ecx] = eax;
+						}
+						while (++ecx);
+
+						ecx = src_fby;   src_fby += src_fdy;
+						ozbuf_ptr += GX_ZBUFW;
+						dst_ptr += GX_BMPPW;
+						ecx >>= FP;      src_fx = src_fbx;
+						src_x = src_fbx; src_fx += src_fdx;
+						ecx <<= 4;       src_ptr = src_base;
+						src_x >>= FP;    src_ptr += ecx;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
+
+				case 1: /* solid pens only */
+					do {
+						do {
+							eax = src_ptr[src_x];
+							src_x = src_fx;
+							src_fx += src_fdx;
+							src_x >>= FP;
+							if (!eax || eax >= shdpen || ozbuf_ptr[ecx] < z8) continue;
+							eax = pal_base[eax];
+							ozbuf_ptr[ecx] = z8;
+							dst_ptr [ecx] = eax;
+						}
+						while (++ecx);
+
+						ecx = src_fby;   src_fby += src_fdy;
+						ozbuf_ptr += GX_ZBUFW;
+						dst_ptr += GX_BMPPW;
+						ecx >>= FP;      src_fx = src_fbx;
+						src_x = src_fbx; src_fx += src_fdx;
+						ecx <<= 4;       src_ptr = src_base;
+						src_x >>= FP;    src_ptr += ecx;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
+
+				case 2: /* all pens solid with alpha blending */
+					do {
+						do {
+							eax = src_ptr[src_x];
+							src_x = src_fx;
+							src_fx += src_fdx;
+							src_x >>= FP;
+							if (!eax || ozbuf_ptr[ecx] < z8) continue;
+							ozbuf_ptr[ecx] = z8;
+
+							BLEND32_MACRO
+						}
+						while (++ecx);
+
+						ecx = src_fby;   src_fby += src_fdy;
+						ozbuf_ptr += GX_ZBUFW;
+						dst_ptr += GX_BMPPW;
+						ecx >>= FP;      src_fx = src_fbx;
+						src_x = src_fbx; src_fx += src_fdx;
+						ecx <<= 4;       src_ptr = src_base;
+						src_x >>= FP;    src_ptr += ecx;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
+
+				case 3: /* solid pens only with alpha blending */
+					do {
+						do {
+							eax = src_ptr[src_x];
+							src_x = src_fx;
+							src_fx += src_fdx;
+							src_x >>= FP;
+							if (!eax || eax >= shdpen || ozbuf_ptr[ecx] < z8) continue;
+							ozbuf_ptr[ecx] = z8;
+
+							BLEND32_MACRO
+						}
+						while (++ecx);
+
+						ecx = src_fby;   src_fby += src_fdy;
+						ozbuf_ptr += GX_ZBUFW;
+						dst_ptr += GX_BMPPW;
+						ecx >>= FP;      src_fx = src_fbx;
+						src_x = src_fbx; src_fx += src_fdx;
+						ecx <<= 4;       src_ptr = src_base;
+						src_x >>= FP;    src_ptr += ecx;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
+
+				case 4: /* shadow pens only */
+					do {
+						do {
+							eax = src_ptr[src_x];
+							src_x = src_fx;
+							src_fx += src_fdx;
+							src_x >>= FP;
+							if (eax < shdpen || szbuf_ptr[ecx*2] < z8 || szbuf_ptr[ecx*2+1] <= p8) continue;
+							eax = dst_ptr[ecx];
+							szbuf_ptr[ecx*2] = z8;
+							szbuf_ptr[ecx*2+1] = p8;
+							eax = (eax>>9&0x7c00) | (eax>>6&0x03e0) | (eax>>3&0x001f);
+							dst_ptr[ecx] = shd_base[eax];
+						}
+						while (++ecx);
+
+						ecx = src_fby;   src_fby += src_fdy;
+						szbuf_ptr += (GX_ZBUFW<<1);
+						dst_ptr += GX_BMPPW;
+						ecx >>= FP;      src_fx = src_fbx;
+						src_x = src_fbx; src_fx += src_fdx;
+						ecx <<= 4;       src_ptr = src_base;
+						src_x >>= FP;    src_ptr += ecx;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
+			}	/* switch (drawmode) */
+		}	/* if (zcode < 0) */
+	}	/* if (!nozoom) */
+	else
 	{
-		do {
+		src_ptr = src_base + (src_fby<<4) + src_fbx;
+		src_fdy = src_fdx * dst_w + src_pitch;
+		ecx = dst_w;
+
+		if (zcode < 0) /* no shadow and z-buffering */
+		{
 			do {
-				eax = *src_ptr;
-				src_ptr += src_fdx;
-				if (!eax || ozbuf_ptr[ecx] < z8) continue;
-				eax = pal_base[eax];
-				ozbuf_ptr[ecx] = z8;
-				dst_ptr[ecx] = eax;
+				do {
+					eax = *src_ptr;
+					src_ptr += src_fdx;
+					if (!eax || eax >= shdpen) continue;
+					dst_ptr[ecx] = pal_base[eax];
+				}
+				while (++ecx);
+
+				src_ptr += src_fdy;
+				dst_ptr += GX_BMPPW;
+				ecx = dst_w;
 			}
-			while (++ecx);
-
-			src_ptr += src_fdy;
-			ozbuf_ptr += GX_ZBUFW;
-			dst_ptr += GX_BMPPW;
-			ecx = dst_w;
+			while (--dst_h);
 		}
-		while (--dst_h);
-	}
-	else if (drawmode == 1) /* solid pens only */
-	{
-		do {
-			do {
-				eax = *src_ptr;
-				src_ptr += src_fdx;
-				if (!eax || eax >= shdpen || ozbuf_ptr[ecx] < z8) continue;
-				eax = pal_base[eax];
-				ozbuf_ptr[ecx] = z8;
-				dst_ptr[ecx] = eax;
+		else
+		{
+			switch (drawmode)
+			{
+				case 0: /* all pens solid */
+					do {
+						do {
+							eax = *src_ptr;
+							src_ptr += src_fdx;
+							if (!eax || ozbuf_ptr[ecx] < z8) continue;
+							eax = pal_base[eax];
+							ozbuf_ptr[ecx] = z8;
+							dst_ptr[ecx] = eax;
+						}
+						while (++ecx);
+
+						src_ptr += src_fdy;
+						ozbuf_ptr += GX_ZBUFW;
+						dst_ptr += GX_BMPPW;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
+
+				case 1:  /* solid pens only */
+					do {
+						do {
+							eax = *src_ptr;
+							src_ptr += src_fdx;
+							if (!eax || eax >= shdpen || ozbuf_ptr[ecx] < z8) continue;
+							eax = pal_base[eax];
+							ozbuf_ptr[ecx] = z8;
+							dst_ptr[ecx] = eax;
+						}
+						while (++ecx);
+
+						src_ptr += src_fdy;
+						ozbuf_ptr += GX_ZBUFW;
+						dst_ptr += GX_BMPPW;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
+
+				case 2: /* all pens solid with alpha blending */
+					do {
+						do {
+							eax = *src_ptr;
+							src_ptr += src_fdx;
+							if (!eax || ozbuf_ptr[ecx] < z8) continue;
+							ozbuf_ptr[ecx] = z8;
+
+							BLEND32_MACRO
+						}
+						while (++ecx);
+
+						src_ptr += src_fdy;
+						ozbuf_ptr += GX_ZBUFW;
+						dst_ptr += GX_BMPPW;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
+
+				case 3: /* solid pens only with alpha blending */
+					do {
+						do {
+							eax = *src_ptr;
+							src_ptr += src_fdx;
+							if (!eax || eax >= shdpen || ozbuf_ptr[ecx] < z8) continue;
+							ozbuf_ptr[ecx] = z8;
+
+							BLEND32_MACRO
+						}
+						while (++ecx);
+
+						src_ptr += src_fdy;
+						ozbuf_ptr += GX_ZBUFW;
+						dst_ptr += GX_BMPPW;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
+
+				case 4: /* shadow pens only */
+					do {
+						do {
+							eax = *src_ptr;
+							src_ptr += src_fdx;
+							if (eax < shdpen || szbuf_ptr[ecx*2] < z8 || szbuf_ptr[ecx*2+1] <= p8) continue;
+							eax = dst_ptr[ecx];
+							szbuf_ptr[ecx*2] = z8;
+							szbuf_ptr[ecx*2+1] = p8;
+							eax = (eax>>9&0x7c00) | (eax>>6&0x03e0) | (eax>>3&0x001f);
+							dst_ptr[ecx] = shd_base[eax];
+						}
+						while (++ecx);
+
+						src_ptr += src_fdy;
+						szbuf_ptr += (GX_ZBUFW<<1);
+						dst_ptr += GX_BMPPW;
+						ecx = dst_w;
+					}
+					while (--dst_h);
+					break;
 			}
-			while (++ecx);
-
-			src_ptr += src_fdy;
-			ozbuf_ptr += GX_ZBUFW;
-			dst_ptr += GX_BMPPW;
-			ecx = dst_w;
 		}
-		while (--dst_h);
 	}
-	else if (drawmode == 2) /* all pens solid with alpha blending */
-	{
-		do {
-			do {
-				eax = *src_ptr;
-				src_ptr += src_fdx;
-				if (!eax || ozbuf_ptr[ecx] < z8) continue;
-				ozbuf_ptr[ecx] = z8;
-
-				BLEND32_MACRO
-			}
-			while (++ecx);
-
-			src_ptr += src_fdy;
-			ozbuf_ptr += GX_ZBUFW;
-			dst_ptr += GX_BMPPW;
-			ecx = dst_w;
-		}
-		while (--dst_h);
-	}
-	else if (drawmode == 3) /* solid pens only with alpha blending */
-	{
-		do {
-			do {
-				eax = *src_ptr;
-				src_ptr += src_fdx;
-				if (!eax || eax >= shdpen || ozbuf_ptr[ecx] < z8) continue;
-				ozbuf_ptr[ecx] = z8;
-
-				BLEND32_MACRO
-			}
-			while (++ecx);
-
-			src_ptr += src_fdy;
-			ozbuf_ptr += GX_ZBUFW;
-			dst_ptr += GX_BMPPW;
-			ecx = dst_w;
-		}
-		while (--dst_h);
-	}
-	else if (drawmode == 4) /* shadow pens only */
-	{
-		do {
-			do {
-				eax = *src_ptr;
-				src_ptr += src_fdx;
-				if (eax < shdpen || szbuf_ptr[ecx*2] < z8 || szbuf_ptr[ecx*2+1] <= p8) continue;
-				eax = dst_ptr[ecx];
-				szbuf_ptr[ecx*2] = z8;
-				szbuf_ptr[ecx*2+1] = p8;
-				eax = (eax>>9&0x7c00) | (eax>>6&0x03e0) | (eax>>3&0x001f);
-				dst_ptr[ecx] = shd_base[eax];
-			}
-			while (++ecx);
-
-			src_ptr += src_fdy;
-			szbuf_ptr += (GX_ZBUFW<<1);
-			dst_ptr += GX_BMPPW;
-			ecx = dst_w;
-		}
-		while (--dst_h);
-	}
-	return;
-
-	DRAWZOOM:
-
-	ecx = src_fby;   src_fby += src_fdy;
-	ecx >>= FP;      src_fx = src_fbx;
-	src_x = src_fbx; src_fx += src_fdx;
-	ecx <<= 4;       src_ptr = src_base;
-	src_x >>= FP;    src_ptr += ecx;
-	ecx = dst_w;
-
-	if (zcode < 0) /* no shadow and z-buffering */
-	{
-		do {
-			do {
-				eax = src_ptr[src_x];
-				src_x = src_fx;
-				src_fx += src_fdx;
-				src_x >>= FP;
-				if (!eax || eax >= shdpen) continue;
-				dst_ptr [ecx] = pal_base[eax];
-			}
-			while (++ecx);
-
-			ecx = src_fby;   src_fby += src_fdy;
-			dst_ptr += GX_BMPPW;
-			ecx >>= FP;      src_fx = src_fbx;
-			src_x = src_fbx; src_fx += src_fdx;
-			ecx <<= 4;       src_ptr = src_base;
-			src_x >>= FP;    src_ptr += ecx;
-			ecx = dst_w;
-		}
-		while (--dst_h);
-	}
-	else if (drawmode == 0) /* all pens solid */
-	{
-		do {
-			do {
-				eax = src_ptr[src_x];
-				src_x = src_fx;
-				src_fx += src_fdx;
-				src_x >>= FP;
-				if (!eax || ozbuf_ptr[ecx] < z8) continue;
-				eax = pal_base[eax];
-				ozbuf_ptr[ecx] = z8;
-				dst_ptr [ecx] = eax;
-			}
-			while (++ecx);
-
-			ecx = src_fby;   src_fby += src_fdy;
-			ozbuf_ptr += GX_ZBUFW;
-			dst_ptr += GX_BMPPW;
-			ecx >>= FP;      src_fx = src_fbx;
-			src_x = src_fbx; src_fx += src_fdx;
-			ecx <<= 4;       src_ptr = src_base;
-			src_x >>= FP;    src_ptr += ecx;
-			ecx = dst_w;
-		}
-		while (--dst_h);
-	}
-	else if (drawmode == 1) /* solid pens only */
-	{
-		do {
-			do {
-				eax = src_ptr[src_x];
-				src_x = src_fx;
-				src_fx += src_fdx;
-				src_x >>= FP;
-				if (!eax || eax >= shdpen || ozbuf_ptr[ecx] < z8) continue;
-				eax = pal_base[eax];
-				ozbuf_ptr[ecx] = z8;
-				dst_ptr [ecx] = eax;
-			}
-			while (++ecx);
-
-			ecx = src_fby;   src_fby += src_fdy;
-			ozbuf_ptr += GX_ZBUFW;
-			dst_ptr += GX_BMPPW;
-			ecx >>= FP;      src_fx = src_fbx;
-			src_x = src_fbx; src_fx += src_fdx;
-			ecx <<= 4;       src_ptr = src_base;
-			src_x >>= FP;    src_ptr += ecx;
-			ecx = dst_w;
-		}
-		while (--dst_h);
-	}
-	else if (drawmode == 2) /* all pens solid with alpha blending */
-	{
-		do {
-			do {
-				eax = src_ptr[src_x];
-				src_x = src_fx;
-				src_fx += src_fdx;
-				src_x >>= FP;
-				if (!eax || ozbuf_ptr[ecx] < z8) continue;
-				ozbuf_ptr[ecx] = z8;
-
-				BLEND32_MACRO
-			}
-			while (++ecx);
-
-			ecx = src_fby;   src_fby += src_fdy;
-			ozbuf_ptr += GX_ZBUFW;
-			dst_ptr += GX_BMPPW;
-			ecx >>= FP;      src_fx = src_fbx;
-			src_x = src_fbx; src_fx += src_fdx;
-			ecx <<= 4;       src_ptr = src_base;
-			src_x >>= FP;    src_ptr += ecx;
-			ecx = dst_w;
-		}
-		while (--dst_h);
-	}
-	else if (drawmode == 3) /* solid pens only with alpha blending */
-	{
-		do {
-			do {
-				eax = src_ptr[src_x];
-				src_x = src_fx;
-				src_fx += src_fdx;
-				src_x >>= FP;
-				if (!eax || eax >= shdpen || ozbuf_ptr[ecx] < z8) continue;
-				ozbuf_ptr[ecx] = z8;
-
-				BLEND32_MACRO
-			}
-			while (++ecx);
-
-			ecx = src_fby;   src_fby += src_fdy;
-			ozbuf_ptr += GX_ZBUFW;
-			dst_ptr += GX_BMPPW;
-			ecx >>= FP;      src_fx = src_fbx;
-			src_x = src_fbx; src_fx += src_fdx;
-			ecx <<= 4;       src_ptr = src_base;
-			src_x >>= FP;    src_ptr += ecx;
-			ecx = dst_w;
-		}
-		while (--dst_h);
-	}
-	else if (drawmode == 4) /* shadow pens only */
-	{
-		do {
-			do {
-				eax = src_ptr[src_x];
-				src_x = src_fx;
-				src_fx += src_fdx;
-				src_x >>= FP;
-				if (eax < shdpen || szbuf_ptr[ecx*2] < z8 || szbuf_ptr[ecx*2+1] <= p8) continue;
-				eax = dst_ptr[ecx];
-				szbuf_ptr[ecx*2] = z8;
-				szbuf_ptr[ecx*2+1] = p8;
-				eax = (eax>>9&0x7c00) | (eax>>6&0x03e0) | (eax>>3&0x001f);
-				dst_ptr[ecx] = shd_base[eax];
-			}
-			while (++ecx);
-
-			ecx = src_fby;   src_fby += src_fdy;
-			szbuf_ptr += (GX_ZBUFW<<1);
-			dst_ptr += GX_BMPPW;
-			ecx >>= FP;      src_fx = src_fbx;
-			src_x = src_fbx; src_fx += src_fdx;
-			ecx <<= 4;       src_ptr = src_base;
-			src_x >>= FP;    src_ptr += ecx;
-			ecx = dst_w;
-		}
-		while (--dst_h);
-	}
-
 #undef FP
 #undef FPONE
 #undef FPHALF
@@ -1407,15 +1416,15 @@ void konamigx_mixer(struct mame_bitmap *bitmap, const struct rectangle *cliprect
 		switch (code)
 		{
 			/*
-				Background layers are represented by negative offset values as follow:
+                Background layers are represented by negative offset values as follow:
 
-				0+ : normal sprites
-				-1 : tile layer A - D
-				-2 : K053936 ROZ+ layer 1
-				-3 : K053936 ROZ+ layer 2
-				-4 : K053250 LVC layer 1
-				-5 : K053250 LVC layer 2
-			*/
+                0+ : normal sprites
+                -1 : tile layer A - D
+                -2 : K053936 ROZ+ layer 1
+                -3 : K053936 ROZ+ layer 2
+                -4 : K053250 LVC layer 1
+                -5 : K053250 LVC layer 2
+            */
 			case 4 :
 				offs = -128;
 				if (sub1flags & 0xf) { if (sub1flags & GXSUB_K053250) offs = -4; else if (sub1) offs = -2; }
@@ -1457,13 +1466,13 @@ void konamigx_mixer(struct mame_bitmap *bitmap, const struct rectangle *cliprect
 		(*K053247_callback)(&code, &color, &pri);
 
 		/*
-			shadow = shadow code
-			spri   = shadow priority
-			temp1  = add solid object
-			temp2  = solid pens draw mode
-			temp3  = add shadow object
-			temp4  = shadow pens draw mode
-		*/
+            shadow = shadow code
+            spri   = shadow priority
+            temp1  = add solid object
+            temp2  = solid pens draw mode
+            temp3  = add shadow object
+            temp4  = shadow pens draw mode
+        */
 		temp4 = temp3 = temp2 = temp1 = spri = shadow = 0;
 
 		if (color & K055555_FULLSHADOW)
@@ -1534,14 +1543,14 @@ void konamigx_mixer(struct mame_bitmap *bitmap, const struct rectangle *cliprect
 		}
 
 		/*
-			default sort order:
-			fedcba9876543210fedcba9876543210
-			xxxxxxxx------------------------ (priority)
-			--------xxxxxxxx---------------- (zcode)
-			----------------xxxxxxxx-------- (offset)
-			------------------------xxxx---- (shadow mode)
-			----------------------------xxxx (shadow code)
-		*/
+            default sort order:
+            fedcba9876543210fedcba9876543210
+            xxxxxxxx------------------------ (priority)
+            --------xxxxxxxx---------------- (zcode)
+            ----------------xxxxxxxx-------- (offset)
+            ------------------------xxxx---- (shadow mode)
+            ----------------------------xxxx (shadow code)
+        */
 		if (temp1)
 		{
 			/* add objects with solid or alpha pens */
@@ -1623,11 +1632,11 @@ void konamigx_mixer(struct mame_bitmap *bitmap, const struct rectangle *cliprect
 					}
 
 					/* blend layer only when:
-						1) vinmix != 0xff
-						2) its internal mix code is set
-						3) all mix code bits are internal(overriden until tile blending has been implemented)
-						4) 0 > alpha < 255;
-					*/
+                        1) vinmix != 0xff
+                        2) its internal mix code is set
+                        3) all mix code bits are internal(overriden until tile blending has been implemented)
+                        4) 0 > alpha < 255;
+                    */
 					if (temp1!=0xff && temp2 /*&& temp3==3*/)
 					{
 						temp4 = K054338_set_alpha_level(temp2);
