@@ -1,69 +1,69 @@
 /***************************************************************************
 
-	Slick Shot input handling
+    Slick Shot input handling
 
-	Unlike the other 8-bit Strata games, Slick Shot has an interesting
-	and fairly complex input system. The actual cabinet has a good-sized
-	gap underneath the monitor, from which a small pool table emerges.
-	An actual cue ball and pool sticks were included with the game.
+    Unlike the other 8-bit Strata games, Slick Shot has an interesting
+    and fairly complex input system. The actual cabinet has a good-sized
+    gap underneath the monitor, from which a small pool table emerges.
+    An actual cue ball and pool sticks were included with the game.
 
-	To "control" the game, players actually put the cue ball on the pool
-	table and shot the ball into the gap. Four sensors underneath the
-	monitor would count how long they saw the ball, and from this data,
-	the velocity and crossing point of the ball could be derived.
+    To "control" the game, players actually put the cue ball on the pool
+    table and shot the ball into the gap. Four sensors underneath the
+    monitor would count how long they saw the ball, and from this data,
+    the velocity and crossing point of the ball could be derived.
 
-	In order to read these sensors, an extra Z80 was added to the board.
-	The Z80 program is astoundingly simple: on reset, it writes a value of
-	$00 to the output port, then waits for either sensor 0 or 1 to fire.
-	As soon as one of those sensors fires, it begins counting how long it
-	takes for the bits corresponding to those sensors, as well as sensors
-	2 and 3, to return to their 0 state. It then writes a $ff to the
-	output port to signal that data is ready and waits for the main CPU
-	to clock the data through.
+    In order to read these sensors, an extra Z80 was added to the board.
+    The Z80 program is astoundingly simple: on reset, it writes a value of
+    $00 to the output port, then waits for either sensor 0 or 1 to fire.
+    As soon as one of those sensors fires, it begins counting how long it
+    takes for the bits corresponding to those sensors, as well as sensors
+    2 and 3, to return to their 0 state. It then writes a $ff to the
+    output port to signal that data is ready and waits for the main CPU
+    to clock the data through.
 
-	On the main program side of things, the result from the Z80 is
-	periodically polled. Once a $ff is seen, 3 words and 1 bytes' worth
-	of data is read from the Z80, after which the Z80 goes into an
-	infinite loop. When the main program is ready to read a result again,
-	it resets the Z80 to start the read going again.
+    On the main program side of things, the result from the Z80 is
+    periodically polled. Once a $ff is seen, 3 words and 1 bytes' worth
+    of data is read from the Z80, after which the Z80 goes into an
+    infinite loop. When the main program is ready to read a result again,
+    it resets the Z80 to start the read going again.
 
-	The way the Z80 reads the data, is as follows:
+    The way the Z80 reads the data, is as follows:
 
-		- write $00 to output
-		- wait for sensor 0 or 1 to fire (go to the 1 state)
-		- count how long that sensor takes to return to 0
-		- count how long sensors 2 and 3 take to return to 0
-		- write $ff to output
-		- wait for data to be clocked through
-		- return 3 words + 1 byte of data:
-			- word 0 = (value of larger of sensor 2/3 counts) - (value of smaller)
-			- word 1 = value of smaller of sensor 2/3 counts
-			- word 2 = value of sensor 0/1
-			- byte = beam data
-				- bit 0 = 1 if sensor 0 fired; 0 if sensor 1 fired
-				- bit 1 = 1 if sensor 3 value > sensor 2 value; 0 otherwise
-		- enter infinite loop
+        - write $00 to output
+        - wait for sensor 0 or 1 to fire (go to the 1 state)
+        - count how long that sensor takes to return to 0
+        - count how long sensors 2 and 3 take to return to 0
+        - write $ff to output
+        - wait for data to be clocked through
+        - return 3 words + 1 byte of data:
+            - word 0 = (value of larger of sensor 2/3 counts) - (value of smaller)
+            - word 1 = value of smaller of sensor 2/3 counts
+            - word 2 = value of sensor 0/1
+            - byte = beam data
+                - bit 0 = 1 if sensor 0 fired; 0 if sensor 1 fired
+                - bit 1 = 1 if sensor 3 value > sensor 2 value; 0 otherwise
+        - enter infinite loop
 
-	Once this data is read from the Z80, it is converted to an intermediate
-	form, and then processed using 32-bit math (yes, on a 6809!) to produce
-	the final velocity and X position of the crossing.
+    Once this data is read from the Z80, it is converted to an intermediate
+    form, and then processed using 32-bit math (yes, on a 6809!) to produce
+    the final velocity and X position of the crossing.
 
-	Because it is not understood exactly where the sensors are placed and
-	how to simulate the actual behavior, this module attempts to do the
-	next best thing: given a velocity and X position, figure out raw
-	sensor values that will travel from the Z80 to the main 6809 and
-	through the calculations produce approximately the correct results.
+    Because it is not understood exactly where the sensors are placed and
+    how to simulate the actual behavior, this module attempts to do the
+    next best thing: given a velocity and X position, figure out raw
+    sensor values that will travel from the Z80 to the main 6809 and
+    through the calculations produce approximately the correct results.
 
-	There are several stages of data:
+    There are several stages of data:
 
-		- sens0, sens1, sens2, sens3 = raw sensor values
-		- word1, word2, word3, beam = values from the Z80 (beam = byte val)
-		- inter1, inter2, inter3, beam = intermediate forms in the 6809
-		- vx, vy, x = final X,Y velocities and X crossing point
+        - sens0, sens1, sens2, sens3 = raw sensor values
+        - word1, word2, word3, beam = values from the Z80 (beam = byte val)
+        - inter1, inter2, inter3, beam = intermediate forms in the 6809
+        - vx, vy, x = final X,Y velocities and X crossing point
 
-	And all the functions here are designed to take you through the various
-	stages, both forwards and backwards, replicating the operations in the
-	6809 or reversing them.
+    And all the functions here are designed to take you through the various
+    stages, both forwards and backwards, replicating the operations in the
+    6809 or reversing them.
 
 ***************************************************************************/
 
@@ -71,29 +71,41 @@
 #include "cpu/z80/z80.h"
 #include "itech8.h"
 
+
+#define YBUFFER_COUNT	15
+#define MINDY			100
+
 static UINT8 z80_ctrl;
 static UINT8 z80_port_val;
 static UINT8 z80_clear_to_send;
 
-static UINT16 nextsensor0, nextsensor1, nextsensor2, nextsensor3;
 static UINT16 sensor0, sensor1, sensor2, sensor3;
 
 static UINT8 curvx, curvy = 1, curx;
-static UINT8 lastshoot;
+
+static INT8 xbuffer[YBUFFER_COUNT];
+static INT8 ybuffer[YBUFFER_COUNT];
+static int ybuffer_next;
+static int curxpos;
+static int last_ytotal;
+
+static UINT8 crosshair_vis;
+static int crosshair_min;
+static int crosshair_max;
 
 
 
 /*************************************
  *
- *	sensors_to_words
+ *  sensors_to_words
  *
- *	converts from raw sensor data to
- *	the three words + byte that the
- *	Z80 sends to the main 6809
+ *  converts from raw sensor data to
+ *  the three words + byte that the
+ *  Z80 sends to the main 6809
  *
  *************************************/
 
-#if 0
+#ifdef STANDALONE
 static void sensors_to_words(UINT16 sens0, UINT16 sens1, UINT16 sens2, UINT16 sens3,
 							UINT16 *word1, UINT16 *word2, UINT16 *word3, UINT8 *beams)
 {
@@ -122,16 +134,16 @@ static void sensors_to_words(UINT16 sens0, UINT16 sens1, UINT16 sens2, UINT16 se
 
 /*************************************
  *
- *	words_to_inters
+ *  words_to_inters
  *
- *	converts the three words + byte
- *	data from the Z80 into the three
- *	intermediate values used in the
- *	final calculations
+ *  converts the three words + byte
+ *  data from the Z80 into the three
+ *  intermediate values used in the
+ *  final calculations
  *
  *************************************/
 
-#if 0
+#ifdef STANDALONE
 static void words_to_inters(UINT16 word1, UINT16 word2, UINT16 word3, UINT8 beams,
 							UINT16 *inter1, UINT16 *inter2, UINT16 *inter3)
 {
@@ -170,11 +182,11 @@ static void words_to_inters(UINT16 word1, UINT16 word2, UINT16 word3, UINT8 beam
 
 /*************************************
  *
- *	inters_to_vels
+ *  inters_to_vels
  *
- *	converts the three intermediate
- *	values to the final velocity and
- *	X position values
+ *  converts the three intermediate
+ *  values to the final velocity and
+ *  X position values
  *
  *************************************/
 
@@ -242,12 +254,12 @@ static void inters_to_vels(UINT16 inter1, UINT16 inter2, UINT16 inter3, UINT8 be
 
 /*************************************
  *
- *	vels_to_inters
+ *  vels_to_inters
  *
- *	converts from the final velocity
- *	and X position values back to
- *	three intermediate values that
- *	will produce the desired result
+ *  converts from the final velocity
+ *  and X position values back to
+ *  three intermediate values that
+ *  will produce the desired result
  *
  *************************************/
 
@@ -295,12 +307,12 @@ static void vels_to_inters(UINT8 x, UINT8 vx, UINT8 vy,
 
 /*************************************
  *
- *	inters_to_words
+ *  inters_to_words
  *
- *	converts the intermediate values
- *	used in the final calculations
- *	back to the three words + byte
- *	data from the Z80
+ *  converts the intermediate values
+ *  used in the final calculations
+ *  back to the three words + byte
+ *  data from the Z80
  *
  *************************************/
 
@@ -358,11 +370,11 @@ static void inters_to_words(UINT16 inter1, UINT16 inter2, UINT16 inter3, UINT8 *
 
 /*************************************
  *
- *	words_to_sensors
+ *  words_to_sensors
  *
- *	converts from the three words +
- *	byte that the Z80 sends to the
- *	main 6809 back to raw sensor data
+ *  converts from the three words +
+ *  byte that the Z80 sends to the
+ *  main 6809 back to raw sensor data
  *
  *************************************/
 
@@ -386,7 +398,7 @@ static void words_to_sensors(UINT16 word1, UINT16 word2, UINT16 word3, UINT8 bea
 
 /*************************************
  *
- *	compute_sensors
+ *  compute_sensors
  *
  *************************************/
 
@@ -403,16 +415,16 @@ static void compute_sensors(void)
 	/* reverse map the inputs */
 	vels_to_inters(curx, curvx, curvy, &inter1, &inter2, &inter3, &beams);
 	inters_to_words(inter1, inter2, inter3, &beams, &word1, &word2, &word3);
-	words_to_sensors(word1, word2, word3, beams, &nextsensor0, &nextsensor1, &nextsensor2, &nextsensor3);
+	words_to_sensors(word1, word2, word3, beams, &sensor0, &sensor1, &sensor2, &sensor3);
 
-	logerror("%15f: Sensor values: %04x %04x %04x %04x\n", timer_get_time(), nextsensor0, nextsensor1, nextsensor2, nextsensor3);
+	logerror("%15f: Sensor values: %04x %04x %04x %04x\n", timer_get_time(), sensor0, sensor1, sensor2, sensor3);
 }
 
 
 
 /*************************************
  *
- *	slikz80_port_r
+ *  slikz80_port_r
  *
  *************************************/
 
@@ -442,7 +454,7 @@ READ8_HANDLER( slikz80_port_r )
 
 /*************************************
  *
- *	slikz80_port_w
+ *  slikz80_port_w
  *
  *************************************/
 
@@ -456,7 +468,7 @@ WRITE8_HANDLER( slikz80_port_w )
 
 /*************************************
  *
- *	slikshot_z80_r
+ *  slikshot_z80_r
  *
  *************************************/
 
@@ -464,8 +476,6 @@ READ8_HANDLER( slikshot_z80_r )
 {
 	/* allow the Z80 to send us stuff now */
 	z80_clear_to_send = 1;
-	timer_set(TIME_NOW, 0, NULL);
-
 	return z80_port_val;
 }
 
@@ -473,7 +483,7 @@ READ8_HANDLER( slikshot_z80_r )
 
 /*************************************
  *
- *	slikshot_z80_control_r
+ *  slikshot_z80_control_r
  *
  *************************************/
 
@@ -486,129 +496,127 @@ READ8_HANDLER( slikshot_z80_control_r )
 
 /*************************************
  *
- *	slikshot_z80_control_w
+ *  slikshot_z80_control_w
  *
  *************************************/
 
+static void delayed_z80_control_w(int data)
+{
+	/* bit 4 controls the reset line on the Z80 */
+
+	/* this is a big kludge: only allow a reset if the Z80 is stopped */
+	/* at its endpoint; otherwise, we never get a result from the Z80 */
+	if ((data & 0x10) || cpunum_get_reg(2, Z80_PC) == 0x13a)
+	{
+		cpunum_set_input_line(2, INPUT_LINE_RESET, (data & 0x10) ? CLEAR_LINE : ASSERT_LINE);
+
+		/* on the rising edge, make the crosshair visible again */
+		if ((data & 0x10) && !(z80_ctrl & 0x10))
+			crosshair_vis = 1;
+	}
+
+	/* boost the interleave whenever this is written to */
+	cpu_boost_interleave(0, TIME_IN_USEC(100));
+
+	/* stash the new value */
+	z80_ctrl = data;
+}
+
+
 WRITE8_HANDLER( slikshot_z80_control_w )
 {
-	UINT8 delta = z80_ctrl ^ data;
-	z80_ctrl = data;
-
-	/* reset the Z80 on bit 4 changing */
-	if (delta & 0x10)
-	{
-/*		logerror("%15f: Reset Z80: %02x  PC=%04x\n", timer_get_time(), data & 0x10, cpunum_get_reg(2, Z80_PC)); */
-
-		/* this is a big kludge: only allow a reset if the Z80 is stopped */
-		/* at its endpoint; otherwise, we never get a result from the Z80 */
-		if ((data & 0x10) || cpunum_get_reg(2, Z80_PC) == 0x13a)
-		{
-			cpunum_set_input_line(2, INPUT_LINE_RESET, (data & 0x10) ? CLEAR_LINE : ASSERT_LINE);
-
-			/* on the rising edge, do housekeeping */
-			if (data & 0x10)
-			{
-				sensor0 = nextsensor0;
-				sensor1 = nextsensor1;
-				sensor2 = nextsensor2;
-				sensor3 = nextsensor3;
-				nextsensor0 = nextsensor1 = nextsensor2 = nextsensor3 = 0;
-				z80_clear_to_send = 0;
-			}
-		}
-	}
-
-	/* on bit 5 going live, this looks like a clock, but the system */
-	/* won't work with it configured as such */
-	if (delta & data & 0x20)
-	{
-/*		logerror("%15f: Clock edge high\n", timer_get_time()); */
-	}
+	timer_set(TIME_NOW, data, delayed_z80_control_w);
 }
 
 
 
 /*************************************
  *
- *	slikshot_extra_draw
+ *  slikshot_set_crosshair_range
  *
- *	render a line representing the
- *	current X crossing and the
- *	velocities
+ *  set the range for the crosshair
  *
  *************************************/
 
-void slikshot_extra_draw(struct mame_bitmap *bitmap, const struct rectangle *cliprect)
+void slikshot_set_crosshair_range(int miny, int maxy)
 {
-	INT8 vx = (INT8)readinputport(3);
-	INT8 vy = (INT8)readinputport(4);
-	UINT8 xpos = readinputport(5);
-	int xstart, ystart, xend, yend;
-	int dx, dy, absdx, absdy;
-	int count, i;
-	int newshoot;
+	crosshair_min = miny;
+	crosshair_max = maxy;
+}
 
-	/* make sure color 256 is white for our crosshair */
-	palette_set_color(256, 0xff, 0xff, 0xff);
 
-	/* compute the updated values */
-	curvx = vx;
-	curvy = (vy < 1) ? 1 : vy;
-	curx = xpos;
+
+/*************************************
+ *
+ *  video_update_slikshot
+ *
+ *************************************/
+
+VIDEO_UPDATE( slikshot )
+{
+	int totaldy, totaldx;
+	int temp, i;
+
+	/* draw the normal video first */
+	video_update_itech8_2page(bitmap, cliprect);
+
+	/* add the current X,Y positions to the list */
+	xbuffer[ybuffer_next % YBUFFER_COUNT] = readinputportbytag_safe("FAKEX", 0);
+	ybuffer[ybuffer_next % YBUFFER_COUNT] = readinputportbytag_safe("FAKEY", 0);
+	ybuffer_next++;
+
+	/* determine where to draw the starting point */
+	curxpos += xbuffer[(ybuffer_next + 1) % YBUFFER_COUNT];
+	if (curxpos < -0x80) curxpos = -0x80;
+	if (curxpos >  0x80) curxpos =  0x80;
+
+	/* compute the total X/Y movement */
+	totaldx = totaldy = 0;
+	for (i = 0; i < YBUFFER_COUNT - 1; i++)
+	{
+		totaldx += xbuffer[(ybuffer_next + i + 1) % YBUFFER_COUNT];
+		totaldy += ybuffer[(ybuffer_next + i + 1) % YBUFFER_COUNT];
+	}
 
 	/* if the shoot button is pressed, fire away */
-	newshoot = readinputport(7) & 1;
-	if (newshoot && !lastshoot)
+	if (totaldy < last_ytotal && last_ytotal > 50 && crosshair_vis)
 	{
+		/* compute the updated values */
+		temp = totaldx;
+		if (temp <= -0x80) temp = -0x7f;
+		if (temp >=  0x80) temp =  0x7f;
+		curvx = temp;
+
+		temp = last_ytotal - 50;
+		if (temp <=  0x10) temp =  0x10;
+		if (temp >=  0x7f) temp =  0x7f;
+		curvy = temp;
+
+		temp = 0x60 + (curxpos * 0x30 / 0x80);
+		if (temp <=  0x30) temp =  0x30;
+		if (temp >=  0x90) temp =  0x90;
+		curx = temp;
+
 		compute_sensors();
-/*		usrintf_showmessage("V=%02x,%02x  X=%02x", curvx, curvy, curx); */
+/*      usrintf_showmessage("V=%02x,%02x  X=%02x", curvx, curvy, curx); */
+		crosshair_vis = 0;
+	}
+	last_ytotal = totaldy;
+
+	/* clear the buffer while the crosshair is not visible */
+	if (!crosshair_vis)
+	{
+		memset(xbuffer, 0, sizeof(xbuffer));
+		memset(ybuffer, 0, sizeof(ybuffer));
 	}
-	lastshoot = newshoot;
 
 	/* draw a crosshair (rotated) */
-	xstart = (((int)curx - 0x60) * 0x100 / 0xd0) + 144;
-	ystart = 256 - 48;
-	xend = xstart + (INT8)curvx;
-	yend = ystart - (INT8)curvy;
-
-	/* compute line params */
-	dx = xend - xstart;
-	dy = yend - ystart;
-	absdx = (dx < 0) ? -dx : dx;
-	absdy = (dy < 0) ? -dy : dy;
-	if (absdx > absdy)
+	if (crosshair_vis)
 	{
-		dy = absdx ? ((dy << 16) / absdx) : 0;
-		dx = (dx < 0) ? -0x10000 : 0x10000;
-		count = absdx;
-	}
-	else
-	{
-		dx = absdy ? ((dx << 16) / absdy) : 0;
-		dy = (dy < 0) ? -0x10000 : 0x10000;
-		count = absdy;
-	}
-
-	/* scale the start points */
-	xstart <<= 16;
-	ystart <<= 16;
-
-	/* draw the line */
-	for (i = 0; i < count; i++)
-	{
-		int px = xstart >> 16, py = ystart >> 16;
-
-		if (px >= cliprect->min_x && px <= cliprect->max_x &&
-			py >= cliprect->min_y && py <= cliprect->max_y)
-		{
-			if (bitmap->depth == 8)
-				((UINT8 *)bitmap->line[py])[px] = Machine->pens[256];
-			else
-				((UINT16 *)bitmap->line[py])[px] = Machine->pens[256];
-		}
-		xstart += dx;
-		ystart += dy;
+		if ((Machine->gamedrv->flags & ORIENTATION_MASK) == ROT90)
+			draw_crosshair(bitmap, 256 - 48, (crosshair_min + crosshair_max) / 2 - (curxpos * (crosshair_max - crosshair_min) / 0x100), cliprect);
+		else
+			draw_crosshair(bitmap, 48, (crosshair_min + crosshair_max) / 2 + (curxpos * (crosshair_max - crosshair_min) / 0x100), cliprect);
 	}
 }
 
@@ -616,14 +624,14 @@ void slikshot_extra_draw(struct mame_bitmap *bitmap, const struct rectangle *cli
 
 /*************************************
  *
- *	main
+ *  main
  *
- *	uncomment this to make a stand
- *	alone version for testing
+ *  uncomment this to make a stand
+ *  alone version for testing
  *
  *************************************/
 
-#if 0
+#ifdef STANDALONE
 
 int main(int argc, char *argv[])
 {
