@@ -1,108 +1,134 @@
 /***************************************************************************
 
-	mame.c
+    mame.c
 
-	Controls execution of the core MAME system.
+    Controls execution of the core MAME system.
 
 ****************************************************************************
 
-	Since there has been confusion in the past over the order of
-	initialization and other such things, here it is, all spelled out
-	as of May, 2002:
+    Since there has been confusion in the past over the order of
+    initialization and other such things, here it is, all spelled out
+    as of March, 2005:
 
-	main()
-		- does platform-specific init
-		- calls run_game()
+    main()
+        - does platform-specific init
+        - calls run_game() [mame.c]
 
-		run_game()
-			- constructs the machine driver
-			- calls init_game_options()
+        run_game() [mame.c]
+            - begins resource tracking (level 1)
+            - calls mame_validitychecks() [mame.c] to perform validity checks on all compiled drivers
+            - calls expand_machine_driver() [mame.c] to construct the machine driver
+            - calls cpuintrf_init() [cpuintrf.c] to determine which CPUs are available
+            - calls init_game_options() [mame.c] to compute parameters based on global options struct
+            - initializes the savegame system
+            - calls osd_init() [osdepend.h] to do platform-specific initialization
 
-			init_game_options()
-				- determines color depth from the options
-				- computes orientation from the options
+            - begins resource tracking (level 2)
+            - calls init_machine() [mame.c]
 
-			- initializes the savegame system
-			- calls osd_init() to do platform-specific initialization
-			- calls init_machine()
+            init_machine() [mame.c]
+                - calls uistring_init() [ui_text.c] to initialize the localized strings
+                - calls code_init() [input.c] to initialize the input system
+                - calls input_port_alloc() [inptport.c] to construct the game's input ports
+                - calls chd_set_interface() [chd.c] to initialize the hard disk system
+                - calls rom_load() [common.c] to load the game's ROMs
+                - calls timer_init() [timer.c] to reset the timer system
+                - calls cpu_init_refresh_timer() [cpuexec.c] to start the refresh timer
+                - calls cpu_init() [cpuexec.c] to initialize the CPUs
+                - calls load_input_port_settings() [input.c] to load the configuration file
+                - calls memory_init() [memory.c] to process the game's memory maps
+                - calls the driver's DRIVER_INIT callback
 
-			init_machine()
-				- initializes the localized strings
-				- initializes the input system
-				- parses and allocates the game's input ports
-				- initializes the hard disk system
-				- loads the game's ROMs
-				- resets the timer system
-				- starts the refresh timer
-				- initializes the CPUs
-				- loads the configuration file
-				- initializes the memory system for the game
-				- calls the driver's DRIVER_INIT callback
+            - calls run_machine() [mame.c]
 
-			- calls run_machine()
+            run_machine() [mame.c]
+                - calls vh_open() [mame.c]
 
-			run_machine()
-				- calls vh_open()
+                vh_open() [mame.c]
+                    - calls palette_start() [palette.c] to allocate the palette
+                    - calls decode_graphics() [mame.c] to decode the graphics
+                    - computes game resolution and aspect ratio
+                    - calls artwork_create_display() [artwork.c] to set up the artwork and init the display
+                    - allocates the scrbitmap
+                    - sets the initial refresh rate and visible area
+                    - calls init_buffered_spriteram() [mame.c] to set up buffered spriteram
+                    - calls builduifont() [usrintrf.c] to create the user interface font
+                    - creates the debugger bitmap and font (old debugger only)
+                    - calls palette_init() [palette.c] to finish palette initialization
+                    - resets the performance tracking variables
 
-				vh_open()
-					- allocates the palette
-					- decodes the graphics
-					- computes vector game resolution
-					- sets up the artwork
-					- calls osd_create_display() to init the display
-					- allocates the scrbitmap
-					- sets the initial visible_area
-					- sets up buffered spriteram
-					- creates the user interface font
-					- creates the debugger bitmap and font
-					- finishes palette initialization
+                - calls tilemap_init() [tilemap.c] to initialize the tilemap system
+                - calls the driver's VIDEO_START callback
+                - calls sound_start() [sndintrf.c] to start the audio system
+                - disposes of regions marked as disposable
+                - calls run_machine_core() [mame.c]
 
-				- initializes the tilemap system
-				- calls the driver's VIDEO_START callback
-				- starts the audio system
-				- disposes of regions marked as disposable
-				- calls run_machine_core()
+                run_machine_core() [mame.c]
+                    - shows the copyright screen
+                    - shows the game warnings
+                    - shows the game info screen
+                    - calls init_user_interface() [usrintrf.c] to initialize the user interface
+                    - calls InitCheat() [cheat.c] to initialize the cheat system
+                    - calls the driver's NVRAM_HANDLER to load NVRAM
+                    - calls cpu_run() [cpuexec.c]
 
-				run_machine_core()
-					- shows the copyright screen
-					- shows the game warnings
-					- initializes the user interface
-					- initializes the cheat system
-					- calls the driver's NVRAM_HANDLER
+                    cpu_run() [cpuexec.c]
+                        - calls mame_debug_init() [mamedbg.c] to init the debugger (old debugger only)
+                        - calls cpu_pre_run() [cpuexec.c]
 
-	--------------( at this point, we're up and running )---------------------------
+                        cpu_pre_run() [cpuexec.c]
+                            - begins resource tracking (level 3)
+                            - calls hs_open() and hs_init() [hiscore.c] to set up high score hacks
+                            - calls cpu_inittimers() [cpuexec.c] to set up basic system timers
+                            - calls watchdog_setup() [cpuexec.c] to set up watchdog timers
+                            - calls sound_reset() [sndintrf.c] to reset all the sound chips
+                            - loops over each CPU and initializes its internal state
+                            - calls the driver's MACHINE_INIT callback
+                            - loops over each CPU and calls cpunum_reset() [cpuintrf.c] to reset it
+                            - calls cpu_vblankreset() [cpuexec.c] to set up the first VBLANK callback
 
-					- calls the driver's NVRAM_HANDLER
-					- tears down the cheat system
-					- saves the game's configuration
+                        --------------( at this point, we're up and running )---------------------------
 
-				- stops the audio system
-				- calls the driver's VIDEO_STOP callback
-				- tears down the tilemap system
-				- calls vh_close()
+                        - calls cpu_post_run() [cpuexec.c]
 
-				vh_close()
-					- frees the decoded graphics
-					- frees the fonts
-					- calls osd_close_display() to shut down the display
-					- tears down the artwork
-					- tears down the palette system
+                        cpu_post_run() [cpuexec.c]
+                            - calls hs_close() [hiscore.c] to flush high score data
+                            - calls the driver's MACHINE_STOP callback
+                            - ends resource tracking (level 3), freeing all auto_mallocs and timers
 
-			- calls shutdown_machine()
+                        - if the machine is just being reset, loops back to the cpu_pre_run() step above
+                        - calls mame_debug_exit() [mamedbg.c] to shut down the debugger (old debugger only)
 
-			shutdown_machine()
-				- tears down the memory system
-				- frees all the memory regions
-				- tears down the hard disks
-				- tears down the CPU system
-				- releases the input ports
-				- tears down the input system
-				- tears down the localized strings
-				- resets the saved state system
+                    - calls the driver's NVRAM_HANDLER to save NVRAM
+                    - calls StopCheat() [cheat.c] to tear down the cheat system
+                    - calls save_input_port_settings() [inptport.c] to save the game's configuration
 
-			- calls osd_exit() to do platform-specific cleanup
+                - calls sound_stop() [sndintrf.c] to stop the audio system
+                - calls the driver's VIDEO_STOP callback
+                - calls tilemap_close() [tilemap.c] to tear down the tilemap system
+                - calls vh_close() [mame.c]
 
-		- exits the program
+                vh_close() [mame.c]
+                    - frees the decoded graphics
+                    - frees the fonts
+                    - calls osd_close_display() [osdepend.h] to shut down the display
+
+            - calls shutdown_machine() [mame.c]
+
+            shutdown_machine() [mame.c]
+                - calls memory_shutdown() [memory.c] to tear down the memory system
+                - frees all the memory regions
+                - calls chd_close_all() [chd.c] to tear down the hard disks
+                - calls cpu_exit() [cpuexec.c] to tear down the CPU system
+                - calls code_close() [input.c] to tear down the input system
+                - calls state_save_reset() [state.c] to reset the saved state system
+                - calls coin_counter_reset() [common.c] to reset coin counters
+
+            - ends resource tracking (level 2), freeing all auto_mallocs and timers
+            - calls osd_exit() [osdepend.h] to do platform-specific cleanup
+            - ends resource tracking (level 1), freeing all auto_mallocs and timers
+
+        - exits the program
 
 ***************************************************************************/
 
@@ -122,7 +148,7 @@
 
 /***************************************************************************
 
-	Constants
+    Constants
 
 ***************************************************************************/
 
@@ -132,7 +158,7 @@
 
 /***************************************************************************
 
-	Global variables
+    Global variables
 
 ***************************************************************************/
 
@@ -190,7 +216,7 @@ int skip_this_frame;
 
 /***************************************************************************
 
-	Hard disk interface prototype
+    Hard disk interface prototype
 
 ***************************************************************************/
 
@@ -213,7 +239,7 @@ static struct chd_interface mame_chd_interface =
 
 /***************************************************************************
 
-	Other function prototypes
+    Other function prototypes
 
 ***************************************************************************/
 
@@ -239,14 +265,14 @@ static int init_buffered_spriteram(void);
 
 /***************************************************************************
 
-	Inline functions
+    Inline functions
 
 ***************************************************************************/
 
 /*-------------------------------------------------
-	bail_and_print - set the bailing flag and
-	print a message if one hasn't already been
-	printed
+    bail_and_print - set the bailing flag and
+    print a message if one hasn't already been
+    printed
 -------------------------------------------------*/
 
 INLINE void bail_and_print(const char *message)
@@ -263,12 +289,12 @@ INLINE void bail_and_print(const char *message)
 
 /***************************************************************************
 
-	Core system management
+    Core system management
 
 ***************************************************************************/
 
 /*-------------------------------------------------
-	run_game - run the given game in a session
+    run_game - run the given game in a session
 -------------------------------------------------*/
 
 int run_game(int game)
@@ -278,7 +304,7 @@ int run_game(int game)
 	begin_resource_tracking();
 
 	/* validity checks -- the default is to perform these in all builds now
-	 * due to the number of incorrect submissions */
+     * due to the number of incorrect submissions */
 	if (!options.skip_validitychecks)
 		if (mame_validitychecks())
 			return 1;
@@ -351,7 +377,7 @@ int run_game(int game)
 
 
 /*-------------------------------------------------
-	init_machine - initialize the emulated machine
+    init_machine - initialize the emulated machine
 -------------------------------------------------*/
 
 static int init_machine(void)
@@ -463,9 +489,9 @@ cant_load_language_file:
 
 
 /*-------------------------------------------------
-	run_machine - start the various subsystems
-	and the CPU emulation; returns non zero in
-	case of error
+    run_machine - start the various subsystems
+    and the CPU emulation; returns non zero in
+    case of error
 -------------------------------------------------*/
 
 static int run_machine(void)
@@ -529,7 +555,7 @@ static int run_machine(void)
 
 
 /*-------------------------------------------------
-	run_machine_core - core execution loop
+    run_machine_core - core execution loop
 -------------------------------------------------*/
 
 void run_machine_core(void)
@@ -596,8 +622,8 @@ void run_machine_core(void)
 
 
 /*-------------------------------------------------
-	shutdown_machine - tear down the emulated
-	machine
+    shutdown_machine - tear down the emulated
+    machine
 -------------------------------------------------*/
 
 static void shutdown_machine(void)
@@ -635,7 +661,7 @@ static void shutdown_machine(void)
 
 
 /*-------------------------------------------------
-	mame_pause - pause or resume the system
+    mame_pause - pause or resume the system
 -------------------------------------------------*/
 
 void mame_pause(int pause)
@@ -649,8 +675,8 @@ void mame_pause(int pause)
 
 
 /*-------------------------------------------------
-	expand_machine_driver - construct a machine
-	driver from the macroized state
+    expand_machine_driver - construct a machine
+    driver from the macroized state
 -------------------------------------------------*/
 
 void expand_machine_driver(void (*constructor)(struct InternalMachineDriver *), struct InternalMachineDriver *output)
@@ -663,7 +689,7 @@ void expand_machine_driver(void (*constructor)(struct InternalMachineDriver *),
 
 
 /*-------------------------------------------------
-	vh_open - start up the video system
+    vh_open - start up the video system
 -------------------------------------------------*/
 
 static int vh_open(void)
@@ -705,7 +731,6 @@ static int vh_open(void)
 	params.colors = palette_get_total_colors_with_ui();
 	params.fps = Machine->drv->frames_per_second;
 	params.video_attributes = Machine->drv->video_attributes;
-	params.orientation = Machine->orientation;
 
 #ifdef MESS
 	artcallbacks = &mess_artwork_callbacks;
@@ -809,7 +834,7 @@ cant_start_palette:
 
 
 /*-------------------------------------------------
-	vh_close - close down the video system
+    vh_close - close down the video system
 -------------------------------------------------*/
 
 static void vh_close(void)
@@ -847,8 +872,8 @@ static void vh_close(void)
 
 
 /*-------------------------------------------------
-	compute_aspect_ratio - determine the aspect
-	ratio encoded in the video attributes
+    compute_aspect_ratio - determine the aspect
+    ratio encoded in the video attributes
 -------------------------------------------------*/
 
 static void compute_aspect_ratio(const struct InternalMachineDriver *drv, int *aspect_x, int *aspect_y)
@@ -871,8 +896,8 @@ static void compute_aspect_ratio(const struct InternalMachineDriver *drv, int *a
 
 
 /*-------------------------------------------------
-	init_game_options - initialize the various
-	game options
+    init_game_options - initialize the various
+    game options
 -------------------------------------------------*/
 
 static int init_game_options(void)
@@ -906,7 +931,6 @@ static int init_game_options(void)
 	Machine->sample_rate = options.samplerate;
 
 	/* get orientation right */
-	Machine->orientation = ROT0;
 	Machine->ui_orientation = options.ui_orientation;
 
 	return 0;
@@ -915,7 +939,7 @@ static int init_game_options(void)
 
 
 /*-------------------------------------------------
-	decode_graphics - decode the graphics
+    decode_graphics - decode the graphics
 -------------------------------------------------*/
 
 static int decode_graphics(const struct GfxDecodeInfo *gfxdecodeinfo)
@@ -946,13 +970,15 @@ static int decode_graphics(const struct GfxDecodeInfo *gfxdecodeinfo)
 		}
 
 		/* loop over all the X/Y offsets, converting fractions */
-		for (j = 0; j < MAX_GFX_SIZE; j++)
+		for (j = 0; j < glcopy.width; j++)
 		{
 			int value = glcopy.xoffset[j];
 			if (IS_FRAC(value))
 				glcopy.xoffset[j] = FRAC_OFFSET(value) + region_length * FRAC_NUM(value) / FRAC_DEN(value);
-
-			value = glcopy.yoffset[j];
+		}
+		for (j = 0; j < glcopy.height; j++)
+		{
+			int value = glcopy.yoffset[j];
 			if (IS_FRAC(value))
 				glcopy.yoffset[j] = FRAC_OFFSET(value) + region_length * FRAC_NUM(value) / FRAC_DEN(value);
 		}
@@ -993,8 +1019,8 @@ static int decode_graphics(const struct GfxDecodeInfo *gfxdecodeinfo)
 
 
 /*-------------------------------------------------
-	scale_vectorgames - scale the vector games
-	to a given resolution
+    scale_vectorgames - scale the vector games
+    to a given resolution
 -------------------------------------------------*/
 
 static void scale_vectorgames(int gfx_width, int gfx_height, int *width, int *height)
@@ -1020,8 +1046,8 @@ static void scale_vectorgames(int gfx_width, int gfx_height, int *width, int *he
 
 
 /*-------------------------------------------------
-	init_buffered_spriteram - initialize the
-	double-buffered spriteram
+    init_buffered_spriteram - initialize the
+    double-buffered spriteram
 -------------------------------------------------*/
 
 static int init_buffered_spriteram(void)
@@ -1065,13 +1091,13 @@ static int init_buffered_spriteram(void)
 
 /***************************************************************************
 
-	Screen rendering and management.
+    Screen rendering and management.
 
 ***************************************************************************/
 
 /*-------------------------------------------------
-	set_visible_area - adjusts the visible portion
-	of the bitmap area dynamically
+    set_visible_area - adjusts the visible portion
+    of the bitmap area dynamically
 -------------------------------------------------*/
 
 void set_visible_area(int min_x, int max_x, int min_y, int max_y)
@@ -1111,8 +1137,8 @@ void set_visible_area(int min_x, int max_x, int min_y, int max_y)
 
 
 /*-------------------------------------------------
-	set_refresh_rate - adjusts the refresh rate
-	of the video mode dynamically
+    set_refresh_rate - adjusts the refresh rate
+    of the video mode dynamically
 -------------------------------------------------*/
 
 void set_refresh_rate(float fps)
@@ -1134,8 +1160,8 @@ void set_refresh_rate(float fps)
 
 
 /*-------------------------------------------------
-	schedule_full_refresh - force a full erase
-	and refresh the next frame
+    schedule_full_refresh - force a full erase
+    and refresh the next frame
 -------------------------------------------------*/
 
 void schedule_full_refresh(void)
@@ -1146,8 +1172,8 @@ void schedule_full_refresh(void)
 
 
 /*-------------------------------------------------
-	reset_partial_updates - reset the partial
-	updating mechanism for a new frame
+    reset_partial_updates - reset the partial
+    updating mechanism for a new frame
 -------------------------------------------------*/
 
 void reset_partial_updates(void)
@@ -1159,9 +1185,9 @@ void reset_partial_updates(void)
 
 
 /*-------------------------------------------------
-	force_partial_update - perform a partial
-	update from the last scanline up to and
-	including the specified scanline
+    force_partial_update - perform a partial
+    update from the last scanline up to and
+    including the specified scanline
 -------------------------------------------------*/
 
 void force_partial_update(int scanline)
@@ -1216,8 +1242,8 @@ void force_partial_update(int scanline)
 
 
 /*-------------------------------------------------
-	draw_screen - render the final screen bitmap
-	and update any artwork
+    draw_screen - render the final screen bitmap
+    and update any artwork
 -------------------------------------------------*/
 int gbPriorityBitmapIsDirty;
 
@@ -1234,8 +1260,8 @@ void draw_screen(void)
 
 
 /*-------------------------------------------------
-	update_video_and_audio - actually call the
-	OSD layer to perform an update
+    update_video_and_audio - actually call the
+    OSD layer to perform an update
 -------------------------------------------------*/
 
 void update_video_and_audio(void)
@@ -1249,6 +1275,12 @@ void update_video_and_audio(void)
 	/* fill in our portion of the display */
 	current_display.changed_flags = 0;
 
+#ifdef MESS
+	if (skip_this_frame == 1)
+		current_display.changed_flags |= GAME_OPTIONAL_FRAMESKIP;
+	skip_this_frame = -1;
+#endif
+	
 	/* set the main game bitmap */
 	current_display.game_bitmap = Machine->scrbitmap;
 	current_display.game_bitmap_update = Machine->absolute_visible_area;
@@ -1313,9 +1345,11 @@ void update_video_and_audio(void)
 
 
 /*-------------------------------------------------
-	recompute_fps - recompute the frame rate
+    recompute_fps - recompute the frame rate
 -------------------------------------------------*/
 
+int vector_updates = 0;
+
 static void recompute_fps(int skipped_it)
 {
 	/* increment the frame counters */
@@ -1345,13 +1379,9 @@ static void recompute_fps(int skipped_it)
 	vfcount++;
 	if (vfcount >= (int)Machine->refresh_rate)
 	{
-#ifndef MESS
-		/* from vidhrdw/avgdvg.c */
-		extern int vector_updates;
-
 		performance.vector_updates_last_second = vector_updates;
 		vector_updates = 0;
-#endif
+
 		vfcount -= (int)Machine->refresh_rate;
 	}
 }
@@ -1359,15 +1389,15 @@ static void recompute_fps(int skipped_it)
 
 
 /*-------------------------------------------------
-	updatescreen - handle frameskipping and UI,
-	plus updating the screen during normal
-	operations
+    updatescreen - handle frameskipping and UI,
+    plus updating the screen during normal
+    operations
 -------------------------------------------------*/
 
 int updatescreen(void)
 {
 	/* update sound */
-	sound_update();
+	sound_frame_update();
 
 	/* if we're not skipping this frame, draw the screen */
 	if (osd_skip_this_frame() == 0)
@@ -1402,13 +1432,13 @@ int updatescreen(void)
 
 /***************************************************************************
 
-	Miscellaneous bits & pieces
+    Miscellaneous bits & pieces
 
 ***************************************************************************/
 
 /*-------------------------------------------------
-	mame_highscore_enabled - return 1 if high
-	scores are enabled
+    mame_highscore_enabled - return 1 if high
+    scores are enabled
 -------------------------------------------------*/
 
 int mame_highscore_enabled(void)
@@ -1427,7 +1457,7 @@ int mame_highscore_enabled(void)
 
 
 /*-------------------------------------------------
-	set_led_status - set the state of a given LED
+    set_led_status - set the state of a given LED
 -------------------------------------------------*/
 
 void set_led_status(int num, int on)
@@ -1441,8 +1471,8 @@ void set_led_status(int num, int on)
 
 
 /*-------------------------------------------------
-	mame_get_performance_info - return performance
-	info
+    mame_get_performance_info - return performance
+    info
 -------------------------------------------------*/
 
 const struct performance_info *mame_get_performance_info(void)
@@ -1453,8 +1483,8 @@ const struct performance_info *mame_get_performance_info(void)
 
 
 /*-------------------------------------------------
-	mame_find_cpu_index - return the index of the
-	given CPU, or -1 if not found
+    mame_find_cpu_index - return the index of the
+    given CPU, or -1 if not found
 -------------------------------------------------*/
 
 int mame_find_cpu_index(const char *tag)
@@ -1471,8 +1501,8 @@ int mame_find_cpu_index(const char *tag)
 
 
 /*-------------------------------------------------
-	machine_add_cpu - add a CPU during machine
-	driver expansion
+    machine_add_cpu - add a CPU during machine
+    driver expansion
 -------------------------------------------------*/
 
 struct MachineCPU *machine_add_cpu(struct InternalMachineDriver *machine, const char *tag, int type, int cpuclock)
@@ -1495,8 +1525,8 @@ struct MachineCPU *machine_add_cpu(struct InternalMachineDriver *machine, const
 
 
 /*-------------------------------------------------
-	machine_find_cpu - find a tagged CPU during
-	machine driver expansion
+    machine_find_cpu - find a tagged CPU during
+    machine driver expansion
 -------------------------------------------------*/
 
 struct MachineCPU *machine_find_cpu(struct InternalMachineDriver *machine, const char *tag)
@@ -1514,8 +1544,8 @@ struct MachineCPU *machine_find_cpu(struct InternalMachineDriver *machine, const
 
 
 /*-------------------------------------------------
-	machine_remove_cpu - remove a tagged CPU
-	during machine driver expansion
+    machine_remove_cpu - remove a tagged CPU
+    during machine driver expansion
 -------------------------------------------------*/
 
 void machine_remove_cpu(struct InternalMachineDriver *machine, const char *tag)
@@ -1536,11 +1566,77 @@ void machine_remove_cpu(struct InternalMachineDriver *machine, const char *tag)
 
 
 /*-------------------------------------------------
-	machine_add_sound - add a sound system during
-	machine driver expansion
+    machine_add_speaker - add a speaker during
+    machine driver expansion
 -------------------------------------------------*/
 
-struct MachineSound *machine_add_sound(struct InternalMachineDriver *machine, const char *tag, int type, void *sndintf)
+struct MachineSpeaker *machine_add_speaker(struct InternalMachineDriver *machine, const char *tag, float x, float y, float z)
+{
+	int speakernum;
+
+	for (speakernum = 0; speakernum < MAX_SPEAKER; speakernum++)
+		if (machine->speaker[speakernum].tag == NULL)
+		{
+			machine->speaker[speakernum].tag = tag;
+			machine->speaker[speakernum].x = x;
+			machine->speaker[speakernum].y = y;
+			machine->speaker[speakernum].z = z;
+			return &machine->speaker[speakernum];
+		}
+
+	logerror("Out of speakers!\n");
+	return NULL;
+}
+
+
+
+/*-------------------------------------------------
+    machine_find_speaker - find a tagged speaker
+    system during machine driver expansion
+-------------------------------------------------*/
+
+struct MachineSpeaker *machine_find_speaker(struct InternalMachineDriver *machine, const char *tag)
+{
+	int speakernum;
+
+	for (speakernum = 0; speakernum < MAX_SPEAKER; speakernum++)
+		if (machine->speaker[speakernum].tag && strcmp(machine->speaker[speakernum].tag, tag) == 0)
+			return &machine->speaker[speakernum];
+
+	logerror("Can't find speaker '%s'!\n", tag);
+	return NULL;
+}
+
+
+
+/*-------------------------------------------------
+    machine_remove_speaker - remove a tagged speaker
+    system during machine driver expansion
+-------------------------------------------------*/
+
+void machine_remove_speaker(struct InternalMachineDriver *machine, const char *tag)
+{
+	int speakernum;
+
+	for (speakernum = 0; speakernum < MAX_SPEAKER; speakernum++)
+		if (machine->speaker[speakernum].tag && strcmp(machine->speaker[speakernum].tag, tag) == 0)
+		{
+			memmove(&machine->speaker[speakernum], &machine->speaker[speakernum + 1], sizeof(machine->speaker[0]) * (MAX_SPEAKER - speakernum - 1));
+			memset(&machine->speaker[MAX_SPEAKER - 1], 0, sizeof(machine->speaker[0]));
+			return;
+		}
+
+	logerror("Can't find speaker '%s'!\n", tag);
+}
+
+
+
+/*-------------------------------------------------
+    machine_add_sound - add a sound system during
+    machine driver expansion
+-------------------------------------------------*/
+
+struct MachineSound *machine_add_sound(struct InternalMachineDriver *machine, const char *tag, int type, int clock)
 {
 	int soundnum;
 
@@ -1549,7 +1645,9 @@ struct MachineSound *machine_add_sound(struct InternalMachineDriver *machine, co
 		{
 			machine->sound[soundnum].tag = tag;
 			machine->sound[soundnum].sound_type = type;
-			machine->sound[soundnum].sound_interface = sndintf;
+			machine->sound[soundnum].clock = clock;
+			machine->sound[soundnum].config = NULL;
+			machine->sound[soundnum].routes = 0;
 			return &machine->sound[soundnum];
 		}
 
@@ -1561,8 +1659,8 @@ struct MachineSound *machine_add_sound(struct InternalMachineDriver *machine, co
 
 
 /*-------------------------------------------------
-	machine_find_sound - find a tagged sound
-	system during machine driver expansion
+    machine_find_sound - find a tagged sound
+    system during machine driver expansion
 -------------------------------------------------*/
 
 struct MachineSound *machine_find_sound(struct InternalMachineDriver *machine, const char *tag)
@@ -1580,8 +1678,8 @@ struct MachineSound *machine_find_sound(struct InternalMachineDriver *machine, c
 
 
 /*-------------------------------------------------
-	machine_remove_sound - remove a tagged sound
-	system during machine driver expansion
+    machine_remove_sound - remove a tagged sound
+    system during machine driver expansion
 -------------------------------------------------*/
 
 void machine_remove_sound(struct InternalMachineDriver *machine, const char *tag)
@@ -1602,8 +1700,8 @@ void machine_remove_sound(struct InternalMachineDriver *machine, const char *tag
 
 
 /*-------------------------------------------------
-	mame_chd_open - interface for opening
-	a hard disk image
+    mame_chd_open - interface for opening
+    a hard disk image
 -------------------------------------------------*/
 
 struct chd_interface_file *mame_chd_open(const char *filename, const char *mode)
@@ -1632,8 +1730,8 @@ struct chd_interface_file *mame_chd_open(const char *filename, const char *mode)
 
 
 /*-------------------------------------------------
-	mame_chd_close - interface for closing
-	a hard disk image
+    mame_chd_close - interface for closing
+    a hard disk image
 -------------------------------------------------*/
 
 void mame_chd_close(struct chd_interface_file *file)
@@ -1644,8 +1742,8 @@ void mame_chd_close(struct chd_interface_file *file)
 
 
 /*-------------------------------------------------
-	mame_chd_read - interface for reading
-	from a hard disk image
+    mame_chd_read - interface for reading
+    from a hard disk image
 -------------------------------------------------*/
 
 UINT32 mame_chd_read(struct chd_interface_file *file, UINT64 offset, UINT32 count, void *buffer)
@@ -1657,8 +1755,8 @@ UINT32 mame_chd_read(struct chd_interface_file *file, UINT64 offset, UINT32 coun
 
 
 /*-------------------------------------------------
-	mame_chd_write - interface for writing
-	to a hard disk image
+    mame_chd_write - interface for writing
+    to a hard disk image
 -------------------------------------------------*/
 
 UINT32 mame_chd_write(struct chd_interface_file *file, UINT64 offset, UINT32 count, const void *buffer)
@@ -1669,8 +1767,8 @@ UINT32 mame_chd_write(struct chd_interface_file *file, UINT64 offset, UINT32 cou
 
 
 /*-------------------------------------------------
-	mame_chd_length - interface for getting
-	the length a hard disk image
+    mame_chd_length - interface for getting
+    the length a hard disk image
 -------------------------------------------------*/
 
 UINT64 mame_chd_length(struct chd_interface_file *file)
@@ -1682,7 +1780,7 @@ UINT64 mame_chd_length(struct chd_interface_file *file)
 
 /***************************************************************************
 
-	Huge bunch of validity checks for the debug build
+    Huge bunch of validity checks for the debug build
 
 ***************************************************************************/
 
@@ -1731,7 +1829,7 @@ int mame_validitychecks(void)
 		}
 
 #if 0
-/*		if (drivers[i]->drv->color_table_len == drivers[i]->drv->total_colors && */
+/*      if (drivers[i]->drv->color_table_len == drivers[i]->drv->total_colors && */
 		if (drivers[i]->drv->color_table_len && drivers[i]->drv->total_colors &&
 				drivers[i]->drv->vh_init_palette == 0)
 		{
@@ -2005,11 +2103,11 @@ int mame_validitychecks(void)
 
 
 /*
-					if (type && (type >= REGION_MAX || type <= REGION_INVALID))
-					{
-						printf("%s: %s has invalid memory region for gfx[%d]\n",drivers[i]->source_file,drivers[i]->name,j);
-						error = 1;
-					}
+                    if (type && (type >= REGION_MAX || type <= REGION_INVALID))
+                    {
+                        printf("%s: %s has invalid memory region for gfx[%d]\n",drivers[i]->source_file,drivers[i]->name,j);
+                        error = 1;
+                    }
 */
 
 					if (!IS_FRAC(drv.gfxdecodeinfo[j].gfxlayout->total))
@@ -2035,7 +2133,7 @@ int mame_validitychecks(void)
 			}
 		}
 
-
+		/* consistency checks on input ports */
 		if (drivers[i]->construct_ipt)
 		{
 			begin_resource_tracking();
@@ -2136,6 +2234,48 @@ int mame_validitychecks(void)
 
 				inp++;
 			}
+
+
+			/* consistency checks on sound and speakers */
+			for (j = 0; j < MAX_SPEAKER && drv.speaker[j].tag; j++)
+			{
+				int k;
+				for (k = 0; k < MAX_SPEAKER && drv.speaker[k].tag; k++)
+					if (j != k && drv.speaker[k].tag && !strcmp(drv.speaker[j].tag, drv.speaker[k].tag))
+					{
+						printf("%s: %s has multiple speakers tagged as '%s'\n",drivers[i]->source_file,drivers[i]->name,drv.speaker[j].tag);
+						error = 1;
+					}
+				for (k = 0; k < MAX_SOUND && drv.sound[k].sound_type != SOUND_DUMMY; k++)
+					if (drv.sound[k].tag && !strcmp(drv.speaker[j].tag, drv.sound[k].tag))
+					{
+						printf("%s: %s has both a speaker and a sound chip tagged as '%s'\n",drivers[i]->source_file,drivers[i]->name,drv.speaker[j].tag);
+						error = 1;
+					}
+			}
+
+			for (j = 0; j < MAX_SOUND && drv.sound[j].sound_type != SOUND_DUMMY; j++)
+			{
+				int k, l;
+				for (k = 0; k < drv.sound[j].routes; k++)
+				{
+					for (l = 0; l < MAX_SPEAKER && drv.speaker[l].tag; l++)
+						if (!strcmp(drv.sound[j].route[k].target, drv.speaker[l].tag))
+							break;
+					if (l >= MAX_SPEAKER || !drv.speaker[l].tag)
+					{
+						for (l = 0; l < MAX_SOUND && drv.sound[l].sound_type != SOUND_DUMMY; l++)
+							if (l != j && drv.sound[l].tag && !strcmp(drv.sound[l].tag, drv.sound[j].route[k].target))
+								break;
+						if (l >= MAX_SOUND || drv.sound[l].sound_type == SOUND_DUMMY)
+						{
+							printf("%s: %s attempting to route sound to non-existant speaker '%s'\n",drivers[i]->source_file,drivers[i]->name,drv.sound[j].route[k].target);
+							error = 1;
+						}
+					}
+				}
+			}
+
 			end_resource_tracking();
 		}
 	}
