@@ -1,8 +1,8 @@
 /***************************************************************************
 
-	mame.h
+    mame.h
 
-	Controls execution of the core MAME system.
+    Controls execution of the core MAME system.
 
 ***************************************************************************/
 
@@ -30,7 +30,7 @@ extern int gbPriorityBitmapIsDirty;
 
 /***************************************************************************
 
-	Parameters
+    Parameters
 
 ***************************************************************************/
 
@@ -59,7 +59,7 @@ extern int gbPriorityBitmapIsDirty;
 
 /***************************************************************************
 
-	Core description of the currently-running machine
+    Core description of the currently-running machine
 
 ***************************************************************************/
 
@@ -102,8 +102,8 @@ struct RunningMachine
 	float					refresh_rate;
 
 	/* remapped palette pen numbers. When you write directly to a bitmap in a
-	   non-paletteized mode, use this array to look up the pen number. For example,
-	   if you want to use color #6 in the palette, use pens[6] instead of just 6. */
+       non-paletteized mode, use this array to look up the pen number. For example,
+       if you want to use color #6 in the palette, use pens[6] instead of just 6. */
 	pen_t *					pens;
 
 	/* lookup table used to map gfx pen numbers to color numbers */
@@ -115,18 +115,12 @@ struct RunningMachine
 	/* video color depth: 16, 15 or 32 */
 	int						color_depth;
 
-	/* video orientation; obsolete; always set to 0 */
-	int						orientation;
-
 
 	/* ----- audio-related information ----- */
 
 	/* the digital audio sample rate; 0 if sound is disabled. */
 	int						sample_rate;
 
-	/* samples loaded from disk */
-	struct GameSamples *	samples;
-
 
 	/* ----- input-related information ----- */
 
@@ -177,7 +171,7 @@ struct RunningMachine
 
 /***************************************************************************
 
-	Options passed from the frontend to the main core
+    Options passed from the frontend to the main core
 
 ***************************************************************************/
 
@@ -247,11 +241,11 @@ struct GameOptions
 
 	const char *controller;	/* controller-specific cfg to load */
 
-#ifdef MESS	
-	UINT32	ram;
+	#ifdef MESS
+	UINT32 ram;
 	struct ImageFile image_files[32];
 	int		image_count;
-	int		disable_normal_ui;
+	int disable_normal_ui;
 
 	int		min_width;		/* minimum width for the display */
 	int		min_height;		/* minimum height for the display */
@@ -262,7 +256,7 @@ struct GameOptions
 
 /***************************************************************************
 
-	Display state passed to the OSD layer for rendering
+    Display state passed to the OSD layer for rendering
 
 ***************************************************************************/
 
@@ -314,7 +308,7 @@ struct mame_display
 
 /***************************************************************************
 
-	Performance data
+    Performance data
 
 ***************************************************************************/
 
@@ -330,7 +324,7 @@ struct performance_info
 
 /***************************************************************************
 
-	Globals referencing the current machine and the global options
+    Globals referencing the current machine and the global options
 
 ***************************************************************************/
 
@@ -341,7 +335,7 @@ extern struct RunningMachine *Machine;
 
 /***************************************************************************
 
-	Function prototypes
+    Function prototypes
 
 ***************************************************************************/
 
