@@ -30,7 +30,7 @@ void osd_wait_for_debugger(void);
 
 /******************************************************************************
 
-	Display
+    Display
 
 ******************************************************************************/
 
@@ -52,7 +52,6 @@ struct osd_create_params
 	int colors;					/* colors in the palette (including UI) */
 	float fps;					/* frame rate */
 	int video_attributes;		/* video flags from driver */
-	int orientation;			/* orientation requested by the user */
 };
 
 
@@ -132,7 +131,7 @@ const char *osd_get_fps_text(const struct performance_info *performance);
 
 /******************************************************************************
 
-	Sound
+    Sound
 
 ******************************************************************************/
 
@@ -163,9 +162,9 @@ void osd_stop_audio_stream(void);
 /*
   control master volume. attenuation is the attenuation in dB (a negative
   number). To convert from dB to a linear volume scale do the following:
-	volume = MAX_VOLUME;
-	while (attenuation++ < 0)
-		volume /= 1.122018454;		//	= (10 ^ (1/20)) = 1dB
+    volume = MAX_VOLUME;
+    while (attenuation++ < 0)
+        volume /= 1.122018454;      //  = (10 ^ (1/20)) = 1dB
 */
 void osd_set_mastervolume(int attenuation);
 int osd_get_mastervolume(void);
@@ -176,7 +175,7 @@ void osd_sound_enable(int enable);
 
 /******************************************************************************
 
-	Controls
+    Controls
 
 ******************************************************************************/
 
@@ -232,7 +231,7 @@ void osd_joystick_end_calibration(void);
 
 /******************************************************************************
 
-	File I/O
+    File I/O
 
 ******************************************************************************/
 
@@ -288,7 +287,7 @@ void osd_fclose(osd_file *file);
 
 /******************************************************************************
 
-	Timing
+    Timing
 
 ******************************************************************************/
 
@@ -309,7 +308,7 @@ cycles_t osd_profiling_ticks(void);
 
 /******************************************************************************
 
-	Miscellaneous
+    Miscellaneous
 
 ******************************************************************************/
 
@@ -328,6 +327,9 @@ int osd_display_loading_rom_message(const char *name,struct rom_load_data *romda
 /* interface is still active while the game is paused. */
 void osd_pause(int paused);
 
+/* checks to see if a pointer is bad */
+int osd_is_bad_read_ptr(const void *ptr, size_t size);
+
 /* aborts the program in some unexpected fatal way */
 #ifdef __GNUC__
 void CLIB_DECL osd_die(const char *text,...)
