@@ -1,5 +1,6 @@
 
 #include "driver.h"
+#include "sound/samples.h"
 
 /* Make sure that the sample name definitions in drivers/astrof.c matches these */
 
@@ -40,7 +41,6 @@ static const char *astrof_sample_names[] =
 struct Samplesinterface astrof_samples_interface =
 {
 	4,	/* 4 channels */
-	25,	/* volume */
 	astrof_sample_names
 };
 
@@ -56,7 +56,6 @@ static const char *tomahawk_sample_names[] =
 struct Samplesinterface tomahawk_samples_interface =
 {
 	1,	/* 1 channel for now */
-	25,	/* volume */
 	0,/*tomahawk_sample_names */
 };
 
@@ -83,7 +82,7 @@ WRITE8_HANDLER( astrof_sample1_w )
 	if ((data & 0x04) && !(last & 0x04))
 	{
 		/* I *know* that the effect select port will be written shortly
-		   after this one, so this works */
+           after this one, so this works */
 		start_explosion = 1;
 	}
 
@@ -137,8 +136,8 @@ WRITE8_HANDLER( astrof_sample2_w )
 		if (data & 0x04)
 		{
 			/* This is really a compound effect, made up of I believe 3 sound
-			   effects, but since our sample contains them all, disable playing
-			   the other effects while the explosion is playing */
+               effects, but since our sample contains them all, disable playing
+               the other effects while the explosion is playing */
 			if (!bosskill_playing)
 			{
 				sample_start(CHANNEL_EXPLOSION,SAMPLE_BOSSKILL,0);
