@@ -33,6 +33,10 @@ Static Program ROM (48K bytes)            4000-FFFF   R    D0-D7
 #include "machine/atarigen.h"
 #include "sndhrdw/atarijsa.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/5220intf.h"
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
+#include "sound/pokey.h"
 
 static UINT8 *bank_base;
 static UINT8 *bank_source_data;
@@ -70,7 +74,7 @@ static WRITE8_HANDLER( jsa3_io_w );
 
 /*************************************
  *
- *	External interfaces
+ *  External interfaces
  *
  *************************************/
 
@@ -159,7 +163,7 @@ void atarijsa_reset(void)
 
 /*************************************
  *
- *	JSA I I/O handlers
+ *  JSA I I/O handlers
  *
  *************************************/
 
@@ -179,15 +183,15 @@ static READ8_HANDLER( jsa1_io_r )
 
 		case 0x004:		/* /RDIO */
 			/*
-				0x80 = self test
-				0x40 = NMI line state (active low)
-				0x20 = sound output full
-				0x10 = TMS5220 ready (active low)
-				0x08 = +5V
-				0x04 = +5V
-				0x02 = coin 2
-				0x01 = coin 1
-			*/
+                0x80 = self test
+                0x40 = NMI line state (active low)
+                0x20 = sound output full
+                0x10 = TMS5220 ready (active low)
+                0x08 = +5V
+                0x04 = +5V
+                0x02 = coin 2
+                0x01 = coin 1
+            */
 			result = readinputport(input_port);
 			if (!(readinputport(test_port) & test_mask)) result ^= 0x80;
 			if (atarigen_cpu_to_sound_ready) result ^= 0x40;
@@ -235,14 +239,14 @@ static WRITE8_HANDLER( jsa1_io_w )
 
 		case 0x204:		/* WRIO */
 			/*
-				0xc0 = bank address
-				0x20 = coin counter 2
-				0x10 = coin counter 1
-				0x08 = squeak (tweaks the 5220 frequency)
-				0x04 = TMS5220 reset (active low)
-				0x02 = TMS5220 write strobe (active low)
-				0x01 = YM2151 reset (active low)
-			*/
+                0xc0 = bank address
+                0x20 = coin counter 2
+                0x10 = coin counter 1
+                0x08 = squeak (tweaks the 5220 frequency)
+                0x04 = TMS5220 reset (active low)
+                0x02 = TMS5220 write strobe (active low)
+                0x01 = YM2151 reset (active low)
+            */
 
 			/* handle TMS5220 I/O */
 			if (has_tms5220)
@@ -266,11 +270,11 @@ static WRITE8_HANDLER( jsa1_io_w )
 
 		case 0x206:		/* MIX */
 			/*
-				0xc0 = TMS5220 volume (0-3)
-				0x30 = POKEY volume (0-3)
-				0x0e = YM2151 volume (0-7)
-				0x01 = low-pass filter enable
-			*/
+                0xc0 = TMS5220 volume (0-3)
+                0x30 = POKEY volume (0-3)
+                0x0e = YM2151 volume (0-7)
+                0x01 = low-pass filter enable
+            */
 			tms5220_volume = ((data >> 6) & 3) * 100 / 3;
 			pokey_volume = ((data >> 4) & 3) * 100 / 3;
 			ym2151_volume = ((data >> 1) & 7) * 100 / 7;
@@ -283,7 +287,7 @@ static WRITE8_HANDLER( jsa1_io_w )
 
 /*************************************
  *
- *	JSA II I/O handlers
+ *  JSA II I/O handlers
  *
  *************************************/
 
@@ -306,15 +310,15 @@ static READ8_HANDLER( jsa2_io_r )
 
 		case 0x004:		/* /RDIO */
 			/*
-				0x80 = self test
-				0x40 = NMI line state (active low)
-				0x20 = sound output full
-				0x10 = +5V
-				0x08 = +5V
-				0x04 = +5V
-				0x02 = coin 2
-				0x01 = coin 1
-			*/
+                0x80 = self test
+                0x40 = NMI line state (active low)
+                0x20 = sound output full
+                0x10 = +5V
+                0x08 = +5V
+                0x04 = +5V
+                0x02 = coin 2
+                0x01 = coin 1
+            */
 			result = readinputport(input_port);
 			if (!(readinputport(test_port) & test_mask)) result ^= 0x80;
 			if (atarigen_cpu_to_sound_ready) result ^= 0x40;
@@ -364,14 +368,14 @@ static WRITE8_HANDLER( jsa2_io_w )
 
 		case 0x204:		/* /WRIO */
 			/*
-				0xc0 = bank address
-				0x20 = coin counter 2
-				0x10 = coin counter 1
-				0x08 = voice frequency (tweaks the OKI6295 frequency)
-				0x04 = OKI6295 reset (active low)
-				0x02 = n/c
-				0x01 = YM2151 reset (active low)
-			*/
+                0xc0 = bank address
+                0x20 = coin counter 2
+                0x10 = coin counter 1
+                0x08 = voice frequency (tweaks the OKI6295 frequency)
+                0x04 = OKI6295 reset (active low)
+                0x02 = n/c
+                0x01 = YM2151 reset (active low)
+            */
 
 			/* update the bank */
 			memcpy(bank_base, &bank_source_data[0x1000 * ((data >> 6) & 3)], 0x1000);
@@ -387,12 +391,12 @@ static WRITE8_HANDLER( jsa2_io_w )
 
 		case 0x206:		/* /MIX */
 			/*
-				0xc0 = n/c
-				0x20 = low-pass filter enable
-				0x10 = n/c
-				0x0e = YM2151 volume (0-7)
-				0x01 = OKI6295 volume (0-1)
-			*/
+                0xc0 = n/c
+                0x20 = low-pass filter enable
+                0x10 = n/c
+                0x0e = YM2151 volume (0-7)
+                0x01 = OKI6295 volume (0-1)
+            */
 			ym2151_volume = ((data >> 1) & 7) * 100 / 7;
 			oki6295_volume = 50 + (data & 1) * 50;
 			update_all_volumes();
@@ -404,7 +408,7 @@ static WRITE8_HANDLER( jsa2_io_w )
 
 /*************************************
  *
- *	JSA III I/O handlers
+ *  JSA III I/O handlers
  *
  *************************************/
 
@@ -425,15 +429,15 @@ static READ8_HANDLER( jsa3_io_r )
 
 		case 0x004:		/* /RDIO */
 			/*
-				0x80 = self test (active high)
-				0x40 = NMI line state (active high)
-				0x20 = sound output full (active high)
-				0x10 = self test (active high)
-				0x08 = service (active high)
-				0x04 = tilt (active high)
-				0x02 = coin L (active high)
-				0x01 = coin R (active high)
-			*/
+                0x80 = self test (active high)
+                0x40 = NMI line state (active high)
+                0x20 = sound output full (active high)
+                0x10 = self test (active high)
+                0x08 = service (active high)
+                0x04 = tilt (active high)
+                0x02 = coin L (active high)
+                0x01 = coin R (active high)
+            */
 			result = readinputport(input_port);
 			if (!(readinputport(test_port) & test_mask)) result ^= 0x90;
 			if (atarigen_cpu_to_sound_ready) result ^= 0x40;
@@ -485,14 +489,14 @@ static WRITE8_HANDLER( jsa3_io_w )
 
 		case 0x204:		/* /WRIO */
 			/*
-				0xc0 = bank address
-				0x20 = coin counter 2
-				0x10 = coin counter 1
-				0x08 = voice frequency (tweaks the OKI6295 frequency)
-				0x04 = OKI6295 reset (active low)
-				0x02 = OKI6295 bank bit 0
-				0x01 = YM2151 reset (active low)
-			*/
+                0xc0 = bank address
+                0x20 = coin counter 2
+                0x10 = coin counter 1
+                0x08 = voice frequency (tweaks the OKI6295 frequency)
+                0x04 = OKI6295 reset (active low)
+                0x02 = OKI6295 bank bit 0
+                0x01 = YM2151 reset (active low)
+            */
 
 			/* update the OKI bank */
 			oki6295_bank_base = (0x40000 * ((data >> 1) & 1)) | (oki6295_bank_base & 0x80000);
@@ -512,12 +516,12 @@ static WRITE8_HANDLER( jsa3_io_w )
 
 		case 0x206:		/* /MIX */
 			/*
-				0xc0 = n/c
-				0x20 = low-pass filter enable
-				0x10 = OKI6295 bank bit 1
-				0x0e = YM2151 volume (0-7)
-				0x01 = OKI6295 volume (0-1)
-			*/
+                0xc0 = n/c
+                0x20 = low-pass filter enable
+                0x10 = OKI6295 bank bit 1
+                0x0e = YM2151 volume (0-7)
+                0x01 = OKI6295 volume (0-1)
+            */
 
 			/* update the OKI bank */
 			oki6295_bank_base = (0x80000 * ((data >> 4) & 1)) | (oki6295_bank_base & 0x40000);
@@ -535,7 +539,7 @@ static WRITE8_HANDLER( jsa3_io_w )
 
 /*************************************
  *
- *	JSA IIIS I/O handlers
+ *  JSA IIIS I/O handlers
  *
  *************************************/
 
@@ -561,15 +565,15 @@ static READ8_HANDLER( jsa3s_io_r )
 
 		case 0x004:		/* /RDIO */
 			/*
-				0x80 = self test (active high)
-				0x40 = NMI line state (active high)
-				0x20 = sound output full (active high)
-				0x10 = self test (active high)
-				0x08 = service (active high)
-				0x04 = tilt (active high)
-				0x02 = coin L (active high)
-				0x01 = coin R (active high)
-			*/
+                0x80 = self test (active high)
+                0x40 = NMI line state (active high)
+                0x20 = sound output full (active high)
+                0x10 = self test (active high)
+                0x08 = service (active high)
+                0x04 = tilt (active high)
+                0x02 = coin L (active high)
+                0x01 = coin R (active high)
+            */
 			result = readinputport(input_port);
 			if (!(readinputport(test_port) & test_mask)) result ^= 0x90;
 			if (atarigen_cpu_to_sound_ready) result ^= 0x40;
@@ -626,14 +630,14 @@ static WRITE8_HANDLER( jsa3s_io_w )
 
 		case 0x204:		/* /WRIO */
 			/*
-				0xc0 = bank address
-				0x20 = coin counter 2
-				0x10 = coin counter 1
-				0x08 = voice frequency (tweaks the OKI6295 frequency)
-				0x04 = OKI6295 reset (active low)
-				0x02 = left OKI6295 bank bit 0
-				0x01 = YM2151 reset (active low)
-			*/
+                0xc0 = bank address
+                0x20 = coin counter 2
+                0x10 = coin counter 1
+                0x08 = voice frequency (tweaks the OKI6295 frequency)
+                0x04 = OKI6295 reset (active low)
+                0x02 = left OKI6295 bank bit 0
+                0x01 = YM2151 reset (active low)
+            */
 
 			/* update the OKI bank */
 			oki6295_bank_base = (0x40000 * ((data >> 1) & 1)) | (oki6295_bank_base & 0x80000);
@@ -654,12 +658,12 @@ static WRITE8_HANDLER( jsa3s_io_w )
 
 		case 0x206:		/* /MIX */
 			/*
-				0xc0 = right OKI6295 bank bits 0-1
-				0x20 = low-pass filter enable
-				0x10 = left OKI6295 bank bit 1
-				0x0e = YM2151 volume (0-7)
-				0x01 = OKI6295 volume (0-1)
-			*/
+                0xc0 = right OKI6295 bank bits 0-1
+                0x20 = low-pass filter enable
+                0x10 = left OKI6295 bank bit 1
+                0x0e = YM2151 volume (0-7)
+                0x01 = OKI6295 volume (0-1)
+            */
 
 			/* update the OKI bank */
 			oki6295_bank_base = (0x80000 * ((data >> 4) & 1)) | (oki6295_bank_base & 0x40000);
@@ -678,7 +682,7 @@ static WRITE8_HANDLER( jsa3s_io_w )
 
 /*************************************
  *
- *	Volume helpers
+ *  Volume helpers
  *
  *************************************/
 
@@ -694,7 +698,7 @@ static void update_all_volumes(void)
 
 /*************************************
  *
- *	Sound CPU memory handlers
+ *  Sound CPU memory handlers
  *
  *************************************/
 
@@ -769,80 +773,38 @@ ADDRESS_MAP_END
 
 /*************************************
  *
- *	Sound definitions
+ *  Sound definitions
  *
  *************************************/
 
-static struct TMS5220interface tms5220_interface =
-{
-	ATARI_CLOCK_3MHz*2/11,	/* potentially ATARI_CLOCK_3MHz/9 as well */
-	100,
-	0
-};
-
-
-static struct POKEYinterface pokey_interface =
-{
-	1,			/* 1 chip */
-	ATARI_CLOCK_3MHz/2,
-	{ 40 },
-};
-
-
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	ATARI_CLOCK_3MHz,
-	{ YM3012_VOL(60,MIXER_PAN_LEFT,60,MIXER_PAN_RIGHT) },
-	{ atarigen_ym2151_irq_gen }
-};
-
-
-static struct YM2151interface ym2151_interface_swapped =
-{
-	1,			/* 1 chip */
-	ATARI_CLOCK_3MHz,
-	{ YM3012_VOL(60,MIXER_PAN_RIGHT,60,MIXER_PAN_LEFT) },
-	{ atarigen_ym2151_irq_gen }
-};
-
-
-static struct OKIM6295interface okim6295_interface =
-{
-	1,              /* 1 chip */
-	{ ATARI_CLOCK_3MHz/3/132 },
-	{ REGION_SOUND1 },
-	{ 75 }
-};
-
-
-static struct OKIM6295interface okim6295s_interface =
-{
-	2, 				/* 2 chips */
-	{ ATARI_CLOCK_3MHz/3/132, ATARI_CLOCK_3MHz/3/132 },
-	{ REGION_SOUND1, REGION_SOUND1 },
-	{ MIXER(75,MIXER_PAN_LEFT), MIXER(75,MIXER_PAN_RIGHT) }
+	atarigen_ym2151_irq_gen
 };
 
 
 
 /*************************************
  *
- *	Machine drivers
+ *  Machine drivers
  *
  *************************************/
 
 /* Used by Blasteroids */
 MACHINE_DRIVER_START( jsa_i_stereo )
-	
+
 	/* basic machine hardware */
 	MDRV_CPU_ADD_TAG("jsa", M6502, ATARI_CLOCK_3MHz/2)
 	MDRV_CPU_PROGRAM_MAP(atarijsa1_readmem,atarijsa1_writemem)
 	MDRV_CPU_PERIODIC_INT(atarigen_6502_irq_gen,(UINT32)(1000000000.0/((double)ATARI_CLOCK_3MHz/4/16/16/14)))
-	
+
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD_TAG("ym", YM2151, ym2151_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD_TAG("ym", YM2151, ATARI_CLOCK_3MHz)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.60)
+	MDRV_SOUND_ROUTE(1, "right", 0.60)
 MACHINE_DRIVER_END
 
 
@@ -851,9 +813,12 @@ MACHINE_DRIVER_START( jsa_i_stereo_swapped )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(jsa_i_stereo)
-	
+
 	/* sound hardware */
-	MDRV_SOUND_REPLACE("ym", YM2151, ym2151_interface_swapped)
+	MDRV_SOUND_REPLACE("ym", YM2151, ATARI_CLOCK_3MHz)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "right", 0.60)
+	MDRV_SOUND_ROUTE(1, "left", 0.60)
 MACHINE_DRIVER_END
 
 
@@ -862,9 +827,11 @@ MACHINE_DRIVER_START( jsa_i_stereo_pokey )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(jsa_i_stereo)
-	
+
 	/* sound hardware */
-	MDRV_SOUND_ADD(POKEY, pokey_interface)
+	MDRV_SOUND_ADD(POKEY, ATARI_CLOCK_3MHz/2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.40)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.40)
 MACHINE_DRIVER_END
 
 
@@ -872,31 +839,48 @@ MACHINE_DRIVER_END
 MACHINE_DRIVER_START( jsa_i_mono_speech )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(jsa_i_stereo)
-	
+	MDRV_CPU_ADD_TAG("jsa", M6502, ATARI_CLOCK_3MHz/2)
+	MDRV_CPU_PROGRAM_MAP(atarijsa1_readmem,atarijsa1_writemem)
+	MDRV_CPU_PERIODIC_INT(atarigen_6502_irq_gen,(UINT32)(1000000000.0/((double)ATARI_CLOCK_3MHz/4/16/16/14)))
+
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(0)
-	MDRV_SOUND_ADD(TMS5220, tms5220_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD_TAG("ym", YM2151, ATARI_CLOCK_3MHz)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.60)
+	MDRV_SOUND_ROUTE(1, "mono", 0.60)
+
+	MDRV_SOUND_ADD(TMS5220, ATARI_CLOCK_3MHz*2/11) /* potentially ATARI_CLOCK_3MHz/9 as well */
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 /* Used by Cyberball 2072, STUN Runner, Skull & Crossbones, ThunderJaws, Hydra, Pit Fighter */
 MACHINE_DRIVER_START( jsa_ii_mono )
-	
+
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(jsa_i_stereo)
-	MDRV_CPU_MODIFY("jsa")
+	MDRV_CPU_ADD_TAG("jsa", M6502, ATARI_CLOCK_3MHz/2)
 	MDRV_CPU_PROGRAM_MAP(atarijsa2_readmem,atarijsa2_writemem)
-	
+	MDRV_CPU_PERIODIC_INT(atarigen_6502_irq_gen,(UINT32)(1000000000.0/((double)ATARI_CLOCK_3MHz/4/16/16/14)))
+
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(0)
-	MDRV_SOUND_ADD_TAG("adpcm", OKIM6295, okim6295_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD_TAG("ym", YM2151, ATARI_CLOCK_3MHz)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.60)
+	MDRV_SOUND_ROUTE(1, "mono", 0.60)
+
+	MDRV_SOUND_ADD_TAG("adpcm", OKIM6295, ATARI_CLOCK_3MHz/3/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
 MACHINE_DRIVER_END
 
 
 /* Used by Batman, Guardians of the 'Hood, Road Riot 4WD */
 MACHINE_DRIVER_START( jsa_iii_mono )
-	
+
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(jsa_ii_mono)
 	MDRV_CPU_MODIFY("jsa")
@@ -906,7 +890,7 @@ MACHINE_DRIVER_END
 
 /* Used by Off the Wall */
 MACHINE_DRIVER_START( jsa_iii_mono_noadpcm )
-	
+
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(jsa_iii_mono)
 
@@ -917,13 +901,25 @@ MACHINE_DRIVER_END
 
 /* Used by Space Lords, Moto Frenzy, Steel Talons, Road Riot's Revenge Rally */
 MACHINE_DRIVER_START( jsa_iiis_stereo )
-	
+
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(jsa_iii_mono)
-	MDRV_CPU_MODIFY("jsa")
+	MDRV_CPU_ADD_TAG("jsa", M6502, ATARI_CLOCK_3MHz/2)
 	MDRV_CPU_PROGRAM_MAP(atarijsa3s_readmem,atarijsa3s_writemem)
-	
+	MDRV_CPU_PERIODIC_INT(atarigen_6502_irq_gen,(UINT32)(1000000000.0/((double)ATARI_CLOCK_3MHz/4/16/16/14)))
+
 	/* sound hardware */
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_REPLACE("adpcm", OKIM6295, okim6295s_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD_TAG("ym", YM2151, ATARI_CLOCK_3MHz)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.60)
+	MDRV_SOUND_ROUTE(1, "right", 0.60)
+
+	MDRV_SOUND_ADD(OKIM6295, ATARI_CLOCK_3MHz/3/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.75)
+
+	MDRV_SOUND_ADD(OKIM6295, ATARI_CLOCK_3MHz/3/132)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.75)
 MACHINE_DRIVER_END
