@@ -1,16 +1,16 @@
 /***************************************************************************
 
-	Cinematronics vector hardware
+    Cinematronics vector hardware
 
-	Special thanks to Neil Bradley, Zonn Moore, and Jeff Mitchell of the
-	Retrocade Alliance
+    Special thanks to Neil Bradley, Zonn Moore, and Jeff Mitchell of the
+    Retrocade Alliance
 
-	Update:
-	6/27/99 Jim Hernandez -- 1st Attempt at Fixing Drone Star Castle sound and
-	                         pitch adjustments.
-	6/30/99 MLR added Rip Off, Solar Quest, Armor Attack (no samples yet)
+    Update:
+    6/27/99 Jim Hernandez -- 1st Attempt at Fixing Drone Star Castle sound and
+                             pitch adjustments.
+    6/30/99 MLR added Rip Off, Solar Quest, Armor Attack (no samples yet)
 
-	Bugs: Sometimes the death explosion (small explosion) does not trigger.
+    Bugs: Sometimes the death explosion (small explosion) does not trigger.
 
 ***************************************************************************/
 
@@ -18,11 +18,13 @@
 #include "cpu/ccpu/ccpu.h"
 #include "machine/z80fmly.h"
 #include "cinemat.h"
+#include "sound/samples.h"
+#include "sound/ay8910.h"
 
 
 /*************************************
  *
- *	Macros
+ *  Macros
  *
  *************************************/
 
@@ -42,7 +44,7 @@
 
 /*************************************
  *
- *	Global variables
+ *  Global variables
  *
  *************************************/
 
@@ -66,14 +68,14 @@ static UINT8 last_portb_write;
 
 /*************************************
  *
- *	Generic sound write
+ *  Generic sound write
  *
  *************************************/
 
 WRITE8_HANDLER( cinemat_sound_control_w )
 {
 	UINT8 oldval = sound_control;
-	
+
 	/* form an 8-bit value with the new bit */
 	sound_control = (sound_control & ~(1 << offset)) | ((data & 1) << offset);
 
@@ -86,7 +88,7 @@ WRITE8_HANDLER( cinemat_sound_control_w )
 
 /*************************************
  *
- *	Generic sound init
+ *  Generic sound init
  *
  *************************************/
 
@@ -94,7 +96,7 @@ static void generic_init(void (*callback)(UINT8, UINT8))
 {
 	/* call the standard init */
 	machine_init_cinemat();
-	
+
 	/* set the sound handler */
 	sound_handler = callback;
 
@@ -117,7 +119,7 @@ static void generic_init(void (*callback)(UINT8, UINT8))
 
 /*************************************
  *
- *	Space Wars
+ *  Space Wars
  *
  *************************************/
 
@@ -138,7 +140,6 @@ static const char *spacewar_sample_names[] =
 static struct Samplesinterface spacewar_samples_interface =
 {
 	8,
-	50,
 	spacewar_sample_names
 };
 
@@ -188,14 +189,19 @@ static MACHINE_INIT( spacewar )
 
 MACHINE_DRIVER_START( spacewar_sound )
 	MDRV_MACHINE_INIT(spacewar)
-	MDRV_SOUND_ADD(SAMPLES, spacewar_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(spacewar_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Barrier
+ *  Barrier
  *
  *************************************/
 
@@ -211,7 +217,6 @@ static const char *barrier_sample_names[] =
 static struct Samplesinterface barrier_samples_interface =
 {
 	3,
-	50,
 	barrier_sample_names
 };
 
@@ -237,14 +242,19 @@ static MACHINE_INIT( barrier )
 
 MACHINE_DRIVER_START( barrier_sound )
 	MDRV_MACHINE_INIT(barrier)
-	MDRV_SOUND_ADD(SAMPLES, barrier_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(barrier_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Speed Freak
+ *  Speed Freak
  *
  *************************************/
 
@@ -258,7 +268,6 @@ static const char *speedfrk_sample_names[] =
 static struct Samplesinterface speedfrk_samples_interface =
 {
 	1,
-	50,
 	speedfrk_sample_names
 };
 
@@ -270,7 +279,7 @@ static void speedfrk_sound_w(UINT8 sound_val, UINT8 bits_changed)
 		current_shift = ((current_shift >> 1) & 0x7fff) | ((~sound_val << 13) & 1);
 		/* high 12 bits control the frequency - counts from value to $FFF, carry triggers */
 		/* another counter */
-		
+
 		/* low 4 bits control the volume of the noise output (explosion?) */
 	}
 
@@ -291,14 +300,19 @@ static MACHINE_INIT( speedfrk )
 
 MACHINE_DRIVER_START( speedfrk_sound )
 	MDRV_MACHINE_INIT(speedfrk)
-	MDRV_SOUND_ADD(SAMPLES, speedfrk_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(speedfrk_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Star Hawk
+ *  Star Hawk
  *
  *************************************/
 
@@ -317,7 +331,6 @@ static const char *starhawk_sample_names[] =
 static struct Samplesinterface starhawk_samples_interface =
 {
 	5,
-	50,
 	starhawk_sample_names
 };
 
@@ -334,19 +347,19 @@ static void starhawk_sound_w(UINT8 sound_val, UINT8 bits_changed)
 	/* left laser - falling edge */
 	if (SOUNDVAL_FALLING_EDGE(0x04))
 		sample_start(2, 2, 0);
-	
+
 	/* K - 0=on, 1=off */
 	if (SOUNDVAL_FALLING_EDGE(0x08))
 		sample_start(3, 3, 1);
 	if (SOUNDVAL_RISING_EDGE(0x08))
 		sample_stop(3);
-	
+
 	/* master - 0=on, 1=off */
 	if (SOUNDVAL_FALLING_EDGE(0x10))
 		sample_start(4, 4, 1);
 	if (SOUNDVAL_RISING_EDGE(0x10))
 		sample_stop(4);
-	
+
 	/* K exit - 1=on, 0=off */
 	if (SOUNDVAL_RISING_EDGE(0x80))
 		sample_start(3, 5, 1);
@@ -361,14 +374,19 @@ static MACHINE_INIT( starhawk )
 
 MACHINE_DRIVER_START( starhawk_sound )
 	MDRV_MACHINE_INIT(starhawk)
-	MDRV_SOUND_ADD(SAMPLES, starhawk_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(starhawk_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Sundance
+ *  Sundance
  *
  *************************************/
 
@@ -387,7 +405,6 @@ static const char *sundance_sample_names[] =
 static struct Samplesinterface sundance_samples_interface =
 {
 	6,
-	50,
 	sundance_sample_names
 };
 
@@ -425,14 +442,19 @@ static MACHINE_INIT( sundance )
 
 MACHINE_DRIVER_START( sundance_sound )
 	MDRV_MACHINE_INIT(sundance)
-	MDRV_SOUND_ADD(SAMPLES, sundance_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(sundance_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Tail Gunner
+ *  Tail Gunner
  *
  *************************************/
 
@@ -451,7 +473,6 @@ static const char *tailg_sample_names[] =
 static struct Samplesinterface tailg_samples_interface =
 {
 	6,
-	50,
 	tailg_sample_names
 };
 
@@ -486,13 +507,13 @@ static void tailg_sound_w(UINT8 sound_val, UINT8 bits_changed)
 			sample_stop(3);
 
 		/* bounce - falling edge */
-		if (SHIFTREG_FALLING_EDGE(0x10))	
+		if (SHIFTREG_FALLING_EDGE(0x10))
 			sample_start(4, 4, 0);
 
 		/* hyperspace - falling edge */
 		if (SHIFTREG_FALLING_EDGE(0x20))
 			sample_start(5, 5, 0);
-		
+
 		/* LED */
 		set_led_status(0, current_shift & 0x40);
 
@@ -508,14 +529,19 @@ static MACHINE_INIT( tailg )
 
 MACHINE_DRIVER_START( tailg_sound )
 	MDRV_MACHINE_INIT(tailg)
-	MDRV_SOUND_ADD(SAMPLES, tailg_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(tailg_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Warrior
+ *  Warrior
  *
  *************************************/
 
@@ -533,7 +559,6 @@ static const char *warrior_sample_names[] =
 static struct Samplesinterface warrior_samples_interface =
 {
 	5,
-	50,
 	warrior_sample_names
 };
 
@@ -571,14 +596,19 @@ static MACHINE_INIT( warrior )
 
 MACHINE_DRIVER_START( warrior_sound )
 	MDRV_MACHINE_INIT(warrior)
-	MDRV_SOUND_ADD(SAMPLES, warrior_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(warrior_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Armor Attack
+ *  Armor Attack
  *
  *************************************/
 
@@ -598,7 +628,6 @@ static const char *armora_sample_names[] =
 static struct Samplesinterface armora_samples_interface =
 {
 	7,
-	50,
 	armora_sample_names
 };
 
@@ -612,11 +641,11 @@ static void armora_sound_w(UINT8 sound_val, UINT8 bits_changed)
 	if (SOUNDVAL_RISING_EDGE(0x01))
 	{
 		/* bits 0-4 control the tank sound speed */
-		
+
 		/* lo explosion - falling edge */
 		if (SHIFTREG_FALLING_EDGE(0x10))
 			sample_start(0, 0, 0);
-		
+
 		/* jeep fire - falling edge */
 		if (SHIFTREG_FALLING_EDGE(0x20))
 			sample_start(1, 1, 0);
@@ -660,14 +689,19 @@ static MACHINE_INIT( armora )
 
 MACHINE_DRIVER_START( armora_sound )
 	MDRV_MACHINE_INIT(armora)
-	MDRV_SOUND_ADD(SAMPLES, armora_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(armora_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Ripoff
+ *  Ripoff
  *
  *************************************/
 
@@ -693,7 +727,6 @@ static const char *ripoff_sample_names[] =
 static struct Samplesinterface ripoff_samples_interface =
 {
 	6,
-	50,
 	ripoff_sample_names
 };
 
@@ -721,7 +754,7 @@ static void ripoff_sound_w(UINT8 sound_val, UINT8 bits_changed)
 			sample_start(1, 1, 1);
 		if (SHIFTREG_RISING_EDGE(0x01))
 			sample_stop(1);
-		
+
 		/* remember the previous value */
 		last_shift = current_shift;
 	}
@@ -746,14 +779,19 @@ static MACHINE_INIT( ripoff )
 
 MACHINE_DRIVER_START( ripoff_sound )
 	MDRV_MACHINE_INIT(ripoff)
-	MDRV_SOUND_ADD(SAMPLES, ripoff_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(ripoff_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Star Castle
+ *  Star Castle
  *
  *************************************/
 
@@ -774,7 +812,6 @@ static const char *starcas_sample_names[] =
 static struct Samplesinterface starcas_samples_interface =
 {
 	8,
-	50,
 	starcas_sample_names
 };
 
@@ -818,7 +855,7 @@ static void starcas_sound_w(UINT8 sound_val, UINT8 bits_changed)
 		/* latch the drone pitch */
 		target_pitch = (current_shift & 7) + ((current_shift & 2) << 2);
         target_pitch = 0x10000 + (target_pitch << 12);
-        
+
         /* once per frame slide the pitch toward the target */
         if (cpu_getcurrentframe() > last_frame)
         {
@@ -854,14 +891,19 @@ static MACHINE_INIT( starcas )
 
 MACHINE_DRIVER_START( starcas_sound )
 	MDRV_MACHINE_INIT(starcas)
-	MDRV_SOUND_ADD(SAMPLES, starcas_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(starcas_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.5)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Solar Quest
+ *  Solar Quest
  *
  *************************************/
 
@@ -882,13 +924,12 @@ static const char *solarq_sample_names[] =
 static struct Samplesinterface solarq_samples_interface =
 {
 	8,
-	50,
 	solarq_sample_names
 };
 
 static void solarq_sound_w(UINT8 sound_val, UINT8 bits_changed)
 {
-    static int target_volume, current_volume;
+    static float target_volume, current_volume;
 
 	/* on the rising edge of bit 0x10, clock bit 0x80 into the shift register */
 	if (SOUNDVAL_RISING_EDGE(0x10))
@@ -899,7 +940,7 @@ static void solarq_sound_w(UINT8 sound_val, UINT8 bits_changed)
 	{
 		/* only the upper 8 bits matter */
 		current_shift >>= 8;
-		
+
 		/* loud explosion - falling edge */
 		if (SHIFTREG_FALLING_EDGE(0x80))
 			sample_start(0, 0, 0);
@@ -911,7 +952,7 @@ static void solarq_sound_w(UINT8 sound_val, UINT8 bits_changed)
 		/* thrust - 0=on, 1=off */
 		if (SHIFTREG_FALLING_EDGE(0x20))
 		{
-			target_volume = 255;
+			target_volume = 1.0;
 			if (!sample_playing(2))
 				sample_start(2, 2, 1);
 		}
@@ -922,9 +963,9 @@ static void solarq_sound_w(UINT8 sound_val, UINT8 bits_changed)
         if (sample_playing(2) && cpu_getcurrentframe() > last_frame)
         {
             if (current_volume > target_volume)
-                current_volume -= 20;
+                current_volume -= 0.078;
             if (current_volume < target_volume)
-                current_volume += 20;
+                current_volume += 0.078;
             if (current_volume > 0)
                 sample_set_volume(2, current_volume);
             else
@@ -958,7 +999,7 @@ static void solarq_sound_w(UINT8 sound_val, UINT8 bits_changed)
 	if (SOUNDVAL_RISING_EDGE(0x01))
 	{
 		int freq, vol;
-		
+
 		/* start/stop the music sample on the high bit */
 		if (SHIFTREG2_RISING_EDGE(0x8000))
 			sample_start(7, 7, 1);
@@ -968,10 +1009,10 @@ static void solarq_sound_w(UINT8 sound_val, UINT8 bits_changed)
 		/* set the frequency */
 		freq = 56818.181818 / (4096 - (current_shift & 0xfff));
 		sample_set_freq(7, 44100 * freq / 1050);
-		
+
 		/* set the volume */
 		vol = (~current_shift >> 12) & 7;
-		sample_set_volume(7, 255 * vol / 7);
+		sample_set_volume(7, vol / 7.0);
 
 		/* remember the previous value */
 		last_shift2 = current_shift;
@@ -985,14 +1026,19 @@ static MACHINE_INIT( solarq )
 
 MACHINE_DRIVER_START( solarq_sound )
 	MDRV_MACHINE_INIT(solarq)
-	MDRV_SOUND_ADD(SAMPLES, solarq_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(solarq_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.5)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Boxing Bugs
+ *  Boxing Bugs
  *
  *************************************/
 
@@ -1017,7 +1063,6 @@ static const char *boxingb_sample_names[] =
 static struct Samplesinterface boxingb_samples_interface =
 {
 	12,
-	50,
 	boxingb_sample_names
 };
 
@@ -1032,7 +1077,7 @@ static void boxingb_sound_w(UINT8 sound_val, UINT8 bits_changed)
 	{
 		/* only the upper 8 bits matter */
 		current_shift >>= 8;
-		
+
 		/* soft explosion - falling edge */
 		if (SHIFTREG_FALLING_EDGE(0x80))
 			sample_start(0, 0, 0);
@@ -1070,12 +1115,12 @@ static void boxingb_sound_w(UINT8 sound_val, UINT8 bits_changed)
 		/* remember the previous value */
 		last_shift = current_shift;
 	}
-	
+
 	/* clock music data on the rising edge of bit 0x01 */
 	if (SOUNDVAL_RISING_EDGE(0x01))
 	{
 		int freq, vol;
-		
+
 		/* start/stop the music sample on the high bit */
 		if (SHIFTREG2_RISING_EDGE(0x8000))
 			sample_start(8, 8, 1);
@@ -1085,10 +1130,10 @@ static void boxingb_sound_w(UINT8 sound_val, UINT8 bits_changed)
 		/* set the frequency */
 		freq = 56818.181818 / (4096 - (current_shift & 0xfff));
 		sample_set_freq(8, 44100 * freq / 1050);
-		
+
 		/* set the volume */
 		vol = (~current_shift >> 12) & 3;
-		sample_set_volume(8, 255 * vol / 3);
+		sample_set_volume(8, vol / 3.0);
 
         /* cannon - falling edge */
         if (SHIFTREG2_RISING_EDGE(0x4000))
@@ -1114,14 +1159,19 @@ static MACHINE_INIT( boxingb )
 
 MACHINE_DRIVER_START( boxingb_sound )
 	MDRV_MACHINE_INIT(boxingb)
-	MDRV_SOUND_ADD(SAMPLES, boxingb_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(boxingb_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	War of the Worlds (B&W)
+ *  War of the Worlds (B&W)
  *
  *************************************/
 
@@ -1142,7 +1192,6 @@ static const char *wotw_sample_names[] =
 static struct Samplesinterface wotw_samples_interface =
 {
 	8,
-	50,
 	wotw_sample_names
 };
 
@@ -1186,7 +1235,7 @@ static void wotw_sound_w(UINT8 sound_val, UINT8 bits_changed)
 		/* latch the drone pitch */
 		target_pitch = (current_shift & 7) + ((current_shift & 2) << 2);
         target_pitch = 0x10000 + (target_pitch << 12);
-        
+
         /* once per frame slide the pitch toward the target */
         if (cpu_getcurrentframe() > last_frame)
         {
@@ -1222,14 +1271,19 @@ static MACHINE_INIT( wotw )
 
 MACHINE_DRIVER_START( wotw_sound )
 	MDRV_MACHINE_INIT(wotw)
-	MDRV_SOUND_ADD(SAMPLES, wotw_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(wotw_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	War of the Worlds (color)
+ *  War of the Worlds (color)
  *
  *************************************/
 
@@ -1250,7 +1304,6 @@ static const char *wotwc_sample_names[] =
 static struct Samplesinterface wotwc_samples_interface =
 {
 	8,
-	50,
 	wotwc_sample_names
 };
 
@@ -1294,7 +1347,7 @@ static void wotwc_sound_w(UINT8 sound_val, UINT8 bits_changed)
 		/* latch the drone pitch */
 		target_pitch = (current_shift & 7) + ((current_shift & 2) << 2);
         target_pitch = 0x10000 + (target_pitch << 12);
-        
+
         /* once per frame slide the pitch toward the target */
         if (cpu_getcurrentframe() > last_frame)
         {
@@ -1330,14 +1383,19 @@ static MACHINE_INIT( wotwc )
 
 MACHINE_DRIVER_START( wotwc_sound )
 	MDRV_MACHINE_INIT(wotwc)
-	MDRV_SOUND_ADD(SAMPLES, wotwc_samples_interface)
+
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_CONFIG(wotwc_samples_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	Demon
+ *  Demon
  *
  *************************************/
 
@@ -1381,16 +1439,12 @@ static WRITE8_HANDLER( sound_portb_w )
 	/* watch for a 0->1 edge of bit 1 ("hard reset") to reset the FIFO */
 	if ((data & 2) != (last_portb_write & 2) && (data & 2) != 0)
 		sound_fifo_in = sound_fifo_out = 0;
-	
+
 	/* bit 2 controls the global mute */
 	if ((data & 4) != (last_portb_write & 4))
-	{
-		int i;
-		for (i = 1; i < 3*3; i++)
-			mixer_set_volume(i, (data & 4) ? 0 : 100);
-	}
+		sound_global_enable(!(data & 4));
 
-	/* remember the last value written */	
+	/* remember the last value written */
 	last_portb_write = data;
 }
 
@@ -1401,15 +1455,20 @@ static WRITE8_HANDLER( sound_output_w )
 }
 
 
-static struct AY8910interface demon_ay8910_interface =
+static struct AY8910interface demon_ay8910_interface_1 =
 {
-	3,
-	3579545,
-	{ 25, 25, 25 },
-	{ sound_porta_r },
-	{ sound_portb_r },
-	{ 0 },
-	{ sound_portb_w, 0, sound_output_w }
+	sound_porta_r,
+	sound_portb_r,
+	0,
+	sound_portb_w
+};
+
+static struct AY8910interface demon_ay8910_interface_3 =
+{
+	0,
+	0,
+	0,
+	sound_output_w
 };
 
 
@@ -1443,7 +1502,7 @@ static MACHINE_INIT( demon_sound )
 	/* reset the FIFO */
 	sound_fifo_in = sound_fifo_out = 0;
 	last_portb_write = 0xff;
-	
+
 	/* turn off channel A on AY8910 #0 because it is used as a low-pass filter */
 	AY8910_set_volume(0, 0, 0);
 }
@@ -1466,6 +1525,7 @@ ADDRESS_MAP_END
 
 
 ADDRESS_MAP_START( demon_sound_ports, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 	AM_RANGE(0x00, 0x03) AM_WRITE(z80ctc_0_w)
 	AM_RANGE(0x1c, 0x1f) AM_WRITE(z80ctc_0_w)
 ADDRESS_MAP_END
@@ -1482,7 +1542,7 @@ MACHINE_DRIVER_START( demon_sound )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 3579545)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_CONFIG(daisy_chain)
 	MDRV_CPU_PROGRAM_MAP(demon_sound_map,0)
 	MDRV_CPU_IO_MAP(demon_sound_ports,0)
@@ -1490,14 +1550,25 @@ MACHINE_DRIVER_START( demon_sound )
 	MDRV_MACHINE_INIT(demon_sound)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(AY8910, demon_ay8910_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 3579545)
+	MDRV_SOUND_CONFIG(demon_ay8910_interface_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 3579545)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+
+	MDRV_SOUND_ADD(AY8910, 3579545)
+	MDRV_SOUND_CONFIG(demon_ay8910_interface_3)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
 
 
 /*************************************
  *
- *	QB3
+ *  QB3
  *
  *************************************/
 
@@ -1512,7 +1583,7 @@ static MACHINE_INIT( qb3_sound )
 {
 	machine_init_demon_sound();
 	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x04, 0x04, 0, 0, qb3_sound_w);
-	
+
 	/* this patch prevents the sound ROM from eating itself when command $0A is sent */
 	/* on a cube rotate */
 	memory_region(REGION_CPU2)[0x11dc] = 0x09;
