@@ -1,87 +1,88 @@
 /***************************************************************************
 
-	Midway DCS Audio Board
+    Midway DCS Audio Board
 
 ****************************************************************************
 
-	There are several variations of this board, which was in use by
-	Midway and eventually Atari for almost 10 years.
-	
-	DCS ROM-based mono:
-		* ADSP-2105 @ 10MHz
-		* single channel output
-		* ROM-based, up to 8MB total
-		* used in:
-			Mortal Kombat 2 (1993)
-			Mortal Kombat 3 (1994)
-			Ultimate Mortal Kombat 3 (1994)
-			Cruisin' USA (1994)
-			Revolution X (1994)
-			Killer Instinct (1994)
-			2 On 2 Open Ice Challenge (1995)
-			WWF Wrestlemania (1995)
-			Killer Instinct 2 (1995)
-			NBA Hangtime (1996)
-			NBA Maximum Hangtime (1996)
-			Cruisin' World (1996)
-			Rampage World Tour (1997)
-			Offroad Challenge (1997)
-	
-	DCS RAM-based stereo (Seattle):
-		* ADSP-2115 @ 16MHz
-		* dual channel output (stereo)
-		* RAM-based, 2-4MB total
-		* used in:
-			War Gods (1995)
-			Wayne Gretzky's 3D Hockey (1996)
-			Mace: The Dark Age (1996)
-			Biofreaks (1997)
-			NFL Blitz (1997)
-			California Speed (1998)
-			Vapor TRX (1998)
-			NFL Blitz '99 (1998)
-			CarnEvil (1998)
-			Hyperdrive (1998)
-			NFL Blitz 2000 Gold (1999)
-			
-	DCS ROM-based stereo (Zeus):
-		* ADSP-2104 @ 16MHz
-		* dual channel output (stereo)
-		* ROM-based, up to 12MB total
-		* used in:
-			Mortal Kombat 4 (1997)
-			Invasion (1999)
-			Cruisin' Exotica (1999)
-			The Grid (2001)
-	
-	DCS RAM-based stereo (Vegas):
-		* ADSP-2104 @ 16MHz
-		* dual channel output (stereo)
-		* RAM-based, 4MB total
-		* used in:
-			Gauntlet Legends (1998)
-			Tenth Degree (1998)
-			Gauntlet Dark Legacy (1999)
-			War: The Final Assault (1999)
-	
-	ADAGE/ADCS RAM-based multichannel:
-		* ADSP-2181 @ 16.667MHz
-		* 2-6 channel output
-		* RAM-based, 4MB total
-		* used in:
-			San Francisco Rush: 2049 (1998)
-			Road Burners (1999)
-			
-	Unknown other DCS boards:
-		* NBA Showtime
-		* NBA Showtime / NFL Blitz 2000 Gold
-		* Cart Fury
+    There are several variations of this board, which was in use by
+    Midway and eventually Atari for almost 10 years.
+
+    DCS ROM-based mono:
+        * ADSP-2105 @ 10MHz
+        * single channel output
+        * ROM-based, up to 8MB total
+        * used in:
+            Mortal Kombat 2 (1993)
+            Mortal Kombat 3 (1994)
+            Ultimate Mortal Kombat 3 (1994)
+            Cruisin' USA (1994)
+            Revolution X (1994)
+            Killer Instinct (1994)
+            2 On 2 Open Ice Challenge (1995)
+            WWF Wrestlemania (1995)
+            Killer Instinct 2 (1995)
+            NBA Hangtime (1996)
+            NBA Maximum Hangtime (1996)
+            Cruisin' World (1996)
+            Rampage World Tour (1997)
+            Offroad Challenge (1997)
+
+    DCS RAM-based stereo (Seattle):
+        * ADSP-2115 @ 16MHz
+        * dual channel output (stereo)
+        * RAM-based, 2-4MB total
+        * used in:
+            War Gods (1995)
+            Wayne Gretzky's 3D Hockey (1996)
+            Mace: The Dark Age (1996)
+            Biofreaks (1997)
+            NFL Blitz (1997)
+            California Speed (1998)
+            Vapor TRX (1998)
+            NFL Blitz '99 (1998)
+            CarnEvil (1998)
+            Hyperdrive (1998)
+            NFL Blitz 2000 Gold (1999)
+
+    DCS ROM-based stereo (Zeus):
+        * ADSP-2104 @ 16MHz
+        * dual channel output (stereo)
+        * ROM-based, up to 12MB total
+        * used in:
+            Mortal Kombat 4 (1997)
+            Invasion (1999)
+            Cruisin' Exotica (1999)
+            The Grid (2001)
+
+    DCS RAM-based stereo (Vegas):
+        * ADSP-2104 @ 16MHz
+        * dual channel output (stereo)
+        * RAM-based, 4MB total
+        * used in:
+            Gauntlet Legends (1998)
+            Tenth Degree (1998)
+            Gauntlet Dark Legacy (1999)
+            War: The Final Assault (1999)
+
+    ADAGE/ADCS RAM-based multichannel:
+        * ADSP-2181 @ 16.667MHz
+        * 2-6 channel output
+        * RAM-based, 4MB total
+        * used in:
+            San Francisco Rush: 2049 (1998)
+            Road Burners (1999)
+
+    Unknown other DCS boards:
+        * NBA Showtime
+        * NBA Showtime / NFL Blitz 2000 Gold
+        * Cart Fury
 
 ****************************************************************************/
 
 #include "driver.h"
 #include "cpu/adsp2100/adsp2100.h"
 #include "dcs.h"
+#include "sound/dmadac.h"
 
 #include <math.h>
 
@@ -95,7 +96,7 @@
 
 
 /***************************************************************************
-	CONSTANTS
+    CONSTANTS
 ****************************************************************************/
 
 #define LCTRL_OUTPUT_EMPTY			0x400
@@ -136,7 +137,7 @@ enum
 
 
 /***************************************************************************
-	STRUCTURES
+    STRUCTURES
 ****************************************************************************/
 
 struct dcs_state
@@ -176,7 +177,7 @@ struct dcs_state
 
 
 /***************************************************************************
-	STATIC GLOBALS
+    STATIC GLOBALS
 ****************************************************************************/
 
 static INT8 dcs_cpunum;
@@ -208,7 +209,7 @@ static mame_timer *transfer_watchdog;
 
 
 /***************************************************************************
-	PROTOTYPES
+    PROTOTYPES
 ****************************************************************************/
 
 static READ16_HANDLER( dcs_sdrc_asic_ver_r );
@@ -240,7 +241,7 @@ static int preprocess_write(data16_t data);
 
 
 /***************************************************************************
-	PROCESSOR STRUCTURES
+    PROCESSOR STRUCTURES
 ****************************************************************************/
 
 /* DCS readmem/writemem structures */
@@ -324,35 +325,48 @@ ADDRESS_MAP_END
 
 
 
-/***************************************************************************
-	AUDIO STRUCTURES
-****************************************************************************/
+/* DCS3-based readmem/writemem structures */
+ADDRESS_MAP_START( dcs3_program_map, ADDRESS_SPACE_PROGRAM, 32 )
+	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	AM_RANGE(0x0000, 0x3fff) AM_RAM	AM_BASE(&dcs_program_ram) /* internal/external program ram */
+ADDRESS_MAP_END
 
-static struct dmadac_interface dcs_dmadac_interface =
-{
-	1,
-	{ 100 }
-};
 
-static struct dmadac_interface dcs2_dmadac_interface =
-{
-	2,
-	{ MIXER(100, MIXER_PAN_RIGHT), MIXER(100, MIXER_PAN_LEFT) }
-};
+ADDRESS_MAP_START( dcs3_data_map, ADDRESS_SPACE_DATA, 16 )
+	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	AM_RANGE(0x0000, 0x03ff) AM_RAMBANK(20) AM_SIZE(&bank20_size) AM_BASE(&dcs_data_ram) /* D/RAM */
+	AM_RANGE(0x0400, 0x0400) AM_READWRITE(input_latch_r, input_latch_ack_w) /* input latch read */
+	AM_RANGE(0x0401, 0x0401) AM_WRITE(output_latch_w)			/* soundlatch write */
+	AM_RANGE(0x0402, 0x0402) AM_READWRITE(output_control_r, output_control_w) /* secondary soundlatch read */
+	AM_RANGE(0x0403, 0x0403) AM_READ(latch_status_r)			/* latch status read */
+	AM_RANGE(0x0404, 0x0407) AM_READ(fifo_input_r)				/* FIFO input read */
+	AM_RANGE(0x0480, 0x0480) AM_READWRITE(dcs2_sram_bank_r, dcs2_sram_bank_w) /* S/RAM bank */
+	AM_RANGE(0x0481, 0x0481) AM_NOP								/* LED in bit $2000 */
+	AM_RANGE(0x0482, 0x0482) AM_READWRITE(dcs_data_bank_select_r, dcs_data_bank_select_w) /* D/RAM bank */
+	AM_RANGE(0x0483, 0x0483) AM_READ(dcs_sdrc_asic_ver_r)		/* SDRC version number */
+	AM_RANGE(0x0800, 0x17ff) AM_RAM								/* S/RAM */
+	AM_RANGE(0x1800, 0x27ff) AM_RAMBANK(21) AM_BASE(&dcs_sram_bank0) /* banked S/RAM */
+	AM_RANGE(0x2800, 0x37ff) AM_RAM								/* S/RAM */
+	AM_RANGE(0x3800, 0x3fdf) AM_RAM								/* internal data ram */
+	AM_RANGE(0x3fe0, 0x3fff) AM_WRITE(dcs_control_w)			/* adsp control regs */
+ADDRESS_MAP_END
 
 
 
 /***************************************************************************
-	MACHINE DRIVERS
+    MACHINE DRIVERS
 ****************************************************************************/
 
 MACHINE_DRIVER_START( dcs_audio )
 	MDRV_CPU_ADD_TAG("dcs", ADSP2105, 10000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(dcs_program_map,0)
 	MDRV_CPU_DATA_MAP(dcs_data_map,0)
 
-	MDRV_SOUND_ADD(DMADAC, dcs_dmadac_interface)
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -366,12 +380,17 @@ MACHINE_DRIVER_END
 
 MACHINE_DRIVER_START( dcs2_audio )
 	MDRV_CPU_ADD_TAG("dcs2", ADSP2115, 16000000)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(dcs2_program_map,0)
 	MDRV_CPU_DATA_MAP(dcs2_data_map,0)
 
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(DMADAC, dcs2_dmadac_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -388,9 +407,37 @@ MACHINE_DRIVER_START( dcs2_audio_2104_rom )
 MACHINE_DRIVER_END
 
 
+MACHINE_DRIVER_START( dcs3_audio )
+	MDRV_CPU_ADD_TAG("dcs3", ADSP2181, 33000000)
+	/* audio CPU */
+	MDRV_CPU_PROGRAM_MAP(dcs3_program_map,0)
+	MDRV_CPU_DATA_MAP(dcs3_data_map,0)
+
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+
+	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+
+	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+MACHINE_DRIVER_END
+
+
 
 /***************************************************************************
-	INITIALIZATION
+    INITIALIZATION
 ****************************************************************************/
 
 static void dcs_boot(void)
@@ -398,7 +445,7 @@ static void dcs_boot(void)
 	UINT32 max_banks = dcs.databank_count * bank20_size / 0x1000;
 	UINT8 buffer[0x1000];
 	int i;
-	
+
 	for (i = 0; i < 0x1000; i++)
 		buffer[i] = dcs.soundboot[(dcs.databank % max_banks) * 0x1000 + i];
 	adsp2105_load_boot_data(buffer, dcs_program_ram);
@@ -487,6 +534,8 @@ void dcs2_init(offs_t polling_offset)
 {
 	/* find the DCS CPU and the sound ROMs */
 	dcs_cpunum = mame_find_cpu_index("dcs2");
+	if (dcs_cpunum == -1)
+		dcs_cpunum = mame_find_cpu_index("dcs3");
 	dcs.channels = 2;
 	dcs.soundboot = (UINT16 *)memory_region(REGION_SOUND1);
 	dcs.sounddata = dcs.soundboot + 0x10000/2;
@@ -551,6 +600,12 @@ void dcs2_rom_init(offs_t polling_offset)
 }
 
 
+void dcs3_init(offs_t polling_offset)
+{
+	dcs2_init(polling_offset);
+}
+
+
 void dcs_set_auto_ack(int state)
 {
 	dcs.auto_ack = state;
@@ -559,7 +614,7 @@ void dcs_set_auto_ack(int state)
 
 
 /***************************************************************************
-	DCS ASIC VERSION
+    DCS ASIC VERSION
 ****************************************************************************/
 
 static READ16_HANDLER( dcs_sdrc_asic_ver_r )
@@ -570,7 +625,7 @@ static READ16_HANDLER( dcs_sdrc_asic_ver_r )
 
 
 /***************************************************************************
-	DCS ROM BANK SELECT
+    DCS ROM BANK SELECT
 ****************************************************************************/
 
 static WRITE16_HANDLER( dcs_data_bank_select_w )
@@ -593,7 +648,7 @@ static READ16_HANDLER( dcs_data_bank_select_r )
 
 
 /***************************************************************************
-	DCS STATIC RAM BANK SELECT
+    DCS STATIC RAM BANK SELECT
 ****************************************************************************/
 
 static WRITE16_HANDLER( dcs2_sram_bank_w )
@@ -615,7 +670,7 @@ static READ16_HANDLER( dcs2_sram_bank_r )
 
 
 /***************************************************************************
-	DCS COMMUNICATIONS
+    DCS COMMUNICATIONS
 ****************************************************************************/
 
 void dcs_set_io_callbacks(void (*output_full_cb)(int), void (*input_empty_cb)(int))
@@ -685,7 +740,7 @@ static READ16_HANDLER( fifo_input_r )
 
 
 /***************************************************************************
-	INPUT LATCH (data from host to DCS)
+    INPUT LATCH (data from host to DCS)
 ****************************************************************************/
 
 static void dcs_delayed_data_w(int data)
@@ -744,7 +799,7 @@ static READ16_HANDLER( input_latch_r )
 
 
 /***************************************************************************
-	OUTPUT LATCH (data from DCS to host)
+    OUTPUT LATCH (data from DCS to host)
 ****************************************************************************/
 
 static void latch_delayed_w(int data)
@@ -792,7 +847,7 @@ int dcs_data_r(void)
 
 
 /***************************************************************************
-	OUTPUT CONTROL BITS (has 3 additional lines to the host)
+    OUTPUT CONTROL BITS (has 3 additional lines to the host)
 ****************************************************************************/
 
 static void output_control_delayed_w(int data)
@@ -827,26 +882,26 @@ int dcs_data2_r(void)
 
 
 /***************************************************************************
-	ADSP CONTROL & TRANSMIT CALLBACK
+    ADSP CONTROL & TRANSMIT CALLBACK
 ****************************************************************************/
 
 /*
-	The ADSP2105 memory map when in boot rom mode is as follows:
+    The ADSP2105 memory map when in boot rom mode is as follows:
 
-	Program Memory:
-	0x0000-0x03ff = Internal Program Ram (contents of boot rom gets copied here)
-	0x0400-0x07ff = Reserved
-	0x0800-0x3fff = External Program Ram
+    Program Memory:
+    0x0000-0x03ff = Internal Program Ram (contents of boot rom gets copied here)
+    0x0400-0x07ff = Reserved
+    0x0800-0x3fff = External Program Ram
 
-	Data Memory:
-	0x0000-0x03ff = External Data - 0 Waitstates
-	0x0400-0x07ff = External Data - 1 Waitstates
-	0x0800-0x2fff = External Data - 2 Waitstates
-	0x3000-0x33ff = External Data - 3 Waitstates
-	0x3400-0x37ff = External Data - 4 Waitstates
-	0x3800-0x39ff = Internal Data Ram
-	0x3a00-0x3bff = Reserved (extra internal ram space on ADSP2101, etc)
-	0x3c00-0x3fff = Memory Mapped control registers & reserved.
+    Data Memory:
+    0x0000-0x03ff = External Data - 0 Waitstates
+    0x0400-0x07ff = External Data - 1 Waitstates
+    0x0800-0x2fff = External Data - 2 Waitstates
+    0x3000-0x33ff = External Data - 3 Waitstates
+    0x3400-0x37ff = External Data - 4 Waitstates
+    0x3800-0x39ff = Internal Data Ram
+    0x3a00-0x3bff = Reserved (extra internal ram space on ADSP2101, etc)
+    0x3c00-0x3fff = Memory Mapped control registers & reserved.
 */
 
 static WRITE16_HANDLER( dcs_control_w )
@@ -892,7 +947,7 @@ static WRITE16_HANDLER( dcs_control_w )
 
 
 /***************************************************************************
-	DCS IRQ GENERATION CALLBACKS
+    DCS IRQ GENERATION CALLBACKS
 ****************************************************************************/
 
 static void dcs_irq(int state)
@@ -1002,7 +1057,7 @@ static void sound_tx_callback(int port, INT32 data)
 
 
 /***************************************************************************
-	VERY BASIC & SAFE OPTIMIZATIONS
+    VERY BASIC & SAFE OPTIMIZATIONS
 ****************************************************************************/
 
 static READ16_HANDLER( dcs_polling_r )
@@ -1014,7 +1069,7 @@ static READ16_HANDLER( dcs_polling_r )
 
 
 /***************************************************************************
-	DATA TRANSFER HLE MECHANISM
+    DATA TRANSFER HLE MECHANISM
 ****************************************************************************/
 
 void dcs_fifo_notify(int count, int max)
@@ -1025,7 +1080,7 @@ void dcs_fifo_notify(int count, int max)
 		transfer_fifo_entries = 0;
 		return;
 	}
-	
+
 	/* preprocess a word */
 	transfer_fifo_entries = count;
 	if (transfer_state != 5 || transfer_fifo_entries == transfer_writes_left || transfer_fifo_entries >= 256)
@@ -1288,7 +1343,7 @@ static int preprocess_stage_2(data16_t data)
 static int preprocess_write(data16_t data)
 {
 	int result;
-	
+
 	/* if we're not DCS2, skip */
 	if (!dcs.sport_timer)
 		return 0;
@@ -1298,7 +1353,7 @@ static int preprocess_write(data16_t data)
 		result = preprocess_stage_1(data);
 	else
 		result = preprocess_stage_2(data);
-	
+
 	/* if we did the write, toggle the full/not full state so interrupts are generated */
 	if (result && dcs.input_empty_cb)
 	{
