@@ -1,6 +1,6 @@
 /***************************************************************************
 
-	Midway DCS Audio Board
+    Midway DCS Audio Board
 
 ****************************************************************************/
 
@@ -10,10 +10,12 @@ MACHINE_DRIVER_EXTERN( dcs2_audio );
 MACHINE_DRIVER_EXTERN( dcs2_audio_2104 );
 MACHINE_DRIVER_EXTERN( dcs2_audio_2104_rom );
 MACHINE_DRIVER_EXTERN( dcs2_audio_2104_rom_word );
+MACHINE_DRIVER_EXTERN( dcs3_audio );
 
 void dcs_init(void);
 void dcs2_init(offs_t polling_offset);
 void dcs2_rom_init(offs_t polling_offset);
+void dcs3_init(offs_t polling_offset);
 void dcs_set_auto_ack(int state);
 
 void dcs_set_fifo_callbacks(UINT16 (*fifo_data_r)(void), UINT16 (*fifo_status_r)(void));
