@@ -1,9 +1,9 @@
 /***************************************************************************
 
-	Exidy 440 sound system
+    Exidy 440 sound system
 
-	Special thanks to Zonn Moore and Neil Bradley for letting me hack
-	their Retrocade CVSD decoder into the sound system here.
+    Special thanks to Zonn Moore and Neil Bradley for letting me hack
+    their Retrocade CVSD decoder into the sound system here.
 
 ***************************************************************************/
 
@@ -93,7 +93,7 @@ static int m6844_interrupt;
 static int m6844_chain;
 
 /* sound interface parameters */
-static int sound_stream;
+static sound_stream *stream;
 static sound_channel_data sound_channel[4];
 
 /* debugging */
@@ -113,7 +113,7 @@ static const int channel_bits[4] =
 
 
 /* function prototypes */
-static void channel_update(int ch, INT16 **buffer, int length);
+static void channel_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length);
 static void m6844_finished(int ch);
 static void play_cvsd(int ch);
 static void stop_cvsd(int ch);
@@ -149,19 +149,13 @@ static void finish_wav_file(void);
 
 /*************************************
  *
- *	Initialize the sound system
+ *  Initialize the sound system
  *
  *************************************/
 
-int exidy440_sh_start(const struct MachineSound *msound)
+void *exidy440_sh_start(int clock, const struct CustomSound_interface *config)
 {
-	const char *names[] =
-	{
-		"Exidy 440 sound left",
-		"Exidy 440 sound right"
-	};
 	int i, length;
-	int vol[2];
 
 	/* reset the system */
 	exidy440_sound_command = 0;
@@ -178,15 +172,11 @@ int exidy440_sh_start(const struct MachineSound *msound)
 	m6844_chain = 0x00;
 
 	/* get stream channels */
-	vol[0] = MIXER(100, MIXER_PAN_LEFT);
-	vol[1] = MIXER(100, MIXER_PAN_RIGHT);
-	sound_stream = stream_init_multi(2, names, vol, SAMPLE_RATE_FAST, 0, channel_update);
+	stream = stream_create(0, 2, SAMPLE_RATE_FAST, NULL, channel_update);
 
 	/* allocate the sample cache */
 	length = memory_region_length(REGION_SOUND1) * 16 + MAX_CACHE_ENTRIES * sizeof(sound_cache_entry);
 	sound_cache = auto_malloc(length);
-	if (!sound_cache)
-		return 1;
 
 	/* determine the hard end of the cache and reset */
 	sound_cache_max = (sound_cache_entry *)((UINT8 *)sound_cache + length);
@@ -194,25 +184,23 @@ int exidy440_sh_start(const struct MachineSound *msound)
 
 	/* allocate the mixer buffer */
 	mixer_buffer_left = auto_malloc(2 * SAMPLE_RATE_FAST * sizeof(INT32));
-	if (!mixer_buffer_left)
-		return 1;
 	mixer_buffer_right = mixer_buffer_left + SAMPLE_RATE_FAST;
 
 	if (SOUND_LOG)
 		debuglog = fopen("sound.log", "w");
 
-	return 0;
+	return auto_malloc(1);
 }
 
 
 
 /*************************************
  *
- *	Tear down the sound system
+ *  Tear down the sound system
  *
  *************************************/
 
-void exidy440_sh_stop(void)
+void exidy440_sh_stop(void *token)
 {
 	if (SOUND_LOG && debuglog)
 		fclose(debuglog);
@@ -222,19 +210,7 @@ void exidy440_sh_stop(void)
 
 /*************************************
  *
- *	Periodic sound update
- *
- *************************************/
-
-void exidy440_sh_update(void)
-{
-}
-
-
-
-/*************************************
- *
- *	Add a bunch of samples to the mix
+ *  Add a bunch of samples to the mix
  *
  *************************************/
 
@@ -278,11 +254,11 @@ static void add_and_scale_samples(int ch, INT32 *dest, int samples, int volume)
 
 /*************************************
  *
- *	Mix the result to 16 bits
+ *  Mix the result to 16 bits
  *
  *************************************/
 
-static void mix_to_16(int length, INT16 *dest_left, INT16 *dest_right)
+static void mix_to_16(int length, stream_sample_t *dest_left, stream_sample_t *dest_right)
 {
 	INT32 *mixer_left = mixer_buffer_left;
 	INT32 *mixer_right = mixer_buffer_right;
@@ -307,12 +283,14 @@ static void mix_to_16(int length, INT16 *dest_left, INT16 *dest_right)
 
 /*************************************
  *
- *	Stream callback
+ *  Stream callback
  *
  *************************************/
 
-static void channel_update(int ch, INT16 **buffer, int length)
+static void channel_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length)
 {
+	int ch;
+
 	/* reset the mixer buffers */
 	memset(mixer_buffer_left, 0, length * sizeof(INT32));
 	memset(mixer_buffer_right, 0, length * sizeof(INT32));
@@ -359,14 +337,14 @@ static void channel_update(int ch, INT16 **buffer, int length)
 	}
 
 	/* all done, time to mix it */
-	mix_to_16(length, buffer[0], buffer[1]);
+	mix_to_16(length, outputs[0], outputs[1]);
 }
 
 
 
 /*************************************
  *
- *	Sound command register
+ *  Sound command register
  *
  *************************************/
 
@@ -383,7 +361,7 @@ READ8_HANDLER( exidy440_sound_command_r )
 
 /*************************************
  *
- *	Sound volume registers
+ *  Sound volume registers
  *
  *************************************/
 
@@ -393,7 +371,7 @@ WRITE8_HANDLER( exidy440_sound_volume_w )
 		fprintf(debuglog, "Volume %02X=%02X\n", offset, data);
 
 	/* update the stream */
-	stream_update(sound_stream, 0);
+	stream_update(stream, 0);
 
 	/* set the new volume */
 	exidy440_sound_volume[offset] = ~data;
@@ -403,7 +381,7 @@ WRITE8_HANDLER( exidy440_sound_volume_w )
 
 /*************************************
  *
- *	Sound interrupt handling
+ *  Sound interrupt handling
  *
  *************************************/
 
@@ -416,14 +394,14 @@ WRITE8_HANDLER( exidy440_sound_interrupt_clear_w )
 
 /*************************************
  *
- *	MC6844 DMA controller interface
+ *  MC6844 DMA controller interface
  *
  *************************************/
 
 void exidy440_m6844_update(void)
 {
 	/* update the stream */
-	stream_update(sound_stream, 0);
+	stream_update(stream, 0);
 }
 
 
@@ -447,7 +425,7 @@ void m6844_finished(int ch)
 
 /*************************************
  *
- *	MC6844 DMA controller I/O
+ *  MC6844 DMA controller I/O
  *
  *************************************/
 
@@ -635,7 +613,7 @@ WRITE8_HANDLER( exidy440_m6844_w )
 
 /*************************************
  *
- *	Sound cache management
+ *  Sound cache management
  *
  *************************************/
 
@@ -687,7 +665,7 @@ INT16 *find_or_add_to_sound_cache(int address, int length, int bits, int frequen
 
 /*************************************
  *
- *	Internal CVSD decoder and player
+ *  Internal CVSD decoder and player
  *
  *************************************/
 
@@ -742,7 +720,7 @@ void stop_cvsd(int ch)
 {
 	/* the DMA channel is marked inactive; that will kill the audio */
 	sound_channel[ch].remaining = 0;
-	stream_update(sound_stream, 0);
+	stream_update(stream, 0);
 
 	if (SOUND_LOG && debuglog)
 		fprintf(debuglog, "Channel %d stop\n", ch);
@@ -752,7 +730,7 @@ void stop_cvsd(int ch)
 
 /*************************************
  *
- *	FIR digital filter
+ *  FIR digital filter
  *
  *************************************/
 
@@ -787,7 +765,7 @@ void fir_filter(INT32 *input, INT16 *output, int count)
 
 /*************************************
  *
- *	CVSD decoder
+ *  CVSD decoder
  *
  *************************************/
 
@@ -943,7 +921,7 @@ void decode_and_filter_cvsd(UINT8 *input, int bytes, int maskbits, int frequency
 
 /*************************************
  *
- *	Debugging
+ *  Debugging
  *
  *************************************/
 
