@@ -1,11 +1,12 @@
 /*************************************************************************
 
-	sndhrdw\atarifb.c
+    sndhrdw\atarifb.c
 
 *************************************************************************/
 
 #include "driver.h"
 #include "firetrk.h"
+#include "sound/discrete.h"
 
 
 WRITE8_HANDLER( firetrk_skid_reset_w )
@@ -89,6 +90,7 @@ WRITE8_HANDLER( firetrk_out2_w )
 /************************************************************************/
 
 const struct discrete_lfsr_desc firetrk_lfsr={
+	DISC_CLK_IS_FREQ,
 	16,			/* Bit Length */
 	0,			/* Reset Value */
 	0,			/* Use Bit 0 as XOR input 0 */
@@ -122,8 +124,8 @@ const struct discrete_555_cc_desc firetrk_motor_vco =
 
 const struct discrete_dac_r1_ladder firetrk_motor_out_dac =
 {
-	2,			/* size of ladder */
-	{RES_K(10), RES_K(10), 0,0,0,0,0,0},	/* R74, R73 */
+	4,			/* size of ladder */
+	{RES_K(10), 0,0, RES_K(10)},	/* R74, -, -, R73 */
 	DEFAULT_TTL_V_LOGIC_1,
 	0,			/* no rBias */
 	0,			/* no rGnd */
@@ -169,10 +171,9 @@ const struct discrete_schmitt_osc_desc firetrk_screech_osc =
 const struct discrete_mixer_desc firetrk_mixer =
 {
 	DISC_MIXER_IS_OP_AMP,
-	7,					/* 7 inputs */
-	{RES_K(4.7), RES_K(22), RES_K(31.333), RES_K(33), RES_K(10.5456), RES_K(32), RES_K(150), 0}, /* R54, R55, R72||(R70+R71), R53, R56 + R37||R35||R36||R34, R58 + R73||R74, R52 */
-	{0,0,0,0,0,0,0,0},			/* No variable resistor nodes */
-	{CAP_U(0.22), CAP_U(0.22), CAP_U(0.01), CAP_U(0.22), CAP_U(0.22), 0, CAP_U(0.22), 0}, /* C34, C32, C44, C35, C33, NA, C31 */
+	{RES_K(4.7), RES_K(22), RES_K(31.333), RES_K(33), RES_K(10.5456), RES_K(32), RES_K(150)}, /* R54, R55, R72||(R70+R71), R53, R56 + R37||R35||R36||R34, R58 + R73||R74, R52 */
+	{0},			/* No variable resistor nodes */
+	{CAP_U(0.22), CAP_U(0.22), CAP_U(0.01), CAP_U(0.22), CAP_U(0.22), 0, CAP_U(0.22)}, /* C34, C32, C44, C35, C33, NA, C31 */
 	0,					/* No rI */
 	RES_K(22),			/* R43 */
 	0,					/* No Filter */
@@ -215,8 +216,8 @@ DISCRETE_SOUND_START(firetrk_discrete_interface)
 	/* summed as the output of the circuit.         */
 	/************************************************/
 	DISCRETE_ADJUSTMENT(NODE_20, 1,
-				RES_K(10),	/* R26 + R27 @ min */
 				RES_K(260),	/* R26 + R27 @ max */
+				RES_K(10),	/* R26 + R27 @ min */
 				DISC_LOGADJ, 8)
 	DISCRETE_DAC_R1(NODE_21, 1,		/* base of Q1 */
 			FIRETRUCK_MOTOR_DATA,	/* IC F8, pins 2,5,6,9 */
@@ -228,14 +229,13 @@ DISCRETE_SOUND_START(firetrk_discrete_interface)
 			CAP_U(0.01),		/* C25 */
 			RES_M(1), 0, 0,		/* R28, no rGnd, no rDis */
 			&firetrk_motor_vco)
-	DISCRETE_COUNTER(NODE_23, 1, FIRETRUCK_ATTRACT_EN,	/* IC A9, QB-QD */
-			NODE_22,				/* from IC B9, pin 3 */
-			5, 1, 0, 1)				/* /6 counter on rising edge */
-	DISCRETE_TRANSFORM2(NODE_24, 1, NODE_23, 2, "01>")	/* IC A9, pin 8 */
+	DISCRETE_COUNTER_7492(NODE_23, 1, FIRETRUCK_ATTRACT_EN,	/* IC A9, QB-QD */
+			NODE_22)									/* from IC B9, pin 3 */
+	DISCRETE_TRANSFORM2(NODE_24, 1, NODE_23, 0x04, "01&")	/* IC A9, pin 8 */
 	DISCRETE_COUNTER(NODE_25, 1, FIRETRUCK_ATTRACT_EN,	/* IC A9, pin 12 */
-			NODE_24,					/* from IC A9, pin 8 */
-			1, 1, 0, 1)					/* /2 counter on rising edge */
-	DISCRETE_TRANSFORM3(NODE_26, 1, NODE_24, NODE_25, 2, "12*0+")	/* Mix the mess together in binary */
+			NODE_24,									/* from IC A9, pin 8 */
+			1, 1, 0, DISC_CLK_ON_F_EDGE)
+	DISCRETE_TRANSFORM3(NODE_26, 1, NODE_23, 2, NODE_25, "01*2+")	/* Mix QA and QB-D together */
 	DISCRETE_DAC_R1(FIRETRUCK_MOTORSND, 1, NODE_26,
 			DEFAULT_TTL_V_LOGIC_1,
 			&firetrk_motor_out_dac)
@@ -302,7 +302,7 @@ DISCRETE_SOUND_START(firetrk_discrete_interface)
 	DISCRETE_TRANSFORM2(NODE_71, 1, NODE_70,
 				5.0 * 680 / (RES_K(10) + 680),	/* vRef = 5V * R64 / (R65 + R64) */
 				"01<")				/* Output is low until vIn drops below vRef */
-	DISCRETE_COUNTER_FIX(NODE_72, 1, NODE_71, FIRETRUCK_HSYNC, 15, 1, 0)	/* IC B10 */
+	DISCRETE_COUNTER(NODE_72, 1, NODE_71, FIRETRUCK_HSYNC, 15, 1, 0, DISC_CLK_IS_FREQ)	/* IC B10 */
 	DISCRETE_TRANSFORM4(FIRETRUCK_BELLSND, 1, NODE_72,
 				8,	/* count 0-7 allow cap voltage to output.  8-15 ground output. */
 				NODE_70,	/* scale logic to cap voltage */
@@ -351,8 +351,8 @@ const struct discrete_555_cc_desc superbug_motor_vco =
 
 const struct discrete_dac_r1_ladder superbug_motor_out_dac =
 {
-	2,			/* size of ladder */
-	{RES_K(10), RES_K(10), 0,0,0,0,0,0},	/* R32, R34 */
+	4,			/* size of ladder */
+	{RES_K(10), 0,0, RES_K(10)},	/* R34, -, -, R32 */
 	DEFAULT_TTL_V_LOGIC_1,
 	0,			/* no rBias */
 	0,			/* no rGnd */
@@ -381,15 +381,14 @@ const struct discrete_schmitt_osc_desc superbug_screech_osc =
 const struct discrete_mixer_desc superbug_mixer =
 {
 	DISC_MIXER_IS_RESISTOR,
-	4,							/* 4 inputs */
-	{RES_K(15), RES_K(10.5456), RES_K(33), RES_K(47), 0,0,0,0}, /* R54, R55, R72||(R70+R71), R53, R56 + R37||R35||R36||R34, R58 + R73||R74, R52 */
-	{0,0,0,0,0,0,0,0},			/* No variable resistor nodes */
-	{0, 0, 0, 0, 0,0,0,0},		/* No caps */
-	0,							/* No rI */
-	RES_K(5),					/* R63 */
-	0,							/* No Filter */
-	CAP_U(0.1),					/* C35 */
-	0,							/* not used in resistor network */
+	{RES_K(15), RES_K(10.5456), RES_K(33), RES_K(4.7)}, /* R54, R55, R72||(R70+R71), R53, R56 + R37||R35||R36||R34, R58 + R73||R74, R52 */
+	{0},			/* No variable resistor nodes */
+	{0},			/* No caps */
+	0,				/* No rI */
+	RES_K(5),		/* R63 */
+	0,				/* No Filter */
+	CAP_U(0.1),		/* C35 */
+	0,				/* not used in resistor network */
 	33000	/* final gain */
 };
 
@@ -421,8 +420,8 @@ DISCRETE_SOUND_START(superbug_discrete_interface)
 	/* drive a modulo 12 counter.                   */
 	/************************************************/
 	DISCRETE_ADJUSTMENT(NODE_20, 1,
-				RES_K(10),	/* R12 + R62 @ min */
 				RES_K(260),	/* R12 + R62 @ max */
+				RES_K(10),	/* R12 + R62 @ min */
 				DISC_LOGADJ, 8)
 	DISCRETE_DAC_R1(NODE_21, 1,		/* base of Q1 */
 			SUPERBUG_SPEED_DATA,	/* IC B5, pins 3, 14, 6, 11 */
@@ -434,16 +433,15 @@ DISCRETE_SOUND_START(superbug_discrete_interface)
 			CAP_U(0.01),		/* C21 */
 			RES_M(3.3), 0, 0,	/* R11, no rGnd, no rDis */
 			&superbug_motor_vco)
-	DISCRETE_COUNTER(NODE_23, 1, SUPERBUG_ATTRACT_EN,	/* IC A7, QB-QD */
-			NODE_22,				/* from IC A6, pin 3 */
-			5, 1, 0, 1)				/* /6 counter on rising edge */
-	DISCRETE_TRANSFORM2(NODE_24, 1, NODE_23, 2, "01>")	/* IC A7, pin 8-QD */
-	DISCRETE_TRANSFORM3(NODE_25, 1, NODE_23, 1, 4, "01=02=|")	/* IC A7, pin 11-QB */
+	DISCRETE_COUNTER_7492(NODE_23, 1, SUPERBUG_ATTRACT_EN,	/* IC A7, QB-QD */
+			NODE_22)										/* from IC A6, pin 3 */
+	DISCRETE_TRANSFORM2(NODE_24, 1, NODE_23, 0x04, "01&")		/* IC A7, pin 8-QD */
+	DISCRETE_TRANSFORM2(NODE_25, 1, NODE_23, 0x01, "01&")	/* IC A7, pin 11-QB */
 	DISCRETE_LOGIC_XOR(NODE_26, 1, NODE_24, NODE_25)	/* Gate A9, pin 8 */
 	DISCRETE_COUNTER(NODE_27, 1, SUPERBUG_ATTRACT_EN,	/* IC A7, pin 12-QA */
-			NODE_26,					/* from IC A9, pin 8 */
-			1, 1, 0, 1)					/* /2 counter on rising edge */
-	DISCRETE_TRANSFORM3(NODE_28, 1, NODE_24, NODE_27, 2, "12*0+")	/* Mix the mess together in binary */
+			NODE_26,									/* from IC A9, pin 8 */
+			1, 1, 0, DISC_CLK_ON_F_EDGE)
+	DISCRETE_TRANSFORM3(NODE_28, 1, NODE_23, 2, NODE_27, "01*2+")	/* Mix QA and QB-D together */
 	DISCRETE_DAC_R1(SUPERBUG_MOTORSND, 1, NODE_28,
 			DEFAULT_TTL_V_LOGIC_1,
 			&superbug_motor_out_dac)
@@ -514,8 +512,8 @@ const struct discrete_555_cc_desc montecar_motor_vco =
 
 const struct discrete_dac_r1_ladder montecar_motor_out_dac =
 {
-	3,			/* size of ladder */
-	{RES_K(10), RES_K(10), RES_K(10), 0,0,0,0,0},	/* R31, R30, R29 */
+	4,			/* size of ladder */
+	{RES_K(10), RES_K(10), 0, RES_K(10)},	/* R31, R30, -, R29 */
 	DEFAULT_TTL_V_LOGIC_1,
 	0,			/* no rBias */
 	0,			/* no rGnd */
@@ -540,6 +538,19 @@ const struct discrete_dac_r1_ladder montecar_bang_dac =
 	0		/* no cSmoothing */
 };
 
+const struct discrete_op_amp_filt_info montecar_bang_filt =
+{
+	1.0/(1.0/RES_K(8.2) + 1.0/RES_K(3.9) + 1.0/RES_K(2.2) + 1.0/RES_K(1)) + RES_K(3.3),	/* R39, R42, R41, R40, r82 */
+	0,
+	680,			/* R83 */
+	0,
+	RES_K(330),		/* r84 */
+	CAP_U(.1),		/* c79 */
+	CAP_U(.1),		/* c78 */
+	0,
+	5, 12, 0
+};
+
 const struct discrete_schmitt_osc_desc montecar_screech_osc =
 {
 	RES_K(2.2),	/* R54 */
@@ -552,16 +563,15 @@ const struct discrete_schmitt_osc_desc montecar_screech_osc =
 const struct discrete_mixer_desc montecar_mixer =
 {
 	DISC_MIXER_IS_OP_AMP,
-	5,				/* 5 inputs */
-	{RES_K(15), RES_K(33), RES_K(10), RES_K(10), RES_K(13.3333), 0,0,0}, /* R93, R97, R96, variable , R95 + R31||R30||R29 */
-	{0,0,0,NODE_30,0,0,0,0},			/* Only drone has variable node */
-	{CAP_U(0.22), CAP_U(0.22), CAP_U(0.22), CAP_U(1), CAP_U(1), 0,0,0},	/* C83, C84, C85, C88, C47 */
+	{RES_K(15), RES_K(33), RES_K(10), RES_K(10), RES_K(13.3333)}, /* R93, R97, R96, variable , R95 + R31||R30||R29 */
+	{0,0,0,NODE_30,0},			/* Only drone has variable node */
+	{CAP_U(0.22), CAP_U(0.22), CAP_U(0.22), CAP_U(1), CAP_U(1)},	/* C83, C84, C85, C88, C47 */
 	RES_K(27),		/* R92 */
 	RES_K(82),		/* R98 */
 	0,				/* No Filter */
 	CAP_U(0.22),	/* C6 */
 	5,				/* vRef */
-	8000	/* final gain */
+	5000	/* final gain */
 };
 
 #define MONTECAR_ATTRACT_EN		NODE_09
@@ -595,8 +605,8 @@ DISCRETE_SOUND_START(montecar_discrete_interface)
 	/* summed as the output of the circuit.         */
 	/************************************************/
 	DISCRETE_ADJUSTMENT(NODE_20, 1,
-				RES_K(10),	/* R87 + R89 @ min */
 				RES_K(260),	/* R87 + R89 @ max */
+				RES_K(10),	/* R87 + R89 @ min */
 				DISC_LOGADJ, 8)
 	DISCRETE_DAC_R1(NODE_21, 1,		/* base of Q7 */
 			MONTECAR_MOTOR_DATA,	/* IC H8, pins 5, 2, 9, 6 */
@@ -608,16 +618,15 @@ DISCRETE_SOUND_START(montecar_discrete_interface)
 			CAP_U(0.01),		/* C81 */
 			RES_M(1), 0, 0,		/* R86, no rGnd, no rDis */
 			&montecar_motor_vco)
-	DISCRETE_COUNTER(NODE_23, 1, MONTECAR_ATTRACT_EN,	/* IC B/C9, QB-QD */
-			NODE_22,				/* from IC C9, pin 9 */
-			5, 1, 0, 1)				/* /6 counter on rising edge */
-	DISCRETE_TRANSFORM2(NODE_24, 1, NODE_23, 2, "01>")	/* IC B/C9, pin 8-QD */
-	DISCRETE_TRANSFORM3(NODE_25, 1, NODE_23, 1, 4, "01=02=|")	/* IC B/C9, pin 11-QB */
+	DISCRETE_COUNTER_7492(NODE_23, 1, MONTECAR_ATTRACT_EN,	/* IC B/C9, QB-QD */
+			NODE_22)										/* from IC C9, pin 9 */
+	DISCRETE_TRANSFORM2(NODE_24, 1, NODE_23, 0x04, "01&")	/* IC B/C9, pin 8-QD */
+	DISCRETE_TRANSFORM2(NODE_25, 1, NODE_23, 0x01, "01&")	/* IC B/C9, pin 11-QB */
 	DISCRETE_LOGIC_XOR(NODE_26, 1, NODE_24, NODE_25)	/* Gate A9, pin 11 */
 	DISCRETE_COUNTER(NODE_27, 1, MONTECAR_ATTRACT_EN,	/* IC B/C9, pin 12-QA */
-			NODE_26,					/* from IC A9, pin 11 */
-			1, 1, 0, 1)					/* /2 counter on rising edge */
-	DISCRETE_TRANSFORM5(NODE_28, 1, NODE_27, NODE_25, NODE_24, 2, 4, "13*24*+0+")	/* Mix the mess together in binary */
+			NODE_26,									/* from IC A9, pin 11 */
+			1, 1, 0, DISC_CLK_ON_F_EDGE)
+	DISCRETE_TRANSFORM3(NODE_28, 1, NODE_23, 2, NODE_27, "01*2+")	/* Mix QA and QB-D together */
 	DISCRETE_DAC_R1(MONTECAR_MOTORSND, 1, NODE_28,
 			DEFAULT_TTL_V_LOGIC_1,
 			&montecar_motor_out_dac)
@@ -631,8 +640,8 @@ DISCRETE_SOUND_START(montecar_discrete_interface)
 	DISCRETE_COMP_ADDER(NODE_30, 1, MONTECAR_DRONE_LOUD_DATA, &montecar_drone_vol_res)	/* make sure to change the node value in the mixer table if you change this node number */
 
 	DISCRETE_ADJUSTMENT(NODE_40, 1,
-				RES_K(10),	/* R85 + R88 @ min */
 				RES_K(260),	/* R85 + R88 @ max */
+				RES_K(10),	/* R85 + R88 @ min */
 				DISC_LOGADJ, 9)
 	DISCRETE_DAC_R1(NODE_41, 1,			/* base of Q7 */
 			MONTECAR_DRONE_MOTOR_DATA,	/* IC H8, pins 19, 16, 12, 15 */
@@ -644,16 +653,15 @@ DISCRETE_SOUND_START(montecar_discrete_interface)
 			CAP_U(0.01),		/* C80 */
 			RES_M(1), 0, 0,		/* R81, no rGnd, no rDis */
 			&montecar_motor_vco)
-	DISCRETE_COUNTER(NODE_43, 1, MONTECAR_ATTRACT_EN,	/* IC A/B9, QB-QD */
-			NODE_42,				/* from IC C9, pin 5 */
-			5, 1, 0, 1)				/* /6 counter on rising edge */
-	DISCRETE_TRANSFORM2(NODE_44, 1, NODE_43, 2, "01>")	/* IC A/B9, pin 8-QD */
-	DISCRETE_TRANSFORM3(NODE_45, 1, NODE_43, 1, 4, "01=02=|")	/* IC A/B9, pin 11-QB */
+	DISCRETE_COUNTER_7492(NODE_43, 1, MONTECAR_ATTRACT_EN,	/* IC A/B9, QB-QD */
+			NODE_42)										/* from IC C9, pin 5 */
+	DISCRETE_TRANSFORM2(NODE_44, 1, NODE_43, 0x04, "01&")	/* IC A/B9, pin 8-QD */
+	DISCRETE_TRANSFORM2(NODE_45, 1, NODE_43, 0x01, "01&")	/* IC A/B9, pin 11-QB */
 	DISCRETE_LOGIC_XOR(NODE_46, 1, NODE_44, NODE_45)	/* Gate A9, pin 6 */
 	DISCRETE_COUNTER(NODE_47, 1, MONTECAR_ATTRACT_EN,	/* IC A/B9, pin 12-QA */
-			NODE_46,				/* from IC A9, pin 6 */
-			1, 1, 0, 1)				/* /2 counter on rising edge */
-	DISCRETE_TRANSFORM5(NODE_48, 1, NODE_47, NODE_45, NODE_44, 2, 4, "13*24*+0+")	/* Mix the mess together in binary */
+			NODE_46,									/* from IC A9, pin 6 */
+			1, 1, 0, DISC_CLK_ON_F_EDGE)
+	DISCRETE_TRANSFORM3(NODE_48, 1, NODE_43, 2, NODE_47, "01*2+")	/* Mix QA and QB-D together */
 	DISCRETE_DAC_R1(MONTECAR_DRONE_MOTORSND, 1, NODE_48,
 			DEFAULT_TTL_V_LOGIC_1,
 			&montecar_motor_out_dac)
@@ -666,17 +674,16 @@ DISCRETE_SOUND_START(montecar_discrete_interface)
 	/*    = 15750/4                                 */
 	/* Output is binary weighted with 4 bits of     */
 	/* crash volume.                                */
-	/*                                              */
-	/* TO DO: add filtering !!!!!!!!!!!!!!!!!!!!!!! */
 	/************************************************/
 	DISCRETE_LFSR_NOISE(MONTECAR_NOISE, MONTECAR_ATTRACT_INV, MONTECAR_ATTRACT_INV,FIRETRUCK_2V , 1.0, 0, 0.5, &firetrk_lfsr)	/* Same as firetrk */
 
 	DISCRETE_SWITCH(NODE_50, 1, MONTECAR_NOISE, 0,	/* Enable gate A9 */
 			MONTECAR_CRASH_DATA)		/* IC J8, pins 3,6,11,14 */
-	DISCRETE_DAC_R1(MONTECAR_BANGSND, 1,	/* Bang */
+	DISCRETE_DAC_R1(NODE_51, 1,	/* Bang */
 			NODE_50,	/* from enable gates A9 */
 			DEFAULT_TTL_V_LOGIC_1,
 			&montecar_bang_dac)
+	DISCRETE_OP_AMP_FILTER(MONTECAR_BANGSND, 1, NODE_51, 0, DISC_OP_AMP_FILTER_IS_BAND_PASS_1M, &montecar_bang_filt)
 
 	/************************************************/
 	/* Screech is just the noise modulating a       */
