@@ -15,25 +15,26 @@
 #include "driver.h"
 #include "cpu/z80/z80.h"
 #include "machine/7474.h"
+#include "sound/ay8910.h"
 
 
 
-/* The timer clock in Scramble which feeds the upper 4 bits of    		*/
-/* AY-3-8910 port A is based on the same clock        					*/
-/* feeding the sound CPU Z80.  It is a divide by      					*/
-/* 5120, formed by a standard divide by 512,        					*/
-/* followed by a divide by 10 using a 4 bit           					*/
-/* bi-quinary count sequence. (See LS90 data sheet    					*/
-/* for an example).                                   					*/
-/*																		*/
-/* Bit 4 comes from the output of the divide by 1024  					*/
-/*       0, 1, 0, 1, 0, 1, 0, 1, 0, 1									*/
-/* Bit 5 comes from the QC output of the LS90 producing a sequence of	*/
-/* 		 0, 0, 1, 1, 0, 0, 1, 1, 1, 0									*/
-/* Bit 6 comes from the QD output of the LS90 producing a sequence of	*/
-/*		 0, 0, 0, 0, 1, 0, 0, 0, 0, 1									*/
-/* Bit 7 comes from the QA output of the LS90 producing a sequence of	*/
-/*		 0, 0, 0, 0, 0, 1, 1, 1, 1, 1			 						*/
+/* The timer clock in Scramble which feeds the upper 4 bits of          */
+/* AY-3-8910 port A is based on the same clock                          */
+/* feeding the sound CPU Z80.  It is a divide by                        */
+/* 5120, formed by a standard divide by 512,                            */
+/* followed by a divide by 10 using a 4 bit                             */
+/* bi-quinary count sequence. (See LS90 data sheet                      */
+/* for an example).                                                     */
+/*                                                                      */
+/* Bit 4 comes from the output of the divide by 1024                    */
+/*       0, 1, 0, 1, 0, 1, 0, 1, 0, 1                                   */
+/* Bit 5 comes from the QC output of the LS90 producing a sequence of   */
+/*       0, 0, 1, 1, 0, 0, 1, 1, 1, 0                                   */
+/* Bit 6 comes from the QD output of the LS90 producing a sequence of   */
+/*       0, 0, 0, 0, 1, 0, 0, 0, 0, 1                                   */
+/* Bit 7 comes from the QA output of the LS90 producing a sequence of   */
+/*       0, 0, 0, 0, 0, 1, 1, 1, 1, 1                                   */
 
 static int scramble_timer[10] =
 {
@@ -60,22 +61,22 @@ READ8_HANDLER( scramble_portB_r )
 
 
 
-/* The timer clock in Frogger which feeds the upper 4 bits of    		*/
-/* AY-3-8910 port A is based on the same clock        					*/
-/* feeding the sound CPU Z80.  It is a divide by      					*/
-/* 5120, formed by a standard divide by 512,        					*/
-/* followed by a divide by 10 using a 4 bit           					*/
-/* bi-quinary count sequence. (See LS90 data sheet    					*/
-/* for an example).                                   					*/
-/*																		*/
-/* Bit 4 comes from the output of the divide by 1024  					*/
-/*       0, 1, 0, 1, 0, 1, 0, 1, 0, 1									*/
-/* Bit 3 comes from the QC output of the LS90 producing a sequence of	*/
-/* 		 0, 0, 1, 1, 0, 0, 1, 1, 1, 0									*/
-/* Bit 6 comes from the QD output of the LS90 producing a sequence of	*/
-/*		 0, 0, 0, 0, 1, 0, 0, 0, 0, 1									*/
-/* Bit 7 comes from the QA output of the LS90 producing a sequence of	*/
-/*		 0, 0, 0, 0, 0, 1, 1, 1, 1, 1			 						*/
+/* The timer clock in Frogger which feeds the upper 4 bits of           */
+/* AY-3-8910 port A is based on the same clock                          */
+/* feeding the sound CPU Z80.  It is a divide by                        */
+/* 5120, formed by a standard divide by 512,                            */
+/* followed by a divide by 10 using a 4 bit                             */
+/* bi-quinary count sequence. (See LS90 data sheet                      */
+/* for an example).                                                     */
+/*                                                                      */
+/* Bit 4 comes from the output of the divide by 1024                    */
+/*       0, 1, 0, 1, 0, 1, 0, 1, 0, 1                                   */
+/* Bit 3 comes from the QC output of the LS90 producing a sequence of   */
+/*       0, 0, 1, 1, 0, 0, 1, 1, 1, 0                                   */
+/* Bit 6 comes from the QD output of the LS90 producing a sequence of   */
+/*       0, 0, 0, 0, 1, 0, 0, 0, 0, 1                                   */
+/* Bit 7 comes from the QA output of the LS90 producing a sequence of   */
+/*       0, 0, 0, 0, 0, 1, 1, 1, 1, 1                                   */
 
 static int frogger_timer[10] =
 {
@@ -108,7 +109,7 @@ WRITE8_HANDLER( scramble_sh_irqtrigger_w )
 	TTL7474_update(2);
 
 	/* bit 4 is sound disable */
-	mixer_sound_enable_global_w(~data & 0x10);
+	sound_global_enable(~data & 0x10);
 }
 
 WRITE8_HANDLER( sfx_sh_irqtrigger_w )
@@ -136,8 +137,8 @@ WRITE8_HANDLER( froggrmc_sh_irqtrigger_w )
 static int scramble_sh_irq_callback(int irqline)
 {
 	/* interrupt acknowledge clears the flip-flop --
-	   we need to pulse the CLR line because MAME's core never clears this
-	   line, only asserts it */
+       we need to pulse the CLR line because MAME's core never clears this
+       line, only asserts it */
 	TTL7474_clear_w(2, 0);
 	TTL7474_update(2);
 
@@ -150,8 +151,8 @@ static int scramble_sh_irq_callback(int irqline)
 static int sfx_sh_irq_callback(int irqline)
 {
 	/* interrupt acknowledge clears the flip-flop --
-	   we need to pulse the CLR line because MAME's core never clears this
-	   line, only asserts it */
+       we need to pulse the CLR line because MAME's core never clears this
+       line, only asserts it */
 	TTL7474_clear_w(3, 0);
 	TTL7474_update(3);
 
@@ -195,7 +196,7 @@ static void filter_w(int chip, int channel, int data)
 	C = 0;
 	if (data & 1) C += 220000;	/* 220000pF = 0.220uF */
 	if (data & 2) C +=  47000;	/*  47000pF = 0.047uF */
-	set_RC_filter(3*chip + channel,1000,5100,0,C);
+/* ASG:fixme    set_RC_filter(3*chip + channel,1000,5100,0,C); */
 }
 
 WRITE8_HANDLER( scramble_filter_w )
