@@ -1,24 +1,24 @@
 /***************************************************************************
 
-	Midway/Williams Audio Boards
-	----------------------------
+    Midway/Williams Audio Boards
+    ----------------------------
 
-	6809 MEMORY MAP
+    6809 MEMORY MAP
 
-	Function                                  Address     R/W  Data
-	---------------------------------------------------------------
-	Program RAM                               0000-07FF   R/W  D0-D7
+    Function                                  Address     R/W  Data
+    ---------------------------------------------------------------
+    Program RAM                               0000-07FF   R/W  D0-D7
 
-	Music (YM-2151)                           2000-2001   R/W  D0-D7
+    Music (YM-2151)                           2000-2001   R/W  D0-D7
 
-	6821 PIA                                  4000-4003   R/W  D0-D7
+    6821 PIA                                  4000-4003   R/W  D0-D7
 
-	HC55516 clock low, digit latch            6000        W    D0
-	HC55516 clock high                        6800        W    xx
+    HC55516 clock low, digit latch            6000        W    D0
+    HC55516 clock high                        6800        W    xx
 
-	Bank select                               7800        W    D0-D2
+    Bank select                               7800        W    D0-D2
 
-	Banked Program ROM                        8000-FFFF   R    D0-D7
+    Banked Program ROM                        8000-FFFF   R    D0-D7
 
 ****************************************************************************/
 
@@ -26,11 +26,14 @@
 #include "machine/6821pia.h"
 #include "cpu/m6809/m6809.h"
 #include "williams.h"
-
+#include "sound/2151intf.h"
+#include "sound/okim6295.h"
+#include "sound/hc55516.h"
+#include "sound/dac.h"
 
 
 /***************************************************************************
-	STATIC GLOBALS
+    STATIC GLOBALS
 ****************************************************************************/
 
 UINT8 williams_sound_int_state;
@@ -44,7 +47,7 @@ static UINT8 adpcm_bank_count;
 
 
 /***************************************************************************
-	PROTOTYPES
+    PROTOTYPES
 ****************************************************************************/
 
 static void init_audio_state(void);
@@ -72,7 +75,7 @@ static WRITE8_HANDLER( narc_slave_bank_select_w );
 
 
 /***************************************************************************
-	PROCESSOR STRUCTURES
+    PROCESSOR STRUCTURES
 ****************************************************************************/
 
 /* CVSD readmem/writemem structures */
@@ -179,111 +182,106 @@ static struct pia6821_interface cvsd_pia_intf =
 
 
 /***************************************************************************
-	AUDIO STRUCTURES
+    AUDIO STRUCTURES
 ****************************************************************************/
 
 /* YM2151 structure (CVSD variant) */
 static struct YM2151interface cvsd_ym2151_interface =
 {
-	1,			/* 1 chip */
-	3579580,
-	{ YM3012_VOL(10,MIXER_PAN_CENTER,10,MIXER_PAN_CENTER) },
-	{ cvsd_ym2151_irq }
+	cvsd_ym2151_irq
 };
 
 
 /* YM2151 structure (ADPCM variant) */
 static struct YM2151interface adpcm_ym2151_interface =
 {
-	1,			/* 1 chip */
-	3579580,
-	{ YM3012_VOL(10,MIXER_PAN_CENTER,10,MIXER_PAN_CENTER) },
-	{ adpcm_ym2151_irq }
-};
-
-
-/* DAC structure (single DAC variant) */
-static struct DACinterface single_dac_interface =
-{
-	1,
-	{ 50 }
-};
-
-
-/* DAC structure (double DAC variant) */
-static struct DACinterface double_dac_interface =
-{
-	2,
-	{ 50, 50 }
-};
-
-
-/* CVSD structure */
-static struct hc55516_interface cvsd_interface =
-{
-	1,			/* 1 chip */
-	{ 80 }
-};
-
-
-/* OKIM6295 structure(s) */
-static struct OKIM6295interface adpcm_6295_interface =
-{
-	1,          	/* 1 chip */
-	{ 8000 },       /* 8000 Hz frequency */
-	{ REGION_SOUND1 },  /* memory */
-	{ 50 }
+	adpcm_ym2151_irq
 };
 
 
 
 /***************************************************************************
-	MACHINE DRIVERS
+    MACHINE DRIVERS
 ****************************************************************************/
 
 MACHINE_DRIVER_START( williams_cvsd_sound )
 	MDRV_CPU_ADD_TAG("cvsd", M6809, 8000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(williams_cvsd_readmem,williams_cvsd_writemem)
 
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, cvsd_ym2151_interface)
-	MDRV_SOUND_ADD(DAC,    single_dac_interface)
-	MDRV_SOUND_ADD(HC55516,cvsd_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579580)
+	MDRV_SOUND_CONFIG(cvsd_ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.10)
+	MDRV_SOUND_ROUTE(1, "right", 0.10)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(0, "right", 0.50)
+
+	MDRV_SOUND_ADD(HC55516, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.80)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.80)
 MACHINE_DRIVER_END
 
 
 MACHINE_DRIVER_START( williams_adpcm_sound )
 	MDRV_CPU_ADD_TAG("adpcm", M6809, 8000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(williams_adpcm_readmem,williams_adpcm_writemem)
 
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151,  adpcm_ym2151_interface)
-	MDRV_SOUND_ADD(DAC,     single_dac_interface)
-	MDRV_SOUND_ADD(OKIM6295,adpcm_6295_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579580)
+	MDRV_SOUND_CONFIG(adpcm_ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.10)
+	MDRV_SOUND_ROUTE(1, "right", 0.10)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(0, "right", 0.50)
+
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
 MACHINE_DRIVER_END
 
 
 MACHINE_DRIVER_START( williams_narc_sound )
 	MDRV_CPU_ADD_TAG("narc1", M6809, 8000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(williams_narc_master_readmem,williams_narc_master_writemem)
 
 	MDRV_CPU_ADD_TAG("narc2", M6809, 8000000/4)
-	MDRV_CPU_FLAGS(CPU_AUDIO_CPU)
+	/* audio CPU */
 	MDRV_CPU_PROGRAM_MAP(williams_narc_slave_readmem,williams_narc_slave_writemem)
 
-	MDRV_SOUND_ATTRIBUTES(SOUND_SUPPORTS_STEREO)
-	MDRV_SOUND_ADD(YM2151, adpcm_ym2151_interface)
-	MDRV_SOUND_ADD(DAC,    double_dac_interface)
-	MDRV_SOUND_ADD(HC55516,cvsd_interface)
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579580)
+	MDRV_SOUND_CONFIG(adpcm_ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 0.10)
+	MDRV_SOUND_ROUTE(1, "right", 0.10)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(0, "right", 0.50)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(0, "left", 0.50)
+	MDRV_SOUND_ROUTE(0, "right", 0.50)
+
+	MDRV_SOUND_ADD(HC55516, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.80)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.80)
 MACHINE_DRIVER_END
 
 
 
 /***************************************************************************
-	INLINES
+    INLINES
 ****************************************************************************/
 
 INLINE UINT8 *get_cvsd_bank_base(int data)
@@ -323,7 +321,7 @@ INLINE UINT8 *get_narc_slave_bank_base(int data)
 
 
 /***************************************************************************
-	INITIALIZATION
+    INITIALIZATION
 ****************************************************************************/
 
 void williams_cvsd_init(int cpunum, int pianum)
@@ -372,8 +370,8 @@ void williams_adpcm_init(int cpunum)
 	for (i = 0; i < MAX_SOUND; i++)
 		if (Machine->drv->sound[i].sound_type == SOUND_OKIM6295)
 		{
-			struct OKIM6295interface *intf = (struct OKIM6295interface *)Machine->drv->sound[i].sound_interface;
-			adpcm_bank_count = memory_region_length(intf->region[0]) / 0x40000;
+			struct OKIM6295interface *intf = (struct OKIM6295interface *)Machine->drv->sound[i].config;
+			adpcm_bank_count = memory_region_length(intf->region) / 0x40000;
 		}
 }
 
@@ -404,7 +402,7 @@ void williams_narc_init(int cpunum)
 static void init_audio_state(void)
 {
 	/* reset the YM2151 state */
-	YM2151_sh_reset();
+	sndti_reset(SOUND_YM2151, 0);
 
 	/* clear all the interrupts */
 	williams_sound_int_state = 0;
@@ -438,8 +436,8 @@ static void locate_audio_hotspot(UINT8 *base, UINT16 start)
 			base[i + 8] == 0xaf && base[i + 9] == 0x4c &&			/* AF 4C       STX   $000C,U */
 			base[i +10] == 0x1c && base[i +11] == 0xaf)				/* 1C AF       ANDCC #$00AF  */
 		{
-/*			counter.hotspot_start = i; */
-/*			counter.hotspot_stop = i + 12; */
+/*          counter.hotspot_start = i; */
+/*          counter.hotspot_stop = i + 12; */
 			logerror("Found hotspot @ %04X", i);
 			return;
 		}
@@ -451,7 +449,7 @@ static void locate_audio_hotspot(UINT8 *base, UINT16 start)
 
 
 /***************************************************************************
-	CVSD IRQ GENERATION CALLBACKS
+    CVSD IRQ GENERATION CALLBACKS
 ****************************************************************************/
 
 static void cvsd_ym2151_irq(int state)
@@ -474,7 +472,7 @@ static void cvsd_irqb(int state)
 
 
 /***************************************************************************
-	ADPCM IRQ GENERATION CALLBACKS
+    ADPCM IRQ GENERATION CALLBACKS
 ****************************************************************************/
 
 static void adpcm_ym2151_irq(int state)
@@ -485,7 +483,7 @@ static void adpcm_ym2151_irq(int state)
 
 
 /***************************************************************************
-	CVSD BANK SELECT
+    CVSD BANK SELECT
 ****************************************************************************/
 
 static WRITE8_HANDLER( cvsd_bank_select_w )
@@ -496,7 +494,7 @@ static WRITE8_HANDLER( cvsd_bank_select_w )
 
 
 /***************************************************************************
-	ADPCM BANK SELECT
+    ADPCM BANK SELECT
 ****************************************************************************/
 
 static WRITE8_HANDLER( adpcm_bank_select_w )
@@ -527,7 +525,7 @@ static WRITE8_HANDLER( adpcm_6295_bank_select_w )
 
 
 /***************************************************************************
-	NARC BANK SELECT
+    NARC BANK SELECT
 ****************************************************************************/
 
 static WRITE8_HANDLER( narc_master_bank_select_w )
@@ -544,7 +542,7 @@ static WRITE8_HANDLER( narc_slave_bank_select_w )
 
 
 /***************************************************************************
-	PIA INTERFACES
+    PIA INTERFACES
 ****************************************************************************/
 
 static READ8_HANDLER( cvsd_pia_r )
@@ -561,7 +559,7 @@ static WRITE8_HANDLER( cvsd_pia_w )
 
 
 /***************************************************************************
-	CVSD COMMUNICATIONS
+    CVSD COMMUNICATIONS
 ****************************************************************************/
 
 static void williams_cvsd_delayed_data_w(int param)
@@ -595,7 +593,7 @@ void williams_cvsd_reset_w(int state)
 
 
 /***************************************************************************
-	ADPCM COMMUNICATIONS
+    ADPCM COMMUNICATIONS
 ****************************************************************************/
 
 static READ8_HANDLER( adpcm_command_r )
@@ -634,7 +632,7 @@ void williams_adpcm_reset_w(int state)
 
 
 /***************************************************************************
-	NARC COMMUNICATIONS
+    NARC COMMUNICATIONS
 ****************************************************************************/
 
 static READ8_HANDLER( narc_command_r )
