@@ -10,9 +10,11 @@
  ************************************************************************
  *
  * DST_ADDDER            - Multichannel adder
+ * DST_CLAMP             - Simple signal clamping circuit
  * DST_COMP_ADDER        - Selectable parallel component circuit
  * DST_DAC_R1            - R1 Ladder DAC with cap filtering
- * DST_DIVIDER           - Division function
+ * DST_DIODE_MIX         - Diode mixer
+ * DST_DIVIDE            - Division function
  * DST_GAIN              - Gain Factor
  * DST_INTEGRATE         - Integration circuits
  * DST_LOGIC_INV         - Logic level invertor
@@ -24,6 +26,7 @@
  * DST_LOGIC_NXOR        - Logic NXOR gate 2 input
  * DST_LOGIC_DFF         - Logic D-type flip/flop
  * DST_MIXER             - Final Mixer Stage
+ * DST_MULTIPLEX         - 1 of x Multiplexer/switch
  * DST_ONESHOT           - One shot pulse generator
  * DST_RAMP              - Ramp up/down
  * DST_SAMPHOLD          - Sample & Hold Implementation
@@ -49,8 +52,10 @@ struct dst_dflipflop_context
 
 struct dst_integrate_context
 {
-	double	vMaxIn;		/* vP - norton VBE */
-	double	vMaxInD;	/* vP - norton VBE - diode drop */
+	double	change;
+	double	vMaxIn;		/* v1 - norton VBE */
+	double	vMaxInD;	/* v1 - norton VBE - diode drop */
+	double	vMaxOut;
 };
 
 #define DISC_MIXER_MAX_INPS	8
@@ -58,6 +63,7 @@ struct dst_integrate_context
 struct dst_mixer_context
 {
 	int	type;
+	int	size;
 	double	rTotal;
 	struct	node_description* rNode[DISC_MIXER_MAX_INPS];	/* Either pointer to input node OR NULL */
 	double	exponent_rc[DISC_MIXER_MAX_INPS];	/* For high pass filtering cause by cIn */
@@ -90,6 +96,11 @@ struct dst_samphold_context
 	int clocktype;
 };
 
+struct dst_size_context
+{
+	int size;
+};
+
 struct dst_tvca_op_amp_context
 {
 	double	vOutMax;		/* Maximum output voltage */
@@ -250,7 +261,7 @@ void dst_dac_r1_step(struct node_description *node)
 		{
 			/* Add up currents of ON circuits per Millman. */
 			/* Off, being 0V and having no current, can be ignored. */
-			if (DST_DAC_R1__DATA & (1 << bit))
+			if ((DST_DAC_R1__DATA & (1 << bit)) && info->r[bit])
 				i += DST_DAC_R1__VON / info->r[bit];
 		}
 
@@ -262,10 +273,10 @@ void dst_dac_r1_step(struct node_description *node)
 	else
 	{
 		/*
-		 * If module is disabled we will just leave the voltage where it was.
-		 * We may want to set it to 0 in the future, but we will probably never
-		 * disable this module.
-		 */
+         * If module is disabled we will just leave the voltage where it was.
+         * We may want to set it to 0 in the future, but we will probably never
+         * disable this module.
+         */
 	}
 }
 
@@ -283,10 +294,10 @@ void dst_dac_r1_reset(struct node_description *node)
 		context->iBias = 0;
 
 	/*
-	 * We will do a small amount of error checking.
-	 * But if you are an idiot and pass a bad ladder table
-	 * then you deserve a crash.
-	 */
+     * We will do a small amount of error checking.
+     * But if you are an idiot and pass a bad ladder table
+     * then you deserve a crash.
+     */
 	if (info->ladderLength < 2)
 	{
 		/* You need at least 2 resistors for a ladder */
@@ -298,18 +309,15 @@ void dst_dac_r1_reset(struct node_description *node)
 	}
 
 	/*
-	 * Calculate the total of all resistors in parallel.
-	 * This is the combined resistance of the voltage sources.
-	 * This is used for the charging curve.
-	 */
+     * Calculate the total of all resistors in parallel.
+     * This is the combined resistance of the voltage sources.
+     * This is used for the charging curve.
+     */
 	context->rTotal = 0;
 	for(bit=0; bit < info->ladderLength; bit++)
 	{
-		if (!info->r[bit])
-		{
-			discrete_log("dst_dac_r1_reset - Resistor can't equal 0");
-		}
-		context->rTotal += 1.0 / info->r[bit];
+		if (info->r[bit])
+			context->rTotal += 1.0 / info->r[bit];
 	}
 	if (info->rBias) context->rTotal += 1.0 / info->rBias;
 	if (info->rGnd) context->rTotal += 1.0 / info->rGnd;
@@ -326,6 +334,52 @@ void dst_dac_r1_reset(struct node_description *node)
 }
 
 
+/************************************************************************
+*
+ * DST_DIODE_MIX  - Diode Mixer
+ *
+ * input[0]    - Enable input value
+ * input[1]    - Diode junction voltage drop
+ * input[2]    - Input 0
+ * .....
+ *
+ * Dec 2004, D Renaud.
+ ************************************************************************/
+#define DST_DIODE_MIX__ENABLE		(*(node->input[0]))
+#define DST_DIODE_MIX__VJUNC		(*(node->input[1]))
+#define DST_DIODE_MIX__INP(addr)	(*(node->input[2 + addr]))
+
+void dst_diode_mix_step(struct node_description *node)
+{
+	struct dst_size_context *context = node->context;
+	double max = 0;
+	int addr;
+
+	if (DST_DIODE_MIX__ENABLE)
+	{
+		for (addr = 0; addr < context->size; addr++)
+		{
+			if (DST_DIODE_MIX__INP(addr) > max) max = DST_DIODE_MIX__INP(addr);
+		}
+		node->output = max - DST_DIODE_MIX__VJUNC;
+		if (node->output < 0) node->output = 0;
+	}
+	else
+	{
+		node->output = 0;
+	}
+}
+
+void dst_diode_mix_reset(struct node_description *node)
+{
+	struct dst_size_context *context = node->context;
+
+	context->size = node->active_inputs - 2;
+
+	dst_diode_mix_step(node);
+}
+
+
 /************************************************************************
  *
  * DST_DIVIDE  - Programmable divider with enable
@@ -448,10 +502,23 @@ void dst_integrate_step(struct node_description *node)
 
 	switch (info->type)
 	{
+		case DISC_INTEGRATE_OP_AMP_1:
+			if (DST_INTEGRATE__TRG0 != 0)
+			{
+				/* This forces the cap to completely charge,
+                 * and the output to go to it's max value.
+                 */
+				node->output = context->vMaxOut;
+				return;
+			}
+			node->output -= context->change;
+			break;
+
 		case DISC_INTEGRATE_OP_AMP_1 | DISC_OP_AMP_IS_NORTON:
 			iNeg = context->vMaxIn / info->r1;
 			iPos = (DST_INTEGRATE__TRG0 - OP_AMP_NORTON_VBE) / info->r2;
 			if (iPos < 0) iPos = 0;
+			node->output += iPos / Machine->sample_rate / info->c;
 			break;
 
 		case DISC_INTEGRATE_OP_AMP_2 | DISC_OP_AMP_IS_NORTON:
@@ -460,22 +527,36 @@ void dst_integrate_step(struct node_description *node)
 			iNeg = dst_trigger_function(trig0, trig1, 0, info->f0) ? context->vMaxInD / info->r1 : 0;
 			iPos =  dst_trigger_function(trig0, trig1, 0, info->f1) ? context->vMaxIn / info->r2 : 0;
 			iPos +=  dst_trigger_function(trig0, trig1, 0, info->f2) ? context->vMaxInD / info->r3 : 0;
+			node->output += (iPos - iNeg) / Machine->sample_rate / info->c;
 			break;
 	}
 
-	node->output += (iPos - iNeg) / Machine->sample_rate / info->c;
 	/* Clip the output. */
 	if (node->output < 0) node->output = 0;
-	if (node->output > context->vMaxIn) node->output = context->vMaxIn;
+	if (node->output > context->vMaxOut) node->output = context->vMaxOut;
 }
 
 void dst_integrate_reset(struct node_description *node)
 {
 	const struct discrete_integrate_info *info = node->custom;
 	struct dst_integrate_context *context = node->context;
+	double	i, v;
 
-	context->vMaxIn = info->vP - OP_AMP_NORTON_VBE;
-	context->vMaxInD = context->vMaxIn - 0.6;
+	if (info->type & DISC_OP_AMP_IS_NORTON)
+	{
+		context->vMaxOut = info->vP - OP_AMP_NORTON_VBE;
+		context->vMaxIn  = info->v1 - OP_AMP_NORTON_VBE;
+		context->vMaxInD = context->vMaxIn - 0.6;
+	}
+	else
+	{
+		context->vMaxOut =  info->vP - OP_AMP_VP_RAIL_OFFSET;
+
+		v = info->v1 * info->r3 / (info->r2 + info->r3);	/* vRef */
+		v = info->v1 - v;	/* actual charging voltage */
+		i = v / info->r1;
+		context->change = i / Machine->sample_rate / info->c;
+	}
 	node->output = 0;
 }
 
@@ -782,7 +863,7 @@ void dst_mixer_step(struct node_description *node)
 	{
 		rTotal = context->rTotal;
 
-		for(bit=0; bit < info->mixerLength; bit++)
+		for(bit=0; bit < context->size; bit++)
 		{
 			rTemp = info->r[bit];
 			connected = 1;
@@ -834,7 +915,7 @@ void dst_mixer_step(struct node_description *node)
 		rTotal = 1.0 / rTotal;
 
 		/* If resistor network or has rI then Millman is used.
-		 * If op-amp then summing formula is used. */
+         * If op-amp then summing formula is used. */
 		v = i * (((context->type & DISC_MIXER_TYPE_MASK) == DISC_MIXER_IS_OP_AMP) ? info->rF : rTotal);
 
 		if ((context->type & DISC_MIXER_TYPE_MASK) == DISC_MIXER_IS_OP_AMP_WITH_RI)
@@ -875,26 +956,28 @@ void dst_mixer_reset(struct node_description *node)
 	int	bit;
 	double	rTemp = 0;
 
+	context->size = node->active_inputs - 1;
+
 	/*
-	 * THERE IS NO ERROR CHECKING!!!!!!!!!
-	 * If you are an idiot and pass a bad ladder table
-	 * then you deserve a crash.
-	 */
+     * THERE IS NO ERROR CHECKING!!!!!!!!!
+     * If you are an idiot and pass a bad ladder table
+     * then you deserve a crash.
+     */
 
 	context->type = ((info->type == DISC_MIXER_IS_OP_AMP) && info->rI) ? DISC_MIXER_IS_OP_AMP_WITH_RI : info->type;
 
 	/*
-	 * Calculate the total of all resistors in parallel.
-	 * This is the combined resistance of the voltage sources.
-	 * Also calculate the exponents while we are here.
-	 */
+     * Calculate the total of all resistors in parallel.
+     * This is the combined resistance of the voltage sources.
+     * Also calculate the exponents while we are here.
+     */
 	context->rTotal = 0;
-	for(bit=0; bit < info->mixerLength; bit++)
+	for(bit=0; bit < context->size; bit++)
 	{
 		if (info->rNode[bit])
 		{
 			context->type = context->type | DISC_MIXER_HAS_R_NODE;
-			context->rNode[bit] = discrete_find_node(info->rNode[bit]);	/* get node pointers */
+			context->rNode[bit] = discrete_find_node(NULL, info->rNode[bit]);	/* get node pointers */
 		}
 		else
 			context->rNode[bit] = NULL;
@@ -960,6 +1043,56 @@ void dst_mixer_reset(struct node_description *node)
 }
 
 
+/************************************************************************
+ *
+ * DST_MULTIPLEX - 1 of x multiplexer/switch
+ *
+ * input[0]    - Enable input value
+ * input[1]    - switch position
+ * input[2]    - input[0]
+ * input[3]    - input[1]
+ * .....
+ *
+ * Dec 2004, D Renaud.
+ ************************************************************************/
+#define DST_MULTIPLEX__ENABLE		(*(node->input[0]))
+#define DST_MULTIPLEX__ADDR			(*(node->input[1]))
+#define DST_MULTIPLEX__INP(addr)	(*(node->input[2 + addr]))
+
+void dst_multiplex_step(struct node_description *node)
+{
+	struct dst_size_context *context = node->context;
+	int addr;
+
+	if(DST_MULTIPLEX__ENABLE)
+	{
+		addr = DST_MULTIPLEX__ADDR;	/* FP to INT */
+		if ((addr >= 0)  && (addr < context->size))
+		{
+			node->output = DST_MULTIPLEX__INP(addr);
+		}
+		else
+		{
+			/* Bad address.  We will leave the output alone. */
+			discrete_log("NODE_%02d - Address = %d. Out of bounds\n",node->node-NODE_00, addr);
+		}
+	}
+	else
+	{
+		node->output=0;
+	}
+}
+
+void dst_multiplex_reset(struct node_description *node)
+{
+	struct dst_size_context *context = node->context;
+
+	context->size = node->active_inputs - 2;
+
+	dst_multiplex_step(node);
+}
+
+
 /************************************************************************
  *
  * DST_ONESHOT - Usage of node_description values for one shot pulse
@@ -1189,7 +1322,6 @@ void dst_switch_step(struct node_description *node)
 {
 	if(DSS_SWITCH__ENABLE)
 	{
-		/* Input 1 switches between input[0]/input[2] */
 		node->output=DSS_SWITCH__SWITCH ? DSS_SWITCH__IN1 : DSS_SWITCH__IN0;
 	}
 	else
@@ -1420,10 +1552,10 @@ void dst_tvca_op_amp_step(struct node_description *node)
 	else
 	{
 		/* F2 is at ground.  The diode blocks this so F2 and r5 are out of circuit.
-		 * So now the discharge rate is dependent upon F3.
-		 * If F3 is at ground then we discharge to 0V through r6.
-		 * If F3 is out of circuit then we discharge to OP_AMP_NORTON_VBE through r6+r7.
-		 * Also we don't go lower then OP_AMP_NORTON_VBE unless F3 is at ground. */
+         * So now the discharge rate is dependent upon F3.
+         * If F3 is at ground then we discharge to 0V through r6.
+         * If F3 is out of circuit then we discharge to OP_AMP_NORTON_VBE through r6+r7.
+         * Also we don't go lower then OP_AMP_NORTON_VBE unless F3 is at ground. */
 		if (!(f3 && (context->vCap1 <= OP_AMP_NORTON_VBE)))
 			context->vCap1 += ((f3 ? OP_AMP_NORTON_VBE : 0.0) - context->vCap1) * context->exponentD[f3];
 	}
@@ -1467,7 +1599,7 @@ void dst_tvca_op_amp_reset(struct node_description *node)
 
 	context->vOutMax = info->vP - OP_AMP_NORTON_VBE;
 	/* This is probably overkill because R5 is usually much lower then r6 or r7,
-	 * but it is better to play it safe. */
+     * but it is better to play it safe. */
 	context->vTrig[0] = (info->vP - 0.6) * (info->r6 / (info->r6 + info->r5));
 	context->vTrig[1] = (info->vP - 0.6 - OP_AMP_NORTON_VBE) * (context->r67 / (context->r67 + info->r5)) + OP_AMP_NORTON_VBE;
 	context->iFixed = context->vOutMax / info->r1;
