@@ -8,19 +8,18 @@
  *
  ************************************************************************
  *
- * DSS_COUNTER      - External clock Binary Counter
- * DSS_COUNTER_FIX  - Fixed Frequency Binary Counter
- * DSS_LFSR_NOISE        - Linear Feedback Shift Register Noise
- * DSS_NOISE             - Noise Source - Random source
- * DSS_NOTE              - Note/tone generator
- * DSS_OP_AMP_OSC        - Op Amp oscillator circuits
- * DSS_SAWTOOTHWAVE      - Sawtooth waveform generator
- * DSS_SCHMITT_OSC       - Schmitt Feedback Oscillator
- * DSS_SINEWAVE          - Sinewave generator source code
- * DSS_SQUAREWAVE        - Squarewave generator source code
- * DSS_SQUAREWFIX        - Squarewave generator - fixed frequency
- * DSS_SQUAREWAVE2       - Squarewave generator - by tOn/tOff
- * DSS_TRIANGLEWAVE      - Triangle waveform generator
+ * DSS_COUNTER        - External clock Binary Counter
+ * DSS_LFSR_NOISE     - Linear Feedback Shift Register Noise
+ * DSS_NOISE          - Noise Source - Random source
+ * DSS_NOTE           - Note/tone generator
+ * DSS_OP_AMP_OSC     - Op Amp oscillator circuits
+ * DSS_SAWTOOTHWAVE   - Sawtooth waveform generator
+ * DSS_SCHMITT_OSC    - Schmitt Feedback Oscillator
+ * DSS_SINEWAVE       - Sinewave generator source code
+ * DSS_SQUAREWAVE     - Squarewave generator source code
+ * DSS_SQUAREWFIX     - Squarewave generator - fixed frequency
+ * DSS_SQUAREWAVE2    - Squarewave generator - by tOn/tOff
+ * DSS_TRIANGLEWAVE   - Triangle waveform generator
  *
  ************************************************************************/
 
@@ -31,19 +30,23 @@ struct dss_adsr_context
 
 struct dss_counter_context
 {
-	int last;		/* Last clock state */
-};
-
-struct dss_counterfix_context
-{
-	double sampleStep;	/* time taken up by 1 audio sample */
-	double tCycle;		/* time period of selected frequency */
-	double tLeft;		/* time left sampling current frequency cycle */
+	int		clock_type;
+	int		out_type;
+	int		is_7492;
+	int		last;		/* Last clock state */
+	int		count;		/* current count */
+	double	t_sample;	/* discrete clock rate in seconds */
+	double	t_clock;	/* fixed counter clock in seconds */
+	double	t_left;		/* time unused during last sample in seconds */
 };
 
 struct dss_lfsr_context
 {
 	unsigned int	lfsr_reg;
+	int				last;		/* Last clock state */
+	double			t_sample;	/* discrete clock rate in seconds */
+	double			t_clock;	/* fixed counter clock in seconds */
+	double			t_left;		/* time unused during last sample in seconds */
 	double			sampleStep;
 	double			shiftStep;
 	double			t;
@@ -56,11 +59,16 @@ struct dss_noise_context
 
 struct dss_note_context
 {
-	double	step;	/* sample time */
-	double	cycle;	/* time for 1 cycle of the given frequency */
-	double	tLeft;	/* time not used up */
-	int		max1;	/* Max 1 Count stored as int for easy use. */
-	int		count;	/* current count */
+	int		clock_type;
+	int		out_type;
+	int		last;		/* Last clock state */
+	double	t_sample;	/* discrete clock rate in seconds */
+	double	t_clock;	/* fixed counter clock in seconds */
+	double	t_left;		/* time unused during last sample in seconds */
+	int		max1;		/* Max 1 Count stored as int for easy use. */
+	int		max2;		/* Max 2 Count stored as int for easy use. */
+	int		count1;		/* current count1 */
+	int		count2;		/* current count2 */
 };
 
 struct dss_op_amp_osc_context
@@ -133,7 +141,7 @@ struct dss_trianglewave_context
  * input3    - Max count
  * input4    - Direction - 0=down, 1=up
  * input5    - Reset Value
- * input6    - Clock type (count on 0/1)
+ * input6    - Clock type
  *
  * Jan 2004, D Renaud.
  ************************************************************************/
@@ -143,101 +151,120 @@ struct dss_trianglewave_context
 #define DSS_COUNTER__MAX		(*(node->input[3]))
 #define DSS_COUNTER__DIR		(*(node->input[4]))
 #define DSS_COUNTER__INIT		(*(node->input[5]))
-#define DSS_COUNTER__TYPE		(*(node->input[6]))
+#define DSS_COUNTER__CLOCK_TYPE	(*(node->input[6]))
+
+const int disc_7492_count[6] = {0x00, 0x01, 0x02, 0x04, 0x05, 0x06};
 
 void dss_counter_step(struct node_description *node)
 {
 	struct dss_counter_context *context = node->context;
-	int clock = (DSS_COUNTER__CLOCK != 0);
-	/*
-	 * We will count at the selected changeover to high/low, only when enabled.
-	 * We don't count if module is not enabled.
-	 * This has the effect of holding the output at it's current value.
-	 */
-	if ((context->last != clock) && DSS_COUNTER__ENABLE)
-	{
-		/* Toggled */
-		context->last = clock;
+	double cycles;
+	int clock = 0, last_count, inc = 0;
+	int max = DSS_COUNTER__MAX;
+	double xTime = 0;
 
-		if (DSS_COUNTER__TYPE == clock)
-		{
-			/* Proper edge */
-			node->output += DSS_COUNTER__DIR ? 1 : -1; /* up/down */
-			if (node->output < 0) node->output = DSS_COUNTER__MAX;
-			if (node->output > DSS_COUNTER__MAX) node->output = 0;
-		}
+	if (context->clock_type == DISC_CLK_IS_FREQ)
+	{
+		/* We need to keep clocking the internal clock even if disabled. */
+		cycles = (context->t_left + context->t_sample) / context->t_clock;
+		inc = (int)cycles;
+		context->t_left = (cycles - inc) * context->t_clock;
+		if (inc) xTime = context->t_left / context->t_sample;
+	}
+	else
+	{
+		clock = (int)DSS_COUNTER__CLOCK;
+		xTime = DSS_COUNTER__CLOCK - clock;
 	}
 
-	/* If reset enabled then set output to the reset value. */
-	if (DSS_COUNTER__RESET) node->output = DSS_COUNTER__INIT;
+
+	/* If reset enabled then set output to the reset value.  No xTime in reset. */
+	if (DSS_COUNTER__RESET)
+	{
+		context->count = DSS_COUNTER__INIT;
+		node->output = context->is_7492 ? 0 : context->count;
+		return;
+	}
+
+	/*
+     * Only count if module is enabled.
+     * This has the effect of holding the output at it's current value.
+     */
+	if (DSS_COUNTER__ENABLE)
+	{
+		last_count = context->count;
+
+		switch (context->clock_type)
+		{
+			case DISC_CLK_ON_F_EDGE:
+			case DISC_CLK_ON_R_EDGE:
+				/* See if the clock has toggled to the proper edge */
+				clock = (clock != 0);
+				if (context->last != clock)
+				{
+					context->last = clock;
+					if (context->clock_type == clock)
+					{
+						/* Toggled */
+						inc = 1;
+					}
+				}
+				break;
+
+		case DISC_CLK_BY_COUNT:
+				/* Clock number of times specified. */
+				inc = clock;
+				break;
+		}
+
+		for (clock = 0; clock < inc; clock++)
+		{
+			context->count += DSS_COUNTER__DIR ? 1 : -1; /* up/down */
+			if (context->count < 0) context->count = max;
+			if (context->count > max) context->count = 0;
+		}
+
+		node->output = context->is_7492 ? disc_7492_count[context->count] : context->count;
+
+		if (context->count != last_count)
+		{
+			/* the xTime is only output if the output changed. */
+			switch (context->out_type)
+			{
+				case DISC_OUT_IS_ENERGY:
+					if (xTime != 0)
+						node->output = (context->count > last_count) ? (last_count + xTime) : (last_count - xTime);
+					break;
+				case DISC_OUT_HAS_XTIME:
+					node->output += xTime;
+					break;
+			}
+		}
+	}
+	else
+		node->output = context->count;
 }
 
 void dss_counter_reset(struct node_description *node)
 {
 	struct dss_counter_context *context = node->context;
 
-	context->last = (DSS_COUNTER__CLOCK != 0);
-	node->output = DSS_COUNTER__INIT; /* Output starts at reset value */
-}
-
-
-/************************************************************************
- *
- * DSS_COUNTER_FIX - Fixed Frequency Binary Counter
- *
- * input0    - Enable input value
- * input1    - Reset input (active high)
- * input2    - Frequency
- * input3    - Max count
- * input4    - Direction - 0=up, 1=down
- * input5    - Reset Value
- *
- * Jan 2004, D Renaud.
- ************************************************************************/
-#define DSS_COUNTER_FIX__ENABLE		(*(node->input[0]))
-#define DSS_COUNTER_FIX__RESET		(*(node->input[1]))
-#define DSS_COUNTER_FIX__FREQ		(*(node->input[2]))
-#define DSS_COUNTER_FIX__MAX		(*(node->input[3]))
-#define DSS_COUNTER_FIX__DIR		(*(node->input[4]))
-#define DSS_COUNTER_FIX__INIT		(*(node->input[5]))
-
-void dss_counterfix_step(struct node_description *node)
-{
-	struct dss_counterfix_context *context = node->context;
-
-	context->tLeft -= context->sampleStep;
-
-	/* The enable input only curtails output, phase rotation still occurs. */
-	while (context->tLeft <= 0)
+	context->clock_type = (int)DSS_COUNTER__CLOCK_TYPE;
+	if (context->clock_type == DISC_COUNTER_IS_7492)
 	{
-
-		/*
-		 * We will count when enabled.
-		 * We don't count if module is not enabled.
-		 * This has the effect of holding the output at it's current value.
-		 */
-		if (DSS_COUNTER_FIX__ENABLE)
-		{
-			node->output += DSS_COUNTER_FIX__DIR ? 1 : -1; /* up/down */
-			if (node->output < 0) node->output = DSS_COUNTER_FIX__MAX;
-			if (node->output > DSS_COUNTER_FIX__MAX) node->output = 0;
-		}
-
-		context->tLeft += context->tCycle;
+		context->clock_type = DISC_CLK_ON_F_EDGE;
+		context->is_7492 = 1;
 	}
-
-	/* If reset enabled then set output to the reset value. */
-	if (DSS_COUNTER_FIX__RESET) node->output = DSS_COUNTER_FIX__INIT;
-}
-
-void dss_counterfix_reset(struct node_description *node)
-{
-	struct dss_counterfix_context *context = node->context;
-
-	context->sampleStep = 1.0 / Machine->sample_rate;
-	context->tCycle = 1.0 / DSS_COUNTER_FIX__FREQ;
-	context->tLeft = context->tCycle;
-	node->output = DSS_COUNTER_FIX__INIT; /* Output starts at reset value */
+	else
+		context->is_7492 = 0;
+	if ((context->clock_type < DISC_CLK_ON_F_EDGE) || (context->clock_type > DISC_CLK_IS_FREQ))
+		discrete_log("Invalid clock type passed in NODE_%d\n", node->node - NODE_START);
+	context->last = 0;
+	context->t_sample = 1.0 / Machine->sample_rate;
+	if (context->clock_type == DISC_CLK_IS_FREQ) context->t_clock = 1.0 / DSS_COUNTER__CLOCK;
+	context->t_left = 0;
+	context->count = DSS_COUNTER__INIT; /* count starts at reset value */
+	node->output = DSS_COUNTER__INIT;
 }
 
 
@@ -247,15 +274,17 @@ void dss_counterfix_reset(struct node_description *node)
  *
  * input0    - Enable input value
  * input1    - Register reset
- * input2    - Noise sample frequency
+ * input2    - Clock Input
  * input3    - Amplitude input value
  * input4    - Input feed bit
  * input5    - Bias
  *
+ * also passed dss_lfsr_context structure
+ *
  ************************************************************************/
 #define DSS_LFSR_NOISE__ENABLE	(*(node->input[0]))
 #define DSS_LFSR_NOISE__RESET	(*(node->input[1]))
-#define DSS_LFSR_NOISE__FREQ	(*(node->input[2]))
+#define DSS_LFSR_NOISE__CLOCK	(*(node->input[2]))
 #define DSS_LFSR_NOISE__AMP		(*(node->input[3]))
 #define DSS_LFSR_NOISE__FEED	(*(node->input[4]))
 #define DSS_LFSR_NOISE__BIAS	(*(node->input[5]))
@@ -321,24 +350,50 @@ void dss_lfsr_step(struct node_description *node)
 {
 	const struct discrete_lfsr_desc *lfsr_desc = node->custom;
 	struct dss_lfsr_context *context = node->context;
-	double shiftAmount;
-	int fb0,fb1,fbresult,i;
+	double cycles;
+	int clock, inc = 0;
+	int fb0,fb1,fbresult;
+
+	if (lfsr_desc->clock_type == DISC_CLK_IS_FREQ)
+	{
+		/* We need to keep clocking the internal clock even if disabled. */
+		cycles = (context->t_left + context->t_sample) / context->t_clock;
+		inc = (int)cycles;
+		context->t_left = (cycles - inc) * context->t_clock;
+	}
 
 	/* Reset everything if necessary */
 	if((DSS_LFSR_NOISE__RESET ? 1 : 0) == ((lfsr_desc->flags & DISC_LFSR_FLAG_RESET_TYPE_H) ? 1 : 0))
 	{
 		dss_lfsr_reset(node);
+		return;
 	}
 
-	i=0;
-	/* Calculate the number of full shift register cycles since last machine sample. */
-	shiftAmount = ((context->sampleStep + context->t) / context->shiftStep);
-	context->t = (shiftAmount - (int)shiftAmount) * context->shiftStep;    /* left over amount of time */
-	while(i<(int)shiftAmount)
+	switch (lfsr_desc->clock_type)
 	{
-		i++;
-		/* Now clock the LFSR by 1 cycle and output */
+		case DISC_CLK_ON_F_EDGE:
+		case DISC_CLK_ON_R_EDGE:
+			/* See if the clock has toggled to the proper edge */
+			clock = (DSS_LFSR_NOISE__CLOCK != 0);
+			if (context->last != clock)
+			{
+				context->last = clock;
+				if (lfsr_desc->clock_type == clock)
+				{
+					/* Toggled */
+					inc = 1;
+				}
+			}
+			break;
 
+		case DISC_CLK_BY_COUNT:
+			/* Clock number of times specified. */
+			inc = (int)DSS_LFSR_NOISE__CLOCK;
+			break;
+	}
+
+	for (clock = 0; clock < inc; clock++)
+	{
 		/* Fetch the last feedback result */
 		fbresult=((context->lfsr_reg)>>(lfsr_desc->bitlength))&0x01;
 
@@ -384,9 +439,12 @@ void dss_lfsr_reset(struct node_description *node)
 	struct dss_lfsr_context *context = node->context;
 	int fb0,fb1,fbresult;
 
-	context->t = 0;
-	context->sampleStep = 1.0 / Machine->sample_rate;
-	context->shiftStep = 1.0 / DSS_LFSR_NOISE__FREQ;
+	if ((lfsr_desc->clock_type < DISC_CLK_ON_F_EDGE) || (lfsr_desc->clock_type > DISC_CLK_IS_FREQ))
+		discrete_log("Invalid clock type passed in NODE_%d\n", node->node - NODE_START);
+	context->last = (DSS_COUNTER__CLOCK != 0);
+	context->t_sample = 1.0 / Machine->sample_rate;
+	if (lfsr_desc->clock_type == DISC_CLK_IS_FREQ) context->t_clock = 1.0 / DSS_LFSR_NOISE__CLOCK;
+	context->t_left = 0;
 
 	context->lfsr_reg=lfsr_desc->reset_value;
 
@@ -471,49 +529,102 @@ void dss_noise_reset(struct node_description *node)
  * DSS_NOTE - Note/tone generator
  *
  * input0    - Enable input value
- * input1    - Frequency value
+ * input1    - Clock Input
  * input2    - data value
  * input3    - Max count 1
  * input4    - Max count 2
+ * input5    - Clock type
  *
  * Mar 2004, D Renaud.
  ************************************************************************/
- #define DSS_NOTE__ENABLE	(*(node->input[0]))
- #define DSS_NOTE__FREQ		(*(node->input[1]))
- #define DSS_NOTE__DATA		(*(node->input[2]))
- #define DSS_NOTE__MAX1		(*(node->input[3]))
- #define DSS_NOTE__MAX2		(*(node->input[4]))
+ #define DSS_NOTE__ENABLE		(*(node->input[0]))
+ #define DSS_NOTE__CLOCK		(*(node->input[1]))
+ #define DSS_NOTE__DATA			(*(node->input[2]))
+ #define DSS_NOTE__MAX1			(*(node->input[3]))
+ #define DSS_NOTE__MAX2			(*(node->input[4]))
+ #define DSS_NOTE__CLOCK_TYPE	(*(node->input[5]))
 
 void dss_note_step(struct node_description *node)
 {
 	struct dss_note_context *context = node->context;
 
-	double	t;	/* time to process in this step */
-	int		i, countsThisStep;
+	double cycles;
+	int clock = 0, last_count2, inc = 0;
+	double xTime = 0;
+
+	if (context->clock_type == DISC_CLK_IS_FREQ)
+	{
+		/* We need to keep clocking the internal clock even if disabled. */
+		cycles = (context->t_left + context->t_sample) / context->t_clock;
+		inc = (int)cycles;
+		context->t_left = (cycles - inc) * context->t_clock;
+		if (inc) xTime = context->t_left / context->t_sample;
+	}
+	else
+	{
+		/* Seperate clock info from xTime info. */
+		clock = (int)DSS_NOTE__CLOCK;
+		xTime = DSS_NOTE__CLOCK - clock;
+	}
 
 	if (DSS_NOTE__ENABLE)
 	{
-		t = context->step + context->tLeft;
-		countsThisStep = (int)(t / context->cycle);
+		last_count2 = context->count2;
 
-		/* This code could probably speed up by using a bunch of compares instead of
-		 * a loop.  But the loop is much more readable. */
-		for (i=0; i<countsThisStep; i++)
+		switch (context->clock_type)
 		{
-			context->count++;
-			if (context->count >= context->max1)
-			{
-				/* Max 1 count reached.  Load Data into counter. */
-				context->count = (int)DSS_NOTE__DATA;
-				if (DSS_NOTE__DATA != DSS_NOTE__MAX1)
+			case DISC_CLK_ON_F_EDGE:
+			case DISC_CLK_ON_R_EDGE:
+				/* See if the clock has toggled to the proper edge */
+				clock = (clock != 0);
+				if (context->last != clock)
 				{
-					/* Count output as long as the data loaded is not already equal to max 1 count. */
-					node->output += 1;
-					if (node->output > DSS_NOTE__MAX2) node->output = 0;
+					context->last = clock;
+					if (context->clock_type == clock)
+					{
+						/* Toggled */
+						inc = 1;
+					}
+				}
+				break;
+
+			case DISC_CLK_BY_COUNT:
+				/* Clock number of times specified. */
+				inc = clock;
+				break;
+		}
+
+		/* Count output as long as the data loaded is not already equal to max 1 count. */
+		if (DSS_NOTE__DATA != DSS_NOTE__MAX1)
+		{
+			for (clock = 0; clock < inc; clock++)
+			{
+				context->count1++;
+				if (context->count1 >= context->max1)
+				{
+					/* Max 1 count reached.  Load Data into counter. */
+					context->count1 = (int)DSS_NOTE__DATA;
+					context->count2 += 1;
+					if (context->count2 > context->max2) context->count2 = 0;
 				}
 			}
 		}
-		context->tLeft = t - context->cycle * countsThisStep;
+
+		node->output = context->count2;
+		if (context->count2 != last_count2)
+		{
+			/* the xTime is only output if the output changed. */
+			switch (context->out_type)
+			{
+				case DISC_OUT_IS_ENERGY:
+					if (xTime != 0)
+						node->output = (context->count2 > last_count2) ? (last_count2 + xTime) : (last_count2 - xTime);
+					break;
+				case DISC_OUT_HAS_XTIME:
+					node->output += xTime;
+					break;
+			}
+		}
 	}
 	else
 		node->output = 0;
@@ -523,11 +634,17 @@ void dss_note_reset(struct node_description *node)
 {
 	struct dss_note_context *context = node->context;
 
-	context->step = 1.0 / Machine->sample_rate;
-	context->cycle = 1.0 / DSS_NOTE__FREQ;
-	context->count = (int)DSS_NOTE__DATA;
+	context->clock_type = (int)DSS_NOTE__CLOCK_TYPE & DISC_CLK_MASK;
+	context->out_type =  (int)DSS_NOTE__CLOCK_TYPE & DISC_OUT_MASK;
+	context->last = (DSS_NOTE__CLOCK != 0);
+	context->t_sample = 1.0 / Machine->sample_rate;
+	if (context->clock_type == DISC_CLK_IS_FREQ) context->t_clock = 1.0 / DSS_NOTE__CLOCK;
+	context->t_left = 0;
+
+	context->count1 = (int)DSS_NOTE__DATA;
+	context->count2 = 0;
 	context->max1 = (int)DSS_NOTE__MAX1;
-	context->tLeft = 0;
+	context->max2 = (int)DSS_NOTE__MAX2;
 	node->output = 0;
 }
 
@@ -741,7 +858,6 @@ void dss_op_amp_osc_reset(struct node_description *node)
 
 	context->vCap = 0;
 	context->step = 1.0 / Machine->sample_rate;
-logerror("type=%d, 0c=%f, 1c=%f, tL=%f, tH=%f, i1=%f, i2=%f\n",context->type,context->iCharge[0],context->iCharge[1],context->thresholdLow,context->thresholdHigh,i1,i2);
 
 	dss_op_amp_osc_step(node);
 }
@@ -842,11 +958,11 @@ void dss_schmitt_osc_step(struct node_description *node)
 	{
 		t = 0;
 		/* The charging voltage to the cap is the sum of the input voltage and the gate
-		 * output voltage in the ratios determined by their resistors in a divider network.
-		 * The input voltage is selectable as straight voltage in or logic level that will
-		 * use vGate as its voltage.  Note that ratioIn is just the ratio of the total
-		 * voltage and needs to be multipled by the input voltage.  ratioFeedback has
-		 * already been multiplied by vGate to save time because that voltage never changes. */
+         * output voltage in the ratios determined by their resistors in a divider network.
+         * The input voltage is selectable as straight voltage in or logic level that will
+         * use vGate as its voltage.  Note that ratioIn is just the ratio of the total
+         * voltage and needs to be multipled by the input voltage.  ratioFeedback has
+         * already been multiplied by vGate to save time because that voltage never changes. */
 		supply = (info->options & DISC_SCHMITT_OSC_IN_IS_VOLTAGE) ? context->ratioIn * DSS_SCHMITT_OSC__VIN : (DSS_SCHMITT_OSC__VIN ? context->ratioIn * info->vGate : 0);
 		supply += (context->state ? context->ratioFeedback : 0);
 		new_vCap = vCap + ((supply - vCap) * exponent);
@@ -915,12 +1031,12 @@ void dss_schmitt_osc_reset(struct node_description *node)
 	double rSource;
 
 	/* The 2 resistors make a voltage divider, so their ratios add together
-	 * to make the charging voltage. */
+     * to make the charging voltage. */
 	context->ratioIn = info->rFeedback / (info->rIn + info->rFeedback);
 	context->ratioFeedback = info->rIn / (info->rIn + info->rFeedback) * info->vGate;
 
 	/* The voltage source resistance works out to the 2 resistors in parallel.
-	 * So use this for the RC charge constant. */
+     * So use this for the RC charge constant. */
 	rSource = 1.0 / ((1.0 / info->rIn) + (1.0 / info->rFeedback));
 	context->rc = rSource * info->c;
 	context->exponent = -1.0 / (context->rc  * Machine->sample_rate);
@@ -1116,7 +1232,7 @@ void dss_squarewfix_reset(struct node_description *node)
 	context->tOff = 1.0 / DSS_SQUAREWFIX__FREQ;	/* cycle time */
 	context->tLeft = DSS_SQUAREWFIX__PHASE / 360.0;	/* convert start phase to % */
 	context->tLeft = context->tLeft - (int)context->tLeft;	/* keep % between 0 & 1 */
-	context->tLeft = context->tLeft < 0 ? 1.0 + context->tLeft : context->tLeft;	/* if - then flip to + phase */
+	context->tLeft = (context->tLeft < 0) ? 1.0 + context->tLeft : context->tLeft;	/* if - then flip to + phase */
 	context->tLeft *= context->tOff;
 	context->tOn = context->tOff * (DSS_SQUAREWFIX__DUTY / 100.0);
 	context->tOff -= context->tOn;
@@ -1159,22 +1275,22 @@ void dss_squarewave2_step(struct node_description *node)
 	struct dss_squarewave_context *context = node->context;
 	double newphase;
 
-	/* Establish trigger phase from time periods */
-	context->trigger=(DSS_SQUAREWAVE2__T_OFF / (DSS_SQUAREWAVE2__T_OFF + DSS_SQUAREWAVE2__T_ON)) * (2.0 * PI);
-
-	/* Work out the phase step based on phase/freq & sample rate */
-	/* The enable input only curtails output, phase rotation     */
-	/* still occurs                                              */
-
-	/*     phase step = 2Pi/(output period/sample period)        */
-	/*                    boils out to                           */
-	/*     phase step = 2Pi/(output period*sample freq)          */
-	newphase = context->phase + ((2.0 * PI) / ((DSS_SQUAREWAVE2__T_OFF + DSS_SQUAREWAVE2__T_ON) * Machine->sample_rate));
-	/* Keep the new phasor in the 2Pi range.*/
-	context->phase = fmod(newphase, 2.0 * PI);
-
 	if(DSS_SQUAREWAVE2__ENABLE)
 	{
+		/* Establish trigger phase from time periods */
+		context->trigger=(DSS_SQUAREWAVE2__T_OFF / (DSS_SQUAREWAVE2__T_OFF + DSS_SQUAREWAVE2__T_ON)) * (2.0 * PI);
+
+		/* Work out the phase step based on phase/freq & sample rate */
+		/* The enable input only curtails output, phase rotation     */
+		/* still occurs                                              */
+
+		/*     phase step = 2Pi/(output period/sample period)        */
+		/*                    boils out to                           */
+		/*     phase step = 2Pi/(output period*sample freq)          */
+		newphase = context->phase + ((2.0 * PI) / ((DSS_SQUAREWAVE2__T_OFF + DSS_SQUAREWAVE2__T_ON) * Machine->sample_rate));
+		/* Keep the new phasor in the 2Pi range.*/
+		context->phase = fmod(newphase, 2.0 * PI);
+
 		if(context->phase>context->trigger)
 			node->output=(DSS_SQUAREWAVE2__AMP/2.0);
 		else
@@ -1195,7 +1311,11 @@ void dss_squarewave2_reset(struct node_description *node)
 	double start;
 
 	/* Establish starting phase, convert from degrees to radians */
-	start = (DSS_SQUAREWAVE2__SHIFT / (DSS_SQUAREWAVE2__T_OFF + DSS_SQUAREWAVE2__T_ON)) * (2.0 * PI);
+	/* Only valid if we have set the on/off time                 */
+	if((DSS_SQUAREWAVE2__T_OFF + DSS_SQUAREWAVE2__T_ON) != 0.0)
+		start = (DSS_SQUAREWAVE2__SHIFT / (DSS_SQUAREWAVE2__T_OFF + DSS_SQUAREWAVE2__T_ON)) * (2.0 * PI);
+	else
+		start = 0.0;
 	/* Make sure its always mod 2Pi */
 	context->phase = fmod(start, 2.0 * PI);
 
@@ -1276,7 +1396,7 @@ void dss_trianglewave_reset(struct node_description *node)
 
 void dss_adsrenv_step(struct node_description *node)
 {
-/*	struct dss_adsr_context *context = node->context; */
+/*  struct dss_adsr_context *context = node->context; */
 
 	if(DSS_ADSR__ENABLE)
 	{
