@@ -13,7 +13,6 @@
 #include "sysdep/sysdep_dsp.h"
 #include "sysdep/sysdep_mixer.h"
 #include "sysdep/misc.h"
-#include "effect.h"
 
 /* be sure that device names are nullified */
 extern void XInput_trackballs_reset();
@@ -66,11 +65,16 @@ static int specify_ram(struct rc_option *option, const char *arg, int priority);
 #endif
 
 /* struct definitions */
-static struct rc_option opts[] = {
+static struct rc_option opts1[] = {
    /* name, shortname, type, dest, deflt, min, max, func, help */
 	{ NULL, NULL, rc_link, video_opts, NULL, 0, 0, NULL, NULL },
-	{ NULL, NULL, rc_link, sound_opts, NULL, 0, 0, NULL, NULL },
 	{ NULL, NULL, rc_link, input_opts, NULL, 0, 0, NULL, NULL },
+	{ NULL, NULL, rc_link, sound_opts, NULL, 0, 0, NULL, NULL },
+	{ NULL, NULL, rc_end, NULL, NULL, 0, 0, NULL, NULL }
+};
+
+static struct rc_option opts2[] = {
+   /* name, shortname, type, dest, deflt, min, max, func, help */
 	{ NULL, NULL, rc_link, network_opts, NULL, 0, 0, NULL, NULL },
 	{ NULL, NULL, rc_link, fileio_opts, NULL, 0, 0, NULL, NULL },
 #ifdef MESS
@@ -99,6 +103,7 @@ static struct rc_option opts[] = {
 	{ "cheat", "c", rc_bool, &options.cheat, "0", 0, 0, NULL, "Enable/disable cheat subsystem" },
 	{ "skip_disclaimer", NULL, rc_bool, &options.skip_disclaimer, "0", 0, 0, NULL, "Skip displaying the disclaimer screen" },
 	{ "skip_gameinfo", NULL, rc_bool, &options.skip_gameinfo, "0", 0, 0, NULL, "Skip displaying the game info screen" },
+	{ "skip_validitychecks", NULL, rc_bool, &options.skip_validitychecks, "1", 0, 0, NULL, "Skip doing the code validity checks" },
 	{ "crconly", NULL, rc_bool, &options.crc_only, "0", 0, 0, NULL, "Use only CRC for all integrity checks" },
 	{ "bios", NULL, rc_string, &options.bios, "default", 0, 14, NULL, "change system bios" },
 	{ "state", NULL, rc_string, &statename, NULL, 0, 0, NULL, "state to load" },
@@ -165,30 +170,30 @@ static int config_printf(const char *fmt, ...)
 
 static int config_handle_arg(char *arg)
 {
-	if (!got_gamename) /* notice: for MESS game means system */
+	/* notice: for MESS game means system */
+	if (got_gamename)
 	{
-		gamename     = arg;
-		got_gamename = 1;
-	}
-	else
-#ifdef MESS
-	{
-		if( options.image_count >= MAX_IMAGES )
-		{
-			fprintf(stderr, "error: too many image names specified!\n");
-			return -1;
-		}
-		/* options.image_files[options.image_count].type = iodevice_type; */
-		/* options.image_files[options.image_count].name = arg; */
-		/* options.image_count++; */
-	}
-#else
-	{
-		fprintf(stderr,"error: duplicate gamename: %s\n", arg);
+		fprintf(stderr, "error: duplicate gamename: %s\n", arg);
 		return -1;
 	}
-#endif
 
+	rompath_extra = osd_dirname(arg);
+
+	if (rompath_extra && !strlen(rompath_extra))
+	{
+		free(rompath_extra);
+		rompath_extra = NULL;
+	}
+
+	gamename = arg;
+
+	if (!gamename || !strlen(gamename))
+	{
+		fprintf(stderr, "error: no gamename given in %s\n", arg);
+		return -1;
+	}
+
+	got_gamename = 1;
 	return 0;
 }
 
@@ -232,11 +237,6 @@ int config_init (int argc, char *argv[])
 
 	memset(&options,0,sizeof(options));
 
-	/* reset trackball devices */
-#ifdef USE_XINPUT_DEVICES
-	XInput_trackballs_reset();
-#endif
-
 	/* Let's see if the endianess of this arch is correct; otherwise,
 	   YELL about it and bail out. */
 #ifdef LSB_FIRST
@@ -245,22 +245,18 @@ int config_init (int argc, char *argv[])
 	if(*((unsigned short*)lsb_test) != 0x0001)
 #endif
 	{
-		fprintf(stderr, "error: compiled byte ordering doesn't match machine byte ordering\n"
-				"are you sure you choose the right arch?\n"
+		fprintf(stderr, "error: compiled byte ordering doesn't match machine byte ordering.\n"
 #ifdef LSB_FIRST
-				"compiled for lsb-first, are you sure you choose the right cpu in makefile.unix\n");
+				"compiled for LSB first, are you sure you chose the right cpu in makefile.unix?\n");
 #else
-				"compiled for msb-first, are you sure you choose the right cpu in makefile.unix\n");
+				"compiled for MSB first, are you sure you chose the right cpu in makefile.unix?\n");
 #endif
 		return OSD_NOT_OK;
 	}
 
-	/* some settings which are static for xmame and thus aren't controled
+	/* some settings which are static for xmame and thus aren't controlled 
 	   by options */
 	options.gui_host = 1;
-#ifdef MESS
-	options.mess_printf_output = xmess_printf_output;
-#endif
 	cheatfile = NULL;
 	db_filename = NULL;
 	history_filename = NULL;
@@ -270,13 +266,16 @@ int config_init (int argc, char *argv[])
 	if (!(rc = rc_create()))
 		return OSD_NOT_OK;
 
+	if(rc_register(rc, opts1))
+		return OSD_NOT_OK;
+
 	if(sysdep_dsp_init(rc, NULL))
 		return OSD_NOT_OK;
 
 	if(sysdep_mixer_init(rc, NULL))
 		return OSD_NOT_OK;
 
-	if(rc_register(rc, opts))
+	if(rc_register(rc, opts2))
 		return OSD_NOT_OK;
 
 	/* get the homedir */
@@ -325,6 +324,24 @@ int config_init (int argc, char *argv[])
 	if (rc_parse_commandline(rc, argc, argv, 2, config_handle_arg))
 		return OSD_NOT_OK;
 
+	if (showmanusage)
+	{
+		rc_print_man_options(rc, stdout);
+		return OSD_OK;
+	}
+
+	if (showversion)
+	{
+		fprintf(stdout, "%s\n", title);
+		return OSD_OK;
+	}
+
+	if (showusage)
+	{
+		show_usage();
+		return OSD_OK;
+	}
+
 	/* parse the various configfiles, starting with the one with the
 	   lowest priority */
 	if(loadconfig)
@@ -348,32 +365,12 @@ int config_init (int argc, char *argv[])
 	if (!stderr_file) stderr_file = stderr;
 	if (!stdout_file) stdout_file = stdout;
 
-	effect_init1();
-
 	if (showconfig)
 	{
 		rc_write(rc, stdout_file, NAME" running parameters");
 		return OSD_OK;
 	}
 
-	if (showmanusage)
-	{
-		rc_print_man_options(rc, stdout_file);
-		return OSD_OK;
-	}
-
-	if (showversion)
-	{
-		fprintf(stdout_file, "%s\n", title);
-		return OSD_OK;
-	}
-
-	if (showusage)
-	{
-		show_usage();
-		return OSD_OK;
-	}
-
 	/* handle frontend options */
 	if ( (i=frontend_list(gamename)) != 1234)
 		return i;
@@ -582,11 +579,11 @@ int config_init (int argc, char *argv[])
 			}
 
 			/* Look up the filename extension in the drivers device list */
-			if (ext && (dev = device_first(drivers[game_index])))
+			if (ext && (dev = Machine->devices))
 			{
 				ext++; /* skip the "." */
 
-				while (dev)
+				while (dev->type < IO_COUNT)
 				{
 					const char *dst = dev->file_extensions;
 					/* scan supported extensions for this device */
@@ -603,7 +600,7 @@ int config_init (int argc, char *argv[])
 						/* skip '\0' once in the list of extensions */
 						dst += strlen(dst) + 1;
 					}
-					dev = device_next(drivers[game_index], dev); 
+					dev++;
 				}
 			}
 			if(!options.image_files[i].type)
@@ -637,28 +634,51 @@ int config_init (int argc, char *argv[])
 	if (language)
 		options.language_file = mame_fopen(0, language, FILETYPE_LANGUAGE,0);
 
+	/* setup ui orientation */
+	options.ui_orientation = drivers[game_index]->flags & ORIENTATION_MASK;
+
+	if (options.ui_orientation & ORIENTATION_SWAP_XY)
+	{
+		/* if only one of the components is inverted, switch them */
+		if ((options.ui_orientation & ROT180) == ORIENTATION_FLIP_X ||
+				(options.ui_orientation & ROT180) == ORIENTATION_FLIP_Y)
+			options.ui_orientation ^= ROT180;
+	}
+
 	return 1234;
 }
 
 void config_exit(void)
 {
+	gamename = NULL;
+
 	if(rc)
 	{
 		sysdep_mixer_exit();
 		sysdep_dsp_exit();
 		rc_destroy(rc);
+		rc = NULL;
 	}
 
-	if(home_dir)
-		free(home_dir);
+	free(home_dir);
+	home_dir = NULL;
 
 	/* close open files */
 	if (options.playback)
+	{
 		mame_fclose(options.playback);
+		options.playback = NULL;
+	}
 	if (options.record)
+	{
 		mame_fclose(options.record);
+		options.record = NULL;
+	}
 	if (options.language_file)
+	{
 		mame_fclose(options.language_file);
+		options.language_file = NULL;
+	}
 }
 
 /* 
@@ -667,7 +687,7 @@ void config_exit(void)
 void show_usage(void) 
 {
 	/* header */
-	fprintf(stdout_file, 
+	fprintf(stdout, 
 #ifdef MESS
 			"Usage: xmess <system> [game] [options]\n"
 #else
@@ -676,32 +696,32 @@ void show_usage(void)
 			"Options:\n");
 
 	/* actual help message */
-	rc_print_help(rc, stdout_file);
+	rc_print_help(rc, stdout);
 
 	/* footer */
-	fprintf(stdout_file, "\nFiles:\n\n");
-	fprintf(stdout_file, "Config Files are parsed in the following order:\n");
-	fprint_columns(stdout_file, SYSCONFDIR"/"NAME"rc",
+	fprintf(stdout, "\nFiles:\n\n");
+	fprintf(stdout, "Config Files are parsed in the following order:\n");
+	fprint_columns(stdout, SYSCONFDIR"/"NAME"rc",
 			"Global configuration config file");
-	fprint_columns(stdout_file, "${HOME}/."NAME"/"NAME"rc",
+	fprint_columns(stdout, "${HOME}/."NAME"/"NAME"rc",
 			"User configuration config file");
-	fprint_columns(stdout_file, SYSCONFDIR"/"NAME"-"DISPLAY_METHOD"rc",
+	fprint_columns(stdout, SYSCONFDIR"/"NAME"-"DISPLAY_METHOD"rc",
 			"Global per display method config file");
-	fprint_columns(stdout_file, "${HOME}/."NAME"/"NAME"-"DISPLAY_METHOD"rc",
+	fprint_columns(stdout, "${HOME}/."NAME"/"NAME"-"DISPLAY_METHOD"rc",
 			"User per display method config file");
-	fprint_columns(stdout_file, SYSCONFDIR"/rc/<game>rc",
+	fprint_columns(stdout, SYSCONFDIR"/rc/<game>rc",
 			"Global per game config file");
-	fprint_columns(stdout_file, "${HOME}/."NAME"/rc/<game>rc",
+	fprint_columns(stdout, "${HOME}/."NAME"/rc/<game>rc",
 			"User per game config file");
-	/*  fprintf(stdout_file, "\nEnvironment variables:\n\n");
-	    fprint_columns(stdout_file, "ROMPATH", "Rom search path"); */
-	fprintf(stdout_file, "\n"
+	/*  fprintf(stdout, "\nEnvironment variables:\n\n");
+	    fprint_columns(stdout, "ROMPATH", "Rom search path"); */
+	fprintf(stdout, "\n"
 #ifdef MESS
 			"M.E.S.S. - Multi-Emulator Super System\n"
-			"Copyright (C) 1998-2004 by the MESS team\n"
+			"Copyright (C) 1998-2005 by the MESS team\n"
 #else
 			"M.A.M.E. - Multiple Arcade Machine Emulator\n"
-			"Copyright (C) 1997-2004 by Nicola Salmoria and the MAME Team\n"
+			"Copyright (C) 1997-2005 by Nicola Salmoria and the MAME Team\n"
 #endif
 			"%s port maintained by Lawrence Gold\n", NAME);
 }
