@@ -77,7 +77,13 @@ UINT8				trying_to_quit;
 /*============================================================ */
 
 /* this will be filled in dynamically */
-static struct OSCodeInfo	codelist[KEY_CODES + JOY_CODES];
+
+#define TOTAL_CODES KEY_CODES \
+	+ SYSDEP_DISPLAY_MOUSE_MAX * (SYSDEP_DISPLAY_MOUSE_AXES + SYSDEP_DISPLAY_MOUSE_BUTTONS) \
+	+ JOY_MAX * (JOY_BUTTONS + JOY_AXES * (JOY_DIRS + 1)) \
+	+ GUN_MAX * 2
+
+static struct OSCodeInfo	codelist[TOTAL_CODES];
 static int			total_codes;
 
 /* Controller override options */
@@ -998,7 +1004,7 @@ static void init_keycodes(void)
 	add_keylist_entry("TAB", KEY_TAB, KEYCODE_TAB);
 	add_keylist_entry("[", KEY_OPENBRACE, KEYCODE_OPENBRACE);
 	add_keylist_entry("]", KEY_CLOSEBRACE, KEYCODE_CLOSEBRACE);
-	add_keylist_entry("ENTE ", KEY_ENTER, KEYCODE_ENTER);
+	add_keylist_entry("ENTER", KEY_ENTER, KEYCODE_ENTER);
 	add_keylist_entry(";", KEY_COLON, KEYCODE_COLON);
 	add_keylist_entry(":", KEY_QUOTE, KEYCODE_QUOTE);
 	add_keylist_entry("\\", KEY_BACKSLASH, KEYCODE_BACKSLASH);
@@ -1024,8 +1030,11 @@ static void init_keycodes(void)
 	add_keylist_entry(". PAD", KEY_DEL_PAD, KEYCODE_DEL_PAD);
 	add_keylist_entry("ENTER PAD", KEY_ENTER_PAD, KEYCODE_ENTER_PAD);
 	add_keylist_entry("PRTSCR", KEY_PRTSCR, KEYCODE_PRTSCR);
-	add_keylist_entry("PAUSE", KEY_PAUSE, KEYCODE_PAUSE);
+#ifdef PAUSE_KEY_119
 	add_keylist_entry("PAUSE", KEY_PAUSE_ALT, KEYCODE_PAUSE);
+#else
+	add_keylist_entry("PAUSE", KEY_PAUSE, KEYCODE_PAUSE);
+#endif
 	add_keylist_entry("LSHIFT", KEY_LSHIFT, KEYCODE_LSHIFT);
 	add_keylist_entry("RSHIFT", KEY_RSHIFT, KEYCODE_RSHIFT);
 	add_keylist_entry("LCTRL", KEY_LCONTROL, KEYCODE_LCONTROL);
@@ -1055,7 +1064,7 @@ int xmame_keyboard_init(void)
 
 void xmame_keyboard_exit()
 {
-	if(kbd_fifo)
+	if (kbd_fifo)
 		kbd_fifo_destroy(kbd_fifo);
 }
 
