@@ -90,6 +90,7 @@ static blit_func_p effect_funcs[] = {
    blit_normal_32_32_direct,
    blit_normal_32_YUY2_direct,
    NULL, /* reserved for 32_YV12_direct */
+#ifndef DISABLE_EFFECTS
    /* scale 2x */
    blit_scale2x_15_15_direct,
    blit_scale2x_16_16, /* Just use the 16 bpp src versions, since we need */
@@ -318,6 +319,7 @@ static blit_func_p effect_funcs[] = {
    blit_fakescan_v_32_32_direct,
    blit_fakescan_v_32_YUY2_direct,
    NULL, /* reserved for 32_YV12_direct */
+#endif
 };
 
 static void rotate_16_16(void *dst, struct mame_bitmap *bitmap, int y, struct rectangle *bounds);
@@ -402,6 +404,7 @@ blit_func_p sysdep_display_effect_open(void)
     first_time = 0;
   }
   
+#ifndef DISABLE_EFFECTS
   /* patch mmx asm blit functions into the table */
   if (sysdep_cpu_caps & SYSDEP_CPU_MMX)
   {
@@ -438,12 +441,13 @@ blit_func_p sysdep_display_effect_open(void)
     effect_funcs[SYSDEP_DISPLAY_EFFECT_MODES*SYSDEP_DISPLAY_EFFECT_6TAP2X+16] =
       blit_6tap_mmx_32_YUY2_direct;
   }
+#endif /* DISABLE_EFFECTS */
 #endif
 
   /* FIXME only allocate if needed and of the right size */
   if (!(effect_dbbuf = malloc(sysdep_display_params.max_width*sysdep_display_params.widthscale*sysdep_display_params.heightscale*4)))
   {
-    fprintf(stderr, "Error: couldnot allocate memory\n");
+    fprintf(stderr, "Error: could not allocate memory\n");
     return NULL;
   }
   memset(effect_dbbuf, sysdep_display_params.max_width*sysdep_display_params.widthscale*sysdep_display_params.heightscale*4, 0);
@@ -519,44 +523,8 @@ blit_func_p sysdep_display_effect_open(void)
     effect_index %= EFFECT_COLOR_FORMATS*3;
   }
 
-  if (sysdep_display_params.orientation)
-  {
-    switch (sysdep_display_params.depth) {
-    case 15:
-    case 16:
-      rotate_func = rotate_16_16;
-      break;
-    case 32:
-      rotate_func = rotate_32_32;
-      break;
-    }
-
-    /* add safety of +- 16 bytes, since some effects assume that this
-       is present and otherwise segfault */
-    if (!(rotate_dbbuf0 = calloc(sysdep_display_params.max_width*((sysdep_display_params.depth+1)/8) + 32, sizeof(char))))
-    {
-      fprintf(stderr, "Error: couldnot allocate memory\n");
-      return NULL;
-    }
-    rotate_dbbuf0 += 16;
-
-    if ((sysdep_display_params.effect == SYSDEP_DISPLAY_EFFECT_SCALE2X) ||
-        (sysdep_display_params.effect == SYSDEP_DISPLAY_EFFECT_HQ2X)    ||
-        (sysdep_display_params.effect == SYSDEP_DISPLAY_EFFECT_LQ2X)) {
-      if (!(rotate_dbbuf1 = calloc(sysdep_display_params.max_width*((sysdep_display_params.depth+1)/8) + 32, sizeof(char))))
-      {
-        fprintf(stderr, "Error: couldnot allocate memory\n");
-        return NULL;
-      }
-      rotate_dbbuf1 += 16;
-      if (!(rotate_dbbuf2 = calloc(sysdep_display_params.max_width*((sysdep_display_params.depth+1)/8) + 32, sizeof(char))))
-      {
-        fprintf(stderr, "Error: couldnot allocate memory\n");
-        return NULL;
-      }
-      rotate_dbbuf2 += 16;
-    }
-  }
+  if (sysdep_display_set_up_rotation())
+	  return NULL;
 
   /* Effect specific initialiasations */
   switch (sysdep_display_params.effect)
@@ -602,7 +570,7 @@ blit_func_p sysdep_display_effect_open(void)
       if (!_6tap2x_buf0 || !_6tap2x_buf1 || !_6tap2x_buf2 || !_6tap2x_buf3 ||
           !_6tap2x_buf4 || !_6tap2x_buf5 )
       {
-        fprintf(stderr, "Error: couldnot allocate memory\n");
+        fprintf(stderr, "Error: could not allocate memory\n");
         return NULL;
       }
       /* We need the palette lookup table to be 888 rgb, this means that the
@@ -660,6 +628,51 @@ blit_func_p sysdep_display_effect_open(void)
   return effect_funcs[effect_index];
 }
 
+/* Set up rotation function and buffer, if needed. */
+int sysdep_display_set_up_rotation(void)
+{
+  if (sysdep_display_params.orientation)
+  {
+    switch (sysdep_display_params.depth) {
+    case 15:
+    case 16:
+      rotate_func = rotate_16_16;
+      break;
+    case 32:
+      rotate_func = rotate_32_32;
+      break;
+    }
+
+    /* add safety of +- 16 bytes, since some effects assume that this
+       is present and otherwise segfault */
+    if (!(rotate_dbbuf0 = calloc(sysdep_display_params.max_width*((sysdep_display_params.depth+1)/8) + 32, sizeof(char))))
+    {
+      fprintf(stderr, "Error: could not allocate memory\n");
+      return -1;
+    }
+    rotate_dbbuf0 += 16;
+
+    if ((sysdep_display_params.effect == SYSDEP_DISPLAY_EFFECT_SCALE2X) ||
+        (sysdep_display_params.effect == SYSDEP_DISPLAY_EFFECT_HQ2X)    ||
+        (sysdep_display_params.effect == SYSDEP_DISPLAY_EFFECT_LQ2X)) {
+      if (!(rotate_dbbuf1 = calloc(sysdep_display_params.max_width*((sysdep_display_params.depth+1)/8) + 32, sizeof(char))))
+      {
+        fprintf(stderr, "Error: could not allocate memory\n");
+        return -1;
+      }
+      rotate_dbbuf1 += 16;
+      if (!(rotate_dbbuf2 = calloc(sysdep_display_params.max_width*((sysdep_display_params.depth+1)/8) + 32, sizeof(char))))
+      {
+        fprintf(stderr, "Error: could not allocate memory\n");
+        return -1;
+      }
+      rotate_dbbuf2 += 16;
+    }
+  }
+
+  return 0;
+}
+
 void sysdep_display_effect_close(void)
 {
   /* if we modifified it then restore palette_info */
