@@ -4,6 +4,7 @@
 #include "audit.h"
 #include "common.h"
 #include "info.h"
+#include "sound/samples.h"
 
 #ifdef MESS
 #include "xmess.h"
@@ -13,6 +14,7 @@ static int frontend_list_clones(char *gamename);
 static int frontend_list_cpu(void);
 static int frontend_list_gamelistheader(void);
 static int frontend_list_hash(int type);
+static void namecopy(char *name_ref, const char *desc, int buf_size);
 
 static int list       = 0;
 static int listclones = 1;
@@ -25,16 +27,19 @@ static int sortby     = 0;
 enum {
 	/* standard list commands */
 	LIST_LIST = 1, LIST_FULL, LIST_GAMES, LIST_DETAILS, LIST_GAMELIST,
-	LIST_SOURCEFILE, LIST_COLORS, LIST_ROMSIZE, LIST_PALETTESIZE,
-	LIST_ROMS, LIST_CRC, LIST_SHA1, LIST_MD5, LIST_SAMPLES, LIST_SAMDIR, 
+	LIST_SOURCEFILE, LIST_COLORS,
+#ifdef MESS
+	/* MESS-specific commands */
+	LIST_MESSDEVICES, LIST_MESSTEXT, LIST_MESSCREATEDIR,	
+#endif
+	LIST_ROMSIZE, LIST_PALETTESIZE, LIST_ROMS, LIST_CRC, LIST_SHA1, 
+	LIST_MD5, LIST_SAMPLES, LIST_SAMDIR, 
 	VERIFY_ROMS, VERIFY_ROMSETS, VERIFY_SAMPLES, VERIFY_SAMPLESETS,
 	/* internal verification list commands (developers only) */
 	LIST_MISSINGROMS, LIST_DUPCRC, LIST_WRONGORIENTATION, LIST_WRONGMERGE,
 	LIST_WRONGFPS,
 	/* standard list commands which require special handling */
-	LIST_CLONES, LIST_XML, LIST_CPU,
-	/* MESS-specific commands */
-	LIST_MESSTEXT, LIST_MESSDEVICES, LIST_MESSCREATEDIR
+	LIST_CLONES, LIST_XML, LIST_CPU
 };
    
 /* Mame frontend interface & commandline */
@@ -47,7 +52,7 @@ struct rc_option frontend_list_opts[] = {
 	{ "listfull", "lf", rc_set_int, &list, NULL, LIST_FULL, 0, NULL, "Like -list, with full description" },
 	{ "listgames", "lg", rc_set_int, &list, NULL, LIST_GAMES, 0, NULL, "Like -list, with manufacturer and year" },
 	{ "listdetails", "ld", rc_set_int, &list, NULL, LIST_DETAILS, 0, NULL, "Like -list, with detailed info" },
-	{ "listgamelist", "lgl", rc_set_int, &list, NULL, LIST_GAMELIST, 0, NULL, "Like -list, with specialy formatted extra info for generating gamelist.mame" },
+	{ "listgamelist", "lgl", rc_set_int, &list, NULL, LIST_GAMELIST, 0, NULL, "Like -list, with specially formatted extra info for generating gamelist.mame" },
 	{ "listsourcefile", "lsf", rc_set_int, &list, NULL, LIST_SOURCEFILE, 0, NULL, "Like -list, with driver sourcefile" },
 	{ "listcolors", "lcol", rc_set_int, &list, NULL, LIST_COLORS, 0, NULL, "Like -list, with the number of colors used" },
 #ifdef MESS
@@ -56,7 +61,7 @@ struct rc_option frontend_list_opts[] = {
 	{ "createdir", NULL, rc_set_int, &list, NULL, LIST_MESSCREATEDIR, 0, NULL, NULL },
 #endif
 	{ "listromsize", "lrs", rc_set_int, &list, NULL, LIST_ROMSIZE, 0, NULL, "Like -list, with the year and size of the roms used" },
-	{ "listpalettesize", "lps", rc_set_int, &list, NULL, LIST_ROMSIZE, 0, NULL, "Like -list, with the year and palette size of the roms used" },
+	{ "listpalettesize", "lps", rc_set_int, &list, NULL, LIST_PALETTESIZE, 0, NULL, "Like -list, with the year and palette size of the roms used" },
 	{ "listroms", "lr", rc_set_int, &list, NULL, LIST_ROMS, 0, NULL, "Like -list, but lists used ROMs" },
 	{ "listcrc", "lcrc", rc_set_int, &list, NULL, LIST_CRC, 0, NULL, "Like -list, but lists used ROMs with CRC-32s" },
 	{ "listsha1", "lsha1", rc_set_int, &list, NULL, LIST_SHA1, 0, NULL, "Like -list, but lists used ROMs with SHA-1s" },
@@ -90,9 +95,16 @@ struct rc_option frontend_list_opts[] = {
 
 int CLIB_DECL compare_names(const void *elem1, const void *elem2)
 {
+	int cmp;
 	struct GameDriver *drv1 = *(struct GameDriver **)elem1;
 	struct GameDriver *drv2 = *(struct GameDriver **)elem2;
-	return strcmp(drv1->description, drv2->description);
+	char name1[200], name2[200];
+	namecopy(name1, drv1->description, 200);
+	namecopy(name2, drv2->description, 200);
+	cmp = strcasecmp(name1, name2);
+	if (cmp == 0)
+		cmp = strcasecmp(drv1->description, drv2->description);
+	return cmp;
 }
 
 int CLIB_DECL compare_driver_names(const void *elem1, const void *elem2)
@@ -149,7 +161,27 @@ int strwildcmp(const char *sp1, const char *sp2)
 		if (s2[i] == '?' && s1[i] != '?') s2[i] = s1[i];
 	}
 
-	return stricmp(s1, s2);
+	return strcasecmp(s1, s2);
+}
+
+static void namecopy(char *name_ref, const char *desc, int buf_size)
+{
+	char name[200];
+
+	strncpy(name, desc, 199);
+	name[199] = 0;
+
+	/* remove details in parenthesis */
+	if (strstr(name, " ("))
+		*strstr(name, " (") = 0;
+
+	/* Move leading "The" to the end */
+	if (strncmp(name, "The ", 4) == 0)
+		snprintf(name_ref, buf_size, "%s, The", name + 4);
+	else if (strncmp(name, "Le ", 3) == 0)
+		snprintf(name_ref, buf_size, "%s, Le", name + 3);
+	else
+		snprintf(name_ref, buf_size, "%s", name);
 }
 
 static int myprintf(char *fmt, ...)
@@ -227,31 +259,20 @@ static int frontend_uses_roms(int driver)
 
 char *get_description(int driver)
 {
-	char *p;
-	char copy[BUF_SIZE];
 	static char description[BUF_SIZE];
 
-	strncpy(copy, drivers[driver]->description, BUF_SIZE);
-
-	/* Remove the additonal description if any */
-	if ((p = strstr(copy, " (")))
-		*p = 0;
-
-	/* Move leading "The" to the end */
-	if (strncmp(copy, "The ", 4) == 0)
-		snprintf(description, BUF_SIZE, "%s, The", copy+4);
-	else if (strncmp(copy, "Le ", 3) == 0)
-		snprintf(description, BUF_SIZE, "%s, Le", copy+3);
-	else
-		strncpy(description, copy, BUF_SIZE);
+	namecopy(description, drivers[driver]->description, BUF_SIZE);
 
 	/* Print the additional description only if we are listing clones */
-	if (listclones && p)
+	if (listclones)
 	{
+		char *pdest;
+		int result;
 		int len = strlen(description);
-
-		*p = ' ';
-		snprintf(description + len, BUF_SIZE - len, p);
+		pdest = strchr(drivers[driver]->description, '(');
+		result = pdest - drivers[driver]->description;
+		if (pdest && result > 0 )
+			snprintf(description + len, BUF_SIZE - len, " %s", strchr(drivers[driver]->description, '('));
 	}
 
 	return description;
@@ -267,21 +288,29 @@ int frontend_list(char *gamename)
 			"--------  -----------\n",
 		/* listgames        */ "year manufacturer                         name\n"
 			"---- ------------------------------------ --------------------------------\n",
-		/* listdetails      */ " romname driver     cpu 1    cpu 2    cpu 3    cpu 4    cpu 5    cpu 6    cpu 7    cpu 8    sound 1     sound 2     sound 3     sound 4     sound 5     name\n"
-			"-------- ---------- -------- -------- -------- -------- -------- -------- -------- -------- ----------- ----------- ----------- ----------- ----------- --------------------------\n",
+		/* listdetails      */ "rom name driver     cpu 1    cpu 2    cpu 3    cpu 4    cpu 5    cpu 6    cpu 7    cpu 8     sound 1     sound 2     sound 3     sound 4     sound 5      name\n"
+			"-------- ---------- -------- -------- -------- -------- -------- -------- -------- --------  ----------- ----------- ----------- ----------- ----------- --------------------------\n",
 		/* listgamelist     */ "",
-		/* listsourcefile   */ "name     sourcefile\n"
-			"-------- ----------\n",
+		/* listsourcefile   */ "name     source file\n"
+			"-------- -----------\n",
 		/* listcolors       */ "name      colors\n"
 			"--------  ------\n",
-		/* listextensions   */ "name      device      image file extensions supported\n"
-			"--------  ----------  -------------------------------\n",
+#ifdef MESS
+		/* listdevices      */ "",
+		/* listtext         */ "",
+		/* createdir        */ "",
+#endif
 		/* listromsize      */ "name    \tyear \tsize\n"
 			"--------\t-----\t----\n",
-		/* listpalettesize  */ "",
+		/* listpalettesize  */ "name    \tyear \tcolors\n"
+			"--------\t-----\t----\n",
 		/* listroms         */ "",
 		/* listcrc          */ "CRC      filename     description\n"
 			"-------- ------------ -----------\n",
+		/* listsha1         */ "SHA1                                     filename     description\n"
+			"---------------------------------------- ------------ -----------\n",
+		/* listmd5          */ "MD5                              filename     description\n"
+			"-------------------------------- ------------ -----------\n",
 		/* listsamples      */ "",
 		/* listsamdir       */ "name      samples dir\n"
 			"--------  -----------\n",
@@ -291,6 +320,9 @@ int frontend_list(char *gamename)
 		/* verifysamples    */ "",
 		/* verifysamplesets */ "name      result\n"
 			"--------  ------\n",
+		/* listclones       */ "",
+		/* listxml          */ "",
+		/* listcpu          */ "",
 		/*** internal verification list commands (developers only) ***/
 		/* listmissingroms  */ "name      clone of  description\n"
 			"--------  --------  -----------\n",
@@ -314,6 +346,7 @@ int frontend_list(char *gamename)
 	 * init first
 	 */
 	cpuintrf_init();
+	sndintrf_init();
 
 	/* sort the list if requested */
 	if (sortby)
@@ -325,9 +358,9 @@ int frontend_list(char *gamename)
 
 		/* qsort as appropriate */
 		if (sortby == 1)
-			qsort(drivers, count, sizeof(drivers[0]), compare_names);
+			qsort((void *)drivers, count, sizeof(drivers[0]), compare_names);
 		else if (sortby == 2)
-			qsort(drivers, count, sizeof(drivers[0]), compare_driver_names);
+			qsort((void *)drivers, count, sizeof(drivers[0]), compare_driver_names);
 	}
 
 	/* listcommands which require special handling */
@@ -345,18 +378,21 @@ int frontend_list(char *gamename)
 			return OSD_OK;
 		case LIST_CPU:
 			return frontend_list_cpu();
-		case LIST_CRC: /* list all crc-32 */
+		case LIST_CRC: /* list all CRC32 */
+			fprintf(stdout_file, header[list - 1]);
 			return frontend_list_hash(HASH_CRC);
-		case LIST_SHA1: /* list all sha-1 */
+		case LIST_SHA1: /* list all SHA1 */
+			fprintf(stdout_file, header[list - 1]);
 			return frontend_list_hash(HASH_SHA1);
-		case LIST_MD5: /* list all md5 */
+		case LIST_MD5: /* list all MD5 */
+			fprintf(stdout_file, header[list - 1]);
 			return frontend_list_hash(HASH_MD5);
 		case LIST_GAMELIST: /* list all of the games */
 			frontend_list_gamelistheader(); /* display the header */
 			break;
 	}
 
-	fprintf(stdout_file, header[list-1]);
+	fprintf(stdout_file, header[list - 1]);
 
 	for (i=0;drivers[i];i++)
 	{
@@ -399,23 +435,14 @@ int frontend_list(char *gamename)
 					for(j=0;j<MAX_CPU;j++)
 					{
 						const struct MachineCPU *x_cpu = drv.cpu;
-						if (x_cpu[j].cpu_flags & CPU_AUDIO_CPU)
-							fprintf(stdout_file, "[%-6s] ",cputype_name(x_cpu[j].cpu_type));
-						else
-							fprintf(stdout_file, "%-8s ",cputype_name(x_cpu[j].cpu_type));
+						fprintf(stdout_file, "%-8s ",cputype_name(x_cpu[j].cpu_type));
 					}
 					fprintf(stdout_file, " ");
 
 					for(j=0;j<MAX_SOUND;j++)
 					{
 						const struct MachineSound *x_sound = drv.sound;
-						if (sound_num(&x_sound[j]))
-						{
-							fprintf(stdout_file, "%dx",sound_num(&x_sound[j]));
-							fprintf(stdout_file, "%-9s ",sound_name(&x_sound[j]));
-						}
-						else
-							fprintf(stdout_file, "%-11s ",sound_name(&x_sound[j]));
+						fprintf(stdout_file, "%-11s ", sndtype_name(x_sound[j].sound_type));
 					}
 
 					/* Lastly, the name of the game and a \newline */
@@ -472,7 +499,7 @@ int frontend_list(char *gamename)
 #if (HAS_SAMPLES)
 								if (drv.sound[j].sound_type == SOUND_SAMPLES)
 								{
-									samplenames = ((struct Samplesinterface *)drv.sound[j].sound_interface)->samplenames;
+									samplenames = ((struct Samplesinterface *)drv.sound[j].config)->samplenames;
 									break;
 								}
 #endif
@@ -554,6 +581,7 @@ int frontend_list(char *gamename)
 					{
 						fprintf(stdout_file, "%-8s\t%-5s\t%u\n",drivers[i]->name,drivers[i]->year,drv.total_colors); 
 					}
+					break;
 
 				case LIST_ROMS: /* game roms list */
 					if(!frontend_uses_roms(i))
@@ -576,7 +604,7 @@ int frontend_list(char *gamename)
 							const char **samplenames = NULL;
 #if (HAS_SAMPLES)
 							if( drv.sound[j].sound_type == SOUND_SAMPLES )
-								samplenames = ((struct Samplesinterface *)drv.sound[j].sound_interface)->samplenames;
+								samplenames = ((struct Samplesinterface *)drv.sound[j].config)->samplenames;
 #endif                        
 							if (samplenames && samplenames[0])
 							{
@@ -617,7 +645,7 @@ int frontend_list(char *gamename)
 						{
 #if (HAS_SAMPLES)
 							if( drv.sound[j].sound_type == SOUND_SAMPLES )
-								samplenames = ((struct Samplesinterface *)drv.sound[j].sound_interface)->samplenames;
+								samplenames = ((struct Samplesinterface *)drv.sound[j].config)->samplenames;
 #endif
 						}
 
