@@ -14,7 +14,6 @@
 #import <unistd.h> 
 #import <AppKit/AppKit.h>
 
-#import "xmame.h"
 #import "osdepend.h"
 #import "driver.h"
 #import "devices.h"
@@ -48,8 +47,6 @@ struct rc_option display_opts[] = {
 	}
 };
 
-struct sysdep_display_prop_struct sysdep_display_properties = { NULL, 0 };
-
 /*
  * Size of the black border
  */
@@ -291,9 +288,6 @@ sysdep_create_display(int depth)
 	puts(Machine->gamedrv->description);
 
 	/* set up the structure for the palette code */
-	display_palette_info.writable_colors = 0;
-	display_palette_info.depth = 16;
-
 #ifdef LSB_FIRST
 	display_palette_info.red_mask = 0x00f0;
 	display_palette_info.green_mask = 0x000f;
@@ -403,31 +397,3 @@ sysdep_update_display(struct mame_bitmap *bitmap)
 	PSWait();
 #endif
 }
-
-/*
- * OpenStep system are always 16bpp capable.
- */
-
-int
-sysdep_display_16bpp_capable(void)
-{
-	return 1;
-}
-
-/*
- * The following functions are dummies - we always generate 16 bit
- * colour output on OpenStep systems.
- */
-
-int
-sysdep_display_alloc_palette(int writable_colours)
-{
-	return OSD_OK;
-}
-
-int
-sysdep_display_set_pen(int pen,
-		unsigned char r, unsigned char g, unsigned char b)
-{
-	return OSD_OK;
-}
