@@ -11,6 +11,9 @@
 #include "artwork.h"
 #include "usrintrf.h"
 #include "vidhrdw/vector.h"
+#ifdef MESS
+#include "mess/mesintrf.h"
+#endif
 
 #include "xmame.h"
 #include "devices.h"
@@ -55,6 +58,14 @@ static struct sysdep_display_open_params debug_params = {
   0, 0, 16, 0, 0, 0, NAME " debug window", 0, 1, 1, 0, 0, 0, 0.0,
   xmame_keyboard_register_event, NULL, NULL };
 
+/* Visual area override related vars, for dual monitor games hacks */
+static struct rectangle game_vis_area;
+static struct rectangle game_vis_area_override_rect[3] = {
+  {-1,-1,-1,-1},
+  {-1,-1,-1,-1},
+  {-1,-1,-1,-1} };
+double game_vis_area_override_aspect[3] = { -1.0, -1.0, -1.0 };
+int game_vis_area_override_index = 0;
 
 /* average FPS calculation */
 static cycles_t start_time = 0;
@@ -105,10 +116,13 @@ struct rc_option video_opts[] = {
    { "scale",		"s",			rc_use_function, NULL,
      NULL,		0,			0,		video_handle_scale,
      "Set X- and Y-Scale to the same factor (increase: left-shift + page-up, decrease: left-shift + page-down)" },
-   { "effect",		"ef",			rc_int,		&user_effect,
-     "0",		SYSDEP_DISPLAY_EFFECT_NONE, SYSDEP_DISPLAY_EFFECT_SCAN_V-1,	NULL,
-     "Video effect:\n"
+#ifndef DISABLE_EFFECTS
+   { "effect", "ef", rc_int, &user_effect, "0", SYSDEP_DISPLAY_EFFECT_NONE, SYSDEP_DISPLAY_EFFECT_SCAN_V - 1, NULL, "Video effect:\n"
+#else
+   { "effect", "ef", rc_int, &user_effect, "0", SYSDEP_DISPLAY_EFFECT_NONE, SYSDEP_DISPLAY_EFFECT_NONE, NULL, "Video effect:\n"
+#endif
 	     "0 = none     (default)\n"
+#ifndef DISABLE_EFFECTS
 	     "1 = scale2x  (smooth scaling effect)\n"
 	     "2 = lq2x     (low quality filter)\n"
 	     "3 = hq2x     (high quality filter)\n"
@@ -117,6 +131,7 @@ struct rc_option video_opts[] = {
 	     "6 = rgbscan  (rgb scanlines)\n"
 	     "7 = scan3    (deluxe scanlines)\n"
 	     "8 = fakescan (black scanlines)\n"
+#endif
              "(increase: left-ctrl + page-up, decrease: left-ctrl + page-down)" },
    { "autodouble",	"adb",			rc_bool,	&use_auto_double,
      "1",		0,			0,		NULL,
@@ -531,6 +546,39 @@ int osd_create_display(const struct osd_create_params *params,
 	debug_params.height     = options.debug_height;
 	debug_params.max_width  = options.debug_width;
 	debug_params.max_height = options.debug_height;
+	
+	/* apply vis area override hacks */
+      	if (!strcmp(drivers[game_index]->clone_of->name, "megatech"))
+      	{
+      	  game_vis_area_override_rect[1].min_y = 192;
+      	  game_vis_area_override_rect[2].max_x = 255;
+      	  game_vis_area_override_rect[2].max_y = 191;
+      	  game_vis_area_override_aspect[1] = (double)4.0/3.0;
+      	  game_vis_area_override_aspect[2] = (double)4.0/3.0;
+      	  game_vis_area_override_index = 1;
+      	}
+      	if (!strcmp(drivers[game_index]->clone_of->name, "playch10"))
+      	{
+      	  game_vis_area_override_rect[1].min_y = 240;
+      	  game_vis_area_override_rect[2].max_y = 239;
+      	  game_vis_area_override_aspect[1] = (double)4.0/3.0;
+      	  game_vis_area_override_aspect[2] = (double)4.0/3.0;
+      	  game_vis_area_override_index = 1;
+      	}
+      	if (!strcmp(drivers[game_index]->name, "punchout"))
+      	{
+      	  game_vis_area_override_rect[1].min_y = 224;
+      	  game_vis_area_override_rect[2].max_y = 223;
+      	  game_vis_area_override_aspect[1] = (double)4.0/3.0;
+      	  game_vis_area_override_aspect[2] = (double)4.0/3.0;
+      	}
+      	if (game_vis_area_override_rect[1].min_y != -1)
+      	{
+      	  game_vis_area_override_aspect[0] = normal_params.aspect_ratio;
+          status_msg  = "Dual monitor Game, press\nleft-ctrl+left-shift+insert\nto toggle visible monitors";
+          show_status = 5.0 * video_fps;
+          ui_show_fps_temp(5.0);
+      	}
 
 	return 0;
 }
@@ -760,6 +808,37 @@ static void update_effect(void)
   }
 }
 
+static void update_game_vis_area(void)
+{
+  if (game_vis_area_override_rect[game_vis_area_override_index].min_x != -1)
+    game_vis_area.min_x =
+      game_vis_area_override_rect[game_vis_area_override_index].min_x;
+
+  if (game_vis_area_override_rect[game_vis_area_override_index].min_y != -1)
+    game_vis_area.min_y =
+      game_vis_area_override_rect[game_vis_area_override_index].min_y;
+
+  if (game_vis_area_override_rect[game_vis_area_override_index].max_x != -1)
+    game_vis_area.max_x =
+      game_vis_area_override_rect[game_vis_area_override_index].max_x;
+
+  if (game_vis_area_override_rect[game_vis_area_override_index].max_y != -1)
+    game_vis_area.max_y =
+      game_vis_area_override_rect[game_vis_area_override_index].max_y;
+      
+  if (!(game_vis_area_override_aspect[game_vis_area_override_index] < 0.0))
+    normal_params.aspect_ratio =
+      game_vis_area_override_aspect[game_vis_area_override_index];
+
+  normal_params.width  = (game_vis_area.max_x + 1) - game_vis_area.min_x;
+  normal_params.height = (game_vis_area.max_y + 1) - game_vis_area.min_y;
+		   
+  set_ui_visarea(game_vis_area.min_x, game_vis_area.min_y,
+    game_vis_area.max_x, game_vis_area.max_y);
+
+  normal_params_changed |= VISIBLE_AREA_CHANGED;
+}
+
 static int skip_next_frame = 0;
 
 typedef int (*skip_next_frame_func)(void);
@@ -816,9 +895,9 @@ void osd_update_video_and_audio(struct mame_display *display)
 	static int palette_changed = 0;
 	
 	/*** STEP 1 update sound,fps,vis_area,palette and leds ***/
-	if (sound_stream)
+	if (sysdep_sound_stream)
 	{
-		sound_stream_update(sound_stream);
+		sysdep_sound_stream_update(sysdep_sound_stream);
 	}
 	if (display->changed_flags & GAME_REFRESH_RATE_CHANGED)
 	{
@@ -827,23 +906,8 @@ void osd_update_video_and_audio(struct mame_display *display)
 	}
 	if (display->changed_flags & GAME_VISIBLE_AREA_CHANGED)
 	{
-		set_ui_visarea(display->game_visible_area.min_x,
-				display->game_visible_area.min_y,
-				display->game_visible_area.max_x,
-				display->game_visible_area.max_y);
-
-                /* fprintf(stderr, "preresize: %dx%d\n", normal_params.width,
-                  normal_params.height); */
-
-		normal_params.width  = (display->game_visible_area.max_x + 1) -
-		   display->game_visible_area.min_x;
-		normal_params.height = (display->game_visible_area.max_y + 1) -
-		   display->game_visible_area.min_y;
-		   
-                /* fprintf(stderr, "resize: %dx%d\n", normal_params.width,
-                  normal_params.height); */
-
-		normal_params_changed |= VISIBLE_AREA_CHANGED;
+	  game_vis_area = display->game_visible_area;
+          update_game_vis_area();
 	}
 	if ((display->changed_flags & GAME_PALETTE_CHANGED))
 		palette_changed = 1;
@@ -856,7 +920,7 @@ void osd_update_video_and_audio(struct mame_display *display)
 	else if (input_ui_pressed(IPT_UI_TOGGLE_DEBUG) && mame_debug)
 		change_debugger_focus(!debugger_has_focus);
 
-	/*** STEP 3: update the focussed display ***/
+	/*** STEP 3: update the focused display ***/
 	if (debugger_has_focus)
 	{
 		if (display->changed_flags & DEBUG_BITMAP_CHANGED)
@@ -864,256 +928,276 @@ void osd_update_video_and_audio(struct mame_display *display)
 	}
 	else
 	{
-            if (code_pressed(KEYCODE_LALT) &&
-                code_pressed(KEYCODE_LCONTROL))
-            {
-                if (code_pressed_memory(KEYCODE_INSERT))
-                        flags |= SYSDEP_DISPLAY_HOTKEY_OPTION0;
-                if (code_pressed_memory(KEYCODE_HOME))
-                        flags |= SYSDEP_DISPLAY_HOTKEY_OPTION1;
-                if (code_pressed_memory(KEYCODE_PGUP))
-                        flags |= SYSDEP_DISPLAY_HOTKEY_OPTION2;
-                if (code_pressed_memory(KEYCODE_END))
-                        flags |= SYSDEP_DISPLAY_HOTKEY_OPTION3;
-                if (code_pressed_memory(KEYCODE_PGDN))
-                        flags |= SYSDEP_DISPLAY_HOTKEY_OPTION4;
-            }
-            else if (code_pressed(KEYCODE_LALT))
-            {
-                if (code_pressed_memory(KEYCODE_INSERT))
-                {
-                        normal_params.video_mode = 0;
-                        normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
-                }
-                if (code_pressed_memory(KEYCODE_HOME))
-                {
-                        normal_params.video_mode = 1;
-                        normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
-                }
-                if (code_pressed_memory(KEYCODE_PGUP))
-                {
-                        normal_params.video_mode = 2;
-                        normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
-                }
-                if (code_pressed_memory(KEYCODE_DEL))
-                {
-                        normal_params.video_mode = 3;
-                        normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
-                }
-                if (code_pressed_memory(KEYCODE_END))
-                {
-                        normal_params.video_mode = 4;
-                        normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
-                }
-                if (code_pressed_memory(KEYCODE_PGDN))
-                {
-                        normal_params.fullscreen = 1 - normal_params.fullscreen;
-                        normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
-                }
-            }
-            else if (code_pressed(KEYCODE_LCONTROL))
-            {
-                int effect_mod = 0;
-                if (code_pressed_memory(KEYCODE_INSERT))
-                        frameskipper = 0;
-                if (code_pressed_memory(KEYCODE_HOME))
-                        frameskipper = 1;
-                if (code_pressed_memory(KEYCODE_DEL))
-                        flags |= SYSDEP_DISPLAY_HOTKEY_GRABMOUSE;
-                if (code_pressed_memory(KEYCODE_END))
-                        flags |= SYSDEP_DISPLAY_HOTKEY_GRABKEYB;
-                if (code_pressed_memory(KEYCODE_PGUP))
-                        effect_mod = 1;
-                if (code_pressed_memory(KEYCODE_PGDN))
-                        effect_mod = -1;
-                if (effect_mod && (sysdep_display_properties.mode_info[
-                     normal_params.video_mode] & SYSDEP_DISPLAY_EFFECTS))
-                {
-                  int i=0, scaled_width, scaled_height;
-
-                  /* check if the effect fits the screen */
-                  do
-                  {
-                    if (!(i&1)) /* 1st try, 3rd try, etc: next effect */
-                    {
-                      /* next effect */
-                      user_effect += effect_mod;
-                      if (user_effect < 0)
-                        user_effect = SYSDEP_DISPLAY_EFFECT_SCAN_V-1;
-                      if (user_effect >= SYSDEP_DISPLAY_EFFECT_SCAN_V)
-                        user_effect = 0;
-                      
-                      update_effect();
-                    }
-                    else /* 2nd try, 4th try... same effect... */
-                    {
-                      normal_params.widthscale  = 1;
-                      normal_params.heightscale = 1;
-                      normal_params.yarbsize    = 0;
-                    }
-                    
-                    /* is this going to fit? */
-                    sysdep_display_check_effect_params(&normal_params);
-                    if (normal_params.orientation & SYSDEP_DISPLAY_SWAPXY)
-                    {
-                      scaled_width  = normal_params.height * normal_params.widthscale;
-                      scaled_height = normal_params.yarbsize? normal_params.yarbsize:
-                        normal_params.width * normal_params.heightscale;
-                    }
-                    else
-                    {
-                      scaled_width  = normal_params.width * normal_params.widthscale;
-                      scaled_height = normal_params.yarbsize? normal_params.yarbsize:
-                        normal_params.height * normal_params.heightscale;
-                    }
-                    i++;
-                  } while ((i <= (2*SYSDEP_DISPLAY_EFFECT_LAST)) &&
-                           ((scaled_width  > sysdep_display_properties.max_width ) ||
-                            (scaled_height > sysdep_display_properties.max_height)));
-
-                  normal_params_changed |= EFFECT_CHANGED;
-                }
-            }
-            else if (code_pressed(KEYCODE_LSHIFT))
-            {
-                int widthscale_mod  = 0;
-                int heightscale_mod = 0;
-                int scale_mod = 0;
-
-                if (code_pressed_memory(KEYCODE_INSERT))
-                        widthscale_mod = 1;
-                if (code_pressed_memory(KEYCODE_DEL))
-                        widthscale_mod = -1;
-                if (code_pressed_memory(KEYCODE_HOME))
-                        heightscale_mod = 1;
-                if (code_pressed_memory(KEYCODE_END))
-                        heightscale_mod = -1;
-                if (code_pressed_memory(KEYCODE_PGUP))
-                        scale_mod = 1;
-                if (code_pressed_memory(KEYCODE_PGDN))
-                        scale_mod = -1;
-                if (scale_mod)
-                {
-                  if (normal_params.widthscale == normal_params.heightscale)
-                  {
-                        normal_params.widthscale  += scale_mod;
-                        normal_params.heightscale += scale_mod;
-                  }
-                  else if (normal_params.widthscale == 
-                           (2*normal_params.heightscale))
-                  {
-                        normal_params.widthscale  += 2*scale_mod;
-                        normal_params.heightscale += scale_mod;
-                  }
-                  else if (normal_params.heightscale == 
-                           (2*normal_params.widthscale))
-                  {
-                        normal_params.widthscale  += scale_mod;
-                        normal_params.heightscale += 2*scale_mod;
-                  }
-                  else
-                  {
-                        normal_params.widthscale  += scale_mod *
-                          normal_params.widthscale;
-                        normal_params.heightscale += scale_mod *
-                          normal_params.heightscale;
-                  }
-                  normal_params_changed |= X_SCALING_CHANGED|Y_SCALING_CHANGED;
-                  sysdep_display_check_effect_params(&normal_params);
-                }
-                if (widthscale_mod)
-                {
-                  normal_params.widthscale += widthscale_mod;
-                  normal_params_changed |= X_SCALING_CHANGED;
-                  sysdep_display_check_effect_params(&normal_params);
-                }
-                if (heightscale_mod)
-                {
-                  normal_params.heightscale += heightscale_mod;
-                  normal_params.yarbsize = 0;
-                  normal_params_changed |= Y_SCALING_CHANGED;
-                  sysdep_display_check_effect_params(&normal_params);
-                }
-            }
-
-            /* determine non hotkey flags */
-	    if (ui_dirty)
-		flags |= SYSDEP_DISPLAY_UI_DIRTY;
-            
-            if (display->changed_flags & GAME_BITMAP_CHANGED)
-            {
-		/* at the end, we need the current time */
-		curr = osd_cycles();
-
-		/* update stats for the FPS average calculation */
-		if (start_time == 0)
+#ifdef MESS
+		if (((Machine->gamedrv->flags & GAME_COMPUTER) == 0) || mess_ui_active())
+#endif
 		{
-			/* start the timer going 1 second into the game */
-			if (timer_get_time() > 1.0)
-				start_time = curr;
-		}
-		else
-		{
-			frames_displayed++;
-			if (frames_displayed + 1 == frames_to_display)
+			if (code_pressed(KEYCODE_LALT) &&
+					code_pressed(KEYCODE_LCONTROL))
 			{
-				char name[20];
-				mame_file *fp;
+				if (code_pressed_memory(KEYCODE_INSERT))
+					flags |= SYSDEP_DISPLAY_HOTKEY_OPTION0;
+				if (code_pressed_memory(KEYCODE_HOME))
+					flags |= SYSDEP_DISPLAY_HOTKEY_OPTION1;
+				if (code_pressed_memory(KEYCODE_PGUP))
+					flags |= SYSDEP_DISPLAY_HOTKEY_OPTION2;
+				if (code_pressed_memory(KEYCODE_END))
+					flags |= SYSDEP_DISPLAY_HOTKEY_OPTION3;
+				if (code_pressed_memory(KEYCODE_PGDN))
+					flags |= SYSDEP_DISPLAY_HOTKEY_OPTION4;
+			}
+			else if (code_pressed(KEYCODE_LSHIFT) &&
+					code_pressed(KEYCODE_LCONTROL))
+			{
+				if (code_pressed_memory(KEYCODE_INSERT))
+				{
+					game_vis_area_override_index++;
+					if(game_vis_area_override_index>2)
+						game_vis_area_override_index = 0;
+					game_vis_area = display->game_visible_area;
+					update_game_vis_area();
+				}
+			}
+			else if (code_pressed(KEYCODE_LALT))
+			{
+				if (code_pressed_memory(KEYCODE_INSERT))
+				{
+					normal_params.video_mode = 0;
+					normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
+				}
+				if (code_pressed_memory(KEYCODE_HOME))
+				{
+					normal_params.video_mode = 1;
+					normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
+				}
+				if (code_pressed_memory(KEYCODE_PGUP))
+				{
+					normal_params.video_mode = 2;
+					normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
+				}
+				if (code_pressed_memory(KEYCODE_DEL))
+				{
+					normal_params.video_mode = 3;
+					normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
+				}
+				if (code_pressed_memory(KEYCODE_END))
+				{
+					normal_params.video_mode = 4;
+					normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
+				}
+				if (code_pressed_memory(KEYCODE_PGDN))
+				{
+					normal_params.fullscreen = 1 - normal_params.fullscreen;
+					normal_params_changed |= VIDMODE_FULLSCREEN_CHANGED;
+				}
+			}
+			else if (code_pressed(KEYCODE_LCONTROL))
+			{
+				int effect_mod = 0;
+				if (code_pressed_memory(KEYCODE_INSERT))
+					frameskipper = 0;
+				if (code_pressed_memory(KEYCODE_HOME))
+					frameskipper = 1;
+				if (code_pressed_memory(KEYCODE_DEL))
+					flags |= SYSDEP_DISPLAY_HOTKEY_GRABMOUSE;
+				if (code_pressed_memory(KEYCODE_END))
+					flags |= SYSDEP_DISPLAY_HOTKEY_GRABKEYB;
+#ifndef DISABLE_EFFECTS
+				if (code_pressed_memory(KEYCODE_PGUP))
+					effect_mod = 1;
+				if (code_pressed_memory(KEYCODE_PGDN))
+					effect_mod = -1;
+#endif
+				if (effect_mod && (sysdep_display_properties.mode_info[
+							normal_params.video_mode] & SYSDEP_DISPLAY_EFFECTS))
+				{
+					int i=0, scaled_width, scaled_height;
 
-				/* make a filename with an underscore prefix */
-				sprintf(name, "_%.8s", Machine->gamedrv->name);
+					/* check if the effect fits the screen */
+					do
+					{
+						if (!(i&1)) /* 1st try, 3rd try, etc: next effect */
+						{
+							/* next effect */
+							user_effect += effect_mod;
+							if (user_effect < 0)
+								user_effect = SYSDEP_DISPLAY_EFFECT_SCAN_V-1;
+							if (user_effect >= SYSDEP_DISPLAY_EFFECT_SCAN_V)
+								user_effect = 0;
 
-				/* write out the screenshot */
-				if ((fp = mame_fopen(Machine->gamedrv->name, name, FILETYPE_SCREENSHOT, 1)) != NULL)
+							update_effect();
+						}
+						else /* 2nd try, 4th try... same effect... */
+						{
+							normal_params.widthscale  = 1;
+							normal_params.heightscale = 1;
+							normal_params.yarbsize    = 0;
+						}
+
+						/* is this going to fit? */
+						sysdep_display_check_effect_params(&normal_params);
+						if (normal_params.orientation & SYSDEP_DISPLAY_SWAPXY)
+						{
+							scaled_width  = normal_params.height * normal_params.widthscale;
+							scaled_height = normal_params.yarbsize? normal_params.yarbsize:
+								normal_params.width * normal_params.heightscale;
+						}
+						else
+						{
+							scaled_width  = normal_params.width * normal_params.widthscale;
+							scaled_height = normal_params.yarbsize? normal_params.yarbsize:
+								normal_params.height * normal_params.heightscale;
+						}
+						i++;
+					} while ((i <= (2*SYSDEP_DISPLAY_EFFECT_LAST)) &&
+							((scaled_width  > sysdep_display_properties.max_width ) ||
+							 (scaled_height > sysdep_display_properties.max_height)));
+
+					normal_params_changed |= EFFECT_CHANGED;
+				}
+			}
+			else if (code_pressed(KEYCODE_LSHIFT))
+			{
+				int widthscale_mod  = 0;
+				int heightscale_mod = 0;
+				int scale_mod = 0;
+
+				if (code_pressed_memory(KEYCODE_INSERT))
+					widthscale_mod = 1;
+				if (code_pressed_memory(KEYCODE_DEL))
+					widthscale_mod = -1;
+				if (code_pressed_memory(KEYCODE_HOME))
+					heightscale_mod = 1;
+				if (code_pressed_memory(KEYCODE_END))
+					heightscale_mod = -1;
+				if (code_pressed_memory(KEYCODE_PGUP))
+					scale_mod = 1;
+				if (code_pressed_memory(KEYCODE_PGDN))
+					scale_mod = -1;
+				if (scale_mod)
+				{
+					if (normal_params.widthscale == normal_params.heightscale)
+					{
+						normal_params.widthscale  += scale_mod;
+						normal_params.heightscale += scale_mod;
+					}
+					else if (normal_params.widthscale == 
+							(2*normal_params.heightscale))
+					{
+						normal_params.widthscale  += 2*scale_mod;
+						normal_params.heightscale += scale_mod;
+					}
+					else if (normal_params.heightscale == 
+							(2*normal_params.widthscale))
+					{
+						normal_params.widthscale  += scale_mod;
+						normal_params.heightscale += 2*scale_mod;
+					}
+					else
+					{
+						normal_params.widthscale  += scale_mod *
+							normal_params.widthscale;
+						normal_params.heightscale += scale_mod *
+							normal_params.heightscale;
+					}
+					normal_params_changed |= X_SCALING_CHANGED|Y_SCALING_CHANGED;
+					sysdep_display_check_effect_params(&normal_params);
+				}
+				if (widthscale_mod)
+				{
+					normal_params.widthscale += widthscale_mod;
+					normal_params_changed |= X_SCALING_CHANGED;
+					sysdep_display_check_effect_params(&normal_params);
+				}
+				if (heightscale_mod)
 				{
-					save_screen_snapshot_as(fp, artwork_get_ui_bitmap());
-					mame_fclose(fp);
+					normal_params.heightscale += heightscale_mod;
+					normal_params.yarbsize = 0;
+					normal_params_changed |= Y_SCALING_CHANGED;
+					sysdep_display_check_effect_params(&normal_params);
 				}
-				trying_to_quit = 1;
 			}
-			end_time = curr;
 		}
-		
-		if (normal_params_changed)
-		        update_params();
-		
-		if (!normal_palette)
+
+		/* determine non hotkey flags */
+		if (ui_dirty)
+			flags |= SYSDEP_DISPLAY_UI_DIRTY;
+
+		if (display->changed_flags & GAME_BITMAP_CHANGED)
 		{
-			/* the palette had been destroyed because of display changes */
-			normal_palette = sysdep_palette_create(&sysdep_display_properties.palette_info, normal_params.depth);
+			struct rectangle vis_area = game_vis_area;
+
+			/* at the end, we need the current time */
+			curr = osd_cycles();
+
+			/* update stats for the FPS average calculation */
+			if (start_time == 0)
+			{
+				/* start the timer going 1 second into the game */
+				if (timer_get_time() > 1.0)
+					start_time = curr;
+			}
+			else
+			{
+				frames_displayed++;
+				if (frames_displayed + 1 == frames_to_display)
+				{
+					char name[20];
+					mame_file *fp;
+
+					/* make a filename with an underscore prefix */
+					sprintf(name, "_%.8s", Machine->gamedrv->name);
+
+					/* write out the screenshot */
+					if ((fp = mame_fopen(Machine->gamedrv->name, name, FILETYPE_SCREENSHOT, 1)) != NULL)
+					{
+						save_screen_snapshot_as(fp, artwork_get_ui_bitmap());
+						mame_fclose(fp);
+					}
+					trying_to_quit = 1;
+				}
+				end_time = curr;
+			}
+
+			if (normal_params_changed)
+				update_params();
+
 			if (!normal_palette)
 			{
-				/* oops this sorta sucks */
-				fprintf(stderr_file, "Argh, creating the palette failed (out of memory?) aborting\n");
-				sysdep_display_close();
-				sysdep_display_exit();
-				exit(1);
+				/* the palette had been destroyed because of display changes */
+				normal_palette = sysdep_palette_create(&sysdep_display_properties.palette_info, normal_params.depth);
+				if (!normal_palette)
+				{
+					/* oops this sorta sucks */
+					fprintf(stderr_file, "Argh, creating the palette failed (out of memory?) aborting\n");
+					sysdep_display_close();
+					sysdep_display_exit();
+					exit(1);
+				}
+				update_palette(display, 1);
+				palette_changed = 0;
 			}
-			update_palette(display, 1);
-			palette_changed = 0;
-		}
-		
-		if (palette_changed)
-		{
-			update_palette(display, 0);
-			palette_changed = 0;
-		}
 
-		profiler_mark(PROFILER_BLIT);
-		/* udpate and check if the display properties were changed */
-		msg = sysdep_display_update(display->game_bitmap,
-		   &(display->game_visible_area),
-		   &(display->game_bitmap_update),
-		   normal_palette, display->led_state, flags);
-		profiler_mark(PROFILER_END);
-		if (msg)
-		{
-		  status_msg  = msg;
-		  show_status = 2.0 * display->game_refresh_rate;
-		  ui_show_fps_temp(2.0);
+			if (palette_changed)
+			{
+				update_palette(display, 0);
+				palette_changed = 0;
+			}
+
+			profiler_mark(PROFILER_BLIT);
+			/* update and check if the display properties were changed */
+			msg = sysdep_display_update(display->game_bitmap,
+					&vis_area, &(display->game_bitmap_update),
+					normal_palette, display->led_state, flags);
+			profiler_mark(PROFILER_END);
+			if (msg)
+			{
+				status_msg  = msg;
+				show_status = 2.0 * display->game_refresh_rate;
+				ui_show_fps_temp(2.0);
+			}
+			flags = 0;
 		}
-		flags = 0;
-            }
 	}
 
 	/*** STEP 4: handle frameskip ***/
@@ -1312,7 +1396,7 @@ const char *osd_get_fps_text(const struct performance_info *performance)
 	  bufsize -= i;
         }
 
-	/* for hotkey choisen effect or scale add effect or scale */
+	/* for hotkey chosen effect or scale add effect or scale */
 	if (show_effect_or_scale)
 	{
           show_effect_or_scale--;
