@@ -15,13 +15,14 @@ extern custom_regs_def custom_regs;
 #define DT_COLOR_WHITE 0;
 
 struct update_regs_def {
-/* display window */	
+/* display window */
 	int v_start;
 	int v_stop;
 	int h_start;
 	int h_stop;
 	int old_DIWSTRT;
 	int old_DIWSTOP;
+	int h_scroll[2];
 /* display data fetch */
 	int ddf_start_pixel;
 	int ddf_word_count;
@@ -32,6 +33,7 @@ struct update_regs_def {
 	int sprite_h_start[8];
 	int sprite_attached[8];
 	int sprite_dma_enabled;
+	UINT16 sprite_data[8][2];
 /* update time variables */
 	int	current_bit;
 	int fetch_pending;
@@ -41,6 +43,8 @@ struct update_regs_def {
 	unsigned char *RAM;
 	unsigned int *sprite_in_scanline;
 	int once_per_frame; /* for unimplemented modes */
+/* HAM mode */
+	UINT16 last_ham_pixel_color;
 };
 
 static struct update_regs_def update_regs;
@@ -48,7 +52,7 @@ static struct update_regs_def update_regs;
 
 /***************************************************************************
 
-	Copper emulation
+    Copper emulation
 
 ***************************************************************************/
 
@@ -87,11 +91,11 @@ INLINE int copper_update( int x_pos, int y_pos, int *end_x ) {
 
 	/*********************************************************************************
 
-		The Copper can only read the lower 8 bits of the vertical counter. To access
-		the next 6 lines, you need to wait for line 255, and then you can check from
-		lines 0 to 6 (corresponding to 256 to 261) to do things before it wraps again.
+        The Copper can only read the lower 8 bits of the vertical counter. To access
+        the next 6 lines, you need to wait for line 255, and then you can check from
+        lines 0 to 6 (corresponding to 256 to 261) to do things before it wraps again.
 
-	 ********************************************************************************/
+     ********************************************************************************/
 
 	y_pos &= 0xff;
 
@@ -143,7 +147,7 @@ INLINE int copper_update( int x_pos, int y_pos, int *end_x ) {
 
 			if ( inst >= min )	/* If not invalid, go at it */
 				/* KT - I've no idea what the memory mask should be so
-				added -1 for now! */
+                added -1 for now! */
 			    amiga_custom_w( inst>>1, param , 0 /*???*/);
 			else {
 				/* stop the copper until the next frame */
@@ -221,56 +225,48 @@ INLINE int copper_update( int x_pos, int y_pos, int *end_x ) {
 
 /***************************************************************************
 
-	Sprites emulation
+    Sprites emulation
 
 ***************************************************************************/
 
 void amiga_sprite_set_pos( int spritenum, unsigned short data ) {
-	
+
 	update_regs.sprite_v_start[spritenum] &= 0x100;
 	update_regs.sprite_v_start[spritenum] |= data >> 8;
-	
+
 	update_regs.sprite_h_start[spritenum] &= 0x01;
 	update_regs.sprite_h_start[spritenum] |= ( data << 1 ) & 0x1fe;
 
 }
 
 void amiga_sprite_set_ctrl( int spritenum, unsigned short data ) {
-	int i;
-	
+
 	update_regs.sprite_h_start[spritenum] &= 0x1fe;
 	update_regs.sprite_h_start[spritenum] |= data & 1;
-	
+
 	update_regs.sprite_v_start[spritenum] &= 0xff;
 	update_regs.sprite_v_start[spritenum] |= ( data << 6 ) & 0x100;
-	
+
 	update_regs.sprite_v_stop[spritenum] = ( data << 7 ) & 0x100;
 	update_regs.sprite_v_stop[spritenum] |= data >> 8;
 
 	if ( spritenum & 1 )
 		update_regs.sprite_attached[spritenum] = data & 0x80;
-	
+
 	/* safety */
 	if ( update_regs.sprite_v_start[spritenum] > update_regs.sprite_v_stop[spritenum] )
 		update_regs.sprite_v_stop[spritenum] = update_regs.sprite_v_start[spritenum];
-	
-	for( i = update_regs.sprite_v_start[spritenum]; i < update_regs.sprite_v_stop[spritenum]; i++ ) {
-		if ( i < Machine->drv->screen_height ) {
-			if ( update_regs.sprite_in_scanline[i] < ( update_regs.sprite_h_start[spritenum] + 16 ) )
-				 update_regs.sprite_in_scanline[i] = ( update_regs.sprite_h_start[spritenum] + 16 );
-		}
-	}			
-}	
+
+}
 
 void amiga_reload_sprite_info( int spritenum ) {
 
 	unsigned char *RAM = memory_region(REGION_CPU1);
-	
+
 	amiga_sprite_set_pos( spritenum, *((data16_t *) &RAM[custom_regs.SPRxPT[spritenum]] ) );
 
 	amiga_sprite_set_ctrl( spritenum, *((data16_t *) &RAM[custom_regs.SPRxPT[spritenum] + 2] ) );
 
-	custom_regs.SPRxPT[spritenum] += 4;
 }
 
 INLINE void amiga_render_sprite( int num, int x, int y, unsigned short *dst ) {
@@ -284,22 +280,17 @@ INLINE void amiga_render_sprite( int num, int x, int y, unsigned short *dst ) {
 		if ( x < update_regs.sprite_h_start[num] || x > update_regs.sprite_h_start[num] + 15 )
 			return;
 
-		if ( y >= update_regs.sprite_v_stop[num] ) {
-			amiga_reload_sprite_info( num );
-			return;
-		}
-
 		bit = 15 - ( x - update_regs.sprite_h_start[num] );
 
 		/* check for attached sprites */
-		if ( num < 6 && update_regs.sprite_attached[num+1] ) {
+		if ( num < 7 && update_regs.sprite_attached[num+1] ) {
 			unsigned short word[4];
 			int color, i;
 
-			word[0] = *((data16_t *) &update_regs.RAM[custom_regs.SPRxPT[num]] );
-			word[1] = *((data16_t *) &update_regs.RAM[custom_regs.SPRxPT[num]+2] );
-			word[2] = *((data16_t *) &update_regs.RAM[custom_regs.SPRxPT[num+1]] );
-			word[3] = *((data16_t *) &update_regs.RAM[custom_regs.SPRxPT[num+2]+2] );
+			word[0] = update_regs.sprite_data[num][0];
+			word[1] = update_regs.sprite_data[num][1];
+			word[2] = update_regs.sprite_data[num+1][0];
+			word[3] = update_regs.sprite_data[num+1][1];
 
 			color = 0;
 
@@ -309,37 +300,69 @@ INLINE void amiga_render_sprite( int num, int x, int y, unsigned short *dst ) {
 			if ( color )
 				dst[x] = Machine->pens[custom_regs.COLOR[color+16]];
 		} else {
-			unsigned short word[2];
-			int color, i;
+			if ( !update_regs.sprite_attached[num] ) {
+				unsigned short word[2];
+				int color, i;
 
-			word[0] = *((data16_t *) &update_regs.RAM[custom_regs.SPRxPT[num]] );
-			word[1] = *((data16_t *) &update_regs.RAM[custom_regs.SPRxPT[num]+2] );
+				word[0] = update_regs.sprite_data[num][0];
+				word[1] = update_regs.sprite_data[num][1];
 
-			color = 0;
+				color = 0;
 
-			for( i = 0; i < 2; i++ )
-				color |= ( ( word[i] >> bit ) & 1 ) << i;
+				for( i = 0; i < 2; i++ )
+					color |= ( ( word[i] >> bit ) & 1 ) << i;
 
-			if ( color ) {
-				color += 16 + ( ( num >> 1 ) << 2 );
-				dst[x] = Machine->pens[custom_regs.COLOR[color]];
+				if ( color ) {
+					color += 16 + ( ( num >> 1 ) << 2 );
+					dst[x] = Machine->pens[custom_regs.COLOR[color]];
+				}
 			}
 		}
 
-		if ( bit == 0 )
-			custom_regs.SPRxPT[num] += 4;
+	}
+}
+
+void amiga_sprite_dma( int scanline )
+{
+	int num;
+	UINT16 dataA, dataB;
+
+	if ( ( custom_regs.DMACON & ( DMACON_SPREN | DMACON_DMAEN ) ) == ( DMACON_SPREN | DMACON_DMAEN ) )
+	{
+		for ( num = 0; num < 8; num++ )
+		{
+			if ( scanline >= update_regs.sprite_v_start[num] && scanline <= update_regs.sprite_v_stop[num] )
+			{
+				custom_regs.SPRxPT[num] += 4;
+				dataA = *((UINT16 *) &update_regs.RAM[custom_regs.SPRxPT[num]] );
+				dataB = *((UINT16 *) &update_regs.RAM[custom_regs.SPRxPT[num]+2] );
+
+				if ( scanline >= update_regs.sprite_v_stop[num] )
+				{
+					amiga_sprite_set_pos( num, dataA );
+					amiga_sprite_set_ctrl( num, dataB );
+					update_regs.sprite_in_scanline[scanline] = 0;
+				}
+				else
+				{
+					update_regs.sprite_data[num][0] = dataA;
+					update_regs.sprite_data[num][1] = dataB;
+					update_regs.sprite_in_scanline[scanline] = update_regs.sprite_h_start[num] + 16;
+				}
+			}
+		}
 	}
 }
 
 /***************************************************************************
 
-	Raster emulation
+    Raster emulation
 
 ***************************************************************************/
 
 INLINE void amiga_display_msg (struct mame_bitmap *bitmap, const char *str ) {
 	static struct DisplayText dt[2];
-	
+
 	if ( update_regs.once_per_frame == 0 ) {
 		dt[0].text = str;
 		dt[0].color = DT_COLOR_WHITE;
@@ -354,7 +377,7 @@ INLINE void amiga_display_msg (struct mame_bitmap *bitmap, const char *str ) {
 
 INLINE void update_modulos ( int planes ) {
 	int i;
-		
+
 	for ( i = 0; i < planes; i++ )
 		if ( i & 1 )
 			custom_regs.BPLPTR[i] += custom_regs.BPL2MOD;
@@ -371,8 +394,8 @@ INLINE void init_update_regs( void ) {
 		update_regs.h_start	= custom_regs.DIWSTRT & 0xff;
 		update_regs.old_DIWSTRT = custom_regs.DIWSTRT;
 	}
-	
-	if ( update_regs.old_DIWSTOP != custom_regs.DIWSTOP ) {	
+
+	if ( update_regs.old_DIWSTOP != custom_regs.DIWSTOP ) {
 		/* display window */
 		update_regs.v_stop = ( custom_regs.DIWSTOP >> 8 ) & 0xff;
 		update_regs.v_stop |= ( ( update_regs.v_stop << 1 ) ^ 0x0100 ) & 0x0100; /* bit 8 = !bit 7 */
@@ -385,7 +408,7 @@ INLINE void init_update_regs( void ) {
 		update_regs.fetch_count = 0;
 		update_regs.old_DDFSTRT = custom_regs.DDFSTRT;
 	}
-		
+
 	/* display data fetch */
 	if ( custom_regs.BPLCON0 & BPLCON0_HIRES ) {
 		ddf_color_clocks_offs = 9; /* 4.5 color clocks * 2 in hi res */
@@ -394,7 +417,7 @@ INLINE void init_update_regs( void ) {
 		ddf_color_clocks_offs = 17; /* 8.5 color clocks * 2 in lo res */
 		ddf_res_offs = 3;
 	}
-	
+
 	update_regs.ddf_start_pixel = ( custom_regs.DDFSTRT << 1 ) + ddf_color_clocks_offs;
 	update_regs.ddf_word_count = ( -( custom_regs.DDFSTRT - custom_regs.DDFSTOP - 12 ) ) >> ddf_res_offs;
 
@@ -402,27 +425,27 @@ INLINE void init_update_regs( void ) {
 		update_regs.back_color = Machine->pens[custom_regs.COLOR[0]];
 		update_regs.old_COLOR0 = custom_regs.COLOR[0];
 	}
-	
+
 	update_regs.sprite_dma_enabled = ( custom_regs.DMACON & ( DMACON_SPREN | DMACON_DMAEN ) ) == ( DMACON_SPREN | DMACON_DMAEN );
-}	
+	update_regs.h_scroll[0] = custom_regs.BPLCON1 & 0xf;
+	update_regs.h_scroll[1] = (custom_regs.BPLCON1 >> 4) & 0xf;
+}
 
 /***********************************************************************************
 
-	Common update stuff coming. (aka abusing the preprocessor)
-	
+    Common update stuff coming. (aka abusing the preprocessor)
+
 ***********************************************************************************/
 #define BEGIN_UPDATE( name ) \
 static void name(struct mame_bitmap *bitmap, unsigned short *dst, int planes, int x, int y, int min_x ) { \
 	int i; \
 	if ( x < update_regs.ddf_start_pixel ) { /* see if we need to start fetching */ \
-		dst[x] = update_regs.back_color; /* fill the pixel with color 0 */ \
 		return; \
 	} else { \
 		/* Now we have to figure out if we need to fetch another 16 bit word */ \
 		if ( update_regs.fetch_pending ) { \
 			/* see if we are past DDFSTOP */ \
 			if ( ++update_regs.fetch_count > update_regs.ddf_word_count ) { \
-				dst[x] = update_regs.back_color; /* fill the pixel with color 0 */ \
 				return; \
 			} \
 			/* fetch the new word from the bitplane pointers, and update them */ \
@@ -433,11 +456,11 @@ static void name(struct mame_bitmap *bitmap, unsigned short *dst, int planes, in
 			update_regs.current_bit = 15; \
 			update_regs.fetch_pending = 0; \
 		} \
+		x += update_regs.h_scroll[0]; \
 		if ( x >= min_x ) { \
 			/* before rendering the pixel, see if we still are within display window bounds */ \
-			if ( x > update_regs.h_stop || x < update_regs.h_start ) { \
-				dst[x] = update_regs.back_color; \
-			} else {
+			if ( x >= update_regs.h_start && x <= update_regs.h_stop ) { \
+
 
 #if 0 /* this is a small kludge for the Mac source code editor */
 } } } }
@@ -447,7 +470,6 @@ static void name(struct mame_bitmap *bitmap, unsigned short *dst, int planes, in
 static void name(struct mame_bitmap *bitmap, unsigned short *dst, int planes, int x, int y, int min_x ) { \
 	int i; \
 	if ( x < update_regs.ddf_start_pixel ) { /* see if we need to start fetching */ \
-		dst[x] = update_regs.back_color; /* fill the pixel with color 0 */ \
 		if ( x < update_regs.h_stop ) { \
 			for ( i = 0; i < 8; i++ ) \
 				amiga_render_sprite( i, x, y, dst ); \
@@ -458,7 +480,6 @@ static void name(struct mame_bitmap *bitmap, unsigned short *dst, int planes, in
 		if ( update_regs.fetch_pending ) { \
 			/* see if we are past DDFSTOP */ \
 			if ( ++update_regs.fetch_count > update_regs.ddf_word_count ) { \
-				dst[x] = update_regs.back_color; /* fill the pixel with color 0 */ \
 				if ( x < update_regs.h_stop ) { \
 					for ( i = 0; i < 8; i++ ) \
 						amiga_render_sprite( i, x, y, dst ); \
@@ -473,11 +494,10 @@ static void name(struct mame_bitmap *bitmap, unsigned short *dst, int planes, in
 			update_regs.current_bit = 15; \
 			update_regs.fetch_pending = 0; \
 		} \
+		x += update_regs.h_scroll[0]; \
 		if ( x >= min_x ) { \
 			/* before rendering the pixel, see if we still are within display window bounds */ \
-			if ( x > update_regs.h_stop || x < update_regs.h_start ) { \
-				dst[x] = update_regs.back_color; \
-			} else {
+			if ( x >= update_regs.h_start && x <= update_regs.h_stop ) { \
 
 #define END_UPDATE( curbit ) \
 			} \
@@ -489,22 +509,36 @@ static void name(struct mame_bitmap *bitmap, unsigned short *dst, int planes, in
 	} \
 }
 
+#define END_UPDATE_WITH_SPRITES( curbit ) \
+			} \
+		} \
+		x -= update_regs.h_scroll[0]; \
+		if ( x >= min_x ) \
+			for ( i = 0; i < 8; i++ ) \
+				amiga_render_sprite(i, x, y, dst); \
+		update_regs.current_bit -= curbit; \
+		/* see if we're done with this word */ \
+		if ( update_regs.current_bit < 0 ) \
+			update_regs.fetch_pending = 1; /* signal we need a new fetch */ \
+	} \
+}
+
 #define UNIMPLEMENTED( name ) \
 	static void name(struct mame_bitmap *bitmap, unsigned short *dst, int planes, int x, int y, int min_x ) { \
-		amiga_display_msg(bitmap,  "Unimplemented screen mode: ##name## " ); \
+		amiga_display_msg(bitmap,  "Unimplemented screen mode: "#name ); \
 	}
 
 
 /***********************************************************************************
 
-	Low Resolution handlers
-	
+    Low Resolution handlers
+
 ***********************************************************************************/
 
 BEGIN_UPDATE( render_pixel_lores ) {
 	/* now we're ready to render it */
 	int color = 0;
-	
+
 	for ( i = 0; i < planes; i++ ) {
 		color |= ( ( ( custom_regs.BPLxDAT[i] ) >> update_regs.current_bit ) & 1 ) << i;
 	}
@@ -523,23 +557,21 @@ BEGIN_UPDATE_WITH_SPRITES( render_pixel_lores_sprites ) {
 
 	dst[x] = Machine->pens[custom_regs.COLOR[color]];
 
-	for ( i = 0; i < 8; i++ )
-		amiga_render_sprite( i, x, y, dst );
-} END_UPDATE( 1 )
+} END_UPDATE_WITH_SPRITES( 1 )
 
 UNIMPLEMENTED( render_pixel_lores_lace )
 UNIMPLEMENTED( render_pixel_lores_lace_sprites )
 
 /***********************************************************************************
 
-	High Resolution handlers
-	
+    High Resolution handlers
+
 ***********************************************************************************/
 
 BEGIN_UPDATE( render_pixel_hires ) {
 	/* now we're ready to render it */
 	int color = 0;
-	
+
 	for ( i = 0; i < planes; i++ ) {
 		color |= ( ( ( custom_regs.BPLxDAT[i] ) >> update_regs.current_bit ) & 1 ) << i;
 	}
@@ -551,24 +583,22 @@ BEGIN_UPDATE( render_pixel_hires ) {
 BEGIN_UPDATE_WITH_SPRITES( render_pixel_hires_sprites ) {
 	/* now we're ready to render it */
 	int color = 0;
-	
+
 	for ( i = 0; i < planes; i++ ) {
 		color |= ( ( ( custom_regs.BPLxDAT[i] ) >> update_regs.current_bit ) & 1 ) << i;
 	}
 
 	dst[x] = Machine->pens[custom_regs.COLOR[color]];
 
-	for ( i = 0; i < 8; i++ )
-		amiga_render_sprite( i, x, y, dst );
-} END_UPDATE( 2 )
+} END_UPDATE_WITH_SPRITES( 2 )
 
 UNIMPLEMENTED( render_pixel_hires_lace )
 UNIMPLEMENTED( render_pixel_hires_lace_sprites )
 
 /***********************************************************************************
 
-	Dual Playfield handlers
-	
+    Dual Playfield handlers
+
 ***********************************************************************************/
 
 BEGIN_UPDATE( render_pixel_dualplayfield_lores ) {
@@ -583,12 +613,12 @@ BEGIN_UPDATE( render_pixel_dualplayfield_lores ) {
 			color[0] |= ( ( ( custom_regs.BPLxDAT[i] ) >> update_regs.current_bit ) & 1 ) << ( i >> 1 );
 		}
 	}
-	
+
 	if ( color[0] || color[1] ) { /* if theres a pixel to draw */
 		if ( custom_regs.BPLCON2 & 0x40 ) { /* check wich playfield has priority */
 			if ( color[1] )
 				dst[x] = Machine->pens[custom_regs.COLOR[color[1]+8]];
-			else			
+			else
 				dst[x] = Machine->pens[custom_regs.COLOR[color[0]]];
 		} else {
 			if ( color[0] )
@@ -610,11 +640,38 @@ UNIMPLEMENTED( render_pixel_dualplayfield_hires_lace_sprites )
 
 /***********************************************************************************
 
-	HAM handlers
-	
+    HAM handlers
+
 ***********************************************************************************/
 
-UNIMPLEMENTED( render_pixel_ham )
+BEGIN_UPDATE( render_pixel_ham ) {
+	/* now we're ready to render it */
+	int color = 0;
+
+	for ( i = 0; i < planes; i++ ) {
+		color |= ( ( ( custom_regs.BPLxDAT[i] ) >> update_regs.current_bit ) & 1 ) << i;
+	}
+
+	switch( (color >> 4) & 0x3 )
+	{
+		case 0x0:
+			update_regs.last_ham_pixel_color = custom_regs.COLOR[color];
+			break;
+		case 0x1:
+			update_regs.last_ham_pixel_color = (update_regs.last_ham_pixel_color & 0x0ff0) | (color & 0xf);
+			break;
+		case 0x2:
+			update_regs.last_ham_pixel_color = (update_regs.last_ham_pixel_color & 0xf0ff) | ((color & 0xf) << 8);
+			break;
+		case 0x3:
+			update_regs.last_ham_pixel_color = (update_regs.last_ham_pixel_color & 0xff0f) | ((color & 0xf) << 4);
+			break;
+	}
+
+	dst[x] = Machine->pens[update_regs.last_ham_pixel_color];
+
+} END_UPDATE(1)
+
 UNIMPLEMENTED( render_pixel_ham_lace )
 UNIMPLEMENTED( render_pixel_ham_sprites )
 UNIMPLEMENTED( render_pixel_ham_lace_sprites )
@@ -670,97 +727,136 @@ static char mode_names[20][48] = {
 #endif
 
 INLINE int get_mode( void ) {
-	
+
 	int ret = 0;
-	
+
 	ret += ( custom_regs.BPLCON0 & BPLCON0_LACE ) ? 5 : 0;
-	
+
 	if ( custom_regs.BPLCON0 & BPLCON0_HOMOD )
 		return ( ret + 4 );
-	
+
 	ret += ( custom_regs.BPLCON0 & BPLCON0_HIRES ) ? 1 : 0;
 	ret += ( custom_regs.BPLCON0 & BPLCON0_DBLPF ) ? 2 : 0;
-	
+
 	return ret;
 }
 
-VIDEO_UPDATE(amiga)
+VIDEO_START(amiga)
+{
+	/* init cached data */
+	update_regs.old_COLOR0 = -1;
+	update_regs.old_DIWSTRT = -1;
+	update_regs.old_DIWSTOP = -1;
+	update_regs.old_DDFSTRT = -1;
+	update_regs.RAM = memory_region(REGION_CPU1);
+
+	update_regs.sprite_in_scanline = auto_malloc( Machine->drv->screen_height * sizeof( int ) );
+	if ( update_regs.sprite_in_scanline == 0 )
+		return 1;
+
+	memset( update_regs.sprite_in_scanline, 0, Machine->drv->screen_height * sizeof( int ) );
+
+	return video_start_generic_bitmapped();
+}
+
+void amiga_prepare_frame(void)
+{
+	/* reset the copper */
+	copper_reset();
+
+	/* preload HAM pixel color */
+	update_regs.last_ham_pixel_color = update_regs.back_color;
+
+}
+
+void amiga_render_scanline(int scanline)
 {
 	int planes = 0, sw = Machine->drv->screen_width;
 	int min_x = Machine->visible_area.min_x;
 	int y, x, start_x, end_x, line_done;
 	unsigned short *dst;
+	int bitplane_dma_disabled;
+	render_pixel_def local_render;
 
-	update_regs.once_per_frame = 0;
+	amiga_sprite_dma(scanline);
 
-	/* reset the copper */
-	copper_reset();
+	y = scanline;
 
 	/* normalize some register values */
 	if ( custom_regs.DDFSTOP < custom_regs.DDFSTRT )
 		custom_regs.DDFSTOP = custom_regs.DDFSTRT;
-	
-	for ( y = 0; y < Machine->drv->screen_height; y++ ) {
-		int bitplane_dma_disabled;
-		render_pixel_def local_render;
-		
-		/* start of a new line, signal we're not done with it and fill up vars */
-		line_done = 0;
-		start_x = 0;
-		dst = ( unsigned short * )bitmap->line[y];
 
-		update_regs.fetch_pending = 1;
-		update_regs.fetch_count = 0;
+	/* start of a new line, signal we're not done with it and fill up vars */
+	line_done = 0;
+	start_x = 0;
+	dst = ( unsigned short * )tmpbitmap->line[y];
 
-		/* make sure we complete the line */
-		do {
-			
-			/* start of a new line... check if the copper is (still) enabled */
-			line_done = copper_update( start_x, y, &end_x );
-			
-			if ( line_done )
-				end_x = sw;
-			
-			/* precaulculate some update registers */
-			init_update_regs();
-			
-			/* get the number of planes */
-			planes = ( custom_regs.BPLCON0 & ( BPLCON0_BPU0 | BPLCON0_BPU1 | BPLCON0_BPU2 ) ) >> 12;
+	update_regs.fetch_pending = 1;
+	update_regs.fetch_count = 0;
 
-			/* precalculate if the bitplane dma is enabled */
-			bitplane_dma_disabled = ( custom_regs.DMACON & ( DMACON_BPLEN | DMACON_DMAEN ) ) != ( DMACON_BPLEN | DMACON_DMAEN );
-			
-			
-			/***************************************************************************
-				First we check for a number of conditions to see if we can render image
-				pixels yet. Otherwise, we fill with the background color.
-			 **************************************************************************/
-			
-			if ( bitplane_dma_disabled || planes == 0 || y < update_regs.v_start || y >= update_regs.v_stop ) {
+	/* make sure we complete the line */
+	do {
+
+		/* start of a new line... check if the copper is (still) enabled */
+		line_done = copper_update( start_x, y, &end_x );
+
+		if ( line_done )
+			end_x = sw;
+
+		/* precaulculate some update registers */
+		init_update_regs();
+
+		/* get the number of planes */
+		planes = ( custom_regs.BPLCON0 & ( BPLCON0_BPU0 | BPLCON0_BPU1 | BPLCON0_BPU2 ) ) >> 12;
+		if ( planes == 6 && (custom_regs.BPLCON0 & (BPLCON0_DBLPF | BPLCON0_HOMOD)) == 0 )
+		{
+			planes = 5;
+		}
+
+		/* precalculate if the bitplane dma is enabled */
+		bitplane_dma_disabled = ( custom_regs.DMACON & ( DMACON_BPLEN | DMACON_DMAEN ) ) != ( DMACON_BPLEN | DMACON_DMAEN );
+
+
+		/***************************************************************************
+            First we check for a number of conditions to see if we can render image
+            pixels yet. Otherwise, we fill with the background color.
+         **************************************************************************/
+
+		if ( bitplane_dma_disabled || planes == 0 || y < update_regs.v_start || y >= update_regs.v_stop ) {
+			for ( x = start_x; x < end_x; x++ )
+				dst[x] = update_regs.back_color;
+		} else { /* render the pixels (inlined for readability ) */
+			if ( update_regs.sprite_in_scanline[y] >= update_regs.h_start )
+				local_render = render_pixel[get_mode()+10];
+			else
+				local_render = render_pixel[get_mode()];
+
+			/* first clear buffer */
+			if ( start_x == 0 ) {
 				for ( x = start_x; x < end_x; x++ )
 					dst[x] = update_regs.back_color;
-			} else { /* render the pixels (inlined for readability ) */
-				if ( update_regs.sprite_in_scanline[y] >= update_regs.h_start )
-					local_render = render_pixel[get_mode()+10];
-				else
-					local_render = render_pixel[get_mode()];
-				
-				for ( x = start_x; x < end_x; x++ )
-					(*local_render)( bitmap, dst, planes, x, y, min_x );
+			} else {
+				for ( x = start_x + update_regs.h_scroll[0]; x < end_x; x++ )
+					dst[x] = update_regs.back_color;
 			}
-			
-			/* now we start from where we left off */
-			start_x = end_x;
 
-		} while ( !line_done );
+			for ( x = start_x; x < end_x; x++ )
+				(*local_render)( tmpbitmap, dst, planes, x, y, min_x );
+		}
+
+		/* now we start from where we left off */
+		start_x = end_x;
+
+	} while ( !line_done );
+
+	if ( y >= update_regs.v_start && y < update_regs.v_stop )
+		update_modulos( planes ); /* update modulos */
+
+	update_regs.sprite_in_scanline[y] = 0;
 
-		if ( y >= update_regs.v_start && y < update_regs.v_stop )
-			update_modulos( planes ); /* update modulos */
-		
-		update_regs.sprite_in_scanline[y] = 0;
-	}
 }
 
+
 PALETTE_INIT( amiga )
 {
 	int i;
@@ -781,20 +877,3 @@ PALETTE_INIT( amiga )
 	}
 }
 
-VIDEO_START(amiga)
-{
-	/* init cached data */
-	update_regs.old_COLOR0 = -1;
-	update_regs.old_DIWSTRT = -1;
-	update_regs.old_DIWSTOP = -1;
-	update_regs.old_DDFSTRT = -1;
-	update_regs.RAM = memory_region(REGION_CPU1);
-	
-	update_regs.sprite_in_scanline = auto_malloc( Machine->drv->screen_height * sizeof( int ) );
-	if ( update_regs.sprite_in_scanline == 0 )
-		return 1;
-
-	memset( update_regs.sprite_in_scanline, 0, Machine->drv->screen_height * sizeof( int ) );
-
-	return 0;
-}
