@@ -13,7 +13,7 @@
 
 /*************************************
  *
- *	Statics
+ *  Statics
  *
  *************************************/
 
@@ -22,6 +22,7 @@ static UINT8 *scanline_dirty;
 static UINT8 *scanline_palette;
 static UINT8 *sprite_data;
 static UINT32 sprite_mask;
+static UINT8 *sprite_bank[2];
 
 static UINT8 last_scanline_palette;
 static UINT8 screen_refresh_counter;
@@ -31,7 +32,7 @@ static UINT8 palettebank_vis;
 
 /*************************************
  *
- *	Video system start
+ *  Video system start
  *
  *************************************/
 
@@ -39,7 +40,9 @@ VIDEO_START( balsente )
 {
 	/* reset the system */
 	palettebank_vis = 0;
-	
+	sprite_bank[0] = memory_region(REGION_GFX1);
+	sprite_bank[1] = memory_region(REGION_GFX1) + 0x10000;
+
 	/* allocate a bitmap */
 	tmpbitmap = auto_bitmap_alloc(Machine->drv->screen_width, Machine->drv->screen_height);
 	if (!tmpbitmap)
@@ -78,7 +81,7 @@ VIDEO_START( balsente )
 
 /*************************************
  *
- *	Video RAM write
+ *  Video RAM write
  *
  *************************************/
 
@@ -98,7 +101,7 @@ WRITE8_HANDLER( balsente_videoram_w )
 
 /*************************************
  *
- *	Palette banking
+ *  Palette banking
  *
  *************************************/
 
@@ -156,7 +159,7 @@ WRITE8_HANDLER( balsente_palette_select_w )
 
 /*************************************
  *
- *	Palette RAM write
+ *  Palette RAM write
  *
  *************************************/
 
@@ -172,11 +175,26 @@ WRITE8_HANDLER( balsente_paletteram_w )
 	palette_set_color(offset / 4, (r << 4) | r, (g << 4) | g, (b << 4) | b);
 }
 
+/*************************************
+ *
+ *  Sprite banking
+ *
+ *************************************/
 
+WRITE8_HANDLER( shrike_sprite_select_w )
+{
+  if( sprite_data != sprite_bank[ (data & 0x80 >> 7) ^ 1 ] )
+  {
+  	logerror( "shrike_sprite_select_w( 0x%02x )\n", data );
+  	sprite_data = sprite_bank[ (data & 0x80 >> 7) ^ 1 ];
+  }
+
+  shrike_shared_6809_w( 1, data );
+}
 
 /*************************************
  *
- *	Sprite drawing
+ *  Sprite drawing
  *
  *************************************/
 
@@ -189,7 +207,7 @@ static void draw_one_sprite(struct mame_bitmap *bitmap, const struct rectangle *
 	int xpos = sprite[3];
 	UINT8 *src;
 	int x, y;
-	
+
 	if (finalclip.min_y < 16)
 		finalclip.min_y = 16;
 	if (finalclip.max_y > 240)
@@ -265,7 +283,7 @@ static void draw_one_sprite(struct mame_bitmap *bitmap, const struct rectangle *
 
 /*************************************
  *
- *	Main screen refresh
+ *  Main screen refresh
  *
  *************************************/
 
