@@ -1,6 +1,6 @@
 /***************************************************************************
 
-	Coors Light Bowling/Bowl-O-Rama hardware
+    Coors Light Bowling/Bowl-O-Rama hardware
 
 ***************************************************************************/
 
@@ -17,7 +17,7 @@ static offs_t blitter_addr;
 
 /*************************************
  *
- *	TMS34061 interfacing
+ *  TMS34061 interfacing
  *
  *************************************/
 
@@ -30,7 +30,6 @@ static struct tms34061_interface tms34061intf =
 {
 	8,						/* VRAM address is (row << rowshift) | col */
 	0x10000,				/* size of video RAM */
-	0x100,					/* size of dirty chunks (must be power of 2) */
 	generate_interrupt		/* interrupt gen callback */
 };
 
@@ -38,7 +37,7 @@ static struct tms34061_interface tms34061intf =
 
 /*************************************
  *
- *	Video start
+ *  Video start
  *
  *************************************/
 
@@ -52,7 +51,7 @@ VIDEO_START( capbowl )
 
 /*************************************
  *
- *	TMS34061 I/O
+ *  TMS34061 I/O
  *
  *************************************/
 
@@ -62,7 +61,7 @@ WRITE8_HANDLER( capbowl_tms34061_w )
 	int col = offset & 0xff;
 
 	/* Column address (CA0-CA8) is hooked up the A0-A7, with A1 being inverted
-	   during register access. CA8 is ignored */
+       during register access. CA8 is ignored */
 	if (func == 0 || func == 2)
 		col ^= 2;
 
@@ -77,7 +76,7 @@ READ8_HANDLER( capbowl_tms34061_r )
 	int col = offset & 0xff;
 
 	/* Column address (CA0-CA8) is hooked up the A0-A7, with A1 being inverted
-	   during register access. CA8 is ignored */
+       during register access. CA8 is ignored */
 	if (func == 0 || func == 2)
 		col ^= 2;
 
@@ -89,7 +88,7 @@ READ8_HANDLER( capbowl_tms34061_r )
 
 /*************************************
  *
- *	Bowl-o-rama blitter
+ *  Bowl-o-rama blitter
  *
  *************************************/
 
@@ -124,9 +123,9 @@ READ8_HANDLER( bowlrama_blitter_r )
 	switch (offset)
 	{
 		/* Read Mask: Graphics data are 4bpp (2 pixels per byte).
-			This function returns 0's for new pixel data.
-			This allows data to be read as a mask, AND the mask with
-			the screen data, then OR new data read by read data command. */
+            This function returns 0's for new pixel data.
+            This allows data to be read as a mask, AND the mask with
+            the screen data, then OR new data read by read data command. */
 		case 0:
 			if (!(data & 0xf0))
 				result |= 0xf0;		/* High nibble is transparent */
@@ -152,13 +151,12 @@ READ8_HANDLER( bowlrama_blitter_r )
 
 /*************************************
  *
- *	Main refresh
+ *  Main refresh
  *
  *************************************/
 
 VIDEO_UPDATE( capbowl )
 {
-	int halfwidth = (cliprect->max_x - cliprect->min_x + 1) / 2;
 	struct tms34061_display state;
 	int x, y;
 
@@ -168,44 +166,32 @@ VIDEO_UPDATE( capbowl )
 	/* if we're blanked, just fill with black */
 	if (state.blanked)
 	{
-		fillbitmap(bitmap, Machine->pens[0], cliprect);
+		fillbitmap(bitmap, get_black_pen(), cliprect);
 		return;
 	}
 
-	/* update the palette and color usage */
-	for (y = Machine->visible_area.min_y; y <= Machine->visible_area.max_y; y++)
-		if (state.dirty[y])
-		{
-			UINT8 *src = &state.vram[256 * y];
-
-			/* update the palette */
-			for (x = 0; x < 16; x++)
-			{
-				int r = *src++ & 0x0f;
-				int g = *src >> 4;
-				int b = *src++ & 0x0f;
-
-				palette_set_color(y * 16 + x, (r << 4) | r, (g << 4) | g, (b << 4) | b);
-			}
-		}
-
 	/* now regenerate the bitmap */
 	for (y = cliprect->min_y; y <= cliprect->max_y; y++)
 	{
-		UINT8 *src = &state.vram[256 * y + 32 + cliprect->min_x / 2];
-		UINT8 scanline[400];
-		UINT8 *dst = scanline;
+		UINT16 *dest = (UINT16 *)bitmap->line[y];
+		UINT8 *src = &state.vram[256 * y];
+		int ybase = 16 * y;
 
-		/* expand row to 8bpp */
-		for (x = 0; x < halfwidth; x++)
+		/* first update the palette for this scanline */
+		for (x = 0; x < 16; x++)
 		{
-			int pix = *src++;
-			*dst++ = pix >> 4;
-			*dst++ = pix & 0x0f;
+			int r = *src++ & 0x0f;
+			int g = *src >> 4;
+			int b = *src++ & 0x0f;
+			palette_set_color(ybase + x, (r << 4) | r, (g << 4) | g, (b << 4) | b);
 		}
 
-		/* redraw the scanline and mark it no longer dirty */
-		draw_scanline8(bitmap, cliprect->min_x, y, halfwidth * 2, scanline, &Machine->pens[16 * y], -1);
-		state.dirty[y] = 0;
+		/* expand row to 8bpp */
+		for (x = cliprect->min_x & ~1; x <= cliprect->max_x; x += 2)
+		{
+			int pix = src[x/2];
+			*dest++ = ybase + (pix >> 4);
+			*dest++ = ybase + (pix & 0x0f);
+		}
 	}
 }
