@@ -232,9 +232,9 @@ PALETTE_INIT( turtles )
 
 	/*  The background color generator is connected this way:
 
-		RED   - 390 ohm resistor
-		GREEN - 470 ohm resistor
-		BLUE  - 390 ohm resistor */
+        RED   - 390 ohm resistor
+        GREEN - 470 ohm resistor
+        BLUE  - 390 ohm resistor */
 
 	for (i = 0; i < 8; i++)
 	{
@@ -256,9 +256,9 @@ PALETTE_INIT( stratgyx )
 
 	/*  The background color generator is connected this way:
 
-		RED   - 270 ohm resistor
-		GREEN - 560 ohm resistor
-		BLUE  - 470 ohm resistor */
+        RED   - 270 ohm resistor
+        GREEN - 560 ohm resistor
+        BLUE  - 470 ohm resistor */
 
 	for (i = 0; i < 8; i++)
 	{
@@ -425,10 +425,10 @@ PALETTE_INIT( mariner )
 
 	/* 16 shades of blue - the 4 bits are connected to the following resistors:
 
-		bit 0 -- 4.7 kohm resistor
-			  -- 2.2 kohm resistor
-			  -- 1   kohm resistor
-		bit 0 -- .47 kohm resistor */
+        bit 0 -- 4.7 kohm resistor
+              -- 2.2 kohm resistor
+              -- 1   kohm resistor
+        bit 0 -- .47 kohm resistor */
 
 	for (i = 0; i < 16; i++)
 	{
@@ -869,6 +869,67 @@ VIDEO_START( drivfrcg )
 	return 0;
 }
 
+data8_t *racknrol_tiles_bank;
+
+WRITE8_HANDLER( racknrol_tiles_bank_w )
+{
+	racknrol_tiles_bank[offset] = data;
+	tilemap_mark_all_tiles_dirty(tilemap);
+}
+
+static void racknrol_get_tile_info(int tile_index)
+{
+	int code = galaxian_videoram[tile_index];
+	UINT8 x = tile_index & 0x1f;
+	UINT8 color = galaxian_attributesram[(x << 1) | 1] & 7;
+	UINT8 bank = racknrol_tiles_bank[x] & 7;
+
+	code |= (bank << 8);
+
+	SET_TILE_INFO(0, code, color, 0)
+}
+
+VIDEO_START( racknrol )
+{
+	tilemap = tilemap_create(racknrol_get_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
+
+	if (!tilemap)
+		return 1;
+
+	tilemap_set_transparent_pen(tilemap,0);
+	tilemap_set_scroll_cols(tilemap, 32);
+	tilemap_set_scroll = tilemap_set_scrolly;
+
+	modify_charcode = 0;
+	modify_spritecode = 0;
+	modify_color = 0;
+	modify_ypos = 0;
+
+	mooncrst_gfxextend = 0;
+
+	draw_bullets = 0;
+
+	draw_background = galaxian_draw_background;
+	background_enable = 0;
+	background_blue = 0;
+	background_red = 0;
+	background_green = 0;
+
+	draw_stars = noop_draw_stars;
+
+	flip_screen_x = 0;
+	flip_screen_y = 0;
+
+	spriteram2_present = 0;
+
+	spritevisiblearea      = &_spritevisiblearea;
+	spritevisibleareaflipx = &_spritevisibleareaflipx;
+
+	color_mask = 0xff;
+
+	return 0;
+}
+
 VIDEO_START( bongo )
 {
 	int ret = video_start_galaxian_plain();
@@ -1345,10 +1406,10 @@ static void stratgyx_draw_background(struct mame_bitmap *bitmap)
 
 	/* the background PROM is connected the following way:
 
-	   bit 0 = 0 enables the blue gun if BCB is asserted
-	   bit 1 = 0 enables the red gun if BCR is asserted and
-	             the green gun if BCG is asserted
-	   bits 2-7 are unconnected */
+       bit 0 = 0 enables the blue gun if BCB is asserted
+       bit 1 = 0 enables the red gun if BCR is asserted and
+                 the green gun if BCG is asserted
+       bits 2-7 are unconnected */
 
 	prom = memory_region(REGION_USER1);
 
@@ -1433,8 +1494,8 @@ static void mariner_draw_background(struct mame_bitmap *bitmap)
 
 
 	/* the background PROM contains the color codes for each 8 pixel
-	   line (column) of the screen.  The first 0x20 bytes for unflipped,
-	   and the 2nd 0x20 bytes for flipped screen. */
+       line (column) of the screen.  The first 0x20 bytes for unflipped,
+       and the 2nd 0x20 bytes for flipped screen. */
 
 	prom = memory_region(REGION_USER1);
 
