@@ -1,6 +1,6 @@
 /*************************************************************************
 
-	Driver for Midway V-Unit games
+    Driver for Midway V-Unit games
 
 **************************************************************************/
 
@@ -14,6 +14,7 @@
 
 #define WATCH_RENDER		(0)
 #define KEEP_STATISTICS		(0)
+#define LOG_DMA				(0)
 
 
 #if KEEP_STATISTICS
@@ -48,7 +49,7 @@ static int polycount, pixelcount, lastfps, framecount, totalframes;
 
 /*************************************
  *
- *	Video system start
+ *  Video system start
  *
  *************************************/
 
@@ -69,8 +70,8 @@ VIDEO_START( midvunit )
 
 /*************************************
  *
- *	Returns true if the quad is
- *	straight-on
+ *  Returns true if the quad is
+ *  straight-on
  *
  *************************************/
 
@@ -164,7 +165,7 @@ INLINE int quad_is_straight(void)
 
 /*************************************
  *
- *	Straight, flat quad renderers
+ *  Straight, flat quad renderers
  *
  *************************************/
 
@@ -243,7 +244,7 @@ static void render_straight_flat_dither_quad(void)
 
 /*************************************
  *
- *	Straight, textured quad renderers
+ *  Straight, textured quad renderers
  *
  *************************************/
 
@@ -465,7 +466,7 @@ static void render_straight_textransmask_quad(void)
 
 /*************************************
  *
- *	Generic flat quad renderer
+ *  Generic flat quad renderer
  *
  *************************************/
 
@@ -542,7 +543,7 @@ static void render_flat_dither_quad(void)
 
 /*************************************
  *
- *	Generic textured quad renderers
+ *  Generic textured quad renderers
  *
  *************************************/
 
@@ -707,7 +708,7 @@ static void render_textransmask_quad(void)
 
 /*************************************
  *
- *	Generic dithered textured quad renderers
+ *  Generic dithered textured quad renderers
  *
  *************************************/
 
@@ -905,7 +906,7 @@ static void render_textransmask_dither_quad(void)
 
 /*************************************
  *
- *	DMA queue processor
+ *  DMA queue processor
  *
  *************************************/
 
@@ -1017,14 +1018,14 @@ static void process_dma_queue(void)
 
 /*************************************
  *
- *	DMA pipe control control
+ *  DMA pipe control control
  *
  *************************************/
 
 WRITE32_HANDLER( midvunit_dma_queue_w )
 {
-if (code_pressed(KEYCODE_L))
-	logerror("%06X:queue(%X) = %08X\n", activecpu_get_pc(), dma_data_index, data);
+	if (LOG_DMA && code_pressed(KEYCODE_L))
+		logerror("%06X:queue(%X) = %08X\n", activecpu_get_pc(), dma_data_index, data);
 	if (dma_data_index < 16)
 		dma_data[dma_data_index++] = data;
 }
@@ -1041,8 +1042,8 @@ READ32_HANDLER( midvunit_dma_trigger_r )
 {
 	if (offset)
 	{
-if (code_pressed(KEYCODE_L))
-	logerror("%06X:trigger\n", activecpu_get_pc());
+		if (LOG_DMA && code_pressed(KEYCODE_L))
+			logerror("%06X:trigger\n", activecpu_get_pc());
 		process_dma_queue();
 		dma_data_index = 0;
 	}
@@ -1053,7 +1054,7 @@ if (code_pressed(KEYCODE_L))
 
 /*************************************
  *
- *	Paging control
+ *  Paging control
  *
  *************************************/
 
@@ -1062,8 +1063,8 @@ WRITE32_HANDLER( midvunit_page_control_w )
 	/* watch for the display page to change */
 	if ((page_control ^ data) & 1)
 	{
-if (code_pressed(KEYCODE_L))
-	logerror("##########################################################\n");
+		if (LOG_DMA && code_pressed(KEYCODE_L))
+			logerror("##########################################################\n");
 #if KEEP_STATISTICS
 		usrintf_showmessage("Polys:%d  Render:%d%%  FPS:%d",
 				polycount, pixelcount / (512*4), lastfps);
@@ -1085,7 +1086,7 @@ READ32_HANDLER( midvunit_page_control_r )
 
 /*************************************
  *
- *	Video control
+ *  Video control
  *
  *************************************/
 
@@ -1106,7 +1107,7 @@ READ32_HANDLER( midvunit_scanline_r )
 
 /*************************************
  *
- *	Video RAM access
+ *  Video RAM access
  *
  *************************************/
 
@@ -1125,7 +1126,7 @@ READ32_HANDLER( midvunit_videoram_r )
 
 /*************************************
  *
- *	Palette RAM access
+ *  Palette RAM access
  *
  *************************************/
 
@@ -1151,7 +1152,7 @@ WRITE32_HANDLER( midvunit_paletteram_w )
 
 /*************************************
  *
- *	Texture RAM access
+ *  Texture RAM access
  *
  *************************************/
 
@@ -1174,7 +1175,7 @@ READ32_HANDLER( midvunit_textureram_r )
 
 /*************************************
  *
- *	Video system update
+ *  Video system update
  *
  *************************************/
 
