@@ -1,6 +1,6 @@
 /*************************************************************************
 
-	Williams/Midway Y/Z-unit system
+    Williams/Midway Y/Z-unit system
 
 **************************************************************************/
 
@@ -49,6 +49,7 @@ static UINT8	videobank_select;
 static int		last_update_scanline;
 
 /* DMA-related variables */
+static UINT8	yawdim_dma;
 static data16_t dma_register[16];
 static struct
 {
@@ -72,7 +73,7 @@ static void scanline0_callback(int param);
 
 /*************************************
  *
- *	Video startup
+ *  Video startup
  *
  *************************************/
 
@@ -94,6 +95,7 @@ static VIDEO_START( common )
 	midyunit_cmos_page = 0;
 	autoerase_enable = 0;
 	last_update_scanline = 0;
+	yawdim_dma = 0;
 
 	/* reset DMA state */
 	memset(dma_register, 0, sizeof(dma_register));
@@ -141,6 +143,14 @@ VIDEO_START( midyunit_6bit )
 }
 
 
+VIDEO_START( mkyawdim )
+{
+	int result = video_start_midyunit_6bit();
+	yawdim_dma = 1;
+	return result;
+}
+
+
 VIDEO_START( midzunit )
 {
 	int result = video_start_common();
@@ -162,7 +172,7 @@ VIDEO_START( midzunit )
 
 /*************************************
  *
- *	Banked graphics ROM access
+ *  Banked graphics ROM access
  *
  *************************************/
 
@@ -180,7 +190,7 @@ READ16_HANDLER( midyunit_gfxrom_r )
 
 /*************************************
  *
- *	Video/color RAM read/write
+ *  Video/color RAM read/write
  *
  *************************************/
 
@@ -217,7 +227,7 @@ READ16_HANDLER( midyunit_vram_r )
 
 /*************************************
  *
- *	Shift register read/write
+ *  Shift register read/write
  *
  *************************************/
 
@@ -236,25 +246,25 @@ void midyunit_from_shiftreg(UINT32 address, UINT16 *shiftreg)
 
 /*************************************
  *
- *	Y/Z-unit control register
+ *  Y/Z-unit control register
  *
  *************************************/
 
 WRITE16_HANDLER( midyunit_control_w )
 {
 	/*
-	 * Narc system register
-	 * ------------------
-	 *
-	 *   | Bit              | Use
-	 * --+-FEDCBA9876543210-+------------
-	 *   | xxxxxxxx-------- |   7 segment led on CPU board
-	 *   | --------xx------ |   CMOS page
-	 *   | ----------x----- | - OBJ PAL RAM select
-	 *   | -----------x---- | - autoerase enable
-	 *   | ---------------- | - watchdog
-	 *
-	 */
+     * Narc system register
+     * ------------------
+     *
+     *   | Bit              | Use
+     * --+-FEDCBA9876543210-+------------
+     *   | xxxxxxxx-------- |   7 segment led on CPU board
+     *   | --------xx------ |   CMOS page
+     *   | ----------x----- | - OBJ PAL RAM select
+     *   | -----------x---- | - autoerase enable
+     *   | ---------------- | - watchdog
+     *
+     */
 
 	if (ACCESSING_LSB)
 	{
@@ -292,7 +302,7 @@ WRITE16_HANDLER( midyunit_control_w )
 
 /*************************************
  *
- *	Palette handlers
+ *  Palette handlers
  *
  *************************************/
 
@@ -318,7 +328,7 @@ WRITE16_HANDLER( midyunit_paletteram_w )
 
 /*************************************
  *
- *	DMA drawing routines
+ *  DMA drawing routines
  *
  *************************************/
 
@@ -339,7 +349,7 @@ typedef void (*dma_draw_func)(void);
 {																				\
 	int height = dma_state.height;												\
 	int width = dma_state.width;												\
-	UINT8 *base = midyunit_gfx_rom;													\
+	UINT8 *base = midyunit_gfx_rom;												\
 	UINT32 offset = dma_state.offset >> 3;										\
 	UINT16 pal = dma_state.palette;												\
 	UINT16 color = pal | dma_state.color;										\
@@ -357,6 +367,10 @@ typedef void (*dma_draw_func)(void);
 		ty = (ty + y) & 0x1ff;													\
 		offset += dma_state.rowbytes;											\
 																				\
+		/* check for over/underrun */											\
+		if (o >= 0x06000000)													\
+			continue;															\
+																				\
 		/* determine destination pointer */										\
 		dest = &local_videoram[ty * 512];										\
 																				\
@@ -437,7 +451,7 @@ DMA_DRAW_FUNC(prefix##_p0c1_xf, XFLIP_YES, PIXEL_COPY,  PIXEL_COLOR)	\
 																												\
 static dma_draw_func prefix[32] =																				\
 {																												\
-/*	B0:N / B1:N			B0:Y / B1:N			B0:N / B1:Y			B0:Y / B1:Y */									\
+/*  B0:N / B1:N         B0:Y / B1:N         B0:N / B1:Y         B0:Y / B1:Y */									\
 	dma_draw_none,		prefix##_p0,		prefix##_p1,		prefix##_p0p1,		/* no color */ 				\
 	prefix##_c0,		prefix##_c0,		prefix##_c0p1,		prefix##_c0p1,		/* color 0 pixels */		\
 	prefix##_c1,		prefix##_p0c1,		prefix##_c1,		prefix##_p0c1,		/* color non-0 pixels */	\
@@ -461,7 +475,7 @@ DECLARE_BLITTER_SET(dma_draw)
 
 /*************************************
  *
- *	DMA finished callback
+ *  DMA finished callback
  *
  *************************************/
 
@@ -488,7 +502,7 @@ static void dma_callback(int is_in_34010_context)
 
 /*************************************
  *
- *	DMA reader
+ *  DMA reader
  *
  *************************************/
 
@@ -529,7 +543,7 @@ READ16_HANDLER( midyunit_dma_r )
 
 /*************************************
  *
- *	DMA write handler
+ *  DMA write handler
  *
  *************************************/
 
@@ -584,10 +598,10 @@ WRITE16_HANDLER( midyunit_dma_w )
 		logerror("----\n");
 		logerror("DMA command %04X: (xflip=%d yflip=%d)\n",
 				command, (command >> 4) & 1, (command >> 5) & 1);
-		logerror("  offset=%08X pos=(%d,%d) w=%d h=%d\n",
+		logerror("  offset=%08X pos=(%d,%d) w=%d h=%d rb=%d\n",
 				dma_register[DMA_OFFSETLO] | (dma_register[DMA_OFFSETHI] << 16),
 				(INT16)dma_register[DMA_XSTART], (INT16)dma_register[DMA_YSTART],
-				dma_register[DMA_WIDTH], dma_register[DMA_HEIGHT]);
+				dma_register[DMA_WIDTH], dma_register[DMA_HEIGHT], (INT16)dma_register[DMA_ROWBYTES]);
 		logerror("  palette=%04X color=%04X\n",
 				dma_register[DMA_PALETTE], dma_register[DMA_COLOR]);
 	}
@@ -608,8 +622,13 @@ WRITE16_HANDLER( midyunit_dma_w )
 	gfxoffset = dma_register[DMA_OFFSETLO] | (dma_register[DMA_OFFSETHI] << 16);
 	if (command & 0x10)
 	{
-		gfxoffset -= (dma_state.width - 1) * 8;
-		dma_state.rowbytes = (dma_state.rowbytes - dma_state.width + 3) & ~3;
+		if (!yawdim_dma)
+		{
+			gfxoffset -= (dma_state.width - 1) * 8;
+			dma_state.rowbytes = (dma_state.rowbytes - dma_state.width + 3) & ~3;
+		}
+		else
+			dma_state.rowbytes = (dma_state.rowbytes + dma_state.width + 3) & ~3;
 		dma_state.xpos += dma_state.width - 1;
 	}
 	else
@@ -676,7 +695,7 @@ WRITE16_HANDLER( midyunit_dma_w )
 
 /*************************************
  *
- *	Partial screen updater
+ *  Partial screen updater
  *
  *************************************/
 
@@ -722,7 +741,7 @@ static void update_partial(int scanline, int render)
 
 /*************************************
  *
- *	34010 display address callback
+ *  34010 display address callback
  *
  *************************************/
 
@@ -734,7 +753,7 @@ void midyunit_display_addr_changed(UINT32 offs, int rowbytes, int scanline)
 
 /*************************************
  *
- *	34010 interrupt callback
+ *  34010 interrupt callback
  *
  *************************************/
 
@@ -747,7 +766,7 @@ void midyunit_display_interrupt(int scanline)
 
 /*************************************
  *
- *	34010 I/O register kludge
+ *  34010 I/O register kludge
  *
  *************************************/
 
@@ -769,7 +788,7 @@ WRITE16_HANDLER( midyunit_io_register_w )
 
 /*************************************
  *
- *	End-of-frame update
+ *  End-of-frame update
  *
  *************************************/
 
@@ -790,7 +809,7 @@ static void scanline0_callback(int param)
 
 /*************************************
  *
- *	Core refresh routine
+ *  Core refresh routine
  *
  *************************************/
 
