@@ -1,6 +1,6 @@
 /*******************************************************************
 
-Rolling Thunder Video Hardware
+Namco System 86 Video Hardware
 
 *******************************************************************/
 
@@ -259,92 +259,98 @@ WRITE8_HANDLER( rthunder_spriteram_w )
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap, const struct rectangle *cliprect, int sprite_priority)
-{
-	const data8_t *source = &spriteram[0];
-	const data8_t *finish = &spriteram[0x0800-16];	/* the last is NOT a sprite */
+/*
+sprite format:
 
-	int sprite_xoffs = spriteram[0x07f5] - 256 * (spriteram[0x07f4] & 1);
+0-3  scratchpad RAM
+4-9  CPU writes here, hardware copies from here to 10-15
+10   xx------  X size (16, 8, 32, 4)
+10   --x-----  X flip
+10   ---xx---  X offset inside 32x32 tile
+10   -----xxx  tile bank
+11   xxxxxxxx  tile number
+12   xxxxxxx-  color
+12   -------x  X position MSB
+13   xxxxxxxx  X position
+14   xxx-----  priority
+14   ---xx---  Y offset inside 32x32 tile
+14   -----xx-  Y size (16, 8, 32, 4)
+14   -------x  Y flip
+15   xxxxxxxx  Y position
+*/
+
+static void draw_sprites(struct mame_bitmap *bitmap, const struct rectangle *cliprect)
+{
+	const data8_t *source = &spriteram[0x0800-0x20];	/* the last is NOT a sprite */
+	const data8_t *finish = &spriteram[0];
+	struct GfxElement *gfx = Machine->gfx[2];
+	struct GfxElement mygfx = *gfx;
+
+	int sprite_xoffs = spriteram[0x07f5] + ((spriteram[0x07f4] & 1) << 8);
 	int sprite_yoffs = spriteram[0x07f7];
 
 	int bank_sprites = Machine->gfx[2]->total_elements / 8;
 
-	while( source<finish )
+	while (source >= finish)
 	{
-/*
-	source[10] S-FT -BBB
-	source[11] TTTT TTTT
-	source[12] CCCC CCCX
-	source[13] XXXX XXXX
-	source[14] PPPT -S-F
-	source[15] YYYY YYYY
-*/
+		static const int sprite_size[4] = { 16, 8, 32, 4 };
+		int attr1 = source[10];
+		int attr2 = source[14];
+		int color = source[12];
+		int flipx = (attr1 & 0x20) >> 5;
+		int flipy = (attr2 & 0x01);
+		int sizex = sprite_size[(attr1 & 0xc0) >> 6];
+		int sizey = sprite_size[(attr2 & 0x06) >> 1];
+		int tx = (attr1 & 0x18) & (~(sizex-1));
+		int ty = (attr2 & 0x18) & (~(sizey-1));
+		int sx = source[13] + ((color & 0x01) << 8);
+		int sy = -source[15] - sizey;
+		int sprite = source[11];
+		int sprite_bank = attr1 & 7;
 		int priority = (source[14] & 0xe0) >> 5;
-		if (priority == sprite_priority)
+		int pri_mask = (0xff << (priority + 1)) & 0xff;
+
+		sprite &= bank_sprites-1;
+		sprite += sprite_bank * bank_sprites;
+		color = color >> 1;
+
+		sx += sprite_xoffs;
+		sy -= sprite_yoffs;
+
+		if (flip_screen)
 		{
-			static int gfx_offs[2][2] =
-			{
-				{ 0, 1 },
-				{ 2, 3 }
-			};
-			int attr1 = source[10];
-			int attr2 = source[14];
-			int color = source[12];
-			int sx = source[13] + (color & 0x01)*256;
-			int sy = 240 - source[15];
-			int flipx = (attr1 & 0x20) >> 5;
-			int flipy = (attr2 & 0x01);
-			int sizex = (attr1 & 0x80) >> 7;
-			int sizey = (attr2 & 0x04) >> 2;
-			int sprite = (source[11] & 0xff)*4;
-			int sprite_bank = attr1 & 7;
-			int x,y;
-
-			sprite &= bank_sprites-1;
-			sprite += sprite_bank * bank_sprites;
-			if ((attr1 & 0x10) && !sizex) sprite += 1;
-			if ((attr2 & 0x10) && !sizey) sprite += 2;
-			color = color >> 1;
-
-			sx += sprite_xoffs;
-			sy -= sprite_yoffs;
-
-			sy -= 16 * sizey;
-
-			if (flip_screen)
-			{
-				sx = 496 - 16 * sizex - sx;
-				sy = 240 - 16 * sizey - sy;
-				flipx ^= 1;
-				flipy ^= 1;
-			}
-
-			for (y = 0;y <= sizey;y++)
-			{
-				for (x = 0;x <= sizex;x++)
-				{
-					drawgfx( bitmap, Machine->gfx[2],
-						sprite + gfx_offs[y ^ (sizey * flipy)][x ^ (sizex * flipx)],
-						color,
-						flipx,flipy,
-						-67 + ((sx + 16*x) & 0x1ff),
-						1 + ((sy + 16*y) & 0xff),
-						cliprect,TRANSPARENCY_PEN,0xf);
-				}
-			}
+			sx = -sx - sizex;
+			sy = -sy - sizey;
+			flipx ^= 1;
+			flipy ^= 1;
 		}
 
-		source+=16;
+		sy++;	/* sprites are buffered and delayed by one scanline */
+
+		/* change GfxElement parameters to draw only the needed part of the 32x32 tile */
+		mygfx.width = sizex;
+		mygfx.height = sizey;
+		mygfx.gfxdata = gfx->gfxdata + tx + ty * gfx->line_modulo;
+
+		pdrawgfx( bitmap, &mygfx,
+				sprite,
+				color,
+				flipx,flipy,
+				sx & 0x1ff,
+				((sy + 16) & 0xff) - 16,
+				cliprect,TRANSPARENCY_PEN,0xf, pri_mask);
+
+		source -= 0x10;
 	}
 }
 
 
 static void set_scroll(int layer)
 {
-	int xdisp[4] = { 20, 18, 21, 19 };
+	int xdisp[4] = { 47, 49, 46, 48 };
 	int scrollx,scrolly;
 
-	scrollx = xscroll[layer] + xdisp[layer];
+	scrollx = xscroll[layer] - xdisp[layer];
 	scrolly = yscroll[layer] + 9;
 	if (flip_screen)
 	{
@@ -369,6 +375,8 @@ VIDEO_UPDATE( namcos86 )
 	set_scroll(2);
 	set_scroll(3);
 
+	fillbitmap(priority_bitmap, 0, cliprect);
+
 	fillbitmap(bitmap,Machine->gfx[0]->colortable[8*backcolor+7],cliprect);
 
 	for (layer = 0;layer < 8;layer++)
@@ -378,11 +386,11 @@ VIDEO_UPDATE( namcos86 )
 		for (i = 3;i >= 0;i--)
 		{
 			if (((xscroll[i] & 0x0e00) >> 9) == layer)
-				tilemap_draw(bitmap,cliprect,tilemap[i],0,0);
+				tilemap_draw_primask(bitmap,cliprect,tilemap[i],0,layer,0);
 		}
-
-		draw_sprites(bitmap,cliprect,layer);
 	}
+
+	draw_sprites(bitmap,cliprect);
 }
 
 
