@@ -7,40 +7,40 @@
 
 Graphics information:
 
-0x00000 - 0xdfff	: Blocks of sprite data, each 0x80 bytes:
-	Each 0x80 block is made up of 0x20 double words, their format is:
-	Word: Sprite number (16 bits)
-	Byte: Palette number (8 bits)
-	Byte: Bit 0: X flip
-		  Bit 1: Y flip
-		  Bit 2: Automatic animation flag (4 tiles?)
-		  Bit 3: Automatic animation flag (8 tiles?)
-		  Bit 4: MSB of sprite number (confirmed, Karnov_r, Mslug). See note.
-		  Bit 5: MSB of sprite number (MSlug2)
-		  Bit 6: MSB of sprite number (Kof97)
-		  Bit 7: Unknown for now
+0x00000 - 0xdfff    : Blocks of sprite data, each 0x80 bytes:
+    Each 0x80 block is made up of 0x20 double words, their format is:
+    Word: Sprite number (16 bits)
+    Byte: Palette number (8 bits)
+    Byte: Bit 0: X flip
+          Bit 1: Y flip
+          Bit 2: Automatic animation flag (4 tiles?)
+          Bit 3: Automatic animation flag (8 tiles?)
+          Bit 4: MSB of sprite number (confirmed, Karnov_r, Mslug). See note.
+          Bit 5: MSB of sprite number (MSlug2)
+          Bit 6: MSB of sprite number (Kof97)
+          Bit 7: Unknown for now
 
-	Each double word sprite is drawn directly underneath the previous one,
-	based on the starting coordinates.
+    Each double word sprite is drawn directly underneath the previous one,
+    based on the starting coordinates.
 
-0x0e000 - 0x0ea00	: Front plane fix tiles (8*8), 2 bytes each
+0x0e000 - 0x0ea00   : Front plane fix tiles (8*8), 2 bytes each
 
 0x10000: Control for sprites banks, arranged in words
 
-	Bit 0 to 3 - Y zoom LSB
-	Bit 4 to 7 - Y zoom MSB (ie, 1 byte for Y zoom).
-	Bit 8 to 11 - X zoom, 0xf is full size (no scale).
-	Bit 12 to 15 - Unknown, probably unused
+    Bit 0 to 3 - Y zoom LSB
+    Bit 4 to 7 - Y zoom MSB (ie, 1 byte for Y zoom).
+    Bit 8 to 11 - X zoom, 0xf is full size (no scale).
+    Bit 12 to 15 - Unknown, probably unused
 
 0x10400: Control for sprite banks, arranged in words
 
-	Bit 0 to 5: Number of sprites in this bank (see note below).
-	Bit 6 - If set, this bank is placed to right of previous bank (same Y-coord).
-	Bit 7 to 15 - Y position for sprite bank.
+    Bit 0 to 5: Number of sprites in this bank (see note below).
+    Bit 6 - If set, this bank is placed to right of previous bank (same Y-coord).
+    Bit 7 to 15 - Y position for sprite bank.
 
 0x10800: Control for sprite banks, arranged in words
-	Bit 0 to 5: Unknown
-	Bit 7 to 15 - X position for sprite bank.
+    Bit 0 to 5: Unknown
+    Bit 7 to 15 - X position for sprite bank.
 
 Notes:
 
@@ -81,23 +81,23 @@ int neogeo_fix_bank_type;
 
 
 /*
-	X zoom table - verified on real hardware
-	        8         = 0
-	    4   8         = 1
-	    4   8  c      = 2
-	  2 4   8  c      = 3
-	  2 4   8  c e    = 4
-	  2 4 6 8  c e    = 5
-	  2 4 6 8 a c e   = 6
-	0 2 4 6 8 a c e   = 7
-	0 2 4 6 89a c e   = 8
-	0 234 6 89a c e   = 9
-	0 234 6 89a c ef  = A
-	0 234 6789a c ef  = B
-	0 234 6789a cdef  = C
-	01234 6789a cdef  = D
-	01234 6789abcdef  = E
-	0123456789abcdef  = F
+    X zoom table - verified on real hardware
+            8         = 0
+        4   8         = 1
+        4   8  c      = 2
+      2 4   8  c      = 3
+      2 4   8  c e    = 4
+      2 4 6 8  c e    = 5
+      2 4 6 8 a c e   = 6
+    0 2 4 6 8 a c e   = 7
+    0 2 4 6 89a c e   = 8
+    0 234 6 89a c e   = 9
+    0 234 6 89a c ef  = A
+    0 234 6789a c ef  = B
+    0 234 6789a cdef  = C
+    01234 6789a cdef  = D
+    01234 6789abcdef  = E
+    0123456789abcdef  = F
 */
 static char zoomx_draw_tables[16][16] =
 {
@@ -250,6 +250,8 @@ WRITE16_HANDLER( neogeo_setpalbank1_16_w )
 
 READ16_HANDLER( neogeo_paletteram16_r )
 {
+	offset &=0xfff; /* mirrored */
+
 	return neogeo_paletteram16[offset];
 }
 
@@ -258,6 +260,8 @@ WRITE16_HANDLER( neogeo_paletteram16_w )
 	data16_t oldword, newword;
 	int r,g,b;
 
+	offset &=0xfff; /* mirrored */
+
 	oldword = newword = neogeo_paletteram16[offset];
 	COMBINE_DATA(&newword);
 
@@ -395,7 +399,7 @@ static void NeoMVSDrawGfxLine(UINT16 **line,const struct GfxElement *gfx,
 	}
 	else		/* normal */
 	{
-		if (zx == 16)
+		if (zx == 0x0f)		/* fixed */
 		{
 			mydword = (fspr[0]<<0)|(fspr[1]<<8)|(fspr[2]<<16)|(fspr[3]<<24);
 			col = (mydword>> 0)&0xf; if (col) bm[ 0] = paldata[col];
@@ -505,12 +509,12 @@ profiler_mark(PROFILER_VIDEO);
 			{
 				my = 0x20;
 
-				if (sy < 248)
+				/*if (sy < 248) */
 					fullmode = 1;
-				else
-					/* kludge to avoid a white line in KOF94 Japan stage... */
-					/* probably indication of a subtle bug somewhere else */
-					fullmode = 0;
+				/*else */
+				/*     kludge to avoid a white line in KOF94 Japan stage...    */
+				/*     probably indication of a subtle bug somewhere else    */
+				/*  fullmode = 0; */
 			}
 			else
 				fullmode = 0;
@@ -549,10 +553,10 @@ profiler_mark(PROFILER_VIDEO);
 				{
 					if (zy)
 					{
-						zoom_line %= 2*zy;
-						if (zoom_line >= zy)
+						zoom_line %= 2*(zy+1);	/* fixed */
+						if (zoom_line >= (zy+1))	/* fixed */
 						{
-							zoom_line = 2*zy-1 - zoom_line;
+							zoom_line = 2*(zy+1)-1 - zoom_line;	/* fixed */
 							invert ^= 1;
 						}
 					}
@@ -575,8 +579,8 @@ profiler_mark(PROFILER_VIDEO);
 				if ( vhigh_tile && (tileatr & 0x20)) tileno+=0x20000;
 				if (vvhigh_tile && (tileatr & 0x40)) tileno+=0x40000;
 
-				if (tileatr & 0x08)      tileno=(tileno&~7)+((tileno+neogeo_frame_counter)&7);
-				else if (tileatr & 0x04) tileno=(tileno&~3)+((tileno+neogeo_frame_counter)&3);
+				if (tileatr & 0x08) tileno=(tileno&~7)|(neogeo_frame_counter&7);	/* fixed */
+				else if (tileatr & 0x04) tileno=(tileno&~3)|(neogeo_frame_counter&3);	/* fixed */
 
 				if (tileatr & 0x02) yoffs ^= 0x0f;	/* flip y */
 
@@ -659,7 +663,7 @@ profiler_mark(PROFILER_VIDEO);
 							cliprect,TRANSPARENCY_PEN,0);
 				}
 			}
-		} /*Banked	 */
+		} /*Banked */
 		else
 		{
 			for (y=cliprect->min_y / 8; y <= cliprect->max_y / 8; y++)
