@@ -23,12 +23,12 @@
 #define INDENT "\t"
 
 /* Output format configuration
-	L1 first level
-	L2 second level
-	B begin a list of items
-	E end a list of items
-	P begin an item
-	N end an item
+    L1 first level
+    L2 second level
+    B begin a list of items
+    E end a list of items
+    P begin an item
+    N end an item
 */
 
 /* Output unformatted */
@@ -549,17 +549,19 @@ struct conversion_t {
 } CONV[] = {
 	{ 1, { "mame", "game", 0, 0, 0 }, process_game },
 	{ 2, { "mame", "game", "name", 0, 0 }, process_gamename },
-	{ 2, { "mame", "game", "sourcefile", 0, 0 }, process_string2 },
+	{ 2, { "mame", "game", "sourcefile", 0, 0 }, process_item2 },
 	{ 2, { "mame", "game", "description", 0, 0 }, process_string2 },
 	{ 2, { "mame", "game", "year", 0, 0 }, process_item2 },
 	{ 2, { "mame", "game", "history", 0, 0 }, process_string2 },
 	{ 2, { "mame", "game", "manufacturer", 0, 0 }, process_string2 },
 	{ 2, { "mame", "game", "disk", 0, 0 }, process_set2 },
 	{ 3, { "mame", "game", "disk", "name", 0 }, process_item3 },
+	{ 3, { "mame", "game", "disk", "merge", 0 }, process_item3 },
 	{ 3, { "mame", "game", "disk", "md5", 0 }, process_hex3 },
 	{ 3, { "mame", "game", "disk", "sha1", 0 }, process_hex3 },
 	{ 3, { "mame", "game", "disk", "region", 0 }, process_item3 },
 	{ 3, { "mame", "game", "disk", "index", 0 }, process_num3 },
+	{ 3, { "mame", "game", "disk", "status", 0 }, process_romstatus },
 	{ 2, { "mame", "game", "cloneof", 0, 0 }, process_reference },
 	{ 2, { "mame", "game", "biosset", 0, 0 }, process_set2 },
 	{ 3, { "mame", "game", "biosset", "name", 0 }, process_item3 },
@@ -583,7 +585,7 @@ struct conversion_t {
 	{ 3, { "mame", "game", "sample", "name", 0 }, process_samplename },
 	{ 2, { "mame", "game", "chip", 0, 0 }, process_set2 },
 	{ 3, { "mame", "game", "chip", "type", 0 }, process_item3 },
-	{ 3, { "mame", "game", "chip", "name", 0 }, process_item3 },
+	{ 3, { "mame", "game", "chip", "name", 0 }, process_string3 },
 	{ 3, { "mame", "game", "chip", "soundonly", 0 }, process_chipsoundonly },
 	{ 3, { "mame", "game", "chip", "clock", 0 }, process_num3 },
 	{ 2, { "mame", "game", "video", 0, 0 }, process_set2 },
@@ -609,6 +611,7 @@ struct conversion_t {
 	{ 4, { "mame", "game", "dipswitch", "dipvalue", "name" }, process_dipswitchdipvaluename },
 	{ 2, { "mame", "game", "driver", 0, 0 }, process_set2 },
 	{ 3, { "mame", "game", "driver", "status", 0 }, process_item3 },
+	{ 3, { "mame", "game", "driver", "emulation", 0 }, process_item3 },
 	{ 3, { "mame", "game", "driver", "color", 0 }, process_item3 },
 	{ 3, { "mame", "game", "driver", "sound", 0 }, process_item3 },
 	{ 3, { "mame", "game", "driver", "graphic", 0 }, process_item3 },
